@@ -14,7 +14,10 @@ Database access via Open Data Base Connection (ODBC) interface. Based on the OTL
 
 from PySAGA.helper import Tool_Wrapper
 
-def Connect_to_ODBC_Source(DSN=None, USER=None, PASSWORD=None, Verbose=2):
+def Connect_to_ODBC_Source(
+    DSN=None,
+    USER=None,
+    PASSWORD=None, Verbose=2):
     '''
     Connect to ODBC Source
     ----------
@@ -39,7 +42,10 @@ def Connect_to_ODBC_Source(DSN=None, USER=None, PASSWORD=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_0(DSN=None, USER=None, PASSWORD=None, Verbose=2):
+def run_tool_db_odbc_0(
+    DSN=None,
+    USER=None,
+    PASSWORD=None, Verbose=2):
     '''
     Connect to ODBC Source
     ----------
@@ -64,7 +70,9 @@ def run_tool_db_odbc_0(DSN=None, USER=None, PASSWORD=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Disconnect_from_ODBC_Source(CONNECTION=None, TRANSACT=None, Verbose=2):
+def Disconnect_from_ODBC_Source(
+    CONNECTION=None,
+    TRANSACT=None, Verbose=2):
     '''
     Disconnect from ODBC Source
     ----------
@@ -87,7 +95,9 @@ def Disconnect_from_ODBC_Source(CONNECTION=None, TRANSACT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_1(CONNECTION=None, TRANSACT=None, Verbose=2):
+def run_tool_db_odbc_1(
+    CONNECTION=None,
+    TRANSACT=None, Verbose=2):
     '''
     Disconnect from ODBC Source
     ----------
@@ -110,7 +120,10 @@ def run_tool_db_odbc_1(CONNECTION=None, TRANSACT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def CommitRollback_Transaction(CONNECTION=None, SOURCE=None, TRANSACT=None, Verbose=2):
+def CommitRollback_Transaction(
+    CONNECTION=None,
+    SOURCE=None,
+    TRANSACT=None, Verbose=2):
     '''
     Commit/Rollback Transaction
     ----------
@@ -135,7 +148,10 @@ def CommitRollback_Transaction(CONNECTION=None, SOURCE=None, TRANSACT=None, Verb
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_2(CONNECTION=None, SOURCE=None, TRANSACT=None, Verbose=2):
+def run_tool_db_odbc_2(
+    CONNECTION=None,
+    SOURCE=None,
+    TRANSACT=None, Verbose=2):
     '''
     Commit/Rollback Transaction
     ----------
@@ -160,7 +176,11 @@ def run_tool_db_odbc_2(CONNECTION=None, SOURCE=None, TRANSACT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Execute_SQL(CONNECTION=None, SQL=None, COMMIT=None, STOP=None, Verbose=2):
+def Execute_SQL(
+    CONNECTION=None,
+    SQL=None,
+    COMMIT=None,
+    STOP=None, Verbose=2):
     '''
     Execute SQL
     ----------
@@ -190,7 +210,11 @@ DROP TABLE myTable1;
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_3(CONNECTION=None, SQL=None, COMMIT=None, STOP=None, Verbose=2):
+def run_tool_db_odbc_3(
+    CONNECTION=None,
+    SQL=None,
+    COMMIT=None,
+    STOP=None, Verbose=2):
     '''
     Execute SQL
     ----------
@@ -220,7 +244,10 @@ DROP TABLE myTable1;
         return Tool.Execute(Verbose)
     return False
 
-def List_Table_Fields(FIELDS=None, CONNECTION=None, TABLE=None, Verbose=2):
+def List_Table_Fields(
+    FIELDS=None,
+    CONNECTION=None,
+    TABLE=None, Verbose=2):
     '''
     List Table Fields
     ----------
@@ -245,7 +272,10 @@ def List_Table_Fields(FIELDS=None, CONNECTION=None, TABLE=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_4(FIELDS=None, CONNECTION=None, TABLE=None, Verbose=2):
+def run_tool_db_odbc_4(
+    FIELDS=None,
+    CONNECTION=None,
+    TABLE=None, Verbose=2):
     '''
     List Table Fields
     ----------
@@ -270,7 +300,10 @@ def run_tool_db_odbc_4(FIELDS=None, CONNECTION=None, TABLE=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Import_Table(TABLE=None, CONNECTION=None, SOURCE=None, Verbose=2):
+def Import_Table(
+    TABLE=None,
+    CONNECTION=None,
+    SOURCE=None, Verbose=2):
     '''
     Import Table
     ----------
@@ -295,7 +328,10 @@ def Import_Table(TABLE=None, CONNECTION=None, SOURCE=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_5(TABLE=None, CONNECTION=None, SOURCE=None, Verbose=2):
+def run_tool_db_odbc_5(
+    TABLE=None,
+    CONNECTION=None,
+    SOURCE=None, Verbose=2):
     '''
     Import Table
     ----------
@@ -320,7 +356,14 @@ def run_tool_db_odbc_5(TABLE=None, CONNECTION=None, SOURCE=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Export_Table(TABLE=None, CONNECTION=None, TABLE_PK=None, TABLE_NN=None, TABLE_UQ=None, NAME=None, EXISTS=None, Verbose=2):
+def Export_Table(
+    TABLE=None,
+    CONNECTION=None,
+    TABLE_PK=None,
+    TABLE_NN=None,
+    TABLE_UQ=None,
+    NAME=None,
+    EXISTS=None, Verbose=2):
     '''
     Export Table
     ----------
@@ -353,7 +396,14 @@ def Export_Table(TABLE=None, CONNECTION=None, TABLE_PK=None, TABLE_NN=None, TABL
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_6(TABLE=None, CONNECTION=None, TABLE_PK=None, TABLE_NN=None, TABLE_UQ=None, NAME=None, EXISTS=None, Verbose=2):
+def run_tool_db_odbc_6(
+    TABLE=None,
+    CONNECTION=None,
+    TABLE_PK=None,
+    TABLE_NN=None,
+    TABLE_UQ=None,
+    NAME=None,
+    EXISTS=None, Verbose=2):
     '''
     Export Table
     ----------
@@ -386,7 +436,9 @@ def run_tool_db_odbc_6(TABLE=None, CONNECTION=None, TABLE_PK=None, TABLE_NN=None
         return Tool.Execute(Verbose)
     return False
 
-def Drop_Table(CONNECTION=None, TABLE=None, Verbose=2):
+def Drop_Table(
+    CONNECTION=None,
+    TABLE=None, Verbose=2):
     '''
     Drop Table
     ----------
@@ -409,7 +461,9 @@ def Drop_Table(CONNECTION=None, TABLE=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_7(CONNECTION=None, TABLE=None, Verbose=2):
+def run_tool_db_odbc_7(
+    CONNECTION=None,
+    TABLE=None, Verbose=2):
     '''
     Drop Table
     ----------
@@ -432,7 +486,16 @@ def run_tool_db_odbc_7(CONNECTION=None, TABLE=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Import_Table_from_Query(TABLE=None, CONNECTION=None, TABLES=None, FIELDS=None, WHERE=None, GROUP=None, HAVING=None, ORDER=None, DISTINCT=None, Verbose=2):
+def Import_Table_from_Query(
+    TABLE=None,
+    CONNECTION=None,
+    TABLES=None,
+    FIELDS=None,
+    WHERE=None,
+    GROUP=None,
+    HAVING=None,
+    ORDER=None,
+    DISTINCT=None, Verbose=2):
     '''
     Import Table from Query
     ----------
@@ -470,7 +533,16 @@ def Import_Table_from_Query(TABLE=None, CONNECTION=None, TABLES=None, FIELDS=Non
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_8(TABLE=None, CONNECTION=None, TABLES=None, FIELDS=None, WHERE=None, GROUP=None, HAVING=None, ORDER=None, DISTINCT=None, Verbose=2):
+def run_tool_db_odbc_8(
+    TABLE=None,
+    CONNECTION=None,
+    TABLES=None,
+    FIELDS=None,
+    WHERE=None,
+    GROUP=None,
+    HAVING=None,
+    ORDER=None,
+    DISTINCT=None, Verbose=2):
     '''
     Import Table from Query
     ----------
@@ -508,7 +580,9 @@ def run_tool_db_odbc_8(TABLE=None, CONNECTION=None, TABLES=None, FIELDS=None, WH
         return Tool.Execute(Verbose)
     return False
 
-def List_Data_Sources(SOURCES=None, CONNECTED=None, Verbose=2):
+def List_Data_Sources(
+    SOURCES=None,
+    CONNECTED=None, Verbose=2):
     '''
     List Data Sources
     ----------
@@ -531,7 +605,9 @@ def List_Data_Sources(SOURCES=None, CONNECTED=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_9(SOURCES=None, CONNECTED=None, Verbose=2):
+def run_tool_db_odbc_9(
+    SOURCES=None,
+    CONNECTED=None, Verbose=2):
     '''
     List Data Sources
     ----------
@@ -554,7 +630,9 @@ def run_tool_db_odbc_9(SOURCES=None, CONNECTED=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def List_Tables(TABLES=None, CONNECTION=None, Verbose=2):
+def List_Tables(
+    TABLES=None,
+    CONNECTION=None, Verbose=2):
     '''
     List Tables
     ----------
@@ -577,7 +655,9 @@ def List_Tables(TABLES=None, CONNECTION=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_10(TABLES=None, CONNECTION=None, Verbose=2):
+def run_tool_db_odbc_10(
+    TABLES=None,
+    CONNECTION=None, Verbose=2):
     '''
     List Tables
     ----------
@@ -600,7 +680,8 @@ def run_tool_db_odbc_10(TABLES=None, CONNECTION=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Disconnect_All(TRANSACT=None, Verbose=2):
+def Disconnect_All(
+    TRANSACT=None, Verbose=2):
     '''
     Disconnect All
     ----------
@@ -621,7 +702,8 @@ def Disconnect_All(TRANSACT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_db_odbc_11(TRANSACT=None, Verbose=2):
+def run_tool_db_odbc_11(
+    TRANSACT=None, Verbose=2):
     '''
     Disconnect All
     ----------
