@@ -14,7 +14,10 @@ Visualization tools for grids.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Color_Palette_Rotation(GRID=None, COLORS=None, DOWN=None, Verbose=2):
+def Color_Palette_Rotation(
+    GRID=None,
+    COLORS=None,
+    DOWN=None, Verbose=2):
     '''
     Color Palette Rotation
     ----------
@@ -39,7 +42,10 @@ def Color_Palette_Rotation(GRID=None, COLORS=None, DOWN=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_visualisation_0(GRID=None, COLORS=None, DOWN=None, Verbose=2):
+def run_tool_grid_visualisation_0(
+    GRID=None,
+    COLORS=None,
+    DOWN=None, Verbose=2):
     '''
     Color Palette Rotation
     ----------
@@ -64,7 +70,23 @@ def run_tool_grid_visualisation_0(GRID=None, COLORS=None, DOWN=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Grid_Animation(GRIDS=None, GRID=None, FILE=None, FILE_NODATA=None, FILE_BGCOL=None, FILE_DELAY=None, FILE_COLORS=None, COLORS=None, NSTEPS=None, PROGRESS=None, LOOP=None, RANGE=None, RANGE_PERCENT=None, RANGE_STDDEV=None, RANGE_KEEP=None, RANGE_USER=None, Verbose=2):
+def Grid_Animation(
+    GRIDS=None,
+    GRID=None,
+    FILE=None,
+    FILE_NODATA=None,
+    FILE_BGCOL=None,
+    FILE_DELAY=None,
+    FILE_COLORS=None,
+    COLORS=None,
+    NSTEPS=None,
+    PROGRESS=None,
+    LOOP=None,
+    RANGE=None,
+    RANGE_PERCENT=None,
+    RANGE_STDDEV=None,
+    RANGE_KEEP=None,
+    RANGE_USER=None, Verbose=2):
     '''
     Grid Animation
     ----------
@@ -115,7 +137,23 @@ def Grid_Animation(GRIDS=None, GRID=None, FILE=None, FILE_NODATA=None, FILE_BGCO
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_visualisation_1(GRIDS=None, GRID=None, FILE=None, FILE_NODATA=None, FILE_BGCOL=None, FILE_DELAY=None, FILE_COLORS=None, COLORS=None, NSTEPS=None, PROGRESS=None, LOOP=None, RANGE=None, RANGE_PERCENT=None, RANGE_STDDEV=None, RANGE_KEEP=None, RANGE_USER=None, Verbose=2):
+def run_tool_grid_visualisation_1(
+    GRIDS=None,
+    GRID=None,
+    FILE=None,
+    FILE_NODATA=None,
+    FILE_BGCOL=None,
+    FILE_DELAY=None,
+    FILE_COLORS=None,
+    COLORS=None,
+    NSTEPS=None,
+    PROGRESS=None,
+    LOOP=None,
+    RANGE=None,
+    RANGE_PERCENT=None,
+    RANGE_STDDEV=None,
+    RANGE_KEEP=None,
+    RANGE_USER=None, Verbose=2):
     '''
     Grid Animation
     ----------
@@ -166,7 +204,11 @@ def run_tool_grid_visualisation_1(GRIDS=None, GRID=None, FILE=None, FILE_NODATA=
         return Tool.Execute(Verbose)
     return False
 
-def Fit_Color_Palette_to_Grid_Values(GRID=None, COUNT=None, SCALE=None, RANGE=None, Verbose=2):
+def Fit_Color_Palette_to_Grid_Values(
+    GRID=None,
+    COUNT=None,
+    SCALE=None,
+    RANGE=None, Verbose=2):
     '''
     Fit Color Palette to Grid Values
     ----------
@@ -193,7 +235,11 @@ def Fit_Color_Palette_to_Grid_Values(GRID=None, COUNT=None, SCALE=None, RANGE=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_visualisation_2(GRID=None, COUNT=None, SCALE=None, RANGE=None, Verbose=2):
+def run_tool_grid_visualisation_2(
+    GRID=None,
+    COUNT=None,
+    SCALE=None,
+    RANGE=None, Verbose=2):
     '''
     Fit Color Palette to Grid Values
     ----------
@@ -220,7 +266,17 @@ def run_tool_grid_visualisation_2(GRID=None, COUNT=None, SCALE=None, RANGE=None,
         return Tool.Execute(Verbose)
     return False
 
-def RGB_Composite(R_GRID=None, G_GRID=None, B_GRID=None, A_GRID=None, RGB=None, METHOD=None, RANGE=None, PERCTL=None, STDDEV=None, NODATA=None, Verbose=2):
+def RGB_Composite(
+    R_GRID=None,
+    G_GRID=None,
+    B_GRID=None,
+    A_GRID=None,
+    RGB=None,
+    METHOD=None,
+    RANGE=None,
+    PERCTL=None,
+    STDDEV=None,
+    NODATA=None, Verbose=2):
     '''
     RGB Composite
     ----------
@@ -259,7 +315,17 @@ def RGB_Composite(R_GRID=None, G_GRID=None, B_GRID=None, A_GRID=None, RGB=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_visualisation_3(R_GRID=None, G_GRID=None, B_GRID=None, A_GRID=None, RGB=None, METHOD=None, RANGE=None, PERCTL=None, STDDEV=None, NODATA=None, Verbose=2):
+def run_tool_grid_visualisation_3(
+    R_GRID=None,
+    G_GRID=None,
+    B_GRID=None,
+    A_GRID=None,
+    RGB=None,
+    METHOD=None,
+    RANGE=None,
+    PERCTL=None,
+    STDDEV=None,
+    NODATA=None, Verbose=2):
     '''
     RGB Composite
     ----------
@@ -298,7 +364,22 @@ def run_tool_grid_visualisation_3(R_GRID=None, G_GRID=None, B_GRID=None, A_GRID=
         return Tool.Execute(Verbose)
     return False
 
-def Create_3D_Image(DEM=None, IMAGE=None, SHAPES=None, RGB=None, RGB_Z=None, ZEXAGG=None, ZEXAGG_MIN=None, Z_ROTATE=None, X_ROTATE=None, X_ROTATE_LEVEL=None, PANBREAK=None, BKCOLOR=None, PROJECTION=None, NX=None, NY=None, Verbose=2):
+def Create_3D_Image(
+    DEM=None,
+    IMAGE=None,
+    SHAPES=None,
+    RGB=None,
+    RGB_Z=None,
+    ZEXAGG=None,
+    ZEXAGG_MIN=None,
+    Z_ROTATE=None,
+    X_ROTATE=None,
+    X_ROTATE_LEVEL=None,
+    PANBREAK=None,
+    BKCOLOR=None,
+    PROJECTION=None,
+    NX=None,
+    NY=None, Verbose=2):
     '''
     Create 3D Image
     ----------
@@ -347,7 +428,22 @@ def Create_3D_Image(DEM=None, IMAGE=None, SHAPES=None, RGB=None, RGB_Z=None, ZEX
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_visualisation_4(DEM=None, IMAGE=None, SHAPES=None, RGB=None, RGB_Z=None, ZEXAGG=None, ZEXAGG_MIN=None, Z_ROTATE=None, X_ROTATE=None, X_ROTATE_LEVEL=None, PANBREAK=None, BKCOLOR=None, PROJECTION=None, NX=None, NY=None, Verbose=2):
+def run_tool_grid_visualisation_4(
+    DEM=None,
+    IMAGE=None,
+    SHAPES=None,
+    RGB=None,
+    RGB_Z=None,
+    ZEXAGG=None,
+    ZEXAGG_MIN=None,
+    Z_ROTATE=None,
+    X_ROTATE=None,
+    X_ROTATE_LEVEL=None,
+    PANBREAK=None,
+    BKCOLOR=None,
+    PROJECTION=None,
+    NX=None,
+    NY=None, Verbose=2):
     '''
     Create 3D Image
     ----------
@@ -396,7 +492,26 @@ def run_tool_grid_visualisation_4(DEM=None, IMAGE=None, SHAPES=None, RGB=None, R
         return Tool.Execute(Verbose)
     return False
 
-def Color_Triangle_Composite(A_GRID=None, B_GRID=None, C_GRID=None, GRID=None, A_COLOR=None, A_METHOD=None, A_RANGE=None, A_PERCTL=None, A_PERCENT=None, B_COLOR=None, B_METHOD=None, B_RANGE=None, B_PERCTL=None, B_PERCENT=None, C_COLOR=None, C_METHOD=None, C_RANGE=None, C_PERCTL=None, C_PERCENT=None, Verbose=2):
+def Color_Triangle_Composite(
+    A_GRID=None,
+    B_GRID=None,
+    C_GRID=None,
+    GRID=None,
+    A_COLOR=None,
+    A_METHOD=None,
+    A_RANGE=None,
+    A_PERCTL=None,
+    A_PERCENT=None,
+    B_COLOR=None,
+    B_METHOD=None,
+    B_RANGE=None,
+    B_PERCTL=None,
+    B_PERCENT=None,
+    C_COLOR=None,
+    C_METHOD=None,
+    C_RANGE=None,
+    C_PERCTL=None,
+    C_PERCENT=None, Verbose=2):
     '''
     Color Triangle Composite
     ----------
@@ -453,7 +568,26 @@ def Color_Triangle_Composite(A_GRID=None, B_GRID=None, C_GRID=None, GRID=None, A
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_visualisation_5(A_GRID=None, B_GRID=None, C_GRID=None, GRID=None, A_COLOR=None, A_METHOD=None, A_RANGE=None, A_PERCTL=None, A_PERCENT=None, B_COLOR=None, B_METHOD=None, B_RANGE=None, B_PERCTL=None, B_PERCENT=None, C_COLOR=None, C_METHOD=None, C_RANGE=None, C_PERCTL=None, C_PERCENT=None, Verbose=2):
+def run_tool_grid_visualisation_5(
+    A_GRID=None,
+    B_GRID=None,
+    C_GRID=None,
+    GRID=None,
+    A_COLOR=None,
+    A_METHOD=None,
+    A_RANGE=None,
+    A_PERCTL=None,
+    A_PERCENT=None,
+    B_COLOR=None,
+    B_METHOD=None,
+    B_RANGE=None,
+    B_PERCTL=None,
+    B_PERCENT=None,
+    C_COLOR=None,
+    C_METHOD=None,
+    C_RANGE=None,
+    C_PERCTL=None,
+    C_PERCENT=None, Verbose=2):
     '''
     Color Triangle Composite
     ----------
@@ -510,7 +644,10 @@ def run_tool_grid_visualisation_5(A_GRID=None, B_GRID=None, C_GRID=None, GRID=No
         return Tool.Execute(Verbose)
     return False
 
-def Histogram_Surface(GRID=None, HIST=None, METHOD=None, Verbose=2):
+def Histogram_Surface(
+    GRID=None,
+    HIST=None,
+    METHOD=None, Verbose=2):
     '''
     Histogram Surface
     ----------
@@ -535,7 +672,10 @@ def Histogram_Surface(GRID=None, HIST=None, METHOD=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_visualisation_6(GRID=None, HIST=None, METHOD=None, Verbose=2):
+def run_tool_grid_visualisation_6(
+    GRID=None,
+    HIST=None,
+    METHOD=None, Verbose=2):
     '''
     Histogram Surface
     ----------
@@ -560,7 +700,11 @@ def run_tool_grid_visualisation_6(GRID=None, HIST=None, METHOD=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def AspectSlope_Grid(ASPECT=None, SLOPE=None, ASPECT_SLOPE=None, LUT=None, Verbose=2):
+def AspectSlope_Grid(
+    ASPECT=None,
+    SLOPE=None,
+    ASPECT_SLOPE=None,
+    LUT=None, Verbose=2):
     '''
     Aspect-Slope Grid
     ----------
@@ -591,7 +735,11 @@ def AspectSlope_Grid(ASPECT=None, SLOPE=None, ASPECT_SLOPE=None, LUT=None, Verbo
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_visualisation_7(ASPECT=None, SLOPE=None, ASPECT_SLOPE=None, LUT=None, Verbose=2):
+def run_tool_grid_visualisation_7(
+    ASPECT=None,
+    SLOPE=None,
+    ASPECT_SLOPE=None,
+    LUT=None, Verbose=2):
     '''
     Aspect-Slope Grid
     ----------
@@ -622,7 +770,16 @@ def run_tool_grid_visualisation_7(ASPECT=None, SLOPE=None, ASPECT_SLOPE=None, LU
         return Tool.Execute(Verbose)
     return False
 
-def Terrain_Map_View(DEM=None, SHADE=None, OPENNESS=None, SLOPE=None, CONTOURS=None, METHOD=None, RADIUS=None, CONTOUR_LINES=None, EQUIDISTANCE=None, Verbose=2):
+def Terrain_Map_View(
+    DEM=None,
+    SHADE=None,
+    OPENNESS=None,
+    SLOPE=None,
+    CONTOURS=None,
+    METHOD=None,
+    RADIUS=None,
+    CONTOUR_LINES=None,
+    EQUIDISTANCE=None, Verbose=2):
     '''
     Terrain Map View
     ----------
@@ -661,7 +818,16 @@ def Terrain_Map_View(DEM=None, SHADE=None, OPENNESS=None, SLOPE=None, CONTOURS=N
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_visualisation_8(DEM=None, SHADE=None, OPENNESS=None, SLOPE=None, CONTOURS=None, METHOD=None, RADIUS=None, CONTOUR_LINES=None, EQUIDISTANCE=None, Verbose=2):
+def run_tool_grid_visualisation_8(
+    DEM=None,
+    SHADE=None,
+    OPENNESS=None,
+    SLOPE=None,
+    CONTOURS=None,
+    METHOD=None,
+    RADIUS=None,
+    CONTOUR_LINES=None,
+    EQUIDISTANCE=None, Verbose=2):
     '''
     Terrain Map View
     ----------
@@ -700,7 +866,13 @@ def run_tool_grid_visualisation_8(DEM=None, SHADE=None, OPENNESS=None, SLOPE=Non
         return Tool.Execute(Verbose)
     return False
 
-def Split_RGB_Composite(RGB=None, R=None, G=None, B=None, A=None, NODATA=None, Verbose=2):
+def Split_RGB_Composite(
+    RGB=None,
+    R=None,
+    G=None,
+    B=None,
+    A=None,
+    NODATA=None, Verbose=2):
     '''
     Split RGB Composite
     ----------
@@ -731,7 +903,13 @@ def Split_RGB_Composite(RGB=None, R=None, G=None, B=None, A=None, NODATA=None, V
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_visualisation_9(RGB=None, R=None, G=None, B=None, A=None, NODATA=None, Verbose=2):
+def run_tool_grid_visualisation_9(
+    RGB=None,
+    R=None,
+    G=None,
+    B=None,
+    A=None,
+    NODATA=None, Verbose=2):
     '''
     Split RGB Composite
     ----------
@@ -762,7 +940,14 @@ def run_tool_grid_visualisation_9(RGB=None, R=None, G=None, B=None, A=None, NODA
         return Tool.Execute(Verbose)
     return False
 
-def Select_Lookup_Table_for_Grid_Visualization(GRID=None, LUT=None, NAME=None, VALUE=None, VALUE_MAX=None, DESCRIPTION=None, COLOR=None, Verbose=2):
+def Select_Lookup_Table_for_Grid_Visualization(
+    GRID=None,
+    LUT=None,
+    NAME=None,
+    VALUE=None,
+    VALUE_MAX=None,
+    DESCRIPTION=None,
+    COLOR=None, Verbose=2):
     '''
     Select Look-up Table for Grid Visualization
     ----------
@@ -795,7 +980,14 @@ def Select_Lookup_Table_for_Grid_Visualization(GRID=None, LUT=None, NAME=None, V
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_visualisation_10(GRID=None, LUT=None, NAME=None, VALUE=None, VALUE_MAX=None, DESCRIPTION=None, COLOR=None, Verbose=2):
+def run_tool_grid_visualisation_10(
+    GRID=None,
+    LUT=None,
+    NAME=None,
+    VALUE=None,
+    VALUE_MAX=None,
+    DESCRIPTION=None,
+    COLOR=None, Verbose=2):
     '''
     Select Look-up Table for Grid Visualization
     ----------
@@ -828,7 +1020,9 @@ def run_tool_grid_visualisation_10(GRID=None, LUT=None, NAME=None, VALUE=None, V
         return Tool.Execute(Verbose)
     return False
 
-def Create_a_Table_from_Lookup_Table(TABLE=None, LUT=None, Verbose=2):
+def Create_a_Table_from_Lookup_Table(
+    TABLE=None,
+    LUT=None, Verbose=2):
     '''
     Create a Table from Look-up Table
     ----------
@@ -851,7 +1045,9 @@ def Create_a_Table_from_Lookup_Table(TABLE=None, LUT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_grid_visualisation_11(TABLE=None, LUT=None, Verbose=2):
+def run_tool_grid_visualisation_11(
+    TABLE=None,
+    LUT=None, Verbose=2):
     '''
     Create a Table from Look-up Table
     ----------
