@@ -18,7 +18,12 @@ Find out more at the [ViGrA - Homepage](https://ukoethe.github.io/vigra/).
 
 from PySAGA.helper import Tool_Wrapper
 
-def Smoothing_ViGrA(INPUT=None, OUTPUT=None, TYPE=None, SCALE=None, EDGE=None, Verbose=2):
+def Smoothing_ViGrA(
+    INPUT=None,
+    OUTPUT=None,
+    TYPE=None,
+    SCALE=None,
+    EDGE=None, Verbose=2):
     '''
     Smoothing (ViGrA)
     ----------
@@ -47,7 +52,12 @@ def Smoothing_ViGrA(INPUT=None, OUTPUT=None, TYPE=None, SCALE=None, EDGE=None, V
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_vigra_0(INPUT=None, OUTPUT=None, TYPE=None, SCALE=None, EDGE=None, Verbose=2):
+def run_tool_imagery_vigra_0(
+    INPUT=None,
+    OUTPUT=None,
+    TYPE=None,
+    SCALE=None,
+    EDGE=None, Verbose=2):
     '''
     Smoothing (ViGrA)
     ----------
@@ -76,7 +86,12 @@ def run_tool_imagery_vigra_0(INPUT=None, OUTPUT=None, TYPE=None, SCALE=None, EDG
         return Tool.Execute(Verbose)
     return False
 
-def Edge_Detection_ViGrA(INPUT=None, OUTPUT=None, TYPE=None, SCALE=None, THRESHOLD=None, Verbose=2):
+def Edge_Detection_ViGrA(
+    INPUT=None,
+    OUTPUT=None,
+    TYPE=None,
+    SCALE=None,
+    THRESHOLD=None, Verbose=2):
     '''
     Edge Detection (ViGrA)
     ----------
@@ -105,7 +120,12 @@ def Edge_Detection_ViGrA(INPUT=None, OUTPUT=None, TYPE=None, SCALE=None, THRESHO
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_vigra_1(INPUT=None, OUTPUT=None, TYPE=None, SCALE=None, THRESHOLD=None, Verbose=2):
+def run_tool_imagery_vigra_1(
+    INPUT=None,
+    OUTPUT=None,
+    TYPE=None,
+    SCALE=None,
+    THRESHOLD=None, Verbose=2):
     '''
     Edge Detection (ViGrA)
     ----------
@@ -134,7 +154,13 @@ def run_tool_imagery_vigra_1(INPUT=None, OUTPUT=None, TYPE=None, SCALE=None, THR
         return Tool.Execute(Verbose)
     return False
 
-def Morphological_Filter_ViGrA(INPUT=None, OUTPUT=None, TYPE=None, RADIUS=None, RANK=None, RESCALE=None, Verbose=2):
+def Morphological_Filter_ViGrA(
+    INPUT=None,
+    OUTPUT=None,
+    TYPE=None,
+    RADIUS=None,
+    RANK=None,
+    RESCALE=None, Verbose=2):
     '''
     Morphological Filter (ViGrA)
     ----------
@@ -165,7 +191,13 @@ def Morphological_Filter_ViGrA(INPUT=None, OUTPUT=None, TYPE=None, RADIUS=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_vigra_2(INPUT=None, OUTPUT=None, TYPE=None, RADIUS=None, RANK=None, RESCALE=None, Verbose=2):
+def run_tool_imagery_vigra_2(
+    INPUT=None,
+    OUTPUT=None,
+    TYPE=None,
+    RADIUS=None,
+    RANK=None,
+    RESCALE=None, Verbose=2):
     '''
     Morphological Filter (ViGrA)
     ----------
@@ -196,7 +228,10 @@ def run_tool_imagery_vigra_2(INPUT=None, OUTPUT=None, TYPE=None, RADIUS=None, RA
         return Tool.Execute(Verbose)
     return False
 
-def Distance_ViGrA(INPUT=None, OUTPUT=None, NORM=None, Verbose=2):
+def Distance_ViGrA(
+    INPUT=None,
+    OUTPUT=None,
+    NORM=None, Verbose=2):
     '''
     Distance (ViGrA)
     ----------
@@ -221,7 +256,10 @@ def Distance_ViGrA(INPUT=None, OUTPUT=None, NORM=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_vigra_3(INPUT=None, OUTPUT=None, NORM=None, Verbose=2):
+def run_tool_imagery_vigra_3(
+    INPUT=None,
+    OUTPUT=None,
+    NORM=None, Verbose=2):
     '''
     Distance (ViGrA)
     ----------
@@ -246,7 +284,12 @@ def run_tool_imagery_vigra_3(INPUT=None, OUTPUT=None, NORM=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Watershed_Segmentation_ViGrA(INPUT=None, OUTPUT=None, SCALE=None, RGB=None, EDGES=None, Verbose=2):
+def Watershed_Segmentation_ViGrA(
+    INPUT=None,
+    OUTPUT=None,
+    SCALE=None,
+    RGB=None,
+    EDGES=None, Verbose=2):
     '''
     Watershed Segmentation (ViGrA)
     ----------
@@ -276,7 +319,12 @@ def Watershed_Segmentation_ViGrA(INPUT=None, OUTPUT=None, SCALE=None, RGB=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_vigra_4(INPUT=None, OUTPUT=None, SCALE=None, RGB=None, EDGES=None, Verbose=2):
+def run_tool_imagery_vigra_4(
+    INPUT=None,
+    OUTPUT=None,
+    SCALE=None,
+    RGB=None,
+    EDGES=None, Verbose=2):
     '''
     Watershed Segmentation (ViGrA)
     ----------
@@ -306,7 +354,11 @@ def run_tool_imagery_vigra_4(INPUT=None, OUTPUT=None, SCALE=None, RGB=None, EDGE
         return Tool.Execute(Verbose)
     return False
 
-def Fourier_Transform_ViGrA(INPUT=None, REAL=None, IMAG=None, CENTER=None, Verbose=2):
+def Fourier_Transform_ViGrA(
+    INPUT=None,
+    REAL=None,
+    IMAG=None,
+    CENTER=None, Verbose=2):
     '''
     Fourier Transform (ViGrA)
     ----------
@@ -333,7 +385,11 @@ def Fourier_Transform_ViGrA(INPUT=None, REAL=None, IMAG=None, CENTER=None, Verbo
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_vigra_5(INPUT=None, REAL=None, IMAG=None, CENTER=None, Verbose=2):
+def run_tool_imagery_vigra_5(
+    INPUT=None,
+    REAL=None,
+    IMAG=None,
+    CENTER=None, Verbose=2):
     '''
     Fourier Transform (ViGrA)
     ----------
@@ -360,7 +416,11 @@ def run_tool_imagery_vigra_5(INPUT=None, REAL=None, IMAG=None, CENTER=None, Verb
         return Tool.Execute(Verbose)
     return False
 
-def Fourier_Transform_Inverse_ViGrA(REAL=None, IMAG=None, OUTPUT=None, CENTER=None, Verbose=2):
+def Fourier_Transform_Inverse_ViGrA(
+    REAL=None,
+    IMAG=None,
+    OUTPUT=None,
+    CENTER=None, Verbose=2):
     '''
     Fourier Transform Inverse (ViGrA)
     ----------
@@ -387,7 +447,11 @@ def Fourier_Transform_Inverse_ViGrA(REAL=None, IMAG=None, OUTPUT=None, CENTER=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_vigra_6(REAL=None, IMAG=None, OUTPUT=None, CENTER=None, Verbose=2):
+def run_tool_imagery_vigra_6(
+    REAL=None,
+    IMAG=None,
+    OUTPUT=None,
+    CENTER=None, Verbose=2):
     '''
     Fourier Transform Inverse (ViGrA)
     ----------
@@ -414,7 +478,13 @@ def run_tool_imagery_vigra_6(REAL=None, IMAG=None, OUTPUT=None, CENTER=None, Ver
         return Tool.Execute(Verbose)
     return False
 
-def Fourier_Filter_ViGrA(INPUT=None, OUTPUT=None, SCALE=None, POWER=None, RANGE=None, FILTER=None, Verbose=2):
+def Fourier_Filter_ViGrA(
+    INPUT=None,
+    OUTPUT=None,
+    SCALE=None,
+    POWER=None,
+    RANGE=None,
+    FILTER=None, Verbose=2):
     '''
     Fourier Filter (ViGrA)
     ----------
@@ -445,7 +515,13 @@ def Fourier_Filter_ViGrA(INPUT=None, OUTPUT=None, SCALE=None, POWER=None, RANGE=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_vigra_8(INPUT=None, OUTPUT=None, SCALE=None, POWER=None, RANGE=None, FILTER=None, Verbose=2):
+def run_tool_imagery_vigra_8(
+    INPUT=None,
+    OUTPUT=None,
+    SCALE=None,
+    POWER=None,
+    RANGE=None,
+    FILTER=None, Verbose=2):
     '''
     Fourier Filter (ViGrA)
     ----------
@@ -476,7 +552,27 @@ def run_tool_imagery_vigra_8(INPUT=None, OUTPUT=None, SCALE=None, POWER=None, RA
         return Tool.Execute(Verbose)
     return False
 
-def Random_Forest_Classification_ViGrA(FEATURES=None, TRAINING=None, CLASSES=None, PROBABILITY=None, PROBABILITIES=None, IMPORTANCES=None, BPROBABILITIES=None, FIELD=None, LABEL_AS_ID=None, DO_MRMR=None, MRMR_NFEATURES=None, MRMR_DISCRETIZE=None, MRMR_THRESHOLD=None, MRMR_METHOD=None, RF_TREE_COUNT=None, RF_TREE_SAMPLES=None, RF_REPLACE=None, RF_SPLIT_MIN_SIZE=None, RF_NODE_FEATURES=None, RF_STRATIFICATION=None, Verbose=2):
+def Random_Forest_Classification_ViGrA(
+    FEATURES=None,
+    TRAINING=None,
+    CLASSES=None,
+    PROBABILITY=None,
+    PROBABILITIES=None,
+    IMPORTANCES=None,
+    BPROBABILITIES=None,
+    FIELD=None,
+    LABEL_AS_ID=None,
+    DO_MRMR=None,
+    MRMR_NFEATURES=None,
+    MRMR_DISCRETIZE=None,
+    MRMR_THRESHOLD=None,
+    MRMR_METHOD=None,
+    RF_TREE_COUNT=None,
+    RF_TREE_SAMPLES=None,
+    RF_REPLACE=None,
+    RF_SPLIT_MIN_SIZE=None,
+    RF_NODE_FEATURES=None,
+    RF_STRATIFICATION=None, Verbose=2):
     '''
     Random Forest Classification (ViGrA)
     ----------
@@ -535,7 +631,27 @@ def Random_Forest_Classification_ViGrA(FEATURES=None, TRAINING=None, CLASSES=Non
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_vigra_9(FEATURES=None, TRAINING=None, CLASSES=None, PROBABILITY=None, PROBABILITIES=None, IMPORTANCES=None, BPROBABILITIES=None, FIELD=None, LABEL_AS_ID=None, DO_MRMR=None, MRMR_NFEATURES=None, MRMR_DISCRETIZE=None, MRMR_THRESHOLD=None, MRMR_METHOD=None, RF_TREE_COUNT=None, RF_TREE_SAMPLES=None, RF_REPLACE=None, RF_SPLIT_MIN_SIZE=None, RF_NODE_FEATURES=None, RF_STRATIFICATION=None, Verbose=2):
+def run_tool_imagery_vigra_9(
+    FEATURES=None,
+    TRAINING=None,
+    CLASSES=None,
+    PROBABILITY=None,
+    PROBABILITIES=None,
+    IMPORTANCES=None,
+    BPROBABILITIES=None,
+    FIELD=None,
+    LABEL_AS_ID=None,
+    DO_MRMR=None,
+    MRMR_NFEATURES=None,
+    MRMR_DISCRETIZE=None,
+    MRMR_THRESHOLD=None,
+    MRMR_METHOD=None,
+    RF_TREE_COUNT=None,
+    RF_TREE_SAMPLES=None,
+    RF_REPLACE=None,
+    RF_SPLIT_MIN_SIZE=None,
+    RF_NODE_FEATURES=None,
+    RF_STRATIFICATION=None, Verbose=2):
     '''
     Random Forest Classification (ViGrA)
     ----------
@@ -594,7 +710,23 @@ def run_tool_imagery_vigra_9(FEATURES=None, TRAINING=None, CLASSES=None, PROBABI
         return Tool.Execute(Verbose)
     return False
 
-def Random_Forest_Presence_Prediction_ViGrA(FEATURES=None, PRESENCE=None, PREDICTION=None, PROBABILITY=None, BACKGROUND=None, DO_MRMR=None, MRMR_NFEATURES=None, MRMR_DISCRETIZE=None, MRMR_THRESHOLD=None, MRMR_METHOD=None, RF_TREE_COUNT=None, RF_TREE_SAMPLES=None, RF_REPLACE=None, RF_SPLIT_MIN_SIZE=None, RF_NODE_FEATURES=None, RF_STRATIFICATION=None, Verbose=2):
+def Random_Forest_Presence_Prediction_ViGrA(
+    FEATURES=None,
+    PRESENCE=None,
+    PREDICTION=None,
+    PROBABILITY=None,
+    BACKGROUND=None,
+    DO_MRMR=None,
+    MRMR_NFEATURES=None,
+    MRMR_DISCRETIZE=None,
+    MRMR_THRESHOLD=None,
+    MRMR_METHOD=None,
+    RF_TREE_COUNT=None,
+    RF_TREE_SAMPLES=None,
+    RF_REPLACE=None,
+    RF_SPLIT_MIN_SIZE=None,
+    RF_NODE_FEATURES=None,
+    RF_STRATIFICATION=None, Verbose=2):
     '''
     Random Forest Presence Prediction (ViGrA)
     ----------
@@ -645,7 +777,23 @@ def Random_Forest_Presence_Prediction_ViGrA(FEATURES=None, PRESENCE=None, PREDIC
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_vigra_10(FEATURES=None, PRESENCE=None, PREDICTION=None, PROBABILITY=None, BACKGROUND=None, DO_MRMR=None, MRMR_NFEATURES=None, MRMR_DISCRETIZE=None, MRMR_THRESHOLD=None, MRMR_METHOD=None, RF_TREE_COUNT=None, RF_TREE_SAMPLES=None, RF_REPLACE=None, RF_SPLIT_MIN_SIZE=None, RF_NODE_FEATURES=None, RF_STRATIFICATION=None, Verbose=2):
+def run_tool_imagery_vigra_10(
+    FEATURES=None,
+    PRESENCE=None,
+    PREDICTION=None,
+    PROBABILITY=None,
+    BACKGROUND=None,
+    DO_MRMR=None,
+    MRMR_NFEATURES=None,
+    MRMR_DISCRETIZE=None,
+    MRMR_THRESHOLD=None,
+    MRMR_METHOD=None,
+    RF_TREE_COUNT=None,
+    RF_TREE_SAMPLES=None,
+    RF_REPLACE=None,
+    RF_SPLIT_MIN_SIZE=None,
+    RF_NODE_FEATURES=None,
+    RF_STRATIFICATION=None, Verbose=2):
     '''
     Random Forest Presence Prediction (ViGrA)
     ----------
@@ -696,7 +844,19 @@ def run_tool_imagery_vigra_10(FEATURES=None, PRESENCE=None, PREDICTION=None, PRO
         return Tool.Execute(Verbose)
     return False
 
-def Random_Forest_Table_Classification_ViGrA(TABLE=None, IMPORTANCES=None, FEATURES=None, PREDICTION=None, TRAINING=None, LABEL_AS_ID=None, RF_TREE_COUNT=None, RF_TREE_SAMPLES=None, RF_REPLACE=None, RF_SPLIT_MIN_SIZE=None, RF_NODE_FEATURES=None, RF_STRATIFICATION=None, Verbose=2):
+def Random_Forest_Table_Classification_ViGrA(
+    TABLE=None,
+    IMPORTANCES=None,
+    FEATURES=None,
+    PREDICTION=None,
+    TRAINING=None,
+    LABEL_AS_ID=None,
+    RF_TREE_COUNT=None,
+    RF_TREE_SAMPLES=None,
+    RF_REPLACE=None,
+    RF_SPLIT_MIN_SIZE=None,
+    RF_NODE_FEATURES=None,
+    RF_STRATIFICATION=None, Verbose=2):
     '''
     Random Forest Table Classification (ViGrA)
     ----------
@@ -739,7 +899,19 @@ def Random_Forest_Table_Classification_ViGrA(TABLE=None, IMPORTANCES=None, FEATU
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_imagery_vigra_11(TABLE=None, IMPORTANCES=None, FEATURES=None, PREDICTION=None, TRAINING=None, LABEL_AS_ID=None, RF_TREE_COUNT=None, RF_TREE_SAMPLES=None, RF_REPLACE=None, RF_SPLIT_MIN_SIZE=None, RF_NODE_FEATURES=None, RF_STRATIFICATION=None, Verbose=2):
+def run_tool_imagery_vigra_11(
+    TABLE=None,
+    IMPORTANCES=None,
+    FEATURES=None,
+    PREDICTION=None,
+    TRAINING=None,
+    LABEL_AS_ID=None,
+    RF_TREE_COUNT=None,
+    RF_TREE_SAMPLES=None,
+    RF_REPLACE=None,
+    RF_SPLIT_MIN_SIZE=None,
+    RF_NODE_FEATURES=None,
+    RF_STRATIFICATION=None, Verbose=2):
     '''
     Random Forest Table Classification (ViGrA)
     ----------
