@@ -14,12 +14,35 @@ Image Import/Export.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Export_to_Image_File(GRID=None, SHADE=None, FILE=None, FILE_WORLD=None, FILE_KML=None, NO_DATA=None, NO_DATA_COL=None, COLOURING=None, COL_COUNT=None, COL_REVERT=None, COL_PALETTE=None, COL_DEPTH=None, GRADUATED=None, STDDEV=None, LINEAR=None, STRETCH=None, SCALE_MODE=None, SCALE_LOG=None, LUT=None, SHADE_TRANS=None, SHADE_COLOURING=None, SHADE_BRIGHT=None, SHADE_STDDEV=None, Verbose=2):
+def Export_to_Image_File(
+    GRID=None,
+    SHADE=None,
+    FILE=None,
+    FILE_WORLD=None,
+    FILE_KML=None,
+    NO_DATA=None,
+    NO_DATA_COL=None,
+    COLOURING=None,
+    COL_COUNT=None,
+    COL_REVERT=None,
+    COL_PALETTE=None,
+    COL_DEPTH=None,
+    GRADUATED=None,
+    STDDEV=None,
+    LINEAR=None,
+    STRETCH=None,
+    SCALE_MODE=None,
+    SCALE_LOG=None,
+    LUT=None,
+    SHADE_TRANS=None,
+    SHADE_COLOURING=None,
+    SHADE_BRIGHT=None,
+    SHADE_STDDEV=None, Verbose=2):
     '''
     Export to Image File
     ----------
     [io_grid_image.0]\n
-    With this tool you can save a RGB to an image file. Optionally, a shade RGB can be overlayed using the specified transparency and brightness adjustment.\n
+    With this tool you can save a RGB to an image file. Optionally, a shade RGB can be overlaid using the specified transparency and brightness adjustment.\n
     If input rasters come with geographic coordinates an additionaloption for KML file creation (Google Earth) is selectable.\n
     Arguments
     ----------
@@ -80,12 +103,35 @@ def Export_to_Image_File(GRID=None, SHADE=None, FILE=None, FILE_WORLD=None, FILE
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_grid_image_0(GRID=None, SHADE=None, FILE=None, FILE_WORLD=None, FILE_KML=None, NO_DATA=None, NO_DATA_COL=None, COLOURING=None, COL_COUNT=None, COL_REVERT=None, COL_PALETTE=None, COL_DEPTH=None, GRADUATED=None, STDDEV=None, LINEAR=None, STRETCH=None, SCALE_MODE=None, SCALE_LOG=None, LUT=None, SHADE_TRANS=None, SHADE_COLOURING=None, SHADE_BRIGHT=None, SHADE_STDDEV=None, Verbose=2):
+def run_tool_io_grid_image_0(
+    GRID=None,
+    SHADE=None,
+    FILE=None,
+    FILE_WORLD=None,
+    FILE_KML=None,
+    NO_DATA=None,
+    NO_DATA_COL=None,
+    COLOURING=None,
+    COL_COUNT=None,
+    COL_REVERT=None,
+    COL_PALETTE=None,
+    COL_DEPTH=None,
+    GRADUATED=None,
+    STDDEV=None,
+    LINEAR=None,
+    STRETCH=None,
+    SCALE_MODE=None,
+    SCALE_LOG=None,
+    LUT=None,
+    SHADE_TRANS=None,
+    SHADE_COLOURING=None,
+    SHADE_BRIGHT=None,
+    SHADE_STDDEV=None, Verbose=2):
     '''
     Export to Image File
     ----------
     [io_grid_image.0]\n
-    With this tool you can save a RGB to an image file. Optionally, a shade RGB can be overlayed using the specified transparency and brightness adjustment.\n
+    With this tool you can save a RGB to an image file. Optionally, a shade RGB can be overlaid using the specified transparency and brightness adjustment.\n
     If input rasters come with geographic coordinates an additionaloption for KML file creation (Google Earth) is selectable.\n
     Arguments
     ----------
@@ -146,7 +192,13 @@ def run_tool_io_grid_image_0(GRID=None, SHADE=None, FILE=None, FILE_WORLD=None,
         return Tool.Execute(Verbose)
     return False
 
-def Import_Image_File(OUT_GRID=None, OUT_RED=None, OUT_GREEN=None, OUT_BLUE=None, FILE=None, METHOD=None, Verbose=2):
+def Import_Image_File(
+    OUT_GRID=None,
+    OUT_RED=None,
+    OUT_GREEN=None,
+    OUT_BLUE=None,
+    FILE=None,
+    METHOD=None, Verbose=2):
     '''
     Import Image File
     ----------
@@ -177,7 +229,13 @@ def Import_Image_File(OUT_GRID=None, OUT_RED=None, OUT_GREEN=None, OUT_BLUE=None
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_grid_image_1(OUT_GRID=None, OUT_RED=None, OUT_GREEN=None, OUT_BLUE=None, FILE=None, METHOD=None, Verbose=2):
+def run_tool_io_grid_image_1(
+    OUT_GRID=None,
+    OUT_RED=None,
+    OUT_GREEN=None,
+    OUT_BLUE=None,
+    FILE=None,
+    METHOD=None, Verbose=2):
     '''
     Import Image File
     ----------
@@ -208,7 +266,20 @@ def run_tool_io_grid_image_1(OUT_GRID=None, OUT_RED=None, OUT_GREEN=None, OUT_BL
         return Tool.Execute(Verbose)
     return False
 
-def Export_Grid_to_KML(GRID=None, SHADE=None, FILE=None, FORMAT=None, COLOURING=None, COL_PALETTE=None, COL_COUNT=None, COL_REVERT=None, STDDEV=None, STRETCH=None, LUT=None, RESAMPLING=None, SHADE_BRIGHT=None, Verbose=2):
+def Export_Grid_to_KML(
+    GRID=None,
+    SHADE=None,
+    FILE=None,
+    FORMAT=None,
+    COLOURING=None,
+    COL_PALETTE=None,
+    COL_COUNT=None,
+    COL_REVERT=None,
+    STDDEV=None,
+    STRETCH=None,
+    LUT=None,
+    RESAMPLING=None,
+    SHADE_BRIGHT=None, Verbose=2):
     '''
     Export Grid to KML
     ----------
@@ -220,10 +291,10 @@ def Export_Grid_to_KML(GRID=None, SHADE=None, FILE=None, FORMAT=None, COLOURING=
     - SHADE [`optional input grid`] : Shade
     - FILE [`file path`] : File
     - FORMAT [`choice`] : Image Format. Available Choices: [0] Portable Network Graphics [1] JPEG - JFIF Compliant [2] Tagged Image File Format [3] Windows or OS/2 Bitmap [4] Zsoft Paintbrush Default: 1
-    - COLOURING [`choice`] : Colouring. Available Choices: [0] stretch to grid's standard deviation [1] stretch to grid's value range [2] stretch to specified value range [3] lookup table [4] rgb coded values Default: 0
-    - COL_PALETTE [`choice`] : Color Palette. Available Choices: [0] DEFAULT [1] DEFAULT_BRIGHT [2] BLACK_WHITE [3] BLACK_RED [4] BLACK_GREEN [5] BLACK_BLUE [6] WHITE_RED [7] WHITE_GREEN [8] WHITE_BLUE [9] YELLOW_RED [10] YELLOW_GREEN [11] YELLOW_BLUE [12] RED_GREEN [13] RED_BLUE [14] GREEN_BLUE [15] RED_GREY_BLUE [16] RED_GREY_GREEN [17] GREEN_GREY_BLUE [18] RED_GREEN_BLUE [19] RED_BLUE_GREEN [20] GREEN_RED_BLUE [21] RAINBOW [22] NEON [23] TOPOGRAPHY [24] ASPECT_1 [25] ASPECT_2 [26] ASPECT_3 Default: 0
+    - COLOURING [`choice`] : Colors. Available Choices: [0] stretch to grid's standard deviation [1] stretch to grid's value range [2] stretch to specified value range [3] lookup table [4] rgb coded values Default: 0
+    - COL_PALETTE [`choice`] : Color Ramp. Available Choices: [0] DEFAULT [1] DEFAULT_BRIGHT [2] BLACK_WHITE [3] BLACK_RED [4] BLACK_GREEN [5] BLACK_BLUE [6] WHITE_RED [7] WHITE_GREEN [8] WHITE_BLUE [9] YELLOW_RED [10] YELLOW_GREEN [11] YELLOW_BLUE [12] RED_GREEN [13] RED_BLUE [14] GREEN_BLUE [15] RED_GREY_BLUE [16] RED_GREY_GREEN [17] GREEN_GREY_BLUE [18] RED_GREEN_BLUE [19] RED_BLUE_GREEN [20] GREEN_RED_BLUE [21] RAINBOW [22] NEON [23] TOPOGRAPHY [24] ASPECT_1 [25] ASPECT_2 [26] ASPECT_3 Default: 0
     - COL_COUNT [`integer number`] : Number of Colors. Default: 100
-    - COL_REVERT [`boolean`] : Revert Palette. Default: 0
+    - COL_REVERT [`boolean`] : Invert Ramp. Default: 0
     - STDDEV [`floating point number`] : Standard Deviation. Minimum: 0.000000 Default: 2.000000
     - STRETCH [`value range`] : Stretch to Value Range
     - LUT [`static table`] : Lookup Table. 5 Fields: - 1. [color] Color - 2. [string] Name - 3. [string] Description - 4. [8 byte floating point number] Minimum - 5. [8 byte floating point number] Maximum 
@@ -253,7 +324,20 @@ def Export_Grid_to_KML(GRID=None, SHADE=None, FILE=None, FORMAT=None, COLOURING=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_grid_image_2(GRID=None, SHADE=None, FILE=None, FORMAT=None, COLOURING=None, COL_PALETTE=None, COL_COUNT=None, COL_REVERT=None, STDDEV=None, STRETCH=None, LUT=None, RESAMPLING=None, SHADE_BRIGHT=None, Verbose=2):
+def run_tool_io_grid_image_2(
+    GRID=None,
+    SHADE=None,
+    FILE=None,
+    FORMAT=None,
+    COLOURING=None,
+    COL_PALETTE=None,
+    COL_COUNT=None,
+    COL_REVERT=None,
+    STDDEV=None,
+    STRETCH=None,
+    LUT=None,
+    RESAMPLING=None,
+    SHADE_BRIGHT=None, Verbose=2):
     '''
     Export Grid to KML
     ----------
@@ -265,10 +349,10 @@ def run_tool_io_grid_image_2(GRID=None, SHADE=None, FILE=None, FORMAT=None, COLO
     - SHADE [`optional input grid`] : Shade
     - FILE [`file path`] : File
     - FORMAT [`choice`] : Image Format. Available Choices: [0] Portable Network Graphics [1] JPEG - JFIF Compliant [2] Tagged Image File Format [3] Windows or OS/2 Bitmap [4] Zsoft Paintbrush Default: 1
-    - COLOURING [`choice`] : Colouring. Available Choices: [0] stretch to grid's standard deviation [1] stretch to grid's value range [2] stretch to specified value range [3] lookup table [4] rgb coded values Default: 0
-    - COL_PALETTE [`choice`] : Color Palette. Available Choices: [0] DEFAULT [1] DEFAULT_BRIGHT [2] BLACK_WHITE [3] BLACK_RED [4] BLACK_GREEN [5] BLACK_BLUE [6] WHITE_RED [7] WHITE_GREEN [8] WHITE_BLUE [9] YELLOW_RED [10] YELLOW_GREEN [11] YELLOW_BLUE [12] RED_GREEN [13] RED_BLUE [14] GREEN_BLUE [15] RED_GREY_BLUE [16] RED_GREY_GREEN [17] GREEN_GREY_BLUE [18] RED_GREEN_BLUE [19] RED_BLUE_GREEN [20] GREEN_RED_BLUE [21] RAINBOW [22] NEON [23] TOPOGRAPHY [24] ASPECT_1 [25] ASPECT_2 [26] ASPECT_3 Default: 0
+    - COLOURING [`choice`] : Colors. Available Choices: [0] stretch to grid's standard deviation [1] stretch to grid's value range [2] stretch to specified value range [3] lookup table [4] rgb coded values Default: 0
+    - COL_PALETTE [`choice`] : Color Ramp. Available Choices: [0] DEFAULT [1] DEFAULT_BRIGHT [2] BLACK_WHITE [3] BLACK_RED [4] BLACK_GREEN [5] BLACK_BLUE [6] WHITE_RED [7] WHITE_GREEN [8] WHITE_BLUE [9] YELLOW_RED [10] YELLOW_GREEN [11] YELLOW_BLUE [12] RED_GREEN [13] RED_BLUE [14] GREEN_BLUE [15] RED_GREY_BLUE [16] RED_GREY_GREEN [17] GREEN_GREY_BLUE [18] RED_GREEN_BLUE [19] RED_BLUE_GREEN [20] GREEN_RED_BLUE [21] RAINBOW [22] NEON [23] TOPOGRAPHY [24] ASPECT_1 [25] ASPECT_2 [26] ASPECT_3 Default: 0
     - COL_COUNT [`integer number`] : Number of Colors. Default: 100
-    - COL_REVERT [`boolean`] : Revert Palette. Default: 0
+    - COL_REVERT [`boolean`] : Invert Ramp. Default: 0
     - STDDEV [`floating point number`] : Standard Deviation. Minimum: 0.000000 Default: 2.000000
     - STRETCH [`value range`] : Stretch to Value Range
     - LUT [`static table`] : Lookup Table. 5 Fields: - 1. [color] Color - 2. [string] Name - 3. [string] Description - 4. [8 byte floating point number] Minimum - 5. [8 byte floating point number] Maximum 
@@ -298,7 +382,9 @@ def run_tool_io_grid_image_2(GRID=None, SHADE=None, FILE=None, FORMAT=None, COLO
         return Tool.Execute(Verbose)
     return False
 
-def Import_Grids_from_KML(GRIDS=None, FILE=None, Verbose=2):
+def Import_Grids_from_KML(
+    GRIDS=None,
+    FILE=None, Verbose=2):
     '''
     Import Grids from KML
     ----------
@@ -321,7 +407,9 @@ def Import_Grids_from_KML(GRIDS=None, FILE=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_grid_image_3(GRIDS=None, FILE=None, Verbose=2):
+def run_tool_io_grid_image_3(
+    GRIDS=None,
+    FILE=None, Verbose=2):
     '''
     Import Grids from KML
     ----------
@@ -344,7 +432,31 @@ def run_tool_io_grid_image_3(GRIDS=None, FILE=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Export_Animated_GIF_File(GRIDS=None, SHADE=None, FILE=None, DELAY=None, COLORS=None, FILE_WORLD=None, FILE_KML=None, NO_DATA=None, NO_DATA_COL=None, COLOURING=None, COL_COUNT=None, COL_REVERT=None, COL_PALETTE=None, GRADUATED=None, STDDEV=None, LINEAR=None, STRETCH=None, SCALE_MODE=None, SCALE_LOG=None, LUT=None, SHADE_TRANS=None, SHADE_COLOURING=None, SHADE_BRIGHT=None, SHADE_STDDEV=None, Verbose=2):
+def Export_Animated_GIF_File(
+    GRIDS=None,
+    SHADE=None,
+    FILE=None,
+    DELAY=None,
+    COLORS=None,
+    FILE_WORLD=None,
+    FILE_KML=None,
+    NO_DATA=None,
+    NO_DATA_COL=None,
+    COLOURING=None,
+    COL_COUNT=None,
+    COL_REVERT=None,
+    COL_PALETTE=None,
+    GRADUATED=None,
+    STDDEV=None,
+    LINEAR=None,
+    STRETCH=None,
+    SCALE_MODE=None,
+    SCALE_LOG=None,
+    LUT=None,
+    SHADE_TRANS=None,
+    SHADE_COLOURING=None,
+    SHADE_BRIGHT=None,
+    SHADE_STDDEV=None, Verbose=2):
     '''
     Export Animated GIF File
     ----------
@@ -412,7 +524,31 @@ def Export_Animated_GIF_File(GRIDS=None, SHADE=None, FILE=None, DELAY=None, COLO
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_grid_image_4(GRIDS=None, SHADE=None, FILE=None, DELAY=None, COLORS=None, FILE_WORLD=None, FILE_KML=None, NO_DATA=None, NO_DATA_COL=None, COLOURING=None, COL_COUNT=None, COL_REVERT=None, COL_PALETTE=None, GRADUATED=None, STDDEV=None, LINEAR=None, STRETCH=None, SCALE_MODE=None, SCALE_LOG=None, LUT=None, SHADE_TRANS=None, SHADE_COLOURING=None, SHADE_BRIGHT=None, SHADE_STDDEV=None, Verbose=2):
+def run_tool_io_grid_image_4(
+    GRIDS=None,
+    SHADE=None,
+    FILE=None,
+    DELAY=None,
+    COLORS=None,
+    FILE_WORLD=None,
+    FILE_KML=None,
+    NO_DATA=None,
+    NO_DATA_COL=None,
+    COLOURING=None,
+    COL_COUNT=None,
+    COL_REVERT=None,
+    COL_PALETTE=None,
+    GRADUATED=None,
+    STDDEV=None,
+    LINEAR=None,
+    STRETCH=None,
+    SCALE_MODE=None,
+    SCALE_LOG=None,
+    LUT=None,
+    SHADE_TRANS=None,
+    SHADE_COLOURING=None,
+    SHADE_BRIGHT=None,
+    SHADE_STDDEV=None, Verbose=2):
     '''
     Export Animated GIF File
     ----------
