@@ -14,7 +14,12 @@ Tools for the handling of virtual datasets.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Create_Virtual_Point_Cloud_Dataset(FILES=None, INPUT_FILE_LIST=None, FILENAME=None, METHOD_PATHS=None, USE_HEADER=None, Verbose=2):
+def Create_Virtual_Point_Cloud_Dataset(
+    FILES=None,
+    INPUT_FILE_LIST=None,
+    FILENAME=None,
+    METHOD_PATHS=None,
+    USE_HEADER=None, Verbose=2):
     '''
     Create Virtual Point Cloud Dataset
     ----------
@@ -45,7 +50,12 @@ def Create_Virtual_Point_Cloud_Dataset(FILES=None, INPUT_FILE_LIST=None, FILENAM
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_virtual_0(FILES=None, INPUT_FILE_LIST=None, FILENAME=None, METHOD_PATHS=None, USE_HEADER=None, Verbose=2):
+def run_tool_io_virtual_0(
+    FILES=None,
+    INPUT_FILE_LIST=None,
+    FILENAME=None,
+    METHOD_PATHS=None,
+    USE_HEADER=None, Verbose=2):
     '''
     Create Virtual Point Cloud Dataset
     ----------
@@ -76,7 +86,25 @@ def run_tool_io_virtual_0(FILES=None, INPUT_FILE_LIST=None, FILENAME=None, METHO
         return Tool.Execute(Verbose)
     return False
 
-def Get_Subset_from_Virtual_Point_Cloud(AOI_SHP=None, AOI_GRID=None, PC_OUT=None, FILENAME=None, FILEPATH=None, COPY_ATTR=None, ATTRIBUTE_LIST=None, CONSTRAIN_QUERY=None, ATTR_FIELD=None, VALUE_RANGE=None, FIELD_TILENAME=None, AOI_GRID_GRIDSYSTEM=None, AOI_XRANGE=None, AOI_YRANGE=None, AOI_ADD_OVERLAP=None, OVERLAP=None, FILENAME_TILE_INFO=None, ONE_PC_PER_POLYGON=None, Verbose=2):
+def Get_Subset_from_Virtual_Point_Cloud(
+    AOI_SHP=None,
+    AOI_GRID=None,
+    PC_OUT=None,
+    FILENAME=None,
+    FILEPATH=None,
+    COPY_ATTR=None,
+    ATTRIBUTE_LIST=None,
+    CONSTRAIN_QUERY=None,
+    ATTR_FIELD=None,
+    VALUE_RANGE=None,
+    FIELD_TILENAME=None,
+    AOI_GRID_GRIDSYSTEM=None,
+    AOI_XRANGE=None,
+    AOI_YRANGE=None,
+    AOI_ADD_OVERLAP=None,
+    OVERLAP=None,
+    FILENAME_TILE_INFO=None,
+    ONE_PC_PER_POLYGON=None, Verbose=2):
     '''
     Get Subset from Virtual Point Cloud
     ----------
@@ -138,7 +166,25 @@ def Get_Subset_from_Virtual_Point_Cloud(AOI_SHP=None, AOI_GRID=None, PC_OUT=None
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_virtual_1(AOI_SHP=None, AOI_GRID=None, PC_OUT=None, FILENAME=None, FILEPATH=None, COPY_ATTR=None, ATTRIBUTE_LIST=None, CONSTRAIN_QUERY=None, ATTR_FIELD=None, VALUE_RANGE=None, FIELD_TILENAME=None, AOI_GRID_GRIDSYSTEM=None, AOI_XRANGE=None, AOI_YRANGE=None, AOI_ADD_OVERLAP=None, OVERLAP=None, FILENAME_TILE_INFO=None, ONE_PC_PER_POLYGON=None, Verbose=2):
+def run_tool_io_virtual_1(
+    AOI_SHP=None,
+    AOI_GRID=None,
+    PC_OUT=None,
+    FILENAME=None,
+    FILEPATH=None,
+    COPY_ATTR=None,
+    ATTRIBUTE_LIST=None,
+    CONSTRAIN_QUERY=None,
+    ATTR_FIELD=None,
+    VALUE_RANGE=None,
+    FIELD_TILENAME=None,
+    AOI_GRID_GRIDSYSTEM=None,
+    AOI_XRANGE=None,
+    AOI_YRANGE=None,
+    AOI_ADD_OVERLAP=None,
+    OVERLAP=None,
+    FILENAME_TILE_INFO=None,
+    ONE_PC_PER_POLYGON=None, Verbose=2):
     '''
     Get Subset from Virtual Point Cloud
     ----------
@@ -200,7 +246,9 @@ def run_tool_io_virtual_1(AOI_SHP=None, AOI_GRID=None, PC_OUT=None, FILENAME=Non
         return Tool.Execute(Verbose)
     return False
 
-def Create_Tileshape_from_Virtual_Point_Cloud(TILE_SHP=None, FILENAME=None, Verbose=2):
+def Create_Tileshape_from_Virtual_Point_Cloud(
+    TILE_SHP=None,
+    FILENAME=None, Verbose=2):
     '''
     Create Tileshape from Virtual Point Cloud
     ----------
@@ -224,7 +272,9 @@ def Create_Tileshape_from_Virtual_Point_Cloud(TILE_SHP=None, FILENAME=None, Verb
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_virtual_2(TILE_SHP=None, FILENAME=None, Verbose=2):
+def run_tool_io_virtual_2(
+    TILE_SHP=None,
+    FILENAME=None, Verbose=2):
     '''
     Create Tileshape from Virtual Point Cloud
     ----------
@@ -248,7 +298,25 @@ def run_tool_io_virtual_2(TILE_SHP=None, FILENAME=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Get_Grid_from_Virtual_Point_Cloud(AOI_SHP=None, AOI_GRID=None, GRID_OUT=None, FILENAME=None, FILEPATH=None, ATTR_FIELD_GRID=None, CELL_SIZE=None, GRID_SYSTEM_FIT=None, METHOD=None, CONSTRAIN_QUERY=None, ATTR_FIELD=None, VALUE_RANGE=None, FIELD_TILENAME=None, AOI_GRID_GRIDSYSTEM=None, AOI_XRANGE=None, AOI_YRANGE=None, AOI_ADD_OVERLAP=None, OVERLAP=None, Verbose=2):
+def Get_Grid_from_Virtual_Point_Cloud(
+    AOI_SHP=None,
+    AOI_GRID=None,
+    GRID_OUT=None,
+    FILENAME=None,
+    FILEPATH=None,
+    ATTR_FIELD_GRID=None,
+    CELL_SIZE=None,
+    GRID_SYSTEM_FIT=None,
+    METHOD=None,
+    CONSTRAIN_QUERY=None,
+    ATTR_FIELD=None,
+    VALUE_RANGE=None,
+    FIELD_TILENAME=None,
+    AOI_GRID_GRIDSYSTEM=None,
+    AOI_XRANGE=None,
+    AOI_YRANGE=None,
+    AOI_ADD_OVERLAP=None,
+    OVERLAP=None, Verbose=2):
     '''
     Get Grid from Virtual Point Cloud
     ----------
@@ -309,7 +377,25 @@ def Get_Grid_from_Virtual_Point_Cloud(AOI_SHP=None, AOI_GRID=None, GRID_OUT=None
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_virtual_4(AOI_SHP=None, AOI_GRID=None, GRID_OUT=None, FILENAME=None, FILEPATH=None, ATTR_FIELD_GRID=None, CELL_SIZE=None, GRID_SYSTEM_FIT=None, METHOD=None, CONSTRAIN_QUERY=None, ATTR_FIELD=None, VALUE_RANGE=None, FIELD_TILENAME=None, AOI_GRID_GRIDSYSTEM=None, AOI_XRANGE=None, AOI_YRANGE=None, AOI_ADD_OVERLAP=None, OVERLAP=None, Verbose=2):
+def run_tool_io_virtual_4(
+    AOI_SHP=None,
+    AOI_GRID=None,
+    GRID_OUT=None,
+    FILENAME=None,
+    FILEPATH=None,
+    ATTR_FIELD_GRID=None,
+    CELL_SIZE=None,
+    GRID_SYSTEM_FIT=None,
+    METHOD=None,
+    CONSTRAIN_QUERY=None,
+    ATTR_FIELD=None,
+    VALUE_RANGE=None,
+    FIELD_TILENAME=None,
+    AOI_GRID_GRIDSYSTEM=None,
+    AOI_XRANGE=None,
+    AOI_YRANGE=None,
+    AOI_ADD_OVERLAP=None,
+    OVERLAP=None, Verbose=2):
     '''
     Get Grid from Virtual Point Cloud
     ----------
@@ -370,7 +456,9 @@ def run_tool_io_virtual_4(AOI_SHP=None, AOI_GRID=None, GRID_OUT=None, FILENAME=N
         return Tool.Execute(Verbose)
     return False
 
-def Remove_Overlap_from_Virtual_Point_Cloud_Tiles(FILENAME=None, FILEPATH=None, Verbose=2):
+def Remove_Overlap_from_Virtual_Point_Cloud_Tiles(
+    FILENAME=None,
+    FILEPATH=None, Verbose=2):
     '''
     Remove Overlap from Virtual Point Cloud Tiles
     ----------
@@ -394,7 +482,9 @@ def Remove_Overlap_from_Virtual_Point_Cloud_Tiles(FILENAME=None, FILEPATH=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_io_virtual_6(FILENAME=None, FILEPATH=None, Verbose=2):
+def run_tool_io_virtual_6(
+    FILENAME=None,
+    FILEPATH=None, Verbose=2):
     '''
     Remove Overlap from Virtual Point Cloud Tiles
     ----------
