@@ -14,7 +14,31 @@ Tools for the georeferencing of spatial data.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Rectify_Grid(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARGET_TEMPLATE=None, TARGET_GRID=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, RESAMPLING=None, BYTEWISE=None, DATA_TYPE=None, CRS_STRING=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def Rectify_Grid(
+    REF_SOURCE=None,
+    GRID=None,
+    REF_TARGET=None,
+    TARGET_TEMPLATE=None,
+    TARGET_GRID=None,
+    XFIELD=None,
+    YFIELD=None,
+    METHOD=None,
+    ORDER=None,
+    RESAMPLING=None,
+    BYTEWISE=None,
+    DATA_TYPE=None,
+    CRS_STRING=None,
+    TARGET_DEFINITION=None,
+    TARGET_USER_SIZE=None,
+    TARGET_USER_XMIN=None,
+    TARGET_USER_XMAX=None,
+    TARGET_USER_YMIN=None,
+    TARGET_USER_YMAX=None,
+    TARGET_USER_COLS=None,
+    TARGET_USER_ROWS=None,
+    TARGET_USER_FLAT=None,
+    TARGET_USER_FITS=None,
+    TARGET_SYSTEM=None, Verbose=2):
     '''
     Rectify Grid
     ----------
@@ -81,7 +105,31 @@ def Rectify_Grid(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARGET_TEMPLATE=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_pj_georeference_1(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARGET_TEMPLATE=None, TARGET_GRID=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, RESAMPLING=None, BYTEWISE=None, DATA_TYPE=None, CRS_STRING=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def run_tool_pj_georeference_1(
+    REF_SOURCE=None,
+    GRID=None,
+    REF_TARGET=None,
+    TARGET_TEMPLATE=None,
+    TARGET_GRID=None,
+    XFIELD=None,
+    YFIELD=None,
+    METHOD=None,
+    ORDER=None,
+    RESAMPLING=None,
+    BYTEWISE=None,
+    DATA_TYPE=None,
+    CRS_STRING=None,
+    TARGET_DEFINITION=None,
+    TARGET_USER_SIZE=None,
+    TARGET_USER_XMIN=None,
+    TARGET_USER_XMAX=None,
+    TARGET_USER_YMIN=None,
+    TARGET_USER_YMAX=None,
+    TARGET_USER_COLS=None,
+    TARGET_USER_ROWS=None,
+    TARGET_USER_FLAT=None,
+    TARGET_USER_FITS=None,
+    TARGET_SYSTEM=None, Verbose=2):
     '''
     Rectify Grid
     ----------
@@ -148,7 +196,15 @@ def run_tool_pj_georeference_1(REF_SOURCE=None, GRID=None, REF_TARGET=None, TARG
         return Tool.Execute(Verbose)
     return False
 
-def Warping_Shapes(REF_SOURCE=None, INPUT=None, REF_TARGET=None, OUTPUT=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, Verbose=2):
+def Warping_Shapes(
+    REF_SOURCE=None,
+    INPUT=None,
+    REF_TARGET=None,
+    OUTPUT=None,
+    XFIELD=None,
+    YFIELD=None,
+    METHOD=None,
+    ORDER=None, Verbose=2):
     '''
     Warping Shapes
     ----------
@@ -183,7 +239,15 @@ def Warping_Shapes(REF_SOURCE=None, INPUT=None, REF_TARGET=None, OUTPUT=None, XF
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_pj_georeference_2(REF_SOURCE=None, INPUT=None, REF_TARGET=None, OUTPUT=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, Verbose=2):
+def run_tool_pj_georeference_2(
+    REF_SOURCE=None,
+    INPUT=None,
+    REF_TARGET=None,
+    OUTPUT=None,
+    XFIELD=None,
+    YFIELD=None,
+    METHOD=None,
+    ORDER=None, Verbose=2):
     '''
     Warping Shapes
     ----------
@@ -218,7 +282,38 @@ def run_tool_pj_georeference_2(REF_SOURCE=None, INPUT=None, REF_TARGET=None, OUT
         return Tool.Execute(Verbose)
     return False
 
-def Direct_Georeferencing_of_Airborne_Photographs(INPUT=None, DEM=None, TARGET_TEMPLATE=None, OUTPUT=None, EXTENT=None, DEM_GRIDSYSTEM=None, DEM_DEFAULT=None, CFL=None, PXSIZE=None, X=None, Y=None, Z=None, OMEGA=None, PHI=None, KAPPA=None, KAPPA_OFF=None, ORIENTATION=None, ROW_ORDER=None, RESAMPLING=None, DATA_TYPE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def Direct_Georeferencing_of_Airborne_Photographs(
+    INPUT=None,
+    DEM=None,
+    TARGET_TEMPLATE=None,
+    OUTPUT=None,
+    EXTENT=None,
+    DEM_GRIDSYSTEM=None,
+    DEM_DEFAULT=None,
+    CFL=None,
+    PXSIZE=None,
+    X=None,
+    Y=None,
+    Z=None,
+    OMEGA=None,
+    PHI=None,
+    KAPPA=None,
+    KAPPA_OFF=None,
+    ORIENTATION=None,
+    ROW_ORDER=None,
+    RESAMPLING=None,
+    DATA_TYPE=None,
+    TARGET_DEFINITION=None,
+    TARGET_USER_SIZE=None,
+    TARGET_USER_XMIN=None,
+    TARGET_USER_XMAX=None,
+    TARGET_USER_YMIN=None,
+    TARGET_USER_YMAX=None,
+    TARGET_USER_COLS=None,
+    TARGET_USER_ROWS=None,
+    TARGET_USER_FLAT=None,
+    TARGET_USER_FITS=None,
+    TARGET_SYSTEM=None, Verbose=2):
     '''
     Direct Georeferencing of Airborne Photographs
     ----------
@@ -299,7 +394,38 @@ def Direct_Georeferencing_of_Airborne_Photographs(INPUT=None, DEM=None, TARGET_T
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_pj_georeference_4(INPUT=None, DEM=None, TARGET_TEMPLATE=None, OUTPUT=None, EXTENT=None, DEM_GRIDSYSTEM=None, DEM_DEFAULT=None, CFL=None, PXSIZE=None, X=None, Y=None, Z=None, OMEGA=None, PHI=None, KAPPA=None, KAPPA_OFF=None, ORIENTATION=None, ROW_ORDER=None, RESAMPLING=None, DATA_TYPE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def run_tool_pj_georeference_4(
+    INPUT=None,
+    DEM=None,
+    TARGET_TEMPLATE=None,
+    OUTPUT=None,
+    EXTENT=None,
+    DEM_GRIDSYSTEM=None,
+    DEM_DEFAULT=None,
+    CFL=None,
+    PXSIZE=None,
+    X=None,
+    Y=None,
+    Z=None,
+    OMEGA=None,
+    PHI=None,
+    KAPPA=None,
+    KAPPA_OFF=None,
+    ORIENTATION=None,
+    ROW_ORDER=None,
+    RESAMPLING=None,
+    DATA_TYPE=None,
+    TARGET_DEFINITION=None,
+    TARGET_USER_SIZE=None,
+    TARGET_USER_XMIN=None,
+    TARGET_USER_XMAX=None,
+    TARGET_USER_YMIN=None,
+    TARGET_USER_YMAX=None,
+    TARGET_USER_COLS=None,
+    TARGET_USER_ROWS=None,
+    TARGET_USER_FLAT=None,
+    TARGET_USER_FITS=None,
+    TARGET_SYSTEM=None, Verbose=2):
     '''
     Direct Georeferencing of Airborne Photographs
     ----------
@@ -380,7 +506,17 @@ def run_tool_pj_georeference_4(INPUT=None, DEM=None, TARGET_TEMPLATE=None, OUTPU
         return Tool.Execute(Verbose)
     return False
 
-def Define_Georeference_for_Grids(GRIDS=None, REFERENCED=None, DEFINITION=None, SYSTEM=None, SIZE=None, XMIN=None, XMAX=None, YMIN=None, YMAX=None, CELL_REF=None, Verbose=2):
+def Define_Georeference_for_Grids(
+    GRIDS=None,
+    REFERENCED=None,
+    DEFINITION=None,
+    SYSTEM=None,
+    SIZE=None,
+    XMIN=None,
+    XMAX=None,
+    YMIN=None,
+    YMAX=None,
+    CELL_REF=None, Verbose=2):
     '''
     Define Georeference for Grids
     ----------
@@ -419,7 +555,17 @@ def Define_Georeference_for_Grids(GRIDS=None, REFERENCED=None, DEFINITION=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_pj_georeference_5(GRIDS=None, REFERENCED=None, DEFINITION=None, SYSTEM=None, SIZE=None, XMIN=None, XMAX=None, YMIN=None, YMAX=None, CELL_REF=None, Verbose=2):
+def run_tool_pj_georeference_5(
+    GRIDS=None,
+    REFERENCED=None,
+    DEFINITION=None,
+    SYSTEM=None,
+    SIZE=None,
+    XMIN=None,
+    XMAX=None,
+    YMIN=None,
+    YMAX=None,
+    CELL_REF=None, Verbose=2):
     '''
     Define Georeference for Grids
     ----------
@@ -458,7 +604,21 @@ def run_tool_pj_georeference_5(GRIDS=None, REFERENCED=None, DEFINITION=None, SYS
         return Tool.Execute(Verbose)
     return False
 
-def World_File_from_Flight_and_Camera_Settings(EXTENT=None, FILE=None, NX=None, NY=None, CFL=None, PXSIZE=None, X=None, Y=None, Z=None, OMEGA=None, PHI=None, KAPPA=None, KAPPA_OFF=None, ORIENTATION=None, Verbose=2):
+def World_File_from_Flight_and_Camera_Settings(
+    EXTENT=None,
+    FILE=None,
+    NX=None,
+    NY=None,
+    CFL=None,
+    PXSIZE=None,
+    X=None,
+    Y=None,
+    Z=None,
+    OMEGA=None,
+    PHI=None,
+    KAPPA=None,
+    KAPPA_OFF=None,
+    ORIENTATION=None, Verbose=2):
     '''
     World File from Flight and Camera Settings
     ----------
@@ -505,7 +665,21 @@ def World_File_from_Flight_and_Camera_Settings(EXTENT=None, FILE=None, NX=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_pj_georeference_6(EXTENT=None, FILE=None, NX=None, NY=None, CFL=None, PXSIZE=None, X=None, Y=None, Z=None, OMEGA=None, PHI=None, KAPPA=None, KAPPA_OFF=None, ORIENTATION=None, Verbose=2):
+def run_tool_pj_georeference_6(
+    EXTENT=None,
+    FILE=None,
+    NX=None,
+    NY=None,
+    CFL=None,
+    PXSIZE=None,
+    X=None,
+    Y=None,
+    Z=None,
+    OMEGA=None,
+    PHI=None,
+    KAPPA=None,
+    KAPPA_OFF=None,
+    ORIENTATION=None, Verbose=2):
     '''
     World File from Flight and Camera Settings
     ----------
@@ -552,7 +726,26 @@ def run_tool_pj_georeference_6(EXTENT=None, FILE=None, NX=None, NY=None, CFL=Non
         return Tool.Execute(Verbose)
     return False
 
-def Georeference_with_Coordinate_Grids(GRID_X=None, GRID_Y=None, GRIDS=None, TARGET_TEMPLATE=None, OUTPUT=None, RESAMPLING=None, BYTEWISE=None, KEEP_TYPE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def Georeference_with_Coordinate_Grids(
+    GRID_X=None,
+    GRID_Y=None,
+    GRIDS=None,
+    TARGET_TEMPLATE=None,
+    OUTPUT=None,
+    RESAMPLING=None,
+    BYTEWISE=None,
+    KEEP_TYPE=None,
+    TARGET_DEFINITION=None,
+    TARGET_USER_SIZE=None,
+    TARGET_USER_XMIN=None,
+    TARGET_USER_XMAX=None,
+    TARGET_USER_YMIN=None,
+    TARGET_USER_YMAX=None,
+    TARGET_USER_COLS=None,
+    TARGET_USER_ROWS=None,
+    TARGET_USER_FLAT=None,
+    TARGET_USER_FITS=None,
+    TARGET_SYSTEM=None, Verbose=2):
     '''
     Georeference with Coordinate Grids
     ----------
@@ -609,7 +802,26 @@ def Georeference_with_Coordinate_Grids(GRID_X=None, GRID_Y=None, GRIDS=None, TAR
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_pj_georeference_7(GRID_X=None, GRID_Y=None, GRIDS=None, TARGET_TEMPLATE=None, OUTPUT=None, RESAMPLING=None, BYTEWISE=None, KEEP_TYPE=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def run_tool_pj_georeference_7(
+    GRID_X=None,
+    GRID_Y=None,
+    GRIDS=None,
+    TARGET_TEMPLATE=None,
+    OUTPUT=None,
+    RESAMPLING=None,
+    BYTEWISE=None,
+    KEEP_TYPE=None,
+    TARGET_DEFINITION=None,
+    TARGET_USER_SIZE=None,
+    TARGET_USER_XMIN=None,
+    TARGET_USER_XMAX=None,
+    TARGET_USER_YMIN=None,
+    TARGET_USER_YMAX=None,
+    TARGET_USER_COLS=None,
+    TARGET_USER_ROWS=None,
+    TARGET_USER_FLAT=None,
+    TARGET_USER_FITS=None,
+    TARGET_SYSTEM=None, Verbose=2):
     '''
     Georeference with Coordinate Grids
     ----------
@@ -666,7 +878,31 @@ def run_tool_pj_georeference_7(GRID_X=None, GRID_Y=None, GRIDS=None, TARGET_TEMP
         return Tool.Execute(Verbose)
     return False
 
-def Rectify_Grid_List(REF_SOURCE=None, GRIDS=None, REF_TARGET=None, TARGET_TEMPLATE=None, TARGET_GRIDS=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, RESAMPLING=None, BYTEWISE=None, DATA_TYPE=None, CRS_STRING=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def Rectify_Grid_List(
+    REF_SOURCE=None,
+    GRIDS=None,
+    REF_TARGET=None,
+    TARGET_TEMPLATE=None,
+    TARGET_GRIDS=None,
+    XFIELD=None,
+    YFIELD=None,
+    METHOD=None,
+    ORDER=None,
+    RESAMPLING=None,
+    BYTEWISE=None,
+    DATA_TYPE=None,
+    CRS_STRING=None,
+    TARGET_DEFINITION=None,
+    TARGET_USER_SIZE=None,
+    TARGET_USER_XMIN=None,
+    TARGET_USER_XMAX=None,
+    TARGET_USER_YMIN=None,
+    TARGET_USER_YMAX=None,
+    TARGET_USER_COLS=None,
+    TARGET_USER_ROWS=None,
+    TARGET_USER_FLAT=None,
+    TARGET_USER_FITS=None,
+    TARGET_SYSTEM=None, Verbose=2):
     '''
     Rectify Grid List
     ----------
@@ -733,7 +969,31 @@ def Rectify_Grid_List(REF_SOURCE=None, GRIDS=None, REF_TARGET=None, TARGET_TEMPL
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_pj_georeference_10(REF_SOURCE=None, GRIDS=None, REF_TARGET=None, TARGET_TEMPLATE=None, TARGET_GRIDS=None, XFIELD=None, YFIELD=None, METHOD=None, ORDER=None, RESAMPLING=None, BYTEWISE=None, DATA_TYPE=None, CRS_STRING=None, TARGET_DEFINITION=None, TARGET_USER_SIZE=None, TARGET_USER_XMIN=None, TARGET_USER_XMAX=None, TARGET_USER_YMIN=None, TARGET_USER_YMAX=None, TARGET_USER_COLS=None, TARGET_USER_ROWS=None, TARGET_USER_FLAT=None, TARGET_USER_FITS=None, TARGET_SYSTEM=None, Verbose=2):
+def run_tool_pj_georeference_10(
+    REF_SOURCE=None,
+    GRIDS=None,
+    REF_TARGET=None,
+    TARGET_TEMPLATE=None,
+    TARGET_GRIDS=None,
+    XFIELD=None,
+    YFIELD=None,
+    METHOD=None,
+    ORDER=None,
+    RESAMPLING=None,
+    BYTEWISE=None,
+    DATA_TYPE=None,
+    CRS_STRING=None,
+    TARGET_DEFINITION=None,
+    TARGET_USER_SIZE=None,
+    TARGET_USER_XMIN=None,
+    TARGET_USER_XMAX=None,
+    TARGET_USER_YMIN=None,
+    TARGET_USER_YMAX=None,
+    TARGET_USER_COLS=None,
+    TARGET_USER_ROWS=None,
+    TARGET_USER_FLAT=None,
+    TARGET_USER_FITS=None,
+    TARGET_SYSTEM=None, Verbose=2):
     '''
     Rectify Grid List
     ----------
