@@ -14,7 +14,11 @@ Tools for polygons.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Polygon_Centroids(POLYGONS=None, CENTROIDS=None, METHOD=None, INSIDE=None, Verbose=2):
+def Polygon_Centroids(
+    POLYGONS=None,
+    CENTROIDS=None,
+    METHOD=None,
+    INSIDE=None, Verbose=2):
     '''
     Polygon Centroids
     ----------
@@ -41,7 +45,11 @@ def Polygon_Centroids(POLYGONS=None, CENTROIDS=None, METHOD=None, INSIDE=None, V
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_1(POLYGONS=None, CENTROIDS=None, METHOD=None, INSIDE=None, Verbose=2):
+def run_tool_shapes_polygons_1(
+    POLYGONS=None,
+    CENTROIDS=None,
+    METHOD=None,
+    INSIDE=None, Verbose=2):
     '''
     Polygon Centroids
     ----------
@@ -68,7 +76,17 @@ def run_tool_shapes_polygons_1(POLYGONS=None, CENTROIDS=None, METHOD=None, INSID
         return Tool.Execute(Verbose)
     return False
 
-def Polygon_Properties(POLYGONS=None, OUTPUT=None, FIELDS=None, BPARTS=None, BPOINTS=None, BEXTENT=None, BCENTER=None, BLENGTH=None, BAREA=None, SCALING=None, Verbose=2):
+def Polygon_Properties(
+    POLYGONS=None,
+    OUTPUT=None,
+    FIELDS=None,
+    BPARTS=None,
+    BPOINTS=None,
+    BEXTENT=None,
+    BCENTER=None,
+    BLENGTH=None,
+    BAREA=None,
+    SCALING=None, Verbose=2):
     '''
     Polygon Properties
     ----------
@@ -107,7 +125,17 @@ def Polygon_Properties(POLYGONS=None, OUTPUT=None, FIELDS=None, BPARTS=None, BPO
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_2(POLYGONS=None, OUTPUT=None, FIELDS=None, BPARTS=None, BPOINTS=None, BEXTENT=None, BCENTER=None, BLENGTH=None, BAREA=None, SCALING=None, Verbose=2):
+def run_tool_shapes_polygons_2(
+    POLYGONS=None,
+    OUTPUT=None,
+    FIELDS=None,
+    BPARTS=None,
+    BPOINTS=None,
+    BEXTENT=None,
+    BCENTER=None,
+    BLENGTH=None,
+    BAREA=None,
+    SCALING=None, Verbose=2):
     '''
     Polygon Properties
     ----------
@@ -146,7 +174,13 @@ def run_tool_shapes_polygons_2(POLYGONS=None, OUTPUT=None, FIELDS=None, BPARTS=N
         return Tool.Execute(Verbose)
     return False
 
-def Convert_Lines_to_Polygons(LINES=None, POLYGONS=None, RINGS=None, SINGLE=None, MERGE=None, SPLIT=None, Verbose=2):
+def Convert_Lines_to_Polygons(
+    LINES=None,
+    POLYGONS=None,
+    RINGS=None,
+    SINGLE=None,
+    MERGE=None,
+    SPLIT=None, Verbose=2):
     '''
     Convert Lines to Polygons
     ----------
@@ -177,7 +211,13 @@ def Convert_Lines_to_Polygons(LINES=None, POLYGONS=None, RINGS=None, SINGLE=None
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_3(LINES=None, POLYGONS=None, RINGS=None, SINGLE=None, MERGE=None, SPLIT=None, Verbose=2):
+def run_tool_shapes_polygons_3(
+    LINES=None,
+    POLYGONS=None,
+    RINGS=None,
+    SINGLE=None,
+    MERGE=None,
+    SPLIT=None, Verbose=2):
     '''
     Convert Lines to Polygons
     ----------
@@ -208,7 +248,19 @@ def run_tool_shapes_polygons_3(LINES=None, POLYGONS=None, RINGS=None, SINGLE=Non
         return Tool.Execute(Verbose)
     return False
 
-def Point_Statistics_for_Polygons(POINTS=None, POLYGONS=None, STATISTICS=None, FIELDS=None, SUM=None, AVG=None, VAR=None, DEV=None, MIN=None, MAX=None, NUM=None, FIELD_NAME=None, Verbose=2):
+def Point_Statistics_for_Polygons(
+    POINTS=None,
+    POLYGONS=None,
+    STATISTICS=None,
+    FIELDS=None,
+    SUM=None,
+    AVG=None,
+    VAR=None,
+    DEV=None,
+    MIN=None,
+    MAX=None,
+    NUM=None,
+    FIELD_NAME=None, Verbose=2):
     '''
     Point Statistics for Polygons
     ----------
@@ -251,7 +303,19 @@ def Point_Statistics_for_Polygons(POINTS=None, POLYGONS=None, STATISTICS=None, F
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_4(POINTS=None, POLYGONS=None, STATISTICS=None, FIELDS=None, SUM=None, AVG=None, VAR=None, DEV=None, MIN=None, MAX=None, NUM=None, FIELD_NAME=None, Verbose=2):
+def run_tool_shapes_polygons_4(
+    POINTS=None,
+    POLYGONS=None,
+    STATISTICS=None,
+    FIELDS=None,
+    SUM=None,
+    AVG=None,
+    VAR=None,
+    DEV=None,
+    MIN=None,
+    MAX=None,
+    NUM=None,
+    FIELD_NAME=None, Verbose=2):
     '''
     Point Statistics for Polygons
     ----------
@@ -294,7 +358,24 @@ def run_tool_shapes_polygons_4(POINTS=None, POLYGONS=None, STATISTICS=None, FIEL
         return Tool.Execute(Verbose)
     return False
 
-def Polygon_Dissolve(POLYGONS=None, DISSOLVED=None, FIELDS=None, STATISTICS=None, STAT_SUM=None, STAT_AVG=None, STAT_MIN=None, STAT_MAX=None, STAT_RNG=None, STAT_DEV=None, STAT_VAR=None, STAT_LST=None, STAT_NUM=None, STAT_NAMING=None, BND_KEEP=None, MIN_AREA=None, SPLIT_DISTINCT=None, Verbose=2):
+def Polygon_Dissolve(
+    POLYGONS=None,
+    DISSOLVED=None,
+    FIELDS=None,
+    STATISTICS=None,
+    STAT_SUM=None,
+    STAT_AVG=None,
+    STAT_MIN=None,
+    STAT_MAX=None,
+    STAT_RNG=None,
+    STAT_DEV=None,
+    STAT_VAR=None,
+    STAT_LST=None,
+    STAT_NUM=None,
+    STAT_NAMING=None,
+    BND_KEEP=None,
+    MIN_AREA=None,
+    SPLIT_DISTINCT=None, Verbose=2):
     '''
     Polygon Dissolve
     ----------
@@ -347,7 +428,24 @@ def Polygon_Dissolve(POLYGONS=None, DISSOLVED=None, FIELDS=None, STATISTICS=None
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_5(POLYGONS=None, DISSOLVED=None, FIELDS=None, STATISTICS=None, STAT_SUM=None, STAT_AVG=None, STAT_MIN=None, STAT_MAX=None, STAT_RNG=None, STAT_DEV=None, STAT_VAR=None, STAT_LST=None, STAT_NUM=None, STAT_NAMING=None, BND_KEEP=None, MIN_AREA=None, SPLIT_DISTINCT=None, Verbose=2):
+def run_tool_shapes_polygons_5(
+    POLYGONS=None,
+    DISSOLVED=None,
+    FIELDS=None,
+    STATISTICS=None,
+    STAT_SUM=None,
+    STAT_AVG=None,
+    STAT_MIN=None,
+    STAT_MAX=None,
+    STAT_RNG=None,
+    STAT_DEV=None,
+    STAT_VAR=None,
+    STAT_LST=None,
+    STAT_NUM=None,
+    STAT_NAMING=None,
+    BND_KEEP=None,
+    MIN_AREA=None,
+    SPLIT_DISTINCT=None, Verbose=2):
     '''
     Polygon Dissolve
     ----------
@@ -400,7 +498,9 @@ def run_tool_shapes_polygons_5(POLYGONS=None, DISSOLVED=None, FIELDS=None, STATI
         return Tool.Execute(Verbose)
     return False
 
-def Convert_PolygonLine_Vertices_to_Points(SHAPES=None, POINTS=None, Verbose=2):
+def Convert_PolygonLine_Vertices_to_Points(
+    SHAPES=None,
+    POINTS=None, Verbose=2):
     '''
     Convert Polygon/Line Vertices to Points
     ----------
@@ -423,7 +523,9 @@ def Convert_PolygonLine_Vertices_to_Points(SHAPES=None, POINTS=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_6(SHAPES=None, POINTS=None, Verbose=2):
+def run_tool_shapes_polygons_6(
+    SHAPES=None,
+    POINTS=None, Verbose=2):
     '''
     Convert Polygon/Line Vertices to Points
     ----------
@@ -446,7 +548,13 @@ def run_tool_shapes_polygons_6(SHAPES=None, POINTS=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Polygon_Shape_Indices(SHAPES=None, INDEX=None, DMAX=None, GYROS=None, FERET=None, FERET_DIRS=None, Verbose=2):
+def Polygon_Shape_Indices(
+    SHAPES=None,
+    INDEX=None,
+    DMAX=None,
+    GYROS=None,
+    FERET=None,
+    FERET_DIRS=None, Verbose=2):
     '''
     Polygon Shape Indices
     ----------
@@ -497,7 +605,13 @@ def Polygon_Shape_Indices(SHAPES=None, INDEX=None, DMAX=None, GYROS=None, FERET=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_7(SHAPES=None, INDEX=None, DMAX=None, GYROS=None, FERET=None, FERET_DIRS=None, Verbose=2):
+def run_tool_shapes_polygons_7(
+    SHAPES=None,
+    INDEX=None,
+    DMAX=None,
+    GYROS=None,
+    FERET=None,
+    FERET_DIRS=None, Verbose=2):
     '''
     Polygon Shape Indices
     ----------
@@ -548,7 +662,12 @@ def run_tool_shapes_polygons_7(SHAPES=None, INDEX=None, DMAX=None, GYROS=None, F
         return Tool.Execute(Verbose)
     return False
 
-def PolygonLine_Intersection(POLYGONS=None, LINES=None, INTERSECT=None, SPLIT_PARTS=None, METHOD=None, Verbose=2):
+def PolygonLine_Intersection(
+    POLYGONS=None,
+    LINES=None,
+    INTERSECT=None,
+    SPLIT_PARTS=None,
+    METHOD=None, Verbose=2):
     '''
     Polygon-Line Intersection
     ----------
@@ -577,7 +696,12 @@ def PolygonLine_Intersection(POLYGONS=None, LINES=None, INTERSECT=None, SPLIT_PA
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_8(POLYGONS=None, LINES=None, INTERSECT=None, SPLIT_PARTS=None, METHOD=None, Verbose=2):
+def run_tool_shapes_polygons_8(
+    POLYGONS=None,
+    LINES=None,
+    INTERSECT=None,
+    SPLIT_PARTS=None,
+    METHOD=None, Verbose=2):
     '''
     Polygon-Line Intersection
     ----------
@@ -606,7 +730,10 @@ def run_tool_shapes_polygons_8(POLYGONS=None, LINES=None, INTERSECT=None, SPLIT_
         return Tool.Execute(Verbose)
     return False
 
-def Polygons_to_Edges_and_Nodes(POLYGONS=None, EDGES=None, NODES=None, Verbose=2):
+def Polygons_to_Edges_and_Nodes(
+    POLYGONS=None,
+    EDGES=None,
+    NODES=None, Verbose=2):
     '''
     Polygons to Edges and Nodes
     ----------
@@ -631,7 +758,10 @@ def Polygons_to_Edges_and_Nodes(POLYGONS=None, EDGES=None, NODES=None, Verbose=2
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_9(POLYGONS=None, EDGES=None, NODES=None, Verbose=2):
+def run_tool_shapes_polygons_9(
+    POLYGONS=None,
+    EDGES=None,
+    NODES=None, Verbose=2):
     '''
     Polygons to Edges and Nodes
     ----------
@@ -656,7 +786,10 @@ def run_tool_shapes_polygons_9(POLYGONS=None, EDGES=None, NODES=None, Verbose=2)
         return Tool.Execute(Verbose)
     return False
 
-def Polygon_Parts_to_Separate_Polygons(POLYGONS=None, PARTS=None, LAKES=None, Verbose=2):
+def Polygon_Parts_to_Separate_Polygons(
+    POLYGONS=None,
+    PARTS=None,
+    LAKES=None, Verbose=2):
     '''
     Polygon Parts to Separate Polygons
     ----------
@@ -681,7 +814,10 @@ def Polygon_Parts_to_Separate_Polygons(POLYGONS=None, PARTS=None, LAKES=None, Ve
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_10(POLYGONS=None, PARTS=None, LAKES=None, Verbose=2):
+def run_tool_shapes_polygons_10(
+    POLYGONS=None,
+    PARTS=None,
+    LAKES=None, Verbose=2):
     '''
     Polygon Parts to Separate Polygons
     ----------
@@ -706,7 +842,14 @@ def run_tool_shapes_polygons_10(POLYGONS=None, PARTS=None, LAKES=None, Verbose=2
         return Tool.Execute(Verbose)
     return False
 
-def Polygon_Clipping(CLIP=None, S_INPUT=None, M_INPUT=None, S_OUTPUT=None, M_OUTPUT=None, DISSOLVE=None, MULTIPLE=None, Verbose=2):
+def Polygon_Clipping(
+    CLIP=None,
+    S_INPUT=None,
+    M_INPUT=None,
+    S_OUTPUT=None,
+    M_OUTPUT=None,
+    DISSOLVE=None,
+    MULTIPLE=None, Verbose=2):
     '''
     Polygon Clipping
     ----------
@@ -740,7 +883,14 @@ def Polygon_Clipping(CLIP=None, S_INPUT=None, M_INPUT=None, S_OUTPUT=None, M_OUT
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_11(CLIP=None, S_INPUT=None, M_INPUT=None, S_OUTPUT=None, M_OUTPUT=None, DISSOLVE=None, MULTIPLE=None, Verbose=2):
+def run_tool_shapes_polygons_11(
+    CLIP=None,
+    S_INPUT=None,
+    M_INPUT=None,
+    S_OUTPUT=None,
+    M_OUTPUT=None,
+    DISSOLVE=None,
+    MULTIPLE=None, Verbose=2):
     '''
     Polygon Clipping
     ----------
@@ -774,7 +924,10 @@ def run_tool_shapes_polygons_11(CLIP=None, S_INPUT=None, M_INPUT=None, S_OUTPUT=
         return Tool.Execute(Verbose)
     return False
 
-def Polygon_SelfIntersection(POLYGONS=None, INTERSECT=None, ID=None, Verbose=2):
+def Polygon_SelfIntersection(
+    POLYGONS=None,
+    INTERSECT=None,
+    ID=None, Verbose=2):
     '''
     Polygon Self-Intersection
     ----------
@@ -802,7 +955,10 @@ def Polygon_SelfIntersection(POLYGONS=None, INTERSECT=None, ID=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_12(POLYGONS=None, INTERSECT=None, ID=None, Verbose=2):
+def run_tool_shapes_polygons_12(
+    POLYGONS=None,
+    INTERSECT=None,
+    ID=None, Verbose=2):
     '''
     Polygon Self-Intersection
     ----------
@@ -830,7 +986,11 @@ def run_tool_shapes_polygons_12(POLYGONS=None, INTERSECT=None, ID=None, Verbose=
         return Tool.Execute(Verbose)
     return False
 
-def Intersect(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
+def Intersect(
+    A=None,
+    B=None,
+    RESULT=None,
+    SPLIT=None, Verbose=2):
     '''
     Intersect
     ----------
@@ -860,7 +1020,11 @@ def Intersect(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_14(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
+def run_tool_shapes_polygons_14(
+    A=None,
+    B=None,
+    RESULT=None,
+    SPLIT=None, Verbose=2):
     '''
     Intersect
     ----------
@@ -890,7 +1054,11 @@ def run_tool_shapes_polygons_14(A=None, B=None, RESULT=None, SPLIT=None, Verbose
         return Tool.Execute(Verbose)
     return False
 
-def Difference(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
+def Difference(
+    A=None,
+    B=None,
+    RESULT=None,
+    SPLIT=None, Verbose=2):
     '''
     Difference
     ----------
@@ -920,7 +1088,11 @@ def Difference(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_15(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
+def run_tool_shapes_polygons_15(
+    A=None,
+    B=None,
+    RESULT=None,
+    SPLIT=None, Verbose=2):
     '''
     Difference
     ----------
@@ -950,7 +1122,11 @@ def run_tool_shapes_polygons_15(A=None, B=None, RESULT=None, SPLIT=None, Verbose
         return Tool.Execute(Verbose)
     return False
 
-def Symmetrical_Difference(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
+def Symmetrical_Difference(
+    A=None,
+    B=None,
+    RESULT=None,
+    SPLIT=None, Verbose=2):
     '''
     Symmetrical Difference
     ----------
@@ -980,7 +1156,11 @@ def Symmetrical_Difference(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_16(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
+def run_tool_shapes_polygons_16(
+    A=None,
+    B=None,
+    RESULT=None,
+    SPLIT=None, Verbose=2):
     '''
     Symmetrical Difference
     ----------
@@ -1010,7 +1190,11 @@ def run_tool_shapes_polygons_16(A=None, B=None, RESULT=None, SPLIT=None, Verbose
         return Tool.Execute(Verbose)
     return False
 
-def Union(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
+def Union(
+    A=None,
+    B=None,
+    RESULT=None,
+    SPLIT=None, Verbose=2):
     '''
     Union
     ----------
@@ -1040,7 +1224,11 @@ def Union(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_17(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
+def run_tool_shapes_polygons_17(
+    A=None,
+    B=None,
+    RESULT=None,
+    SPLIT=None, Verbose=2):
     '''
     Union
     ----------
@@ -1070,7 +1258,11 @@ def run_tool_shapes_polygons_17(A=None, B=None, RESULT=None, SPLIT=None, Verbose
         return Tool.Execute(Verbose)
     return False
 
-def Update(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
+def Update(
+    A=None,
+    B=None,
+    RESULT=None,
+    SPLIT=None, Verbose=2):
     '''
     Update
     ----------
@@ -1100,7 +1292,11 @@ def Update(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_18(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
+def run_tool_shapes_polygons_18(
+    A=None,
+    B=None,
+    RESULT=None,
+    SPLIT=None, Verbose=2):
     '''
     Update
     ----------
@@ -1130,7 +1326,11 @@ def run_tool_shapes_polygons_18(A=None, B=None, RESULT=None, SPLIT=None, Verbose
         return Tool.Execute(Verbose)
     return False
 
-def Identity(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
+def Identity(
+    A=None,
+    B=None,
+    RESULT=None,
+    SPLIT=None, Verbose=2):
     '''
     Identity
     ----------
@@ -1160,7 +1360,11 @@ def Identity(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_19(A=None, B=None, RESULT=None, SPLIT=None, Verbose=2):
+def run_tool_shapes_polygons_19(
+    A=None,
+    B=None,
+    RESULT=None,
+    SPLIT=None, Verbose=2):
     '''
     Identity
     ----------
@@ -1190,7 +1394,12 @@ def run_tool_shapes_polygons_19(A=None, B=None, RESULT=None, SPLIT=None, Verbose
         return Tool.Execute(Verbose)
     return False
 
-def Add_Point_Attributes_to_Polygons(INPUT=None, POINTS=None, OUTPUT=None, FIELDS=None, ADD_LOCATION_INFO=None, Verbose=2):
+def Add_Point_Attributes_to_Polygons(
+    INPUT=None,
+    POINTS=None,
+    OUTPUT=None,
+    FIELDS=None,
+    ADD_LOCATION_INFO=None, Verbose=2):
     '''
     Add Point Attributes to Polygons
     ----------
@@ -1220,7 +1429,12 @@ def Add_Point_Attributes_to_Polygons(INPUT=None, POINTS=None, OUTPUT=None, FIELD
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_20(INPUT=None, POINTS=None, OUTPUT=None, FIELDS=None, ADD_LOCATION_INFO=None, Verbose=2):
+def run_tool_shapes_polygons_20(
+    INPUT=None,
+    POINTS=None,
+    OUTPUT=None,
+    FIELDS=None,
+    ADD_LOCATION_INFO=None, Verbose=2):
     '''
     Add Point Attributes to Polygons
     ----------
@@ -1250,7 +1464,9 @@ def run_tool_shapes_polygons_20(INPUT=None, POINTS=None, OUTPUT=None, FIELDS=Non
         return Tool.Execute(Verbose)
     return False
 
-def Flatten_Polygon_Layer(INPUT=None, OUTPUT=None, Verbose=2):
+def Flatten_Polygon_Layer(
+    INPUT=None,
+    OUTPUT=None, Verbose=2):
     '''
     Flatten Polygon Layer
     ----------
@@ -1273,7 +1489,9 @@ def Flatten_Polygon_Layer(INPUT=None, OUTPUT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_21(INPUT=None, OUTPUT=None, Verbose=2):
+def run_tool_shapes_polygons_21(
+    INPUT=None,
+    OUTPUT=None, Verbose=2):
     '''
     Flatten Polygon Layer
     ----------
@@ -1296,7 +1514,13 @@ def run_tool_shapes_polygons_21(INPUT=None, OUTPUT=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Shared_Polygon_Edges(POLYGONS=None, EDGES=None, ATTRIBUTE=None, VERTICES=None, EPSILON=None, DOUBLE=None, Verbose=2):
+def Shared_Polygon_Edges(
+    POLYGONS=None,
+    EDGES=None,
+    ATTRIBUTE=None,
+    VERTICES=None,
+    EPSILON=None,
+    DOUBLE=None, Verbose=2):
     '''
     Shared Polygon Edges
     ----------
@@ -1327,7 +1551,13 @@ def Shared_Polygon_Edges(POLYGONS=None, EDGES=None, ATTRIBUTE=None, VERTICES=Non
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_22(POLYGONS=None, EDGES=None, ATTRIBUTE=None, VERTICES=None, EPSILON=None, DOUBLE=None, Verbose=2):
+def run_tool_shapes_polygons_22(
+    POLYGONS=None,
+    EDGES=None,
+    ATTRIBUTE=None,
+    VERTICES=None,
+    EPSILON=None,
+    DOUBLE=None, Verbose=2):
     '''
     Shared Polygon Edges
     ----------
@@ -1358,7 +1588,13 @@ def run_tool_shapes_polygons_22(POLYGONS=None, EDGES=None, ATTRIBUTE=None, VERTI
         return Tool.Execute(Verbose)
     return False
 
-def Polygon_Generalization(POLYGONS=None, GENERALIZED=None, THRESHOLD=None, JOIN_TO=None, VERTICES=None, EPSILON=None, Verbose=2):
+def Polygon_Generalization(
+    POLYGONS=None,
+    GENERALIZED=None,
+    THRESHOLD=None,
+    JOIN_TO=None,
+    VERTICES=None,
+    EPSILON=None, Verbose=2):
     '''
     Polygon Generalization
     ----------
@@ -1389,7 +1625,13 @@ def Polygon_Generalization(POLYGONS=None, GENERALIZED=None, THRESHOLD=None, JOIN
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_23(POLYGONS=None, GENERALIZED=None, THRESHOLD=None, JOIN_TO=None, VERTICES=None, EPSILON=None, Verbose=2):
+def run_tool_shapes_polygons_23(
+    POLYGONS=None,
+    GENERALIZED=None,
+    THRESHOLD=None,
+    JOIN_TO=None,
+    VERTICES=None,
+    EPSILON=None, Verbose=2):
     '''
     Polygon Generalization
     ----------
@@ -1420,7 +1662,9 @@ def run_tool_shapes_polygons_23(POLYGONS=None, GENERALIZED=None, THRESHOLD=None,
         return Tool.Execute(Verbose)
     return False
 
-def Invert_Ring_Ordering(POLYGONS=None, INVERTED=None, Verbose=2):
+def Invert_Ring_Ordering(
+    POLYGONS=None,
+    INVERTED=None, Verbose=2):
     '''
     Invert Ring Ordering
     ----------
@@ -1443,7 +1687,9 @@ def Invert_Ring_Ordering(POLYGONS=None, INVERTED=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_24(POLYGONS=None, INVERTED=None, Verbose=2):
+def run_tool_shapes_polygons_24(
+    POLYGONS=None,
+    INVERTED=None, Verbose=2):
     '''
     Invert Ring Ordering
     ----------
@@ -1466,7 +1712,9 @@ def run_tool_shapes_polygons_24(POLYGONS=None, INVERTED=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Total_Length_of_Lines_per_Polygon(POLYGONS=None, LINES=None, Verbose=2):
+def Total_Length_of_Lines_per_Polygon(
+    POLYGONS=None,
+    LINES=None, Verbose=2):
     '''
     Total Length of Lines per Polygon
     ----------
@@ -1489,7 +1737,9 @@ def Total_Length_of_Lines_per_Polygon(POLYGONS=None, LINES=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_length_of_lines(POLYGONS=None, LINES=None, Verbose=2):
+def run_tool_shapes_polygons_length_of_lines(
+    POLYGONS=None,
+    LINES=None, Verbose=2):
     '''
     Total Length of Lines per Polygon
     ----------
@@ -1512,7 +1762,10 @@ def run_tool_shapes_polygons_length_of_lines(POLYGONS=None, LINES=None, Verbose=
         return Tool.Execute(Verbose)
     return False
 
-def Largest_Circles_in_Polygons(POLYGONS=None, CIRCLES=None, RESOLUTION=None, Verbose=2):
+def Largest_Circles_in_Polygons(
+    POLYGONS=None,
+    CIRCLES=None,
+    RESOLUTION=None, Verbose=2):
     '''
     Largest Circles in Polygons
     ----------
@@ -1537,7 +1790,10 @@ def Largest_Circles_in_Polygons(POLYGONS=None, CIRCLES=None, RESOLUTION=None, Ve
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_max_interior_circles(POLYGONS=None, CIRCLES=None, RESOLUTION=None, Verbose=2):
+def run_tool_shapes_polygons_max_interior_circles(
+    POLYGONS=None,
+    CIRCLES=None,
+    RESOLUTION=None, Verbose=2):
     '''
     Largest Circles in Polygons
     ----------
@@ -1562,7 +1818,10 @@ def run_tool_shapes_polygons_max_interior_circles(POLYGONS=None, CIRCLES=None, R
         return Tool.Execute(Verbose)
     return False
 
-def Remove_Boundary_Polygons(POLYGONS=None, RESULT=None, METHOD=None, Verbose=2):
+def Remove_Boundary_Polygons(
+    POLYGONS=None,
+    RESULT=None,
+    METHOD=None, Verbose=2):
     '''
     Remove Boundary Polygons
     ----------
@@ -1587,7 +1846,10 @@ def Remove_Boundary_Polygons(POLYGONS=None, RESULT=None, METHOD=None, Verbose=2)
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_shapes_polygons_remove_from_boundary(POLYGONS=None, RESULT=None, METHOD=None, Verbose=2):
+def run_tool_shapes_polygons_remove_from_boundary(
+    POLYGONS=None,
+    RESULT=None,
+    METHOD=None, Verbose=2):
     '''
     Remove Boundary Polygons
     ----------
