@@ -14,7 +14,12 @@ Tools for spatial and geostatistical analyses.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Fast_Representativeness(INPUT=None, RESULT=None, RESULT_LOD=None, SEEDS=None, LOD=None, Verbose=2):
+def Fast_Representativeness(
+    INPUT=None,
+    RESULT=None,
+    RESULT_LOD=None,
+    SEEDS=None,
+    LOD=None, Verbose=2):
     '''
     Fast Representativeness
     ----------
@@ -45,7 +50,12 @@ def Fast_Representativeness(INPUT=None, RESULT=None, RESULT_LOD=None, SEEDS=None
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_0(INPUT=None, RESULT=None, RESULT_LOD=None, SEEDS=None, LOD=None, Verbose=2):
+def run_tool_statistics_grid_0(
+    INPUT=None,
+    RESULT=None,
+    RESULT_LOD=None,
+    SEEDS=None,
+    LOD=None, Verbose=2):
     '''
     Fast Representativeness
     ----------
@@ -76,7 +86,30 @@ def run_tool_statistics_grid_0(INPUT=None, RESULT=None, RESULT_LOD=None, SEEDS=N
         return Tool.Execute(Verbose)
     return False
 
-def Focal_Statistics(GRID=None, MEAN=None, MIN=None, MAX=None, RANGE=None, STDDEV=None, VARIANCE=None, SUM=None, DIFF=None, DEVMEAN=None, PERCENT=None, MEDIAN=None, MINORITY=None, MAJORITY=None, BCENTER=None, KERNEL_TYPE=None, KERNEL_INNER=None, KERNEL_RADIUS=None, KERNEL_DIRECTION=None, KERNEL_TOLERANCE=None, DW_WEIGHTING=None, DW_IDW_POWER=None, DW_BANDWIDTH=None, Verbose=2):
+def Focal_Statistics(
+    GRID=None,
+    MEAN=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    STDDEV=None,
+    VARIANCE=None,
+    SUM=None,
+    DIFF=None,
+    DEVMEAN=None,
+    PERCENT=None,
+    MEDIAN=None,
+    MINORITY=None,
+    MAJORITY=None,
+    BCENTER=None,
+    KERNEL_TYPE=None,
+    KERNEL_INNER=None,
+    KERNEL_RADIUS=None,
+    KERNEL_DIRECTION=None,
+    KERNEL_TOLERANCE=None,
+    DW_WEIGHTING=None,
+    DW_IDW_POWER=None,
+    DW_BANDWIDTH=None, Verbose=2):
     '''
     Focal Statistics
     ----------
@@ -141,7 +174,30 @@ def Focal_Statistics(GRID=None, MEAN=None, MIN=None, MAX=None, RANGE=None, STDDE
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_1(GRID=None, MEAN=None, MIN=None, MAX=None, RANGE=None, STDDEV=None, VARIANCE=None, SUM=None, DIFF=None, DEVMEAN=None, PERCENT=None, MEDIAN=None, MINORITY=None, MAJORITY=None, BCENTER=None, KERNEL_TYPE=None, KERNEL_INNER=None, KERNEL_RADIUS=None, KERNEL_DIRECTION=None, KERNEL_TOLERANCE=None, DW_WEIGHTING=None, DW_IDW_POWER=None, DW_BANDWIDTH=None, Verbose=2):
+def run_tool_statistics_grid_1(
+    GRID=None,
+    MEAN=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    STDDEV=None,
+    VARIANCE=None,
+    SUM=None,
+    DIFF=None,
+    DEVMEAN=None,
+    PERCENT=None,
+    MEDIAN=None,
+    MINORITY=None,
+    MAJORITY=None,
+    BCENTER=None,
+    KERNEL_TYPE=None,
+    KERNEL_INNER=None,
+    KERNEL_RADIUS=None,
+    KERNEL_DIRECTION=None,
+    KERNEL_TOLERANCE=None,
+    DW_WEIGHTING=None,
+    DW_IDW_POWER=None,
+    DW_BANDWIDTH=None, Verbose=2):
     '''
     Focal Statistics
     ----------
@@ -206,7 +262,11 @@ def run_tool_statistics_grid_1(GRID=None, MEAN=None, MIN=None, MAX=None, RANGE=N
         return Tool.Execute(Verbose)
     return False
 
-def Representativeness_Grid(INPUT=None, RESULT=None, RADIUS=None, EXPONENT=None, Verbose=2):
+def Representativeness_Grid(
+    INPUT=None,
+    RESULT=None,
+    RADIUS=None,
+    EXPONENT=None, Verbose=2):
     '''
     Representativeness (Grid)
     ----------
@@ -233,7 +293,11 @@ def Representativeness_Grid(INPUT=None, RESULT=None, RADIUS=None, EXPONENT=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_2(INPUT=None, RESULT=None, RADIUS=None, EXPONENT=None, Verbose=2):
+def run_tool_statistics_grid_2(
+    INPUT=None,
+    RESULT=None,
+    RADIUS=None,
+    EXPONENT=None, Verbose=2):
     '''
     Representativeness (Grid)
     ----------
@@ -260,7 +324,12 @@ def run_tool_statistics_grid_2(INPUT=None, RESULT=None, RADIUS=None, EXPONENT=No
         return Tool.Execute(Verbose)
     return False
 
-def Radius_of_Variance_Grid(INPUT=None, RESULT=None, STDDEV=None, RADIUS=None, OUTPUT=None, Verbose=2):
+def Radius_of_Variance_Grid(
+    INPUT=None,
+    RESULT=None,
+    STDDEV=None,
+    RADIUS=None,
+    OUTPUT=None, Verbose=2):
     '''
     Radius of Variance (Grid)
     ----------
@@ -289,7 +358,12 @@ def Radius_of_Variance_Grid(INPUT=None, RESULT=None, STDDEV=None, RADIUS=None, O
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_3(INPUT=None, RESULT=None, STDDEV=None, RADIUS=None, OUTPUT=None, Verbose=2):
+def run_tool_statistics_grid_3(
+    INPUT=None,
+    RESULT=None,
+    STDDEV=None,
+    RADIUS=None,
+    OUTPUT=None, Verbose=2):
     '''
     Radius of Variance (Grid)
     ----------
@@ -318,7 +392,22 @@ def run_tool_statistics_grid_3(INPUT=None, RESULT=None, STDDEV=None, RADIUS=None
         return Tool.Execute(Verbose)
     return False
 
-def Statistics_for_Grids(GRIDS=None, WEIGHTS=None, MEAN=None, MIN=None, MAX=None, RANGE=None, SUM=None, SUM2=None, VAR=None, STDDEV=None, STDDEVLO=None, STDDEVHI=None, PCTL=None, RESAMPLING=None, PCTL_VAL=None, Verbose=2):
+def Statistics_for_Grids(
+    GRIDS=None,
+    WEIGHTS=None,
+    MEAN=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    SUM=None,
+    SUM2=None,
+    VAR=None,
+    STDDEV=None,
+    STDDEVLO=None,
+    STDDEVHI=None,
+    PCTL=None,
+    RESAMPLING=None,
+    PCTL_VAL=None, Verbose=2):
     '''
     Statistics for Grids
     ----------
@@ -368,7 +457,22 @@ def Statistics_for_Grids(GRIDS=None, WEIGHTS=None, MEAN=None, MIN=None, MAX=None
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_4(GRIDS=None, WEIGHTS=None, MEAN=None, MIN=None, MAX=None, RANGE=None, SUM=None, SUM2=None, VAR=None, STDDEV=None, STDDEVLO=None, STDDEVHI=None, PCTL=None, RESAMPLING=None, PCTL_VAL=None, Verbose=2):
+def run_tool_statistics_grid_4(
+    GRIDS=None,
+    WEIGHTS=None,
+    MEAN=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    SUM=None,
+    SUM2=None,
+    VAR=None,
+    STDDEV=None,
+    STDDEVLO=None,
+    STDDEVHI=None,
+    PCTL=None,
+    RESAMPLING=None,
+    PCTL_VAL=None, Verbose=2):
     '''
     Statistics for Grids
     ----------
@@ -418,7 +522,14 @@ def run_tool_statistics_grid_4(GRIDS=None, WEIGHTS=None, MEAN=None, MIN=None, MA
         return Tool.Execute(Verbose)
     return False
 
-def Zonal_Grid_Statistics(ZONES=None, CATLIST=None, STATLIST=None, ASPECT=None, UCU=None, OUTTAB=None, SHORTNAMES=None, Verbose=2):
+def Zonal_Grid_Statistics(
+    ZONES=None,
+    CATLIST=None,
+    STATLIST=None,
+    ASPECT=None,
+    UCU=None,
+    OUTTAB=None,
+    SHORTNAMES=None, Verbose=2):
     '''
     Zonal Grid Statistics
     ----------
@@ -465,7 +576,14 @@ def Zonal_Grid_Statistics(ZONES=None, CATLIST=None, STATLIST=None, ASPECT=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_5(ZONES=None, CATLIST=None, STATLIST=None, ASPECT=None, UCU=None, OUTTAB=None, SHORTNAMES=None, Verbose=2):
+def run_tool_statistics_grid_5(
+    ZONES=None,
+    CATLIST=None,
+    STATLIST=None,
+    ASPECT=None,
+    UCU=None,
+    OUTTAB=None,
+    SHORTNAMES=None, Verbose=2):
     '''
     Zonal Grid Statistics
     ----------
@@ -512,7 +630,27 @@ def run_tool_statistics_grid_5(ZONES=None, CATLIST=None, STATLIST=None, ASPECT=N
         return Tool.Execute(Verbose)
     return False
 
-def Directional_Statistics_for_Single_Grid(GRID=None, POINTS=None, MEAN=None, DIFMEAN=None, MIN=None, MAX=None, RANGE=None, VAR=None, STDDEV=None, STDDEVLO=None, STDDEVHI=None, DEVMEAN=None, PERCENT=None, POINTS_OUT=None, DIRECTION=None, TOLERANCE=None, MAXDISTANCE=None, DW_WEIGHTING=None, DW_IDW_POWER=None, DW_BANDWIDTH=None, Verbose=2):
+def Directional_Statistics_for_Single_Grid(
+    GRID=None,
+    POINTS=None,
+    MEAN=None,
+    DIFMEAN=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    VAR=None,
+    STDDEV=None,
+    STDDEVLO=None,
+    STDDEVHI=None,
+    DEVMEAN=None,
+    PERCENT=None,
+    POINTS_OUT=None,
+    DIRECTION=None,
+    TOLERANCE=None,
+    MAXDISTANCE=None,
+    DW_WEIGHTING=None,
+    DW_IDW_POWER=None,
+    DW_BANDWIDTH=None, Verbose=2):
     '''
     Directional Statistics for Single Grid
     ----------
@@ -571,7 +709,27 @@ def Directional_Statistics_for_Single_Grid(GRID=None, POINTS=None, MEAN=None, DI
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_6(GRID=None, POINTS=None, MEAN=None, DIFMEAN=None, MIN=None, MAX=None, RANGE=None, VAR=None, STDDEV=None, STDDEVLO=None, STDDEVHI=None, DEVMEAN=None, PERCENT=None, POINTS_OUT=None, DIRECTION=None, TOLERANCE=None, MAXDISTANCE=None, DW_WEIGHTING=None, DW_IDW_POWER=None, DW_BANDWIDTH=None, Verbose=2):
+def run_tool_statistics_grid_6(
+    GRID=None,
+    POINTS=None,
+    MEAN=None,
+    DIFMEAN=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    VAR=None,
+    STDDEV=None,
+    STDDEVLO=None,
+    STDDEVHI=None,
+    DEVMEAN=None,
+    PERCENT=None,
+    POINTS_OUT=None,
+    DIRECTION=None,
+    TOLERANCE=None,
+    MAXDISTANCE=None,
+    DW_WEIGHTING=None,
+    DW_IDW_POWER=None,
+    DW_BANDWIDTH=None, Verbose=2):
     '''
     Directional Statistics for Single Grid
     ----------
@@ -630,7 +788,11 @@ def run_tool_statistics_grid_6(GRID=None, POINTS=None, MEAN=None, DIFMEAN=None,
         return Tool.Execute(Verbose)
     return False
 
-def Global_Morans_I_for_Grids(GRID=None, RESULT=None, CONTIGUITY=None, DIALOG=None, Verbose=2):
+def Global_Morans_I_for_Grids(
+    GRID=None,
+    RESULT=None,
+    CONTIGUITY=None,
+    DIALOG=None, Verbose=2):
     '''
     Global Moran's I for Grids
     ----------
@@ -657,7 +819,11 @@ def Global_Morans_I_for_Grids(GRID=None, RESULT=None, CONTIGUITY=None, DIALOG=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_7(GRID=None, RESULT=None, CONTIGUITY=None, DIALOG=None, Verbose=2):
+def run_tool_statistics_grid_7(
+    GRID=None,
+    RESULT=None,
+    CONTIGUITY=None,
+    DIALOG=None, Verbose=2):
     '''
     Global Moran's I for Grids
     ----------
@@ -684,7 +850,14 @@ def run_tool_statistics_grid_7(GRID=None, RESULT=None, CONTIGUITY=None, DIALOG=N
         return Tool.Execute(Verbose)
     return False
 
-def Principal_Component_Analysis(GRIDS=None, EIGEN_INPUT=None, PCA=None, EIGEN=None, METHOD=None, COMPONENTS=None, OVERWRITE=None, Verbose=2):
+def Principal_Component_Analysis(
+    GRIDS=None,
+    EIGEN_INPUT=None,
+    PCA=None,
+    EIGEN=None,
+    METHOD=None,
+    COMPONENTS=None,
+    OVERWRITE=None, Verbose=2):
     '''
     Principal Component Analysis
     ----------
@@ -717,7 +890,14 @@ def Principal_Component_Analysis(GRIDS=None, EIGEN_INPUT=None, PCA=None, EIGEN=N
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_8(GRIDS=None, EIGEN_INPUT=None, PCA=None, EIGEN=None, METHOD=None, COMPONENTS=None, OVERWRITE=None, Verbose=2):
+def run_tool_statistics_grid_8(
+    GRIDS=None,
+    EIGEN_INPUT=None,
+    PCA=None,
+    EIGEN=None,
+    METHOD=None,
+    COMPONENTS=None,
+    OVERWRITE=None, Verbose=2):
     '''
     Principal Component Analysis
     ----------
@@ -750,7 +930,15 @@ def run_tool_statistics_grid_8(GRIDS=None, EIGEN_INPUT=None, PCA=None, EIGEN=Non
         return Tool.Execute(Verbose)
     return False
 
-def MultiBand_Variation(BANDS=None, MEAN=None, STDDEV=None, DIFF=None, RADIUS=None, DW_WEIGHTING=None, DW_IDW_POWER=None, DW_BANDWIDTH=None, Verbose=2):
+def MultiBand_Variation(
+    BANDS=None,
+    MEAN=None,
+    STDDEV=None,
+    DIFF=None,
+    RADIUS=None,
+    DW_WEIGHTING=None,
+    DW_IDW_POWER=None,
+    DW_BANDWIDTH=None, Verbose=2):
     '''
     Multi-Band Variation
     ----------
@@ -785,7 +973,15 @@ def MultiBand_Variation(BANDS=None, MEAN=None, STDDEV=None, DIFF=None, RADIUS=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_9(BANDS=None, MEAN=None, STDDEV=None, DIFF=None, RADIUS=None, DW_WEIGHTING=None, DW_IDW_POWER=None, DW_BANDWIDTH=None, Verbose=2):
+def run_tool_statistics_grid_9(
+    BANDS=None,
+    MEAN=None,
+    STDDEV=None,
+    DIFF=None,
+    RADIUS=None,
+    DW_WEIGHTING=None,
+    DW_IDW_POWER=None,
+    DW_BANDWIDTH=None, Verbose=2):
     '''
     Multi-Band Variation
     ----------
@@ -820,7 +1016,10 @@ def run_tool_statistics_grid_9(BANDS=None, MEAN=None, STDDEV=None, DIFF=None, RA
         return Tool.Execute(Verbose)
     return False
 
-def Inverse_Principal_Components_Rotation(PCA=None, EIGEN=None, GRIDS=None, Verbose=2):
+def Inverse_Principal_Components_Rotation(
+    PCA=None,
+    EIGEN=None,
+    GRIDS=None, Verbose=2):
     '''
     Inverse Principal Components Rotation
     ----------
@@ -845,7 +1044,10 @@ def Inverse_Principal_Components_Rotation(PCA=None, EIGEN=None, GRIDS=None, Verb
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_10(PCA=None, EIGEN=None, GRIDS=None, Verbose=2):
+def run_tool_statistics_grid_10(
+    PCA=None,
+    EIGEN=None,
+    GRIDS=None, Verbose=2):
     '''
     Inverse Principal Components Rotation
     ----------
@@ -870,7 +1072,9 @@ def run_tool_statistics_grid_10(PCA=None, EIGEN=None, GRIDS=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Longitudinal_Grid_Statistics(GRID=None, STATS=None, Verbose=2):
+def Longitudinal_Grid_Statistics(
+    GRID=None,
+    STATS=None, Verbose=2):
     '''
     Longitudinal Grid Statistics
     ----------
@@ -893,7 +1097,9 @@ def Longitudinal_Grid_Statistics(GRID=None, STATS=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_11(GRID=None, STATS=None, Verbose=2):
+def run_tool_statistics_grid_11(
+    GRID=None,
+    STATS=None, Verbose=2):
     '''
     Longitudinal Grid Statistics
     ----------
@@ -916,7 +1122,9 @@ def run_tool_statistics_grid_11(GRID=None, STATS=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Meridional_Grid_Statistics(GRID=None, STATS=None, Verbose=2):
+def Meridional_Grid_Statistics(
+    GRID=None,
+    STATS=None, Verbose=2):
     '''
     Meridional Grid Statistics
     ----------
@@ -939,7 +1147,9 @@ def Meridional_Grid_Statistics(GRID=None, STATS=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_12(GRID=None, STATS=None, Verbose=2):
+def run_tool_statistics_grid_12(
+    GRID=None,
+    STATS=None, Verbose=2):
     '''
     Meridional Grid Statistics
     ----------
@@ -962,7 +1172,25 @@ def run_tool_statistics_grid_12(GRID=None, STATS=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Save_Grid_Statistics_to_Table(GRIDS=None, STATS=None, DATA_CELLS=None, NODATA_CELLS=None, CELLSIZE=None, MEAN=None, MIN=None, MAX=None, RANGE=None, SUM=None, SUM2=None, VAR=None, STDDEV=None, STDDEVLO=None, STDDEVHI=None, PCTL_VAL=None, PCTL_HST=None, SAMPLES=None, Verbose=2):
+def Save_Grid_Statistics_to_Table(
+    GRIDS=None,
+    STATS=None,
+    DATA_CELLS=None,
+    NODATA_CELLS=None,
+    CELLSIZE=None,
+    MEAN=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    SUM=None,
+    SUM2=None,
+    VAR=None,
+    STDDEV=None,
+    STDDEVLO=None,
+    STDDEVHI=None,
+    PCTL_VAL=None,
+    PCTL_HST=None,
+    SAMPLES=None, Verbose=2):
     '''
     Save Grid Statistics to Table
     ----------
@@ -1017,7 +1245,25 @@ def Save_Grid_Statistics_to_Table(GRIDS=None, STATS=None, DATA_CELLS=None, NODAT
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_13(GRIDS=None, STATS=None, DATA_CELLS=None, NODATA_CELLS=None, CELLSIZE=None, MEAN=None, MIN=None, MAX=None, RANGE=None, SUM=None, SUM2=None, VAR=None, STDDEV=None, STDDEVLO=None, STDDEVHI=None, PCTL_VAL=None, PCTL_HST=None, SAMPLES=None, Verbose=2):
+def run_tool_statistics_grid_13(
+    GRIDS=None,
+    STATS=None,
+    DATA_CELLS=None,
+    NODATA_CELLS=None,
+    CELLSIZE=None,
+    MEAN=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    SUM=None,
+    SUM2=None,
+    VAR=None,
+    STDDEV=None,
+    STDDEVLO=None,
+    STDDEVHI=None,
+    PCTL_VAL=None,
+    PCTL_HST=None,
+    SAMPLES=None, Verbose=2):
     '''
     Save Grid Statistics to Table
     ----------
@@ -1072,7 +1318,13 @@ def run_tool_statistics_grid_13(GRIDS=None, STATS=None, DATA_CELLS=None, NODATA_
         return Tool.Execute(Verbose)
     return False
 
-def Categorical_Coincidence(GRIDS=None, CATEGORIES=None, COINCIDENCE=None, MAJ_COUNT=None, MAJ_VALUE=None, RADIUS=None, Verbose=2):
+def Categorical_Coincidence(
+    GRIDS=None,
+    CATEGORIES=None,
+    COINCIDENCE=None,
+    MAJ_COUNT=None,
+    MAJ_VALUE=None,
+    RADIUS=None, Verbose=2):
     '''
     Categorical Coincidence
     ----------
@@ -1103,7 +1355,13 @@ def Categorical_Coincidence(GRIDS=None, CATEGORIES=None, COINCIDENCE=None, MAJ_C
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_14(GRIDS=None, CATEGORIES=None, COINCIDENCE=None, MAJ_COUNT=None, MAJ_VALUE=None, RADIUS=None, Verbose=2):
+def run_tool_statistics_grid_14(
+    GRIDS=None,
+    CATEGORIES=None,
+    COINCIDENCE=None,
+    MAJ_COUNT=None,
+    MAJ_VALUE=None,
+    RADIUS=None, Verbose=2):
     '''
     Categorical Coincidence
     ----------
@@ -1134,7 +1392,17 @@ def run_tool_statistics_grid_14(GRIDS=None, CATEGORIES=None, COINCIDENCE=None, M
         return Tool.Execute(Verbose)
     return False
 
-def Focal_PCA_on_a_Grid(GRID=None, BASE=None, PCA=None, EIGEN=None, COMPONENTS=None, BASE_OUT=None, OVERWRITE=None, KERNEL_TYPE=None, KERNEL_RADIUS=None, METHOD=None, Verbose=2):
+def Focal_PCA_on_a_Grid(
+    GRID=None,
+    BASE=None,
+    PCA=None,
+    EIGEN=None,
+    COMPONENTS=None,
+    BASE_OUT=None,
+    OVERWRITE=None,
+    KERNEL_TYPE=None,
+    KERNEL_RADIUS=None,
+    METHOD=None, Verbose=2):
     '''
     Focal PCA on a Grid
     ----------
@@ -1173,7 +1441,17 @@ def Focal_PCA_on_a_Grid(GRID=None, BASE=None, PCA=None, EIGEN=None, COMPONENTS=N
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_15(GRID=None, BASE=None, PCA=None, EIGEN=None, COMPONENTS=None, BASE_OUT=None, OVERWRITE=None, KERNEL_TYPE=None, KERNEL_RADIUS=None, METHOD=None, Verbose=2):
+def run_tool_statistics_grid_15(
+    GRID=None,
+    BASE=None,
+    PCA=None,
+    EIGEN=None,
+    COMPONENTS=None,
+    BASE_OUT=None,
+    OVERWRITE=None,
+    KERNEL_TYPE=None,
+    KERNEL_RADIUS=None,
+    METHOD=None, Verbose=2):
     '''
     Focal PCA on a Grid
     ----------
@@ -1212,7 +1490,24 @@ def run_tool_statistics_grid_15(GRID=None, BASE=None, PCA=None, EIGEN=None, COMP
         return Tool.Execute(Verbose)
     return False
 
-def Statistics_for_Grids_from_Files(COUNT=None, MIN=None, MAX=None, RANGE=None, SUM=None, SUM2=None, MEAN=None, VAR=None, STDDEV=None, HISTOGRAM=None, QUANTILES=None, GRID_SYSTEM=None, FILES=None, HCLASSES=None, HRANGE=None, CUMULATIVE=None, QUANTVALS=None, Verbose=2):
+def Statistics_for_Grids_from_Files(
+    COUNT=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    SUM=None,
+    SUM2=None,
+    MEAN=None,
+    VAR=None,
+    STDDEV=None,
+    HISTOGRAM=None,
+    QUANTILES=None,
+    GRID_SYSTEM=None,
+    FILES=None,
+    HCLASSES=None,
+    HRANGE=None,
+    CUMULATIVE=None,
+    QUANTVALS=None, Verbose=2):
     '''
     Statistics for Grids from Files
     ----------
@@ -1265,7 +1560,24 @@ def Statistics_for_Grids_from_Files(COUNT=None, MIN=None, MAX=None, RANGE=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_16(COUNT=None, MIN=None, MAX=None, RANGE=None, SUM=None, SUM2=None, MEAN=None, VAR=None, STDDEV=None, HISTOGRAM=None, QUANTILES=None, GRID_SYSTEM=None, FILES=None, HCLASSES=None, HRANGE=None, CUMULATIVE=None, QUANTVALS=None, Verbose=2):
+def run_tool_statistics_grid_16(
+    COUNT=None,
+    MIN=None,
+    MAX=None,
+    RANGE=None,
+    SUM=None,
+    SUM2=None,
+    MEAN=None,
+    VAR=None,
+    STDDEV=None,
+    HISTOGRAM=None,
+    QUANTILES=None,
+    GRID_SYSTEM=None,
+    FILES=None,
+    HCLASSES=None,
+    HRANGE=None,
+    CUMULATIVE=None,
+    QUANTVALS=None, Verbose=2):
     '''
     Statistics for Grids from Files
     ----------
@@ -1318,7 +1630,17 @@ def run_tool_statistics_grid_16(COUNT=None, MIN=None, MAX=None, RANGE=None, SUM=
         return Tool.Execute(Verbose)
     return False
 
-def Build_Statistics_for_Grids(GRIDS=None, COUNT=None, SUM=None, SUM2=None, MIN=None, MAX=None, HISTOGRAM=None, HCLASSES=None, HMIN=None, HMAX=None, Verbose=2):
+def Build_Statistics_for_Grids(
+    GRIDS=None,
+    COUNT=None,
+    SUM=None,
+    SUM2=None,
+    MIN=None,
+    MAX=None,
+    HISTOGRAM=None,
+    HCLASSES=None,
+    HMIN=None,
+    HMAX=None, Verbose=2):
     '''
     Build Statistics for Grids
     ----------
@@ -1357,7 +1679,17 @@ def Build_Statistics_for_Grids(GRIDS=None, COUNT=None, SUM=None, SUM2=None, MIN=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_17(GRIDS=None, COUNT=None, SUM=None, SUM2=None, MIN=None, MAX=None, HISTOGRAM=None, HCLASSES=None, HMIN=None, HMAX=None, Verbose=2):
+def run_tool_statistics_grid_17(
+    GRIDS=None,
+    COUNT=None,
+    SUM=None,
+    SUM2=None,
+    MIN=None,
+    MAX=None,
+    HISTOGRAM=None,
+    HCLASSES=None,
+    HMIN=None,
+    HMAX=None, Verbose=2):
     '''
     Build Statistics for Grids
     ----------
@@ -1396,7 +1728,19 @@ def run_tool_statistics_grid_17(GRIDS=None, COUNT=None, SUM=None, SUM2=None, MIN
         return Tool.Execute(Verbose)
     return False
 
-def Evaluate_Statistics_for_Grids(COUNT=None, SUM=None, SUM2=None, MIN=None, MAX=None, HISTOGRAM=None, RANGE=None, MEAN=None, VAR=None, STDDEV=None, QUANTILES=None, QUANTVALS=None, Verbose=2):
+def Evaluate_Statistics_for_Grids(
+    COUNT=None,
+    SUM=None,
+    SUM2=None,
+    MIN=None,
+    MAX=None,
+    HISTOGRAM=None,
+    RANGE=None,
+    MEAN=None,
+    VAR=None,
+    STDDEV=None,
+    QUANTILES=None,
+    QUANTVALS=None, Verbose=2):
     '''
     Evaluate Statistics for Grids
     ----------
@@ -1439,7 +1783,19 @@ def Evaluate_Statistics_for_Grids(COUNT=None, SUM=None, SUM2=None, MIN=None, MAX
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_18(COUNT=None, SUM=None, SUM2=None, MIN=None, MAX=None, HISTOGRAM=None, RANGE=None, MEAN=None, VAR=None, STDDEV=None, QUANTILES=None, QUANTVALS=None, Verbose=2):
+def run_tool_statistics_grid_18(
+    COUNT=None,
+    SUM=None,
+    SUM2=None,
+    MIN=None,
+    MAX=None,
+    HISTOGRAM=None,
+    RANGE=None,
+    MEAN=None,
+    VAR=None,
+    STDDEV=None,
+    QUANTILES=None,
+    QUANTVALS=None, Verbose=2):
     '''
     Evaluate Statistics for Grids
     ----------
@@ -1482,7 +1838,14 @@ def run_tool_statistics_grid_18(COUNT=None, SUM=None, SUM2=None, MIN=None, MAX=N
         return Tool.Execute(Verbose)
     return False
 
-def Add_Statistics_for_Grids(GRIDS=None, COUNT=None, SUM=None, SUM2=None, MIN=None, MAX=None, HISTOGRAM=None, Verbose=2):
+def Add_Statistics_for_Grids(
+    GRIDS=None,
+    COUNT=None,
+    SUM=None,
+    SUM2=None,
+    MIN=None,
+    MAX=None,
+    HISTOGRAM=None, Verbose=2):
     '''
     Add Statistics for Grids
     ----------
@@ -1515,7 +1878,14 @@ def Add_Statistics_for_Grids(GRIDS=None, COUNT=None, SUM=None, SUM2=None, MIN=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_19(GRIDS=None, COUNT=None, SUM=None, SUM2=None, MIN=None, MAX=None, HISTOGRAM=None, Verbose=2):
+def run_tool_statistics_grid_19(
+    GRIDS=None,
+    COUNT=None,
+    SUM=None,
+    SUM2=None,
+    MIN=None,
+    MAX=None,
+    HISTOGRAM=None, Verbose=2):
     '''
     Add Statistics for Grids
     ----------
@@ -1548,7 +1918,14 @@ def run_tool_statistics_grid_19(GRIDS=None, COUNT=None, SUM=None, SUM2=None, MIN
         return Tool.Execute(Verbose)
     return False
 
-def Unique_Value_Statistics_for_Grids(GRIDS=None, MAJORITY=None, MAJORITY_COUNT=None, MINORITY=None, MINORITY_COUNT=None, NUNIQUES=None, UNAMBIGUOUS=None, Verbose=2):
+def Unique_Value_Statistics_for_Grids(
+    GRIDS=None,
+    MAJORITY=None,
+    MAJORITY_COUNT=None,
+    MINORITY=None,
+    MINORITY_COUNT=None,
+    NUNIQUES=None,
+    UNAMBIGUOUS=None, Verbose=2):
     '''
     Unique Value Statistics for Grids
     ----------
@@ -1581,7 +1958,14 @@ def Unique_Value_Statistics_for_Grids(GRIDS=None, MAJORITY=None, MAJORITY_COUNT=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_20(GRIDS=None, MAJORITY=None, MAJORITY_COUNT=None, MINORITY=None, MINORITY_COUNT=None, NUNIQUES=None, UNAMBIGUOUS=None, Verbose=2):
+def run_tool_statistics_grid_20(
+    GRIDS=None,
+    MAJORITY=None,
+    MAJORITY_COUNT=None,
+    MINORITY=None,
+    MINORITY_COUNT=None,
+    NUNIQUES=None,
+    UNAMBIGUOUS=None, Verbose=2):
     '''
     Unique Value Statistics for Grids
     ----------
@@ -1614,7 +1998,16 @@ def run_tool_statistics_grid_20(GRIDS=None, MAJORITY=None, MAJORITY_COUNT=None,
         return Tool.Execute(Verbose)
     return False
 
-def Grid_Histogram(GRID=None, HISTOGRAM=None, CLASSIFY=None, BINS=None, RANGE=None, LUT=None, UNCLASSED=None, PARALLEL=None, MAXSAMPLES=None, Verbose=2):
+def Grid_Histogram(
+    GRID=None,
+    HISTOGRAM=None,
+    CLASSIFY=None,
+    BINS=None,
+    RANGE=None,
+    LUT=None,
+    UNCLASSED=None,
+    PARALLEL=None,
+    MAXSAMPLES=None, Verbose=2):
     '''
     Grid Histogram
     ----------
@@ -1651,7 +2044,16 @@ def Grid_Histogram(GRID=None, HISTOGRAM=None, CLASSIFY=None, BINS=None, RANGE=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_21(GRID=None, HISTOGRAM=None, CLASSIFY=None, BINS=None, RANGE=None, LUT=None, UNCLASSED=None, PARALLEL=None, MAXSAMPLES=None, Verbose=2):
+def run_tool_statistics_grid_21(
+    GRID=None,
+    HISTOGRAM=None,
+    CLASSIFY=None,
+    BINS=None,
+    RANGE=None,
+    LUT=None,
+    UNCLASSED=None,
+    PARALLEL=None,
+    MAXSAMPLES=None, Verbose=2):
     '''
     Grid Histogram
     ----------
@@ -1688,7 +2090,18 @@ def run_tool_statistics_grid_21(GRID=None, HISTOGRAM=None, CLASSIFY=None, BINS=N
         return Tool.Execute(Verbose)
     return False
 
-def Directional_Grid_Statistics(GRID=None, MEAN=None, GRID_SYSTEM=None, BEGIN=None, END=None, STEP=None, TOLERANCE=None, MAXDISTANCE=None, DW_WEIGHTING=None, DW_IDW_POWER=None, DW_BANDWIDTH=None, Verbose=2):
+def Directional_Grid_Statistics(
+    GRID=None,
+    MEAN=None,
+    GRID_SYSTEM=None,
+    BEGIN=None,
+    END=None,
+    STEP=None,
+    TOLERANCE=None,
+    MAXDISTANCE=None,
+    DW_WEIGHTING=None,
+    DW_IDW_POWER=None,
+    DW_BANDWIDTH=None, Verbose=2):
     '''
     Directional Grid Statistics
     ----------
@@ -1729,7 +2142,18 @@ def Directional_Grid_Statistics(GRID=None, MEAN=None, GRID_SYSTEM=None, BEGIN=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_statistics_grid_directional_grid_statistics(GRID=None, MEAN=None, GRID_SYSTEM=None, BEGIN=None, END=None, STEP=None, TOLERANCE=None, MAXDISTANCE=None, DW_WEIGHTING=None, DW_IDW_POWER=None, DW_BANDWIDTH=None, Verbose=2):
+def run_tool_statistics_grid_directional_grid_statistics(
+    GRID=None,
+    MEAN=None,
+    GRID_SYSTEM=None,
+    BEGIN=None,
+    END=None,
+    STEP=None,
+    TOLERANCE=None,
+    MAXDISTANCE=None,
+    DW_WEIGHTING=None,
+    DW_IDW_POWER=None,
+    DW_BANDWIDTH=None, Verbose=2):
     '''
     Directional Grid Statistics
     ----------
