@@ -14,7 +14,19 @@ Tools for (grid based) digital terrain analysis.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Channel_Network(ELEVATION=None, INIT_GRID=None, SINKROUTE=None, DIV_GRID=None, TRACE_WEIGHT=None, CHNLNTWRK=None, CHNLROUTE=None, SHAPES=None, INIT_METHOD=None, INIT_VALUE=None, DIV_CELLS=None, MINLEN=None, Verbose=2):
+def Channel_Network(
+    ELEVATION=None,
+    INIT_GRID=None,
+    SINKROUTE=None,
+    DIV_GRID=None,
+    TRACE_WEIGHT=None,
+    CHNLNTWRK=None,
+    CHNLROUTE=None,
+    SHAPES=None,
+    INIT_METHOD=None,
+    INIT_VALUE=None,
+    DIV_CELLS=None,
+    MINLEN=None, Verbose=2):
     '''
     Channel Network
     ----------
@@ -64,7 +76,19 @@ Controls under which condition a channel is initiated.
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_channels_0(ELEVATION=None, INIT_GRID=None, SINKROUTE=None, DIV_GRID=None, TRACE_WEIGHT=None, CHNLNTWRK=None, CHNLROUTE=None, SHAPES=None, INIT_METHOD=None, INIT_VALUE=None, DIV_CELLS=None, MINLEN=None, Verbose=2):
+def run_tool_ta_channels_0(
+    ELEVATION=None,
+    INIT_GRID=None,
+    SINKROUTE=None,
+    DIV_GRID=None,
+    TRACE_WEIGHT=None,
+    CHNLNTWRK=None,
+    CHNLROUTE=None,
+    SHAPES=None,
+    INIT_METHOD=None,
+    INIT_VALUE=None,
+    DIV_CELLS=None,
+    MINLEN=None, Verbose=2):
     '''
     Channel Network
     ----------
@@ -114,7 +138,12 @@ Controls under which condition a channel is initiated.
         return Tool.Execute(Verbose)
     return False
 
-def Watershed_Basins(ELEVATION=None, CHANNELS=None, SINKROUTE=None, BASINS=None, MINSIZE=None, Verbose=2):
+def Watershed_Basins(
+    ELEVATION=None,
+    CHANNELS=None,
+    SINKROUTE=None,
+    BASINS=None,
+    MINSIZE=None, Verbose=2):
     '''
     Watershed Basins
     ----------
@@ -143,7 +172,12 @@ def Watershed_Basins(ELEVATION=None, CHANNELS=None, SINKROUTE=None, BASINS=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_channels_1(ELEVATION=None, CHANNELS=None, SINKROUTE=None, BASINS=None, MINSIZE=None, Verbose=2):
+def run_tool_ta_channels_1(
+    ELEVATION=None,
+    CHANNELS=None,
+    SINKROUTE=None,
+    BASINS=None,
+    MINSIZE=None, Verbose=2):
     '''
     Watershed Basins
     ----------
@@ -172,7 +206,16 @@ def run_tool_ta_channels_1(ELEVATION=None, CHANNELS=None, SINKROUTE=None, BASINS
         return Tool.Execute(Verbose)
     return False
 
-def Watershed_Basins_Extended(DEM=None, CHANNELS=None, BASINS=None, SUBBASINS=None, V_BASINS=None, V_SUBBASINS=None, HEADS=None, MOUTHS=None, DISTANCE=None, Verbose=2):
+def Watershed_Basins_Extended(
+    DEM=None,
+    CHANNELS=None,
+    BASINS=None,
+    SUBBASINS=None,
+    V_BASINS=None,
+    V_SUBBASINS=None,
+    HEADS=None,
+    MOUTHS=None,
+    DISTANCE=None, Verbose=2):
     '''
     Watershed Basins (Extended)
     ----------
@@ -209,7 +252,16 @@ def Watershed_Basins_Extended(DEM=None, CHANNELS=None, BASINS=None, SUBBASINS=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_channels_2(DEM=None, CHANNELS=None, BASINS=None, SUBBASINS=None, V_BASINS=None, V_SUBBASINS=None, HEADS=None, MOUTHS=None, DISTANCE=None, Verbose=2):
+def run_tool_ta_channels_2(
+    DEM=None,
+    CHANNELS=None,
+    BASINS=None,
+    SUBBASINS=None,
+    V_BASINS=None,
+    V_SUBBASINS=None,
+    HEADS=None,
+    MOUTHS=None,
+    DISTANCE=None, Verbose=2):
     '''
     Watershed Basins (Extended)
     ----------
@@ -246,7 +298,14 @@ def run_tool_ta_channels_2(DEM=None, CHANNELS=None, BASINS=None, SUBBASINS=None,
         return Tool.Execute(Verbose)
     return False
 
-def Vertical_Distance_to_Channel_Network(ELEVATION=None, CHANNELS=None, DISTANCE=None, BASELEVEL=None, THRESHOLD=None, MAXITER=None, NOUNDERGROUND=None, Verbose=2):
+def Vertical_Distance_to_Channel_Network(
+    ELEVATION=None,
+    CHANNELS=None,
+    DISTANCE=None,
+    BASELEVEL=None,
+    THRESHOLD=None,
+    MAXITER=None,
+    NOUNDERGROUND=None, Verbose=2):
     '''
     Vertical Distance to Channel Network
     ----------
@@ -281,7 +340,14 @@ def Vertical_Distance_to_Channel_Network(ELEVATION=None, CHANNELS=None, DISTANCE
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_channels_3(ELEVATION=None, CHANNELS=None, DISTANCE=None, BASELEVEL=None, THRESHOLD=None, MAXITER=None, NOUNDERGROUND=None, Verbose=2):
+def run_tool_ta_channels_3(
+    ELEVATION=None,
+    CHANNELS=None,
+    DISTANCE=None,
+    BASELEVEL=None,
+    THRESHOLD=None,
+    MAXITER=None,
+    NOUNDERGROUND=None, Verbose=2):
     '''
     Vertical Distance to Channel Network
     ----------
@@ -316,7 +382,24 @@ def run_tool_ta_channels_3(ELEVATION=None, CHANNELS=None, DISTANCE=None, BASELEV
         return Tool.Execute(Verbose)
     return False
 
-def Overland_Flow_Distance_to_Channel_Network(ELEVATION=None, CHANNELS=None, ROUTE=None, FIELDS=None, FLOW_K=None, FLOW_R=None, DISTANCE=None, DISTVERT=None, DISTHORZ=None, TIME=None, SDR=None, PASSES=None, METHOD=None, BOUNDARY=None, FLOW_B=None, FLOW_K_DEFAULT=None, FLOW_R_DEFAULT=None, Verbose=2):
+def Overland_Flow_Distance_to_Channel_Network(
+    ELEVATION=None,
+    CHANNELS=None,
+    ROUTE=None,
+    FIELDS=None,
+    FLOW_K=None,
+    FLOW_R=None,
+    DISTANCE=None,
+    DISTVERT=None,
+    DISTHORZ=None,
+    TIME=None,
+    SDR=None,
+    PASSES=None,
+    METHOD=None,
+    BOUNDARY=None,
+    FLOW_B=None,
+    FLOW_K_DEFAULT=None,
+    FLOW_R_DEFAULT=None, Verbose=2):
     '''
     Overland Flow Distance to Channel Network
     ----------
@@ -371,7 +454,24 @@ def Overland_Flow_Distance_to_Channel_Network(ELEVATION=None, CHANNELS=None, ROU
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_channels_4(ELEVATION=None, CHANNELS=None, ROUTE=None, FIELDS=None, FLOW_K=None, FLOW_R=None, DISTANCE=None, DISTVERT=None, DISTHORZ=None, TIME=None, SDR=None, PASSES=None, METHOD=None, BOUNDARY=None, FLOW_B=None, FLOW_K_DEFAULT=None, FLOW_R_DEFAULT=None, Verbose=2):
+def run_tool_ta_channels_4(
+    ELEVATION=None,
+    CHANNELS=None,
+    ROUTE=None,
+    FIELDS=None,
+    FLOW_K=None,
+    FLOW_R=None,
+    DISTANCE=None,
+    DISTVERT=None,
+    DISTHORZ=None,
+    TIME=None,
+    SDR=None,
+    PASSES=None,
+    METHOD=None,
+    BOUNDARY=None,
+    FLOW_B=None,
+    FLOW_K_DEFAULT=None,
+    FLOW_R_DEFAULT=None, Verbose=2):
     '''
     Overland Flow Distance to Channel Network
     ----------
@@ -426,7 +526,17 @@ def run_tool_ta_channels_4(ELEVATION=None, CHANNELS=None, ROUTE=None, FIELDS=Non
         return Tool.Execute(Verbose)
     return False
 
-def Channel_Network_and_Drainage_Basins(DEM=None, DIRECTION=None, CONNECTION=None, ORDER=None, BASIN=None, SEGMENTS=None, BASINS=None, NODES=None, THRESHOLD=None, SUBBASINS=None, Verbose=2):
+def Channel_Network_and_Drainage_Basins(
+    DEM=None,
+    DIRECTION=None,
+    CONNECTION=None,
+    ORDER=None,
+    BASIN=None,
+    SEGMENTS=None,
+    BASINS=None,
+    NODES=None,
+    THRESHOLD=None,
+    SUBBASINS=None, Verbose=2):
     '''
     Channel Network and Drainage Basins
     ----------
@@ -465,7 +575,17 @@ def Channel_Network_and_Drainage_Basins(DEM=None, DIRECTION=None, CONNECTION=Non
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_channels_5(DEM=None, DIRECTION=None, CONNECTION=None, ORDER=None, BASIN=None, SEGMENTS=None, BASINS=None, NODES=None, THRESHOLD=None, SUBBASINS=None, Verbose=2):
+def run_tool_ta_channels_5(
+    DEM=None,
+    DIRECTION=None,
+    CONNECTION=None,
+    ORDER=None,
+    BASIN=None,
+    SEGMENTS=None,
+    BASINS=None,
+    NODES=None,
+    THRESHOLD=None,
+    SUBBASINS=None, Verbose=2):
     '''
     Channel Network and Drainage Basins
     ----------
@@ -504,7 +624,9 @@ def run_tool_ta_channels_5(DEM=None, DIRECTION=None, CONNECTION=None, ORDER=None
         return Tool.Execute(Verbose)
     return False
 
-def Strahler_Order(DEM=None, STRAHLER=None, Verbose=2):
+def Strahler_Order(
+    DEM=None,
+    STRAHLER=None, Verbose=2):
     '''
     Strahler Order
     ----------
@@ -527,7 +649,9 @@ def Strahler_Order(DEM=None, STRAHLER=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_channels_6(DEM=None, STRAHLER=None, Verbose=2):
+def run_tool_ta_channels_6(
+    DEM=None,
+    STRAHLER=None, Verbose=2):
     '''
     Strahler Order
     ----------
@@ -550,7 +674,14 @@ def run_tool_ta_channels_6(DEM=None, STRAHLER=None, Verbose=2):
         return Tool.Execute(Verbose)
     return False
 
-def Valley_Depth(ELEVATION=None, VALLEY_DEPTH=None, RIDGE_LEVEL=None, THRESHOLD=None, MAXITER=None, NOUNDERGROUND=None, ORDER=None, Verbose=2):
+def Valley_Depth(
+    ELEVATION=None,
+    VALLEY_DEPTH=None,
+    RIDGE_LEVEL=None,
+    THRESHOLD=None,
+    MAXITER=None,
+    NOUNDERGROUND=None,
+    ORDER=None, Verbose=2):
     '''
     Valley Depth
     ----------
@@ -586,7 +717,14 @@ def Valley_Depth(ELEVATION=None, VALLEY_DEPTH=None, RIDGE_LEVEL=None, THRESHOLD=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_channels_7(ELEVATION=None, VALLEY_DEPTH=None, RIDGE_LEVEL=None, THRESHOLD=None, MAXITER=None, NOUNDERGROUND=None, ORDER=None, Verbose=2):
+def run_tool_ta_channels_7(
+    ELEVATION=None,
+    VALLEY_DEPTH=None,
+    RIDGE_LEVEL=None,
+    THRESHOLD=None,
+    MAXITER=None,
+    NOUNDERGROUND=None,
+    ORDER=None, Verbose=2):
     '''
     Valley Depth
     ----------
