@@ -14,7 +14,25 @@ This library provides one-step tools for compound terrain analyses.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Compound_Basic_Terrain_Analysis(ELEVATION=None, SHADE=None, SLOPE=None, ASPECT=None, HCURV=None, VCURV=None, CONVERGENCE=None, SINKS=None, FLOW=None, WETNESS=None, LSFACTOR=None, CHANNELS=None, BASINS=None, CHNL_BASE=None, CHNL_DIST=None, VALL_DEPTH=None, RSP=None, THRESHOLD=None, Verbose=2):
+def Compound_Basic_Terrain_Analysis(
+    ELEVATION=None,
+    SHADE=None,
+    SLOPE=None,
+    ASPECT=None,
+    HCURV=None,
+    VCURV=None,
+    CONVERGENCE=None,
+    SINKS=None,
+    FLOW=None,
+    WETNESS=None,
+    LSFACTOR=None,
+    CHANNELS=None,
+    BASINS=None,
+    CHNL_BASE=None,
+    CHNL_DIST=None,
+    VALL_DEPTH=None,
+    RSP=None,
+    THRESHOLD=None, Verbose=2):
     '''
     Compound Basic Terrain Analysis
     ----------
@@ -74,7 +92,25 @@ def Compound_Basic_Terrain_Analysis(ELEVATION=None, SHADE=None, SLOPE=None, ASPE
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_compound_0(ELEVATION=None, SHADE=None, SLOPE=None, ASPECT=None, HCURV=None, VCURV=None, CONVERGENCE=None, SINKS=None, FLOW=None, WETNESS=None, LSFACTOR=None, CHANNELS=None, BASINS=None, CHNL_BASE=None, CHNL_DIST=None, VALL_DEPTH=None, RSP=None, THRESHOLD=None, Verbose=2):
+def run_tool_ta_compound_0(
+    ELEVATION=None,
+    SHADE=None,
+    SLOPE=None,
+    ASPECT=None,
+    HCURV=None,
+    VCURV=None,
+    CONVERGENCE=None,
+    SINKS=None,
+    FLOW=None,
+    WETNESS=None,
+    LSFACTOR=None,
+    CHANNELS=None,
+    BASINS=None,
+    CHNL_BASE=None,
+    CHNL_DIST=None,
+    VALL_DEPTH=None,
+    RSP=None,
+    THRESHOLD=None, Verbose=2):
     '''
     Compound Basic Terrain Analysis
     ----------
@@ -134,7 +170,31 @@ def run_tool_ta_compound_0(ELEVATION=None, SHADE=None, SLOPE=None, ASPECT=None,
         return Tool.Execute(Verbose)
     return False
 
-def Compound_Morphometric_Terrain_Analysis(ELEVATION=None, SURFACE_AREA=None, SLOPE=None, ASPECT=None, NORTHNESS=None, EASTNESS=None, CONVERGENCE=None, CURVE_PLAN=None, CURVE_CROSS=None, CURVE_PROFILE=None, CURVE_LONGITUDE=None, CURVE_DOWNSLOPE=None, CURVE_UPSLOPE=None, MASS_BALANCE=None, CELL_BALANCE=None, TPI=None, TERRAIN_CONVEXITY=None, TERRAIN_TEXTURE=None, TRI=None, VRM=None, PROTECTION=None, OPENNESS_POS=None, OPENNESS_NEG=None, SCALE=None, Verbose=2):
+def Compound_Morphometric_Terrain_Analysis(
+    ELEVATION=None,
+    SURFACE_AREA=None,
+    SLOPE=None,
+    ASPECT=None,
+    NORTHNESS=None,
+    EASTNESS=None,
+    CONVERGENCE=None,
+    CURVE_PLAN=None,
+    CURVE_CROSS=None,
+    CURVE_PROFILE=None,
+    CURVE_LONGITUDE=None,
+    CURVE_DOWNSLOPE=None,
+    CURVE_UPSLOPE=None,
+    MASS_BALANCE=None,
+    CELL_BALANCE=None,
+    TPI=None,
+    TERRAIN_CONVEXITY=None,
+    TERRAIN_TEXTURE=None,
+    TRI=None,
+    VRM=None,
+    PROTECTION=None,
+    OPENNESS_POS=None,
+    OPENNESS_NEG=None,
+    SCALE=None, Verbose=2):
     '''
     Compound Morphometric Terrain Analysis
     ----------
@@ -213,7 +273,31 @@ def Compound_Morphometric_Terrain_Analysis(ELEVATION=None, SURFACE_AREA=None, SL
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_compound_1(ELEVATION=None, SURFACE_AREA=None, SLOPE=None, ASPECT=None, NORTHNESS=None, EASTNESS=None, CONVERGENCE=None, CURVE_PLAN=None, CURVE_CROSS=None, CURVE_PROFILE=None, CURVE_LONGITUDE=None, CURVE_DOWNSLOPE=None, CURVE_UPSLOPE=None, MASS_BALANCE=None, CELL_BALANCE=None, TPI=None, TERRAIN_CONVEXITY=None, TERRAIN_TEXTURE=None, TRI=None, VRM=None, PROTECTION=None, OPENNESS_POS=None, OPENNESS_NEG=None, SCALE=None, Verbose=2):
+def run_tool_ta_compound_1(
+    ELEVATION=None,
+    SURFACE_AREA=None,
+    SLOPE=None,
+    ASPECT=None,
+    NORTHNESS=None,
+    EASTNESS=None,
+    CONVERGENCE=None,
+    CURVE_PLAN=None,
+    CURVE_CROSS=None,
+    CURVE_PROFILE=None,
+    CURVE_LONGITUDE=None,
+    CURVE_DOWNSLOPE=None,
+    CURVE_UPSLOPE=None,
+    MASS_BALANCE=None,
+    CELL_BALANCE=None,
+    TPI=None,
+    TERRAIN_CONVEXITY=None,
+    TERRAIN_TEXTURE=None,
+    TRI=None,
+    VRM=None,
+    PROTECTION=None,
+    OPENNESS_POS=None,
+    OPENNESS_NEG=None,
+    SCALE=None, Verbose=2):
     '''
     Compound Morphometric Terrain Analysis
     ----------
@@ -292,7 +376,19 @@ def run_tool_ta_compound_1(ELEVATION=None, SURFACE_AREA=None, SLOPE=None, ASPECT
         return Tool.Execute(Verbose)
     return False
 
-def Compound_Hydrologic_Terrain_Analysis(ELEVATION=None, SINKS=None, TCA=None, SCA=None, TWI=None, TWI_SAGA=None, LS=None, SPI=None, CIT=None, METHOD_PREPROC=None, METHOD_FLOWACC=None, METHOD_LS=None, Verbose=2):
+def Compound_Hydrologic_Terrain_Analysis(
+    ELEVATION=None,
+    SINKS=None,
+    TCA=None,
+    SCA=None,
+    TWI=None,
+    TWI_SAGA=None,
+    LS=None,
+    SPI=None,
+    CIT=None,
+    METHOD_PREPROC=None,
+    METHOD_FLOWACC=None,
+    METHOD_LS=None, Verbose=2):
     '''
     Compound Hydrologic Terrain Analysis
     ----------
@@ -344,7 +440,19 @@ def Compound_Hydrologic_Terrain_Analysis(ELEVATION=None, SINKS=None, TCA=None, S
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_compound_2(ELEVATION=None, SINKS=None, TCA=None, SCA=None, TWI=None, TWI_SAGA=None, LS=None, SPI=None, CIT=None, METHOD_PREPROC=None, METHOD_FLOWACC=None, METHOD_LS=None, Verbose=2):
+def run_tool_ta_compound_2(
+    ELEVATION=None,
+    SINKS=None,
+    TCA=None,
+    SCA=None,
+    TWI=None,
+    TWI_SAGA=None,
+    LS=None,
+    SPI=None,
+    CIT=None,
+    METHOD_PREPROC=None,
+    METHOD_FLOWACC=None,
+    METHOD_LS=None, Verbose=2):
     '''
     Compound Hydrologic Terrain Analysis
     ----------
@@ -396,7 +504,20 @@ def run_tool_ta_compound_2(ELEVATION=None, SINKS=None, TCA=None, SCA=None, TWI=N
         return Tool.Execute(Verbose)
     return False
 
-def Compound_Channel_Network_Analysis(ELEVATION=None, CHANNELS=None, BASINS=None, SUBBASINS=None, HEADS=None, MOUTHS=None, FLOW_DISTANCE=None, FLOW_DISTHORZ=None, FLOW_DISTVERT=None, CHNL_BASE=None, CHNL_DIST=None, METHOD_PREPROC=None, THRESHOLD=None, Verbose=2):
+def Compound_Channel_Network_Analysis(
+    ELEVATION=None,
+    CHANNELS=None,
+    BASINS=None,
+    SUBBASINS=None,
+    HEADS=None,
+    MOUTHS=None,
+    FLOW_DISTANCE=None,
+    FLOW_DISTHORZ=None,
+    FLOW_DISTVERT=None,
+    CHNL_BASE=None,
+    CHNL_DIST=None,
+    METHOD_PREPROC=None,
+    THRESHOLD=None, Verbose=2):
     '''
     Compound Channel Network Analysis
     ----------
@@ -448,7 +569,20 @@ def Compound_Channel_Network_Analysis(ELEVATION=None, CHANNELS=None, BASINS=None
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_compound_3(ELEVATION=None, CHANNELS=None, BASINS=None, SUBBASINS=None, HEADS=None, MOUTHS=None, FLOW_DISTANCE=None, FLOW_DISTHORZ=None, FLOW_DISTVERT=None, CHNL_BASE=None, CHNL_DIST=None, METHOD_PREPROC=None, THRESHOLD=None, Verbose=2):
+def run_tool_ta_compound_3(
+    ELEVATION=None,
+    CHANNELS=None,
+    BASINS=None,
+    SUBBASINS=None,
+    HEADS=None,
+    MOUTHS=None,
+    FLOW_DISTANCE=None,
+    FLOW_DISTHORZ=None,
+    FLOW_DISTVERT=None,
+    CHNL_BASE=None,
+    CHNL_DIST=None,
+    METHOD_PREPROC=None,
+    THRESHOLD=None, Verbose=2):
     '''
     Compound Channel Network Analysis
     ----------
@@ -500,7 +634,16 @@ def run_tool_ta_compound_3(ELEVATION=None, CHANNELS=None, BASINS=None, SUBBASINS
         return Tool.Execute(Verbose)
     return False
 
-def Compound_Terrain_Classification(ELEVATION=None, SPECPOINTS=None, CURVATURE=None, FUZZY=None, MORPHOMETRIC=None, TPI=None, GEOMORPHONS=None, TERRAINSURF=None, SCALE=None, Verbose=2):
+def Compound_Terrain_Classification(
+    ELEVATION=None,
+    SPECPOINTS=None,
+    CURVATURE=None,
+    FUZZY=None,
+    MORPHOMETRIC=None,
+    TPI=None,
+    GEOMORPHONS=None,
+    TERRAINSURF=None,
+    SCALE=None, Verbose=2):
     '''
     Compound Terrain Classification
     ----------
@@ -544,7 +687,16 @@ def Compound_Terrain_Classification(ELEVATION=None, SPECPOINTS=None, CURVATURE=N
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_compound_4(ELEVATION=None, SPECPOINTS=None, CURVATURE=None, FUZZY=None, MORPHOMETRIC=None, TPI=None, GEOMORPHONS=None, TERRAINSURF=None, SCALE=None, Verbose=2):
+def run_tool_ta_compound_4(
+    ELEVATION=None,
+    SPECPOINTS=None,
+    CURVATURE=None,
+    FUZZY=None,
+    MORPHOMETRIC=None,
+    TPI=None,
+    GEOMORPHONS=None,
+    TERRAINSURF=None,
+    SCALE=None, Verbose=2):
     '''
     Compound Terrain Classification
     ----------
