@@ -14,7 +14,20 @@ Lighting and visibility related analyses for digital terrain models.
 
 from PySAGA.helper import Tool_Wrapper
 
-def Analytical_Hillshading(ELEVATION=None, SHADE=None, METHOD=None, POSITION=None, AZIMUTH=None, DECLINATION=None, DATE=None, TIME=None, EXAGGERATION=None, UNIT=None, SHADOW=None, NDIRS=None, RADIUS=None, Verbose=2):
+def Analytical_Hillshading(
+    ELEVATION=None,
+    SHADE=None,
+    METHOD=None,
+    POSITION=None,
+    AZIMUTH=None,
+    DECLINATION=None,
+    DATE=None,
+    TIME=None,
+    EXAGGERATION=None,
+    UNIT=None,
+    SHADOW=None,
+    NDIRS=None,
+    RADIUS=None, Verbose=2):
     '''
     Analytical Hillshading
     ----------
@@ -28,7 +41,7 @@ def Analytical_Hillshading(ELEVATION=None, SHADE=None, METHOD=None, POSITION=Non
     - POSITION [`choice`] : Sun's Position. Available Choices: [0] azimuth and height [1] date and time Default: 0
     - AZIMUTH [`floating point number`] : Azimuth. Minimum: 0.000000 Maximum: 360.000000 Default: 315.000000 Direction of the light source, measured in degree clockwise from the North direction.
     - DECLINATION [`floating point number`] : Height. Minimum: 0.000000 Maximum: 90.000000 Default: 45.000000 Height of the light source, measured in degree above the horizon.
-    - DATE [`date`] : Day. Default: 2025-01-20
+    - DATE [`date`] : Day. Default: 2025-04-01
     - TIME [`floating point number`] : Hour. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
     - EXAGGERATION [`floating point number`] : Exaggeration. Default: 1.000000 The terrain exaggeration factor allows one to increase the shading contrasts in flat areas.
     - UNIT [`choice`] : Unit. Available Choices: [0] radians [1] degree Default: 0
@@ -59,7 +72,20 @@ def Analytical_Hillshading(ELEVATION=None, SHADE=None, METHOD=None, POSITION=Non
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_lighting_0(ELEVATION=None, SHADE=None, METHOD=None, POSITION=None, AZIMUTH=None, DECLINATION=None, DATE=None, TIME=None, EXAGGERATION=None, UNIT=None, SHADOW=None, NDIRS=None, RADIUS=None, Verbose=2):
+def run_tool_ta_lighting_0(
+    ELEVATION=None,
+    SHADE=None,
+    METHOD=None,
+    POSITION=None,
+    AZIMUTH=None,
+    DECLINATION=None,
+    DATE=None,
+    TIME=None,
+    EXAGGERATION=None,
+    UNIT=None,
+    SHADOW=None,
+    NDIRS=None,
+    RADIUS=None, Verbose=2):
     '''
     Analytical Hillshading
     ----------
@@ -73,7 +99,7 @@ def run_tool_ta_lighting_0(ELEVATION=None, SHADE=None, METHOD=None, POSITION=Non
     - POSITION [`choice`] : Sun's Position. Available Choices: [0] azimuth and height [1] date and time Default: 0
     - AZIMUTH [`floating point number`] : Azimuth. Minimum: 0.000000 Maximum: 360.000000 Default: 315.000000 Direction of the light source, measured in degree clockwise from the North direction.
     - DECLINATION [`floating point number`] : Height. Minimum: 0.000000 Maximum: 90.000000 Default: 45.000000 Height of the light source, measured in degree above the horizon.
-    - DATE [`date`] : Day. Default: 2025-01-20
+    - DATE [`date`] : Day. Default: 2025-04-01
     - TIME [`floating point number`] : Hour. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
     - EXAGGERATION [`floating point number`] : Exaggeration. Default: 1.000000 The terrain exaggeration factor allows one to increase the shading contrasts in flat areas.
     - UNIT [`choice`] : Unit. Available Choices: [0] radians [1] degree Default: 0
@@ -104,7 +130,40 @@ def run_tool_ta_lighting_0(ELEVATION=None, SHADE=None, METHOD=None, POSITION=Non
         return Tool.Execute(Verbose)
     return False
 
-def Potential_Incoming_Solar_Radiation(GRD_DEM=None, GRD_SVF=None, GRD_VAPOUR=None, GRD_LINKE=None, GRD_DIRECT=None, GRD_DIFFUS=None, GRD_TOTAL=None, GRD_RATIO=None, GRD_FLAT=None, GRD_DURATION=None, GRD_SUNRISE=None, GRD_SUNSET=None, GRD_VAPOUR_DEFAULT=None, GRD_LINKE_DEFAULT=None, SOLARCONST=None, LOCALSVF=None, UNITS=None, SHADOW=None, LOCATION=None, LATITUDE=None, PERIOD=None, DAY=None, DAY_STOP=None, DAYS_STEP=None, MOMENT=None, HOUR_RANGE=None, HOUR_STEP=None, METHOD=None, ATMOSPHERE=None, PRESSURE=None, WATER=None, DUST=None, LUMPED=None, Verbose=2):
+def Potential_Incoming_Solar_Radiation(
+    GRD_DEM=None,
+    GRD_SVF=None,
+    GRD_VAPOUR=None,
+    GRD_LINKE=None,
+    GRD_DIRECT=None,
+    GRD_DIFFUS=None,
+    GRD_TOTAL=None,
+    GRD_RATIO=None,
+    GRD_FLAT=None,
+    GRD_DURATION=None,
+    GRD_SUNRISE=None,
+    GRD_SUNSET=None,
+    GRD_VAPOUR_DEFAULT=None,
+    GRD_LINKE_DEFAULT=None,
+    SOLARCONST=None,
+    LOCALSVF=None,
+    UNITS=None,
+    SHADOW=None,
+    LOCATION=None,
+    LATITUDE=None,
+    PERIOD=None,
+    DAY=None,
+    DAY_STOP=None,
+    DAYS_STEP=None,
+    MOMENT=None,
+    HOUR_RANGE=None,
+    HOUR_STEP=None,
+    METHOD=None,
+    ATMOSPHERE=None,
+    PRESSURE=None,
+    WATER=None,
+    DUST=None,
+    LUMPED=None, Verbose=2):
     '''
     Potential Incoming Solar Radiation
     ----------
@@ -134,8 +193,8 @@ def Potential_Incoming_Solar_Radiation(GRD_DEM=None, GRD_SVF=None, GRD_VAPOUR=No
     - LOCATION [`choice`] : Location. Available Choices: [0] constant latitude [1] calculate from grid system Default: 0
     - LATITUDE [`degree`] : Latitude. Minimum: -90.000000 Maximum: 90.000000 Default: 53.000000
     - PERIOD [`choice`] : Time Period. Available Choices: [0] moment [1] day [2] range of days Default: 1 Momentum output will be in units of power [W/m²], time span will be in units of energy, either [kWh/m²], [kJ/m²], or [J/cm²].
-    - DAY [`date`] : Day. Default: 2025-01-20
-    - DAY_STOP [`date`] : Last Day. Default: 2025-01-20
+    - DAY [`date`] : Day. Default: 2025-04-01
+    - DAY_STOP [`date`] : Last Day. Default: 2025-04-01
     - DAYS_STEP [`integer number`] : Resolution [d]. Minimum: 1 Default: 5 Time step size for a range of days calculation given in days.
     - MOMENT [`floating point number`] : Moment [h]. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
     - HOUR_RANGE [`value range`] : Time Span [h]. Time span used for the calculation of daily radiation sums.
@@ -190,7 +249,40 @@ def Potential_Incoming_Solar_Radiation(GRD_DEM=None, GRD_SVF=None, GRD_VAPOUR=No
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_lighting_2(GRD_DEM=None, GRD_SVF=None, GRD_VAPOUR=None, GRD_LINKE=None, GRD_DIRECT=None, GRD_DIFFUS=None, GRD_TOTAL=None, GRD_RATIO=None, GRD_FLAT=None, GRD_DURATION=None, GRD_SUNRISE=None, GRD_SUNSET=None, GRD_VAPOUR_DEFAULT=None, GRD_LINKE_DEFAULT=None, SOLARCONST=None, LOCALSVF=None, UNITS=None, SHADOW=None, LOCATION=None, LATITUDE=None, PERIOD=None, DAY=None, DAY_STOP=None, DAYS_STEP=None, MOMENT=None, HOUR_RANGE=None, HOUR_STEP=None, METHOD=None, ATMOSPHERE=None, PRESSURE=None, WATER=None, DUST=None, LUMPED=None, Verbose=2):
+def run_tool_ta_lighting_2(
+    GRD_DEM=None,
+    GRD_SVF=None,
+    GRD_VAPOUR=None,
+    GRD_LINKE=None,
+    GRD_DIRECT=None,
+    GRD_DIFFUS=None,
+    GRD_TOTAL=None,
+    GRD_RATIO=None,
+    GRD_FLAT=None,
+    GRD_DURATION=None,
+    GRD_SUNRISE=None,
+    GRD_SUNSET=None,
+    GRD_VAPOUR_DEFAULT=None,
+    GRD_LINKE_DEFAULT=None,
+    SOLARCONST=None,
+    LOCALSVF=None,
+    UNITS=None,
+    SHADOW=None,
+    LOCATION=None,
+    LATITUDE=None,
+    PERIOD=None,
+    DAY=None,
+    DAY_STOP=None,
+    DAYS_STEP=None,
+    MOMENT=None,
+    HOUR_RANGE=None,
+    HOUR_STEP=None,
+    METHOD=None,
+    ATMOSPHERE=None,
+    PRESSURE=None,
+    WATER=None,
+    DUST=None,
+    LUMPED=None, Verbose=2):
     '''
     Potential Incoming Solar Radiation
     ----------
@@ -220,8 +312,8 @@ def run_tool_ta_lighting_2(GRD_DEM=None, GRD_SVF=None, GRD_VAPOUR=None, GRD_LINK
     - LOCATION [`choice`] : Location. Available Choices: [0] constant latitude [1] calculate from grid system Default: 0
     - LATITUDE [`degree`] : Latitude. Minimum: -90.000000 Maximum: 90.000000 Default: 53.000000
     - PERIOD [`choice`] : Time Period. Available Choices: [0] moment [1] day [2] range of days Default: 1 Momentum output will be in units of power [W/m²], time span will be in units of energy, either [kWh/m²], [kJ/m²], or [J/cm²].
-    - DAY [`date`] : Day. Default: 2025-01-20
-    - DAY_STOP [`date`] : Last Day. Default: 2025-01-20
+    - DAY [`date`] : Day. Default: 2025-04-01
+    - DAY_STOP [`date`] : Last Day. Default: 2025-04-01
     - DAYS_STEP [`integer number`] : Resolution [d]. Minimum: 1 Default: 5 Time step size for a range of days calculation given in days.
     - MOMENT [`floating point number`] : Moment [h]. Minimum: 0.000000 Maximum: 24.000000 Default: 12.000000
     - HOUR_RANGE [`value range`] : Time Span [h]. Time span used for the calculation of daily radiation sums.
@@ -276,7 +368,17 @@ def run_tool_ta_lighting_2(GRD_DEM=None, GRD_SVF=None, GRD_VAPOUR=None, GRD_LINK
         return Tool.Execute(Verbose)
     return False
 
-def Sky_View_Factor(DEM=None, VISIBLE=None, SVF=None, SIMPLE=None, TERRAIN=None, DISTANCE=None, RADIUS=None, NDIRS=None, METHOD=None, DLEVEL=None, Verbose=2):
+def Sky_View_Factor(
+    DEM=None,
+    VISIBLE=None,
+    SVF=None,
+    SIMPLE=None,
+    TERRAIN=None,
+    DISTANCE=None,
+    RADIUS=None,
+    NDIRS=None,
+    METHOD=None,
+    DLEVEL=None, Verbose=2):
     '''
     Sky View Factor
     ----------
@@ -315,7 +417,17 @@ def Sky_View_Factor(DEM=None, VISIBLE=None, SVF=None, SIMPLE=None, TERRAIN=None,
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_lighting_3(DEM=None, VISIBLE=None, SVF=None, SIMPLE=None, TERRAIN=None, DISTANCE=None, RADIUS=None, NDIRS=None, METHOD=None, DLEVEL=None, Verbose=2):
+def run_tool_ta_lighting_3(
+    DEM=None,
+    VISIBLE=None,
+    SVF=None,
+    SIMPLE=None,
+    TERRAIN=None,
+    DISTANCE=None,
+    RADIUS=None,
+    NDIRS=None,
+    METHOD=None,
+    DLEVEL=None, Verbose=2):
     '''
     Sky View Factor
     ----------
@@ -354,7 +466,18 @@ def run_tool_ta_lighting_3(DEM=None, VISIBLE=None, SVF=None, SIMPLE=None, TERRAI
         return Tool.Execute(Verbose)
     return False
 
-def Topographic_Openness(DEM=None, POS=None, NEG=None, RADIUS=None, DIRECTIONS=None, DIRECTION=None, NDIRS=None, METHOD=None, DLEVEL=None, UNIT=None, NADIR=None, Verbose=2):
+def Topographic_Openness(
+    DEM=None,
+    POS=None,
+    NEG=None,
+    RADIUS=None,
+    DIRECTIONS=None,
+    DIRECTION=None,
+    NDIRS=None,
+    METHOD=None,
+    DLEVEL=None,
+    UNIT=None,
+    NADIR=None, Verbose=2):
     '''
     Topographic Openness
     ----------
@@ -395,7 +518,18 @@ def Topographic_Openness(DEM=None, POS=None, NEG=None, RADIUS=None, DIRECTIONS=N
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_lighting_5(DEM=None, POS=None, NEG=None, RADIUS=None, DIRECTIONS=None, DIRECTION=None, NDIRS=None, METHOD=None, DLEVEL=None, UNIT=None, NADIR=None, Verbose=2):
+def run_tool_ta_lighting_5(
+    DEM=None,
+    POS=None,
+    NEG=None,
+    RADIUS=None,
+    DIRECTIONS=None,
+    DIRECTION=None,
+    NDIRS=None,
+    METHOD=None,
+    DLEVEL=None,
+    UNIT=None,
+    NADIR=None, Verbose=2):
     '''
     Topographic Openness
     ----------
@@ -436,7 +570,16 @@ def run_tool_ta_lighting_5(DEM=None, POS=None, NEG=None, RADIUS=None, DIRECTIONS
         return Tool.Execute(Verbose)
     return False
 
-def Visibility_Analysis(ELEVATION=None, POINTS=None, VISIBILITY=None, METHOD=None, UNIT=None, CUMULATIVE=None, NODATA=None, HEIGHT=None, HEIGHT_DEFAULT=None, Verbose=2):
+def Visibility_Analysis(
+    ELEVATION=None,
+    POINTS=None,
+    VISIBILITY=None,
+    METHOD=None,
+    UNIT=None,
+    CUMULATIVE=None,
+    NODATA=None,
+    HEIGHT=None,
+    HEIGHT_DEFAULT=None, Verbose=2):
     '''
     Visibility Analysis
     ----------
@@ -473,7 +616,16 @@ def Visibility_Analysis(ELEVATION=None, POINTS=None, VISIBILITY=None, METHOD=Non
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_lighting_6(ELEVATION=None, POINTS=None, VISIBILITY=None, METHOD=None, UNIT=None, CUMULATIVE=None, NODATA=None, HEIGHT=None, HEIGHT_DEFAULT=None, Verbose=2):
+def run_tool_ta_lighting_6(
+    ELEVATION=None,
+    POINTS=None,
+    VISIBILITY=None,
+    METHOD=None,
+    UNIT=None,
+    CUMULATIVE=None,
+    NODATA=None,
+    HEIGHT=None,
+    HEIGHT_DEFAULT=None, Verbose=2):
     '''
     Visibility Analysis
     ----------
@@ -510,7 +662,13 @@ def run_tool_ta_lighting_6(ELEVATION=None, POINTS=None, VISIBILITY=None, METHOD=
         return Tool.Execute(Verbose)
     return False
 
-def Potential_Annual_Insolation(DEM=None, INSOLATION=None, STEPS=None, UNITS=None, HOUR_STEP=None, YEAR=None, Verbose=2):
+def Potential_Annual_Insolation(
+    DEM=None,
+    INSOLATION=None,
+    STEPS=None,
+    UNITS=None,
+    HOUR_STEP=None,
+    YEAR=None, Verbose=2):
     '''
     Potential Annual Insolation
     ----------
@@ -541,7 +699,13 @@ def Potential_Annual_Insolation(DEM=None, INSOLATION=None, STEPS=None, UNITS=Non
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_lighting_7(DEM=None, INSOLATION=None, STEPS=None, UNITS=None, HOUR_STEP=None, YEAR=None, Verbose=2):
+def run_tool_ta_lighting_7(
+    DEM=None,
+    INSOLATION=None,
+    STEPS=None,
+    UNITS=None,
+    HOUR_STEP=None,
+    YEAR=None, Verbose=2):
     '''
     Potential Annual Insolation
     ----------
@@ -572,7 +736,13 @@ def run_tool_ta_lighting_7(DEM=None, INSOLATION=None, STEPS=None, UNITS=None, HO
         return Tool.Execute(Verbose)
     return False
 
-def Geomorphons(DEM=None, GEOMORPHONS=None, THRESHOLD=None, RADIUS=None, METHOD=None, DLEVEL=None, Verbose=2):
+def Geomorphons(
+    DEM=None,
+    GEOMORPHONS=None,
+    THRESHOLD=None,
+    RADIUS=None,
+    METHOD=None,
+    DLEVEL=None, Verbose=2):
     '''
     Geomorphons
     ----------
@@ -603,7 +773,13 @@ def Geomorphons(DEM=None, GEOMORPHONS=None, THRESHOLD=None, RADIUS=None, METHOD=
         return Tool.Execute(Verbose)
     return False
 
-def run_tool_ta_lighting_8(DEM=None, GEOMORPHONS=None, THRESHOLD=None, RADIUS=None, METHOD=None, DLEVEL=None, Verbose=2):
+def run_tool_ta_lighting_8(
+    DEM=None,
+    GEOMORPHONS=None,
+    THRESHOLD=None,
+    RADIUS=None,
+    METHOD=None,
+    DLEVEL=None, Verbose=2):
     '''
     Geomorphons
     ----------
