@@ -55,9 +55,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -73,9 +73,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -96,9 +96,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -116,9 +116,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -170,9 +170,9 @@ typedef unsigned long long		uLong;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //                   Parallelization                     //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -183,9 +183,9 @@ SAGA_API_DLL_EXPORT int				SG_OMP_Get_Thread_Num		(void);
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Memory							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -216,7 +216,7 @@ SAGA_API_DLL_EXPORT void			SG_Mem_Set_Double	(char *Buffer, double Value, bool b
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -281,9 +281,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -360,7 +360,7 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -415,7 +415,7 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -471,7 +471,7 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -527,9 +527,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						String							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -635,7 +635,9 @@ public:
 	int								Printf				(const char    *Format, ...);
 	int								Printf				(const wchar_t *Format, ...);
 
-	size_t							Replace				(const CSG_String &sOld, const CSG_String &sNew, bool bReplaceAll = true);
+	size_t							Replace				(const CSG_String &Old, const CSG_String &New, bool bReplaceAll = true);
+	size_t							Replace_Single_Char	(const SG_Char     Old, const CSG_String &New, bool bReplaceAll = true);
+	size_t							Replace_Single_Char	(const SG_Char     Old, const SG_Char     New, bool bReplaceAll = true);
 
 	CSG_String &					Remove				(size_t pos);
 	CSG_String &					Remove				(size_t pos, size_t len);
@@ -802,9 +804,9 @@ SAGA_API_DLL_EXPORT CSG_String		SG_HTML_Tag_Replacer			(const CSG_String &Text);
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -921,9 +923,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -983,9 +985,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Data Types						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1090,16 +1092,17 @@ SAGA_API_DLL_EXPORT bool			SG_Data_Type_Range_Check	(TSG_Data_Type Type, double
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						File							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 typedef enum
 {
 	SG_FILE_TYPE_NORMAL,
-	SG_FILE_TYPE_ZIP
+	SG_FILE_TYPE_ZIP,
+	SG_FILE_TYPE_TAR
 }
 TSG_File_Type;
 
@@ -1127,8 +1130,8 @@ public:
 	CSG_File(void);
 	virtual ~CSG_File(void);
 
-									CSG_File			(const CSG_String &FileName, int Mode = SG_FILE_R, bool bBinary = true, int Encoding = SG_FILE_ENCODING_ANSI);
-	virtual bool					Open				(const CSG_String &FileName, int Mode = SG_FILE_R, bool bBinary = true, int Encoding = SG_FILE_ENCODING_ANSI);
+									CSG_File			(const SG_Char *FileName, int Mode = SG_FILE_R, bool bBinary = true, int Encoding = SG_FILE_ENCODING_ANSI);
+	virtual bool					Open				(const SG_Char *FileName, int Mode = SG_FILE_R, bool bBinary = true, int Encoding = SG_FILE_ENCODING_ANSI);
 
 	virtual bool					Close				(void);
 
@@ -1153,6 +1156,8 @@ public:
 
 	sLong							Tell				(void)	const;
 
+	bool							Flush				(void);
+
 	int								Printf				(const char    *Format, ...);
 	int								Printf				(const wchar_t *Format, ...);
 
@@ -1161,7 +1166,7 @@ public:
 	size_t							Read				(      CSG_String &Buffer, size_t Size)	const;
 	size_t							Write				(const CSG_String &Buffer)				const;
 
-	bool							Read_Line			(CSG_String &sLine)	const;
+	bool							Read_Line			(CSG_String &Line)	const;
 
 	int								Read_Char			(void)	const;
 	int								Read_Int			(				bool bBigEndian = false)	const;
@@ -1192,45 +1197,72 @@ protected:
 };
 
 //---------------------------------------------------------
-class SAGA_API_DLL_EXPORT CSG_File_Zip : public CSG_File
+class SAGA_API_DLL_EXPORT CSG_Archive : public CSG_File
 {
 public:
 
-	CSG_File_Zip(void);
-	virtual ~CSG_File_Zip(void);
+	CSG_Archive(void);
+	virtual ~CSG_Archive(void);
 
-									CSG_File_Zip		(const CSG_String &FileName, int Mode = SG_FILE_R, int Encoding = SG_FILE_ENCODING_ANSI);
-	virtual bool					Open				(const CSG_String &FileName, int Mode = SG_FILE_R, int Encoding = SG_FILE_ENCODING_ANSI);
+									CSG_Archive			(const SG_Char *FileName, int Mode = SG_FILE_R, int Encoding = SG_FILE_ENCODING_ANSI);
+	virtual bool					Open				(const SG_Char *FileName, int Mode = SG_FILE_R, int Encoding = SG_FILE_ENCODING_ANSI);
+	virtual bool					Open				(const SG_Char *FileName, int Mode, bool bBinary, int Encoding) { return( Open(FileName, Mode, Encoding) ); }
 
 	virtual bool					Close				(void);
 
-	virtual TSG_File_Type			Get_File_Type		(void)	const	{	return( SG_FILE_TYPE_ZIP );	}
+	virtual const CSG_String &		Get_Archive			(void)	const	{	return( m_Archive );	}
+	virtual TSG_File_Type			Get_File_Type		(void)	const	{	return( m_Type    );	}
+	bool							is_Zip				(void)	const	{	return( m_Type == SG_FILE_TYPE_ZIP ); }
+	bool							is_Tar				(void)	const	{	return( m_Type == SG_FILE_TYPE_TAR ); }
 
-	bool							Add_Directory		(const CSG_String &Name);
-	bool							Add_File			(const CSG_String &Name, bool bBinary = true);
+	bool							Add_Directory		(const SG_Char *Name);
+	bool							Add_File			(const SG_Char *Name, bool bBinary = true);
 
 	size_t							Get_File_Count		(void)	{	return( m_Files.Get_Size() );	}
-	bool							Get_File			(const CSG_String &Name);
+	bool							Get_File			(const SG_Char *Name);
 	bool							Get_File			(size_t Index);
 	virtual CSG_String				Get_File_Name		(size_t Index);
 	bool							is_Directory		(size_t Index);
 
+	bool							Extract_All			(const SG_Char *toDirectory = NULL);
+	bool							Extract				(const SG_Char *File, const SG_Char *toFile = NULL);
+
 
 protected:
 
+	TSG_File_Type					m_Type = SG_FILE_TYPE_NORMAL;
+
+	CSG_String						m_Archive;
+
 	CSG_Array_Pointer				m_Files;
 
 };
 
+//---------------------------------------------------------
+class SAGA_API_DLL_EXPORT CSG_ZLib
+{
+public:
+
+	CSG_ZLib(void);
+
+	static bool						is_GZip_Supported			(void);
+
+	static CSG_String				Compress					(const CSG_String &File, const CSG_String &Target = "");
+	static CSG_String				Uncompress					(const CSG_String &File, const CSG_String &Target = "");
+
+};
+
+//---------------------------------------------------------
+#define CSG_File_Zip CSG_Archive // for backward compatibility
+
 //---------------------------------------------------------
 SAGA_API_DLL_EXPORT bool			SG_Dir_Exists				(const CSG_String &Directory);
 SAGA_API_DLL_EXPORT bool			SG_Dir_Create				(const CSG_String &Directory, bool bFullPath = false);
 SAGA_API_DLL_EXPORT bool			SG_Dir_Delete				(const CSG_String &Directory, bool bRecursive = false);
 SAGA_API_DLL_EXPORT CSG_String		SG_Dir_Get_Current			(void);
 SAGA_API_DLL_EXPORT CSG_String		SG_Dir_Get_Temp				(void);
-SAGA_API_DLL_EXPORT bool			SG_Dir_List_Subdirectories	(CSG_Strings &List, const CSG_String &Directory);
-SAGA_API_DLL_EXPORT bool			SG_Dir_List_Files			(CSG_Strings &List, const CSG_String &Directory);
-SAGA_API_DLL_EXPORT bool			SG_Dir_List_Files			(CSG_Strings &List, const CSG_String &Directory, const CSG_String &Extension);
+SAGA_API_DLL_EXPORT bool			SG_Dir_List_Subdirectories	(CSG_Strings &List, const CSG_String &Directory                                  , bool bRecursive = false);
+SAGA_API_DLL_EXPORT bool			SG_Dir_List_Files			(CSG_Strings &List, const CSG_String &Directory, const CSG_String &Extension = "", bool bRecursive = false);
 
 SAGA_API_DLL_EXPORT bool			SG_File_Exists				(const CSG_String &FileName);
 SAGA_API_DLL_EXPORT bool			SG_File_Delete				(const CSG_String &FileName);
@@ -1243,9 +1275,9 @@ SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_Path_Relative	(const CSG_String &Dir
 SAGA_API_DLL_EXPORT CSG_String		SG_File_Make_Path			(const CSG_String &Directory, const CSG_String &Name);
 SAGA_API_DLL_EXPORT CSG_String		SG_File_Make_Path			(const CSG_String &Directory, const CSG_String &Name, const CSG_String &Extension);
 SAGA_API_DLL_EXPORT bool			SG_File_Cmp_Path			(const CSG_String &Path1, const CSG_String &Path2);
-SAGA_API_DLL_EXPORT bool			SG_File_Cmp_Extension		(const CSG_String &FileName, const CSG_String &Extension);
-SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_Extension		(const CSG_String &FileName);
-SAGA_API_DLL_EXPORT bool			SG_File_Set_Extension		(      CSG_String &FileName, const CSG_String &Extension);
+SAGA_API_DLL_EXPORT bool			SG_File_Cmp_Extension		(const CSG_String &File, const CSG_String &Extension);
+SAGA_API_DLL_EXPORT CSG_String		SG_File_Get_Extension		(const CSG_String &File);
+SAGA_API_DLL_EXPORT bool			SG_File_Set_Extension		(      CSG_String &File, const CSG_String &Extension);
 
 //---------------------------------------------------------
 SAGA_API_DLL_EXPORT bool			SG_Get_Environment			(const CSG_String &Variable,       CSG_String *Value = NULL);
@@ -1253,9 +1285,9 @@ SAGA_API_DLL_EXPORT bool			SG_Set_Environment			(const CSG_String &Variable, con
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Colors							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1291,37 +1323,72 @@ SAGA_API_DLL_EXPORT bool			SG_Set_Environment			(const CSG_String &Variable, con
 //---------------------------------------------------------
 enum ESG_Colors
 {
-	SG_COLORS_DEFAULT			= 0,
+	SG_COLORS_DEFAULT = 0,
 	SG_COLORS_DEFAULT_BRIGHT,
+	SG_COLORS_RAINBOW,
+	SG_COLORS_RAINBOW_2,
+
 	SG_COLORS_BLACK_WHITE,
 	SG_COLORS_BLACK_RED,
 	SG_COLORS_BLACK_GREEN,
 	SG_COLORS_BLACK_BLUE,
+
 	SG_COLORS_WHITE_RED,
 	SG_COLORS_WHITE_GREEN,
 	SG_COLORS_WHITE_BLUE,
+
 	SG_COLORS_YELLOW_RED,
 	SG_COLORS_YELLOW_GREEN,
 	SG_COLORS_YELLOW_BLUE,
+
+	SG_COLORS_BLUE_RED,
 	SG_COLORS_GREEN_RED,
-	SG_COLORS_RED_GREEN,
-	SG_COLORS_RED_BLUE,
 	SG_COLORS_GREEN_BLUE,
+
+	SG_COLORS_BLUE_WHITE_RED,
+	SG_COLORS_GREEN_WHITE_RED,
+	SG_COLORS_GREEN_WHITE_BLUE,
+
+	SG_COLORS_BLUE_GREY_RED,
 	SG_COLORS_RED_GREY_BLUE,
+	SG_COLORS_GREEN_GREY_RED,
 	SG_COLORS_RED_GREY_GREEN,
 	SG_COLORS_GREEN_GREY_BLUE,
+
+	SG_COLORS_BLUE_YELLOW_RED,
+	SG_COLORS_GREEN_YELLOW_RED,
+	SG_COLORS_RED_YELLOW_GREEN,
+	SG_COLORS_GREEN_YELLOW_BLUE,
+
 	SG_COLORS_RED_GREEN_BLUE,
 	SG_COLORS_RED_BLUE_GREEN,
 	SG_COLORS_GREEN_RED_BLUE,
-	SG_COLORS_RAINBOW,
 	SG_COLORS_NEON,
+
 	SG_COLORS_TOPOGRAPHY,
 	SG_COLORS_TOPOGRAPHY_2,
 	SG_COLORS_TOPOGRAPHY_3,
-	SG_COLORS_PRECIPITATION,
+	SG_COLORS_TOPOGRAPHY_4,
+
 	SG_COLORS_ASPECT_1,
 	SG_COLORS_ASPECT_2,
 	SG_COLORS_ASPECT_3,
+
+	SG_COLORS_THERMAL_1,
+	SG_COLORS_THERMAL_2,
+
+	SG_COLORS_PRECIPITATION_1,
+	SG_COLORS_PRECIPITATION_2,
+	SG_COLORS_PRECIPITATION_3,
+	SG_COLORS_PRECIPITATION_4,
+	SG_COLORS_PRECIPITATION_5,
+
+	SG_COLORS_VEGETATION,
+
+	SG_COLORS_SPECTRUM_1,
+	SG_COLORS_SPECTRUM_2,
+	SG_COLORS_SPECTRUM_3,
+
 	SG_COLORS_COUNT
 };
 
@@ -1385,8 +1452,8 @@ public:
 
 	static int						Get_Predefined_Count(void);
 	static CSG_String				Get_Predefined_Name	(int Identifier);
-	bool							Set_Predefined		(int Index, bool bRevert = false, int nColors = 11);
-	bool							Set_Palette			(int Index, bool bRevert = false, int nColors = 11)	{	return( Set_Predefined(Index, bRevert, nColors) );	}
+	bool							Set_Predefined		(int Index, bool bRevert = false, int nColors = 0);
+	bool							Set_Palette			(int Index, bool bRevert = false, int nColors = 0)	{	return( Set_Predefined(Index, bRevert, nColors) );	}
 	bool							Set_Default			(int nColors = 11);
 	bool							Set_Ramp			(long Color_A, long Color_B);
 	bool							Set_Ramp			(long Color_A, long Color_B, int iColor_A, int iColor_B);
@@ -1423,9 +1490,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Translator						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1491,9 +1558,9 @@ SAGA_API_DLL_EXPORT const SG_Char *		SG_Translate		(const CSG_String &Text);
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						UI Callback						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1571,6 +1638,7 @@ typedef enum
 	CALLBACK_MESSAGE_ADD_EXECUTION,
 
 	CALLBACK_DATAOBJECT_ADD,
+	CALLBACK_DATAOBJECT_DEL,
 	CALLBACK_DATAOBJECT_UPDATE,
 	CALLBACK_DATAOBJECT_SHOW,
 	CALLBACK_DATAOBJECT_ASIMAGE,
@@ -1672,6 +1740,7 @@ SAGA_API_DLL_EXPORT void					SG_UI_ProgressAndMsg_Lock	(bool bOn);
 SAGA_API_DLL_EXPORT void					SG_UI_ProgressAndMsg_Reset	(void);
 
 SAGA_API_DLL_EXPORT bool					SG_UI_DataObject_Add		(class CSG_Data_Object *pDataObject, int Show);
+SAGA_API_DLL_EXPORT bool					SG_UI_DataObject_Del		(class CSG_Data_Object *pDataObject, bool bConfirm);
 SAGA_API_DLL_EXPORT bool					SG_UI_DataObject_Update		(class CSG_Data_Object *pDataObject, int Show, class CSG_Parameters *pParameters);
 SAGA_API_DLL_EXPORT bool					SG_UI_DataObject_Show		(class CSG_Data_Object *pDataObject, int Show);
 SAGA_API_DLL_EXPORT bool					SG_UI_DataObject_asImage	(class CSG_Data_Object *pDataObject, class CSG_Grid *pGrid);
@@ -1692,23 +1761,25 @@ SAGA_API_DLL_EXPORT int						SG_UI_Window_Arrange		(int Arrange);
 SAGA_API_DLL_EXPORT void *					SG_UI_Get_Window_Main		(void);
 SAGA_API_DLL_EXPORT CSG_String				SG_UI_Get_Application_Path	(bool bPathOnly = false);
 SAGA_API_DLL_EXPORT CSG_String				SG_UI_Get_Application_Name	(void);
+SAGA_API_DLL_EXPORT CSG_String				SG_UI_Set_Application_Name	(const CSG_String &Name = "");
+SAGA_API_DLL_EXPORT CSG_String				SG_UI_Get_API_Path			(void);
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //                     Environment                       //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-SAGA_API_DLL_EXPORT bool					SG_Initialize_Environment	(bool bLibraries = true, bool bProjections = true, const SG_Char *Directory = NULL, bool bInitializeWX = true);
+SAGA_API_DLL_EXPORT bool					SG_Initialize_Environment	(bool bLibraries = true, bool bProjections = true, const SG_Char *SAGA_Path = NULL, bool bInitializeWX = true);
 SAGA_API_DLL_EXPORT bool					SG_Uninitialize_Environment	(void);
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
