@@ -566,22 +566,45 @@ size_t CSG_String::Replace(const CSG_String &sOld, const CSG_String &sNew, bool
 }
 
 //---------------------------------------------------------
-size_t CSG_String::Replace_Single_Char(SG_Char Old, SG_Char New, bool bReplaceAll)
+size_t CSG_String::Replace_Single_Char(const SG_Char Old, const CSG_String &New, bool bReplaceAll)
+{
+	size_t n = 0; CSG_String s;
+
+	for(size_t i=0; i<Length(); i++)
+	{
+		if( (n == 0 || bReplaceAll)
+		&&  Get_Char(i) == Old && ((i < 1 || !isalnum(Get_Char(i - 1))) && (i >= Length() - 1 || !isalnum(Get_Char(i + 1)))) )
+		{
+			s += New; n++;
+		}
+		else
+		{
+			s += Get_Char(i);
+		}
+	}
+
+	if( n )
+	{
+		*m_pString	= *s.m_pString;
+	}
+
+	return( n );
+}
+
+//---------------------------------------------------------
+size_t CSG_String::Replace_Single_Char(const SG_Char Old, const SG_Char New, bool bReplaceAll)
 {
 	size_t n = 0;
 
 	for(size_t i=0; i<Length(); i++)
 	{
-		if( Get_Char(i) == Old )
+		if( Get_Char(i) == Old && ((i < 1 || !isalnum(Get_Char(i - 1))) && (i >= Length() - 1 || !isalnum(Get_Char(i + 1)))) )
 		{
-			if( (i < 1 || !isalnum(Get_Char(i - 1))) && (i >= Length() - 1 || !isalnum(Get_Char(i + 1))) )
-			{
-				Set_Char(i, New); n++;
+			Set_Char(i, New); n++;
 
-				if( !bReplaceAll )
-				{
-					return( n );
-				}
+			if( !bReplaceAll )
+			{
+				return( n );
 			}
 		}
 	}
@@ -1332,6 +1355,8 @@ void			SG_Flip_Decimal_Separators(CSG_String &String)
   * If Precision is -99 (the default) it will simply use %f format.
   * If 'Precision' is -98 the string will always be formatted
   * with the %e format specification (i.e. scientific: d.dddd e dd).
+  * If 'Precision' is -97 the string will be formatted with the
+  * %e or %f format specification depended on which produces the shorter string.
   * If Precision is zero (= 0) no decimals will be printed
   * If Precision is positive (> 0) it specifies the fix number
   * of decimals ("%.*f", Precision, Value),
@@ -1341,7 +1366,7 @@ void			SG_Flip_Decimal_Separators(CSG_String &String)
 //---------------------------------------------------------
 CSG_String		SG_Get_String(double Value, int Precision)
 {
-	CSG_String	s;
+	CSG_String s;
 
 	if     ( Precision == -99 )
 	{
@@ -1351,6 +1376,10 @@ CSG_String		SG_Get_String(double Value, int Precision)
 	{
 		s.Printf("%e", Value);
 	}
+	else if( Precision == -97 )
+	{
+		s.Printf("%g", Value);
+	}
 	else if( Precision ==   0 )
 	{
 		s.Printf("%d", (int)Value);
@@ -1361,24 +1390,28 @@ CSG_String		SG_Get_String(double Value, int Precision)
 	}
 	else // if( Precision < 0 )
 	{
-		Precision	= SG_Get_Significant_Decimals(Value, abs(Precision));
+		int Decimals = SG_Get_Significant_Decimals(Value, 18); Precision = abs(Precision);
 
-		if( Precision == 0 )
+		if( Decimals == 0 )
 		{
-			s.Printf("%.0f", Value);
+			s.Printf("%d", (int)Value);
 		}
-		else // if( Precision > 0 )
+		else if( Decimals > Precision )
 		{
-			s.Printf("%.*f", Precision, Value);
+			s.Printf("%g", Value);
+		}
+		else // if( Decimals <= Precision )
+		{
+			s.Printf("%.*f", Decimals, Value);
 
 			while( s.Length() > 1 && s[s.Length() - 1] == '0' )
 			{
-				s	= s.Left(s.Length() - 1);
+				s = s.Left(s.Length() - 1);
 			}
 
 			if( s.Length() > 1 && (s[s.Length() - 1] == '.' || s[s.Length() - 1] == ',') )
 			{
-				s	= s.Left(s.Length() - 1);
+				s = s.Left(s.Length() - 1);
 			}
 		}
 	}
