@@ -677,15 +677,25 @@ CSG_String CSG_DateTime::Get_Month_Choices(void)
 //---------------------------------------------------------
 bool		SG_JulianDayNumber_To_Date(double JDN, int &y, int &m, int &d)
 {
-	int	J	= (int)floor(JDN);
-	int	f	= J + 1401 + (((4 * J + 274277) / 146097) * 3) / 4 - 38;
-	int	e	= 4 * f + 3;
-	int	g	= (e % 1461) / 4;
-	int	h	= 5 * g + 2;
+	double Z = floor(JDN + 0.5);
+	double F = JDN + 0.5 - Z;
+	double a = floor((Z - 1867216.25) / 36524.25);
+	double A = Z + 1 + a - floor(a / 4);
+	double B = A + 1524;
+	double C = floor((B - 122.1) / 365.25);
+	double D = floor(365.25 * C);
+	double E = floor((B - D) / 30.6001);
 
-	d	= (h % 153) / 5 + 1;
-	m	= (h / 153 + 2) % 12 + 1;
-	y	= (e / 1461) - 4716 + (12 + 2 - m) / 12; 
+	d = int(B - D - floor(30.6001 * E) + F);
+
+	if( E <= 13 )
+	{
+		m = E -  1; y = C - 4716;
+	}
+	else
+	{
+		m = E - 13; y = C - 4715;
+	}
 
 	return( true );
 }
@@ -697,11 +707,7 @@ bool		SG_JulianDayNumber_To_Date(double JDN, int &y, int &m, int &d)
 //---------------------------------------------------------
 CSG_String		SG_JulianDayNumber_To_Date(double JDN)
 {
-	JDN	= 0.5 + floor(JDN);
-
-	CSG_String	Date;
-
-	int	y, m, d;
+	CSG_String Date; int y, m, d;
 
 	if( SG_JulianDayNumber_To_Date(JDN, y, m, d) )
 	{
@@ -723,51 +729,47 @@ CSG_String		SG_JulianDayNumber_To_Date(int JDN)
 
 //---------------------------------------------------------
 /**
-  * Returns the Julian Day Number calculated from Gregorian date (year, month, day).
+  * Returns the Julian Day Number for the requested Gregorian
+  * date (year, month, day). Month should be in the range of
+  * 1 (= january) to 12 (= december), day in the range of 1
+  * to 31.
 */
 //---------------------------------------------------------
-double			SG_Date_To_JulianDayNumber(int y, int m, int d)
+double			SG_Date_To_JulianDayNumber(int Year, int Month, int Day)
 {
-	int	a	= m <= 2 ? 1 : 0;
+	if( Month <= 2 ) { Year--; Month += 12; }
 
-	y	+= 4800 - a;
-	m	+= 12 * a - 3;
-
-	double	JDN	= d + floor((153. * m + 2.) / 5.) + 365. * y + floor(y / 4.) - floor(y / 100.) + floor(y / 400.) - 32045.;
-
-	return( JDN );
+	return( floor(365.25 * (Year + 4716)) + floor(30.6001 * (Month + 1)) + Day + 2. - floor(Year / 100) + floor(Year / 400) - 1524.5 );
 }
 
 //---------------------------------------------------------
 /**
-  * Returns the Julian Day Number.
+  * Returns the Julian Day Number for the requested date.
+  * Date string is best provided be given in ISO format
+  * (YYYY-MM-DD), or alternatively as YY-MM-DD or DD-MM-YYYY.
 */
 //---------------------------------------------------------
 double			SG_Date_To_JulianDayNumber(const CSG_String &Date)
 {
-	if( Date.Length() < 10 )
+	if( Date.Length() >= 10 )
 	{
-		return( 0.0 );
+		bool BC = Date[0] == '-';
+
+		CSG_Strings ymd(SG_String_Tokenize(BC ? Date.AfterFirst('-') : Date, "-./"));
+
+		if( ymd.Get_Count() >= 3 )
+		{
+			bool inv = ymd[2].Length() == 4;
+
+			int y = ymd[inv ? 2 : 0].asInt(); if( BC ) { y = -y; }
+			int m = ymd[          1].asInt(); if( m < 1 ) { m = 1; } else if( m > 12 ) { m = 12; }
+			int d = ymd[inv ? 0 : 2].asInt(); if( d < 1 ) { d = 1; } else if( d > 31 ) { d = 31; }
+
+			return( SG_Date_To_JulianDayNumber(y, m, d) );
+		}
 	}
 
-	int	bBC	= Date[0] == '-' ? -1 : 1;
-
-	CSG_String_Tokenizer	t(bBC < 0 ? Date.AfterFirst('-') : Date, "-./");
-
-	if( t.Get_Tokens_Count() < 3 )
-	{
-		return( 0.0 );
-	}
-
-	CSG_Strings	s; for(int i=0; i<3; i++) s += t.Get_Next_Token();
-
-	bool	bISO	= s[0].Length() == 4;	// yyyy-mm-dd (ISO 8601)
-
-	int	y	= s[bISO ? 0 : 2].asInt() * bBC;
-	int	m	= s[         1  ].asInt(); if( m < 1 ) m = 1; else if( m > 12 ) m = 12;
-	int	d	= s[bISO ? 2 : 0].asInt(); if( d < 1 ) d = 1; else if( d > 31 ) d = 31;
-
-	return( SG_Date_To_JulianDayNumber(y, m, d) );
+	return( 0. );
 }
 
 
@@ -832,28 +834,32 @@ int SG_Get_Day_MidOfMonth(int Month, bool bLeapYear)
   * Jean Meeus: Astronomical Algorithms, accuracy of 0.01 degree
 */
 //---------------------------------------------------------
-bool SG_Get_Sun_Position(double JulianDayNumber, double &RA, double &Dec)
+bool SG_Get_Sun_Position(double JDN, double &RA, double &Dec)
 {
-	//-----------------------------------------------------
-	double	T	= (JulianDayNumber - 2451545.0 ) / 36525.0;	// Number of Julian centuries since 2000/01/01 at 12 UT (JDN = 2451545.0)
+	double T = (JDN - 2451545.) / 36525.; // Number of Julian centuries since 2000-01-01 at 12 UT (JDN = 2451545.0)
 
-	double	M	= M_DEG_TO_RAD *  (357.52910 + 35999.05030 * T - 0.0001559 * T*T - 0.00000048 * T*T*T);	// mean anomaly
-	double	L	= M_DEG_TO_RAD * ((280.46645 + 36000.76983 * T + 0.0003032 * T*T)						// mean longitude
-							   + ((1.914600 - 0.004817 * T - 0.000014  * T*T) * sin(M)
-							   +  (0.019993 - 0.000101 * T) * sin(2.0 * M) + 0.000290 * sin(3.0 * M)));	// true longitude
+	double M =  357.52910 + 35999.05030 * T - 0.0001559 * T*T - 0.00000048 * T*T*T; // mean anomaly
+
+	M *= M_DEG_TO_RAD;
+
+	double L = (280.46645 + 36000.76983 * T + 0.0003032 * T*T)                      // mean longitude
+	         + ((1.914600 - 0.004817 * T - 0.000014  * T*T) * sin(M)
+	         +  (0.019993 - 0.000101 * T) * sin(2. * M) + 0.000290 * sin(3. * M));  // true longitude
+
+	L *= M_DEG_TO_RAD;
 
 	//-----------------------------------------------------
 	// convert ecliptic longitude to right ascension RA and declination delta
 
-	static const double	Ecliptic_Obliquity	= M_DEG_TO_RAD * 23.43929111;
+	static const double	Ecliptic_Obliquity = M_DEG_TO_RAD * 23.43929111;
 
-	double	X	= cos(L);
-	double	Y	= cos(Ecliptic_Obliquity) * sin(L);
-	double	Z	= sin(Ecliptic_Obliquity) * sin(L);
-	double	R	= sqrt(1.0 - Z*Z); 
+	double X = cos(L);
+	double Y = cos(Ecliptic_Obliquity) * sin(L);
+	double Z = sin(Ecliptic_Obliquity) * sin(L);
+	double R = sqrt(1. - Z*Z); 
 
 	Dec	= atan2(Z, R);
-	RA	= 2.0 * atan2(Y, (X + R));
+	RA	= 2. * atan2(Y, (X + R));
 
 	return( true );
 }
@@ -872,36 +878,89 @@ bool SG_Get_Sun_Position(const CSG_DateTime &Time, double &RA, double &Dec)
   * Returns true if Sun is above horizon.
 */
 //---------------------------------------------------------
-bool SG_Get_Sun_Position(double JulianDayNumber, double Longitude, double Latitude, double &Height, double &Azimuth)
+bool SG_Get_Sun_Position(double JDN, double Longitude, double Latitude, double &Height, double &Azimuth, bool bRefraction)
 {
 	//-----------------------------------------------------
 	// 1. Get right ascension RA and declination delta
 
-	double	RA, Delta;	SG_Get_Sun_Position(JulianDayNumber, RA, Delta);
+	double RA, Dec; SG_Get_Sun_Position(JDN, RA, Dec);
 
 	//-----------------------------------------------------
 	// 2. compute sidereal time (radians) at Greenwich local sidereal time at longitude (radians)
 
-	double	T		= (JulianDayNumber - 2451545.0 ) / 36525.0;
+	double T     = (JDN - 2451545.) / 36525.;
 
-	double	Theta	= Longitude + M_DEG_TO_RAD * (280.46061837 + 360.98564736629 * (JulianDayNumber - 2451545.0) + T*T * (0.000387933 - T / 38710000.0));
+	double Theta = Longitude + M_DEG_TO_RAD * (280.46061837 + 360.98564736629 * (JDN - 2451545.) + T*T * (0.000387933 - T / 38710000.));
 
-	double	Tau		= Theta - RA;	// compute local hour angle (radians)
+	double HA    = Theta - RA; // compute local hour angle (radians)
 
 	//-----------------------------------------------------
-	// 3. convert (tau, delta) to horizon coordinates (h, az) of the observer
+	// 3. convert (HA, Dec) to horizon coordinates (height, azimuth) of the observer
 
-	Height	= asin ( sin(Latitude) * sin(Delta) + cos(Latitude) * cos(Delta) * cos(Tau));
-	Azimuth	= atan2(-sin(Tau) * cos(Delta), cos(Latitude) * sin(Delta) - sin(Latitude) * cos(Delta) * cos(Tau));
-//	Azimuth	= atan2(-sin(Tau), cos(Latitude) * tan(Delta) - sin(Latitude) * cos(Tau));	// previous formula gives same result but is better because of division by zero effects...
+	Height	= asin ( sin(Latitude) * sin(Dec) + cos(Latitude) * cos(Dec) * cos(HA));
+	Azimuth	= atan2(-sin(HA) * cos(Dec), cos(Latitude) * sin(Dec) - sin(Latitude) * cos(Dec) * cos(HA));
+//	Azimuth	= atan2(-sin(HA), cos(Latitude) * tan(Dec) - sin(Latitude) * cos(HA)); // previous formula gives same result but is better because of division by zero effects...
 
-	return( Height > 0.0 );
+	if( bRefraction )
+	{
+		double Refraction = SG_Get_Sun_Refraction(Height, true);
+
+		if( Refraction >= 0. )
+		{
+			Height += Refraction;
+		}
+	}
+
+	return( Height > 0. );
 }
 
 //---------------------------------------------------------
-bool SG_Get_Sun_Position(const CSG_DateTime &Time, double Longitude, double Latitude, double &Height, double &Azimuth)
+bool SG_Get_Sun_Position(const CSG_DateTime &Time, double Longitude, double Latitude, double &Height, double &Azimuth, bool bRefraction)
 {
-	return( SG_Get_Sun_Position(Time.Get_JDN(), Longitude, Latitude, Height, Azimuth) );
+	return( SG_Get_Sun_Position(Time.Get_JDN(), Longitude, Latitude, Height, Azimuth, bRefraction) );
+}
+
+//---------------------------------------------------------
+bool SG_Get_Sun_Position(double JDN, double Longitude, double Latitude, CSG_Vector &Position, bool bRefraction)
+{
+	Position.Create(2); return( SG_Get_Sun_Position(JDN, Longitude, Latitude, Position[0], Position[1], bRefraction) );
+}
+
+//---------------------------------------------------------
+bool SG_Get_Sun_Position(const CSG_DateTime &Time, double Longitude, double Latitude, CSG_Vector &Position, bool bRefraction)
+{
+	Position.Create(2); return( SG_Get_Sun_Position(Time.Get_JDN(), Longitude, Latitude, Position[0], Position[1], bRefraction) );
+}
+
+//---------------------------------------------------------
+/**
+* Refraction correction for U.S. Standard Atmosphere.
+* If bRadians is true input Height is expected to be
+* given in radians and returned height will be in
+* radians too.
+*/
+//---------------------------------------------------------
+double SG_Get_Sun_Refraction(double Height, bool bRadians)
+{
+	// 3.51823 = 1013.25mb / 288K
+
+	double z = bRadians ? M_RAD_TO_DEG * Height : Height;
+
+	if( z > -0.766 )
+	{
+		if( z >= 19.225 )
+		{
+			z = 3.51823 * 0.00452 / tan(z * M_DEG_TO_RAD);
+		}
+		else
+		{
+			z = 3.51823 * (0.1594 + z * (0.0196 + 0.00002 * z) ) / (1. + z * (0.505 + 0.0845 * z));
+		}
+
+		return( bRadians ? M_DEG_TO_RAD * z : z );
+	}
+
+	return( -1. );
 }
 
 
@@ -912,13 +971,13 @@ bool SG_Get_Sun_Position(const CSG_DateTime &Time, double Longitude, double Lati
 //---------------------------------------------------------
 double SG_Get_Day_Length(int DayOfYear, double Latitude)
 {
-	double	tanLat	= tan(Latitude * M_DEG_TO_RAD);
+	double tanLat = tan(Latitude * M_DEG_TO_RAD);
 
-	double	JD		= DayOfYear * M_PI * 2. / 365.;
+	double JD     = DayOfYear * M_PI_360 / 365.;
 
-	double	SunDec	= 0.4093 * sin(JD - 1.405);	// solar declination
+	double SunDec = 0.4093 * sin(JD - 1.405); // solar declination
 
-	double	d		= -tanLat * tan(SunDec);	// sunset hour angle
+	double d      = -tanLat * tan(SunDec); // sunset hour angle
 
 	return( acos(d < -1 ? -1 : d < 1 ? d : 1) * 24. / M_PI );
 }
