@@ -202,6 +202,14 @@ void CSG_Parameters::Destroy(void)
 void CSG_Parameters::Set_Tool(CSG_Tool *pTool)
 {
 	m_pTool = pTool;
+
+	for(int i=0; i<Get_Count(); i++)
+	{
+		if( m_Parameters[i]->Get_Type() == PARAMETER_TYPE_Parameters )
+		{
+			m_Parameters[i]->asParameters()->Set_Tool(pTool);
+		}
+	}
 }
 
 //---------------------------------------------------------
@@ -312,7 +320,7 @@ bool CSG_Parameters::has_GUI(void) const
 //---------------------------------------------------------
 void CSG_Parameters::Set_Identifier(const CSG_String &Identifier)
 {
-	m_Identifier	= Identifier;
+	m_Identifier = Identifier;
 }
 
 //---------------------------------------------------------
@@ -332,7 +340,7 @@ bool CSG_Parameters::Cmp_Identifier(const CSG_String &Identifier)	const
 //---------------------------------------------------------
 void CSG_Parameters::Set_Name(const CSG_String &Name)
 {
-	m_Name			= Name;
+	m_Name = Name;
 }
 
 //---------------------------------------------------------
@@ -342,7 +350,7 @@ void CSG_Parameters::Set_Name(const CSG_String &Name)
 //---------------------------------------------------------
 void CSG_Parameters::Set_Description(const CSG_String &Description)
 {
-	m_Description	= Description;
+	m_Description = Description;
 }
 
 //---------------------------------------------------------
@@ -356,12 +364,12 @@ void CSG_Parameters::Add_Reference(const CSG_String &Authors, const CSG_String &
 
 	if( Link && *Link )
 	{
-		Reference	+= CSG_String::Format(" <a href=\"%s\">%s</a>.", Link, Link_Text && *Link_Text ? Link_Text : Link);
+		Reference += CSG_String::Format(" <a href=\"%s\">%s</a>.", Link, Link_Text && *Link_Text ? Link_Text : Link);
 	}
 
 	if( !Reference.is_Empty() )
 	{
-		m_References	+= Reference;
+		m_References += Reference;
 	}
 
 	m_References.Sort();
@@ -374,7 +382,7 @@ void CSG_Parameters::Add_Reference(const CSG_String &Authors, const CSG_String &
 //---------------------------------------------------------
 void CSG_Parameters::Add_Reference(const CSG_String &Link, const SG_Char *Link_Text)
 {
-	m_References	+= CSG_String::Format("<a href=\"%s\">%s</a>", Link.c_str(), Link_Text && *Link_Text ? Link_Text : Link.c_str());
+	m_References += CSG_String::Format("<a href=\"%s\">%s</a>", Link.c_str(), Link_Text && *Link_Text ? Link_Text : Link.c_str());
 
 	m_References.Sort();
 }
@@ -409,7 +417,7 @@ void CSG_Parameters::Set_Enabled(bool bEnabled)
 //---------------------------------------------------------
 void CSG_Parameters::Set_Enabled(const CSG_String &Identifier, bool bEnabled)
 {
-	CSG_Parameter	*pParameter	= Get_Parameter(Identifier);
+	CSG_Parameter *pParameter = Get_Parameter(Identifier);
 
 	if( pParameter )
 	{
@@ -524,7 +532,7 @@ CSG_Parameter * CSG_Parameters::Add_Data_Type(const CSG_String &ParentID, const
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Choice(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, const CSG_String &Items, int Default)
 {
-	CSG_Parameter	*pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Choice, 0);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Choice, 0);
 
 	pParameter->asChoice()->Set_Items(Items);
 
@@ -539,7 +547,7 @@ CSG_Parameter * CSG_Parameters::Add_Choice(const CSG_String &ParentID, const CSG
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Choices(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, const CSG_String &Items)
 {
-	CSG_Parameter	*pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Choices, 0);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Choices, 0);
 
 	pParameter->asChoices()->Set_Items(Items);
 
@@ -560,14 +568,14 @@ CSG_Parameter * CSG_Parameters::Add_Info_String(const CSG_String &ParentID, cons
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_FilePath(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, const SG_Char *Filter, const SG_Char *Default, bool bSave, bool bDirectory, bool bMultiple)
 {
-	CSG_Parameter	*pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_FilePath, 0);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_FilePath, 0);
 
 	pParameter->asFilePath()->Set_Filter        (Filter    );
 	pParameter->asFilePath()->Set_Flag_Save     (bSave     );
 	pParameter->asFilePath()->Set_Flag_Multiple (bMultiple );
 	pParameter->asFilePath()->Set_Flag_Directory(bDirectory);
 
-	bool	bCallback	= Set_Callback(false);
+	bool bCallback = Set_Callback(false);
 	pParameter->Set_Value  (Default);
 	pParameter->Set_Default(Default);
 	Set_Callback(bCallback);
@@ -575,16 +583,36 @@ CSG_Parameter * CSG_Parameters::Add_FilePath(const CSG_String &ParentID, const C
 	return( pParameter );
 }
 
+//---------------------------------------------------------
+CSG_Parameter * CSG_Parameters::Add_Colors(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Palette, int nColors, bool bRevert)
+{
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Colors, 0);
+
+	pParameter->asColors()->Create(nColors, Palette, bRevert);
+
+	return( pParameter );
+}
+
+CSG_Parameter * CSG_Parameters::Add_Colors(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, CSG_Colors *pInit)
+{
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Colors, 0);
+
+	if( pInit )
+	{
+		pParameter->asColors()->Create(*pInit);
+	}
+
+	return( pParameter );
+}
+
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Font(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, const SG_Char *pInit)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Font, 0);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Font, 0);
 
 	if( pInit && *pInit )
 	{
-		bool	bCallback	= Set_Callback(false);
+		bool bCallback = Set_Callback(false);
 		pParameter->Set_Value  (pInit);
 		pParameter->Set_Default(pInit);
 		Set_Callback(bCallback);
@@ -593,24 +621,10 @@ CSG_Parameter * CSG_Parameters::Add_Font(const CSG_String &ParentID, const CSG_S
 	return( pParameter );
 }
 
-//---------------------------------------------------------
-CSG_Parameter * CSG_Parameters::Add_Colors(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, CSG_Colors *pInit)
-{
-	CSG_Parameter			*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Colors, 0);
-
-	pParameter->asColors()->Assign(pInit);
-
-	return( pParameter );
-}
-
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_FixedTable(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, CSG_Table *pTemplate)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_FixedTable, 0);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_FixedTable, 0);
 
 	pParameter->asTable()->Create(pTemplate);
 	pParameter->asTable()->Set_Name(Name);
@@ -627,9 +641,7 @@ CSG_Parameter * CSG_Parameters::Add_FixedTable(const CSG_String &ParentID, const
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Grid_System(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, CSG_Grid_System *pInit)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Grid_System, 0);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Grid_System, 0);
 
 	if( pInit )
 	{
@@ -642,25 +654,23 @@ CSG_Parameter * CSG_Parameters::Add_Grid_System(const CSG_String &ParentID, cons
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Grid(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint, bool bSystem_Dependent, TSG_Data_Type Preferred_Type)
 {
-	CSG_Parameter	*pParameter, *pParent = Get_Parameter(ParentID);
-
-	CSG_String	SystemID;
+	CSG_String SystemID; CSG_Parameter *pParent = Get_Parameter(ParentID);
 
 	if( pParent && pParent->Get_Type() == PARAMETER_TYPE_Grid_System )
 	{
-		SystemID	= pParent->Get_Identifier();
+		SystemID = pParent->Get_Identifier();
 	}
 	else if( bSystem_Dependent && m_pGrid_System )
 	{
-		SystemID	= m_pGrid_System->Get_Identifier();
+		SystemID = m_pGrid_System->Get_Identifier();
 	}
 	else
 	{
-		pParent		= Add_Grid_System(pParent ? pParent->Get_Identifier() : SG_T(""), ID + "_GRIDSYSTEM", _TL("Grid system"), "");
-		SystemID	= pParent->Get_Identifier();
+		pParent  = Add_Grid_System(pParent ? pParent->Get_Identifier() : SG_T(""), ID + "_GRIDSYSTEM", _TL("Grid system"), "");
+		SystemID = pParent->Get_Identifier();
 	}
 
-	pParameter	= _Add(SystemID, ID, Name, Description, PARAMETER_TYPE_Grid, Constraint);
+	CSG_Parameter *pParameter = _Add(SystemID, ID, Name, Description, PARAMETER_TYPE_Grid, Constraint);
 
 	((CSG_Parameter_Grid *)pParameter)->Set_Preferred_Type(Preferred_Type);
 
@@ -670,7 +680,7 @@ CSG_Parameter * CSG_Parameters::Add_Grid(const CSG_String &ParentID, const CSG_S
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Grid_or_Const(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, double Value, double Minimum, bool bMinimum, double Maximum, bool bMaximum, bool bSystem_Dependent)
 {
-	CSG_Parameter	*pParameter	= Add_Grid(ParentID, ID, Name, Description, PARAMETER_INPUT_OPTIONAL, bSystem_Dependent);
+	CSG_Parameter *pParameter = Add_Grid(ParentID, ID, Name, Description, PARAMETER_INPUT_OPTIONAL, bSystem_Dependent);
 
 	((CSG_Parameter_Grid *)pParameter)->Add_Default(Value, Minimum, bMinimum, Maximum, bMaximum);
 
@@ -680,9 +690,7 @@ CSG_Parameter * CSG_Parameters::Add_Grid_or_Const(const CSG_String &ParentID, co
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Grid_Output(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
 
 	((CSG_Parameter_Data_Object_Output *)pParameter)->Set_DataObject_Type(SG_DATAOBJECT_TYPE_Grid);
 
@@ -692,20 +700,18 @@ CSG_Parameter * CSG_Parameters::Add_Grid_Output(const CSG_String &ParentID, cons
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Grid_List(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint, bool bSystem_Dependent)
 {
-	CSG_Parameter	*pParameter, *pParent = Get_Parameter(ParentID);
-
-	CSG_String	SystemID;
+	CSG_String SystemID; CSG_Parameter *pParent = Get_Parameter(ParentID);
 
 	if( pParent && pParent->Get_Type() == PARAMETER_TYPE_Grid_System )
 	{
-		SystemID	= pParent->Get_Identifier();
+		SystemID = pParent->Get_Identifier();
 	}
 	else if( bSystem_Dependent && m_pGrid_System && !((Constraint & PARAMETER_OUTPUT) && (Constraint & PARAMETER_OPTIONAL)) )
 	{
-		SystemID	= m_pGrid_System->Get_Identifier();
+		SystemID = m_pGrid_System->Get_Identifier();
 	}
 
-	pParameter	= _Add(SystemID, ID, Name, Description, PARAMETER_TYPE_Grid_List, Constraint);
+	CSG_Parameter *pParameter = _Add(SystemID, ID, Name, Description, PARAMETER_TYPE_Grid_List, Constraint);
 
 	return( pParameter );
 }
@@ -718,25 +724,23 @@ CSG_Parameter * CSG_Parameters::Add_Grid_List(const CSG_String &ParentID, const
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Grids(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint, bool bSystem_Dependent, TSG_Data_Type Preferred_Type)
 {
-	CSG_Parameter	*pParameter, *pParent = Get_Parameter(ParentID);
-
-	CSG_String	SystemID;
+	CSG_String SystemID; CSG_Parameter *pParent = Get_Parameter(ParentID);
 
 	if( pParent && pParent->Get_Type() == PARAMETER_TYPE_Grid_System )
 	{
-		SystemID	= pParent->Get_Identifier();
+		SystemID = pParent->Get_Identifier();
 	}
 	else if( bSystem_Dependent && m_pGrid_System )
 	{
-		SystemID	= m_pGrid_System->Get_Identifier();
+		SystemID = m_pGrid_System->Get_Identifier();
 	}
 	else
 	{
-		pParent		= Add_Grid_System(pParent ? pParent->Get_Identifier() : SG_T(""), ID + "_GRIDSYSTEM", _TL("Grid system"), "");
-		SystemID	= pParent->Get_Identifier();
+		pParent  = Add_Grid_System(pParent ? pParent->Get_Identifier() : SG_T(""), ID + "_GRIDSYSTEM", _TL("Grid system"), "");
+		SystemID = pParent->Get_Identifier();
 	}
 
-	pParameter	= _Add(SystemID, ID, Name, Description, PARAMETER_TYPE_Grids, Constraint);
+	CSG_Parameter *pParameter = _Add(SystemID, ID, Name, Description, PARAMETER_TYPE_Grids, Constraint);
 
 	((CSG_Parameter_Grids *)pParameter)->Set_Preferred_Type(Preferred_Type);
 
@@ -746,9 +750,7 @@ CSG_Parameter * CSG_Parameters::Add_Grids(const CSG_String &ParentID, const CSG_
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Grids_Output(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
 
 	((CSG_Parameter_Data_Object_Output *)pParameter)->Set_DataObject_Type(SG_DATAOBJECT_TYPE_Grids);
 
@@ -758,20 +760,18 @@ CSG_Parameter * CSG_Parameters::Add_Grids_Output(const CSG_String &ParentID, con
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Grids_List(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint, bool bSystem_Dependent)
 {
-	CSG_Parameter	*pParameter, *pParent = Get_Parameter(ParentID);
-
-	CSG_String	SystemID;
+	CSG_String SystemID; CSG_Parameter *pParent = Get_Parameter(ParentID);
 
 	if( pParent && pParent->Get_Type() == PARAMETER_TYPE_Grid_System )
 	{
-		SystemID	= pParent->Get_Identifier();
+		SystemID = pParent->Get_Identifier();
 	}
 	else if( bSystem_Dependent && m_pGrid_System && !((Constraint & PARAMETER_OUTPUT) && (Constraint & PARAMETER_OPTIONAL)) )
 	{
-		SystemID	= m_pGrid_System->Get_Identifier();
+		SystemID = m_pGrid_System->Get_Identifier();
 	}
 
-	pParameter	= _Add(SystemID, ID, Name, Description, PARAMETER_TYPE_Grids_List, Constraint);
+	CSG_Parameter *pParameter = _Add(SystemID, ID, Name, Description, PARAMETER_TYPE_Grids_List, Constraint);
 
 	return( pParameter );
 }
@@ -784,7 +784,7 @@ CSG_Parameter * CSG_Parameters::Add_Grids_List(const CSG_String &ParentID, const
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Table_Field(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, bool bAllowNone)
 {
-	CSG_Parameter	*pParent = Get_Parameter(ParentID);
+	CSG_Parameter *pParent = Get_Parameter(ParentID);
 
 	if( pParent && (
 		pParent->Get_Type() == PARAMETER_TYPE_Table
@@ -801,7 +801,7 @@ CSG_Parameter * CSG_Parameters::Add_Table_Field(const CSG_String &ParentID, cons
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Table_Field_or_Const(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, double Value, double Minimum, bool bMinimum, double Maximum, bool bMaximum)
 {
-	CSG_Parameter	*pParameter	= Add_Table_Field(ParentID, ID, Name, Description, true);
+	CSG_Parameter *pParameter = Add_Table_Field(ParentID, ID, Name, Description, true);
 
 	if( pParameter )
 	{
@@ -814,7 +814,7 @@ CSG_Parameter * CSG_Parameters::Add_Table_Field_or_Const(const CSG_String &Paren
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Table_Fields(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description)
 {
-	CSG_Parameter	*pParent = Get_Parameter(ParentID);
+	CSG_Parameter *pParent = Get_Parameter(ParentID);
 
 	if( pParent && (
 		pParent->Get_Type() == PARAMETER_TYPE_Table
@@ -831,9 +831,7 @@ CSG_Parameter * CSG_Parameters::Add_Table_Fields(const CSG_String &ParentID, con
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Table(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Table, Constraint);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Table, Constraint);
 
 	return( pParameter );
 }
@@ -841,9 +839,7 @@ CSG_Parameter * CSG_Parameters::Add_Table(const CSG_String &ParentID, const CSG_
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Table_Output(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
 
 	((CSG_Parameter_Data_Object_Output *)pParameter)->Set_DataObject_Type(SG_DATAOBJECT_TYPE_Table);
 
@@ -853,9 +849,7 @@ CSG_Parameter * CSG_Parameters::Add_Table_Output(const CSG_String &ParentID, con
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Table_List(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Table_List, Constraint);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Table_List, Constraint);
 
 	return( pParameter );
 }
@@ -868,9 +862,7 @@ CSG_Parameter * CSG_Parameters::Add_Table_List(const CSG_String &ParentID, const
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Shapes(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint, TSG_Shape_Type Shape_Type)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Shapes, Constraint);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Shapes, Constraint);
 
 	((CSG_Parameter_Shapes *)pParameter)->Set_Shape_Type(Shape_Type);
 
@@ -880,9 +872,7 @@ CSG_Parameter * CSG_Parameters::Add_Shapes(const CSG_String &ParentID, const CSG
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Shapes_Output(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
 
 	((CSG_Parameter_Data_Object_Output *)pParameter)->Set_DataObject_Type(SG_DATAOBJECT_TYPE_Shapes);
 
@@ -892,9 +882,7 @@ CSG_Parameter * CSG_Parameters::Add_Shapes_Output(const CSG_String &ParentID, co
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Shapes_List(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint, TSG_Shape_Type Type)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Shapes_List, Constraint);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Shapes_List, Constraint);
 
 	((CSG_Parameter_Shapes_List *)pParameter)->Set_Shape_Type(Type);
 
@@ -909,9 +897,7 @@ CSG_Parameter * CSG_Parameters::Add_Shapes_List(const CSG_String &ParentID, cons
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_TIN(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_TIN, Constraint);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_TIN, Constraint);
 
 	return( pParameter );
 }
@@ -919,9 +905,7 @@ CSG_Parameter * CSG_Parameters::Add_TIN(const CSG_String &ParentID, const CSG_St
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_TIN_Output(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
 
 	((CSG_Parameter_Data_Object_Output *)pParameter)->Set_DataObject_Type(SG_DATAOBJECT_TYPE_TIN);
 
@@ -931,9 +915,7 @@ CSG_Parameter * CSG_Parameters::Add_TIN_Output(const CSG_String &ParentID, const
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_TIN_List(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_TIN_List, Constraint);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_TIN_List, Constraint);
 
 	return( pParameter );
 }
@@ -946,9 +928,7 @@ CSG_Parameter * CSG_Parameters::Add_TIN_List(const CSG_String &ParentID, const C
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_PointCloud(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_PointCloud, Constraint);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_PointCloud, Constraint);
 
 	return( pParameter );
 }
@@ -956,9 +936,7 @@ CSG_Parameter * CSG_Parameters::Add_PointCloud(const CSG_String &ParentID, const
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_PointCloud_Output(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_DataObject_Output, PARAMETER_OUTPUT_OPTIONAL);
 
 	((CSG_Parameter_Data_Object_Output *)pParameter)->Set_DataObject_Type(SG_DATAOBJECT_TYPE_PointCloud);
 
@@ -968,9 +946,7 @@ CSG_Parameter * CSG_Parameters::Add_PointCloud_Output(const CSG_String &ParentID
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_PointCloud_List(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, int Constraint)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_PointCloud_List, Constraint);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_PointCloud_List, Constraint);
 
 	return( pParameter );
 }
@@ -983,9 +959,7 @@ CSG_Parameter * CSG_Parameters::Add_PointCloud_List(const CSG_String &ParentID,
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::Add_Parameters(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description)
 {
-	CSG_Parameter	*pParameter;
-
-	pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Parameters, 0);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Parameters, 0);
 
 	pParameter->asParameters()->m_Callback = m_Callback;
 	pParameter->asParameters()->m_pTool    = m_pTool;
@@ -1012,12 +986,12 @@ CSG_Parameter * CSG_Parameters::_Add_Value(const CSG_String &ParentID, const CSG
 		break;
 
 	default:	// if not valid set Type to [double]...
-		Type	= PARAMETER_TYPE_Double;
+		Type = PARAMETER_TYPE_Double;
 	}
 
-	CSG_Parameter	*pParameter	= _Add(ParentID, ID, Name, Description, Type, bInformation ? PARAMETER_INFORMATION : 0);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, Type, bInformation ? PARAMETER_INFORMATION : 0);
 
-	bool	bCallback	= Set_Callback(false);
+	bool bCallback = Set_Callback(false);
 
 	if( !bInformation )
 	{
@@ -1062,13 +1036,13 @@ CSG_Parameter * CSG_Parameters::_Add_Range(const CSG_String &ParentID, const CSG
 	//-----------------------------------------------------
 	if( Default_Min > Default_Max )
 	{
-		double	d	= Default_Min;
-		Default_Min	= Default_Max;
-		Default_Max	= d;
+		double    d = Default_Min;
+		Default_Min = Default_Max;
+		Default_Max = d;
 	}
 
 	//-----------------------------------------------------
-	CSG_Parameter	*pParameter	= _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Range, bInformation ? PARAMETER_INFORMATION : 0);
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, PARAMETER_TYPE_Range, bInformation ? PARAMETER_INFORMATION : 0);
 
 	pParameter->asRange()->Get_Min_Parameter()->Set_Minimum(Minimum, bMinimum);
 	pParameter->asRange()->Get_Min_Parameter()->Set_Maximum(Maximum, bMaximum);
@@ -1086,11 +1060,9 @@ CSG_Parameter * CSG_Parameters::_Add_Range(const CSG_String &ParentID, const CSG
 //---------------------------------------------------------
 CSG_Parameter * CSG_Parameters::_Add_String(const CSG_String &ParentID, const CSG_String &ID, const CSG_String &Name, const CSG_String &Description, bool bInformation, const SG_Char *String, bool bLongText, bool bPassword)
 {
-	CSG_Parameter	*pParameter;
+	CSG_Parameter *pParameter = _Add(ParentID, ID, Name, Description, bLongText ? PARAMETER_TYPE_Text : PARAMETER_TYPE_String, bInformation ? PARAMETER_INFORMATION : 0);
 
-	pParameter	= _Add(ParentID, ID, Name, Description, bLongText ? PARAMETER_TYPE_Text : PARAMETER_TYPE_String, bInformation ? PARAMETER_INFORMATION : 0);
-
-	bool	bCallback	= Set_Callback(false);
+	bool bCallback = Set_Callback(false);
 	pParameter->Set_Value  (String);
 	pParameter->Set_Default(String);
 	Set_Callback(bCallback);
@@ -1202,7 +1174,25 @@ CSG_Parameter * CSG_Parameters::_Add(CSG_Parameter *pSource)
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CSG_Parameter * CSG_Parameters::Get_Parameter(const CSG_String &ID)	const
+CSG_Parameter * CSG_Parameters::Get_Parameter(int i, bool MsgOnError) const
+{
+	if( i >= 0 && i < m_nParameters )
+	{
+		return( m_Parameters[i] );
+	}
+
+	if( MsgOnError )
+	{
+		SG_UI_Msg_Add_Error(CSG_String::Format("%s index=[%d]", _TL("Could not find requested parameter!"), i));
+	}
+
+	return( NULL );
+}
+
+//---------------------------------------------------------
+CSG_Parameter * CSG_Parameters::Get_Parameter(const char       *ID, bool MsgOnError) const { return( Get_Parameter(CSG_String(ID), MsgOnError) ); }
+CSG_Parameter * CSG_Parameters::Get_Parameter(const wchar_t    *ID, bool MsgOnError) const { return( Get_Parameter(CSG_String(ID), MsgOnError) ); }
+CSG_Parameter * CSG_Parameters::Get_Parameter(const CSG_String &ID, bool MsgOnError) const
 {
 	if( m_Parameters && !ID.is_Empty() )
 	{
@@ -1217,7 +1207,7 @@ CSG_Parameter * CSG_Parameters::Get_Parameter(const CSG_String &ID)	const
 		//-------------------------------------------------
 		if( ID.Find('.') > 0 )	// id not found? check for sub-parameter ('id.id')!
 		{
-			CSG_Parameter	*pParameter	= Get_Parameter(ID.BeforeFirst('.'));
+			CSG_Parameter *pParameter = Get_Parameter(ID.BeforeFirst('.'));
 
 			if( pParameter )
 			{
@@ -1243,6 +1233,12 @@ CSG_Parameter * CSG_Parameters::Get_Parameter(const CSG_String &ID)	const
 				}
 			}
 		}
+
+		//-------------------------------------------------
+		if( MsgOnError )
+		{
+			SG_UI_Msg_Add_Error(CSG_String::Format("%s id=[%s]", _TL("Could not find requested parameter!"), ID.c_str()));
+		}
 	}
 
 	return( NULL );
@@ -1554,11 +1550,16 @@ bool CSG_Parameters::Assign_Parameters(CSG_Parameters *pSource)
 	for(int i=0; i<pSource->m_nParameters; i++)
 	{
 		_Add(pSource->m_Parameters[i]);
+
+		if( m_Parameters[i]->asParameters() )
+		{
+			m_Parameters[i]->asParameters()->Set_Tool(m_pTool);
+		}
 	}
 
 	if( pSource->m_pGrid_System )
 	{
-		m_pGrid_System	= Get_Parameter(pSource->m_pGrid_System->Get_Identifier());
+		m_pGrid_System = Get_Parameter(pSource->m_pGrid_System->Get_Identifier());
 	}
 
 	return( m_nParameters == pSource->m_nParameters );
@@ -1906,7 +1907,7 @@ bool CSG_Parameters::DataObjects_Set_Projection(const CSG_Projection &Projection
 //---------------------------------------------------------
 bool CSG_Parameters::Get_String(CSG_String &String, bool bOptionsOnly)
 {
-	bool	bResult	= false;
+	bool bResult = false;
 
 	if( Get_Count() > 0 )
 	{
@@ -1914,20 +1915,22 @@ bool CSG_Parameters::Get_String(CSG_String &String, bool bOptionsOnly)
 		{
 			m_pGrid_System->_Set_String();
 
-			String	+= CSG_String::Format("%s: %s\n", m_pGrid_System->Get_Name(), m_pGrid_System->asString());
+			String += CSG_String::Format("%s: %s\n", m_pGrid_System->Get_Name(), m_pGrid_System->asString());
 		}
 
 		for(int i=0; i<Get_Count(); i++)
 		{
-			CSG_Parameter	*p	= m_Parameters[i];
+			CSG_Parameter &P = *m_Parameters[i];
 
-			if( (!bOptionsOnly || p->is_Option()) && !p->asGrid_System() && p->is_Enabled() && !p->is_Information() && !(p->Get_Type() == PARAMETER_TYPE_String && ((CSG_Parameter_String *)p)->is_Password()) )
+			if( (!bOptionsOnly || P.is_Option()) && !P.asGrid_System() && P.is_Enabled() && !P.is_Information() && !(P.Get_Type() == PARAMETER_TYPE_String && ((CSG_Parameter_String *)&P)->is_Password()) )
 			{
-				bResult	= true;
+				bResult = true;
 
-				p->_Set_String(); // forcing update (at scripting level some parameter types can be changed without the Set_Parameter() mechanism)
+				P._Set_String(); // forcing update (at scripting level some parameter types can be changed without the Set_Parameter() mechanism)
 
-				String	+= CSG_String::Format("%s: %s\n", p->Get_Name(), p->asString());
+				CSG_String s(P.asString()); if( s.Length() > 256 ) { s = s.Left(256) + "..."; }
+
+				String += CSG_String::Format("%s: %s\n", P.Get_Name(), s.c_str());
 			}
 		}
 	}
@@ -1938,16 +1941,16 @@ bool CSG_Parameters::Get_String(CSG_String &String, bool bOptionsOnly)
 //---------------------------------------------------------
 bool CSG_Parameters::Msg_String(bool bOptionsOnly)
 {
-	CSG_String	Msg;
+	CSG_String Message;
 
-	if( Get_String(Msg, bOptionsOnly) )
+	if( Get_String(Message, bOptionsOnly) )
 	{
 		SG_UI_Msg_Add_Execution(CSG_String::Format("\n__________\n[%s] %s:\n", m_Name.c_str(),
 			bOptionsOnly ? _TL("Options") : _TL("Parameters")),
 			false, SG_UI_MSG_STYLE_NORMAL
 		);
 
-		SG_UI_Msg_Add_Execution(Msg, false, SG_UI_MSG_STYLE_01);
+		SG_UI_Msg_Add_Execution(Message, false, SG_UI_MSG_STYLE_01);
 
 		return( true );
 	}
@@ -1963,53 +1966,48 @@ bool CSG_Parameters::Msg_String(bool bOptionsOnly)
 //---------------------------------------------------------
 bool CSG_Parameters::Set_History(CSG_MetaData &MetaData, bool bOptions, bool bDataObjects)
 {
-	CSG_MetaData	*pEntry;
-	CSG_Data_Object	*pObject;
-
-	//-----------------------------------------------------
-	if( bOptions )
+	if( bOptions ) // get options...
 	{
-		for(int i=0; i<Get_Count(); i++)	// get options...
+		for(int i=0; i<Get_Count(); i++)
 		{
-			CSG_Parameter	*p	= m_Parameters[i];
+			CSG_Parameter &P = *m_Parameters[i];
 
-			if(	p->is_Option() && p->is_Enabled() && !p->is_Information()
-			&&	!(p->Get_Type() == PARAMETER_TYPE_String && ((CSG_Parameter_String *)p)->is_Password()) )
+			if(	P.is_Option() && P.is_Enabled() && !P.is_Information() && !(P.Get_Type() == PARAMETER_TYPE_String && ((CSG_Parameter_String *)&P)->is_Password()) )
 			{
-				p->Serialize(MetaData, true);
+				P.Serialize(MetaData, true);
 			}
-
-			//---------------------------------------------
-			else if( p->is_Parameters() )
+			else if( P.is_Parameters() )
 			{
-				p->asParameters()->Set_History(MetaData, true, false);
+				P.asParameters()->Set_History(MetaData, true, false);
 			}
 		}
 	}
 
 	//-----------------------------------------------------
-	if( bDataObjects )
+	if( bDataObjects ) // get input with history...
 	{
-		for(int i=0; i<Get_Count(); i++)	// get input with history...
+		for(int i=0; i<Get_Count(); i++)
 		{
-			CSG_Parameter	*p	= m_Parameters[i];
+			CSG_Parameter &P = *m_Parameters[i];
 
 			//---------------------------------------------
-			if( p->is_Input() )
+			if( P.is_Input() )
 			{
-				if( p->is_DataObject() && (pObject = p->asDataObject()) != NULL  )
+				if( P.is_DataObject() && P.asDataObject() )
 				{
-					pEntry	= MetaData.Add_Child("INPUT");
+					CSG_Data_Object *pObject = P.asDataObject();
 
-					pEntry->Add_Property("type" , p->Get_Type_Identifier());
-					pEntry->Add_Property("id"   , p->Get_Identifier     ());
-					pEntry->Add_Property("name" , p->Get_Name           ());
-					pEntry->Add_Property("parms",    Get_Identifier     ());
+					CSG_MetaData *pEntry = MetaData.Add_Child("INPUT");
 
-					if( p->Get_Type() == PARAMETER_TYPE_Grid
-					||  p->Get_Type() == PARAMETER_TYPE_Grids )
+					pEntry->Add_Property("type" , P.Get_Type_Identifier());
+					pEntry->Add_Property("id"   , P.Get_Identifier     ());
+					pEntry->Add_Property("name" , P.Get_Name           ());
+					pEntry->Add_Property("parms",   Get_Identifier     ());
+
+					if( P.Get_Type() == PARAMETER_TYPE_Grid
+					||  P.Get_Type() == PARAMETER_TYPE_Grids )
 					{
-						pEntry->Add_Property("system", p->Get_Parent()->Get_Identifier());
+						pEntry->Add_Property("system", P.Get_Parent()->Get_Identifier());
 					}
 
 					if( pObject->Get_History().Get_Children_Count() > 0 )
@@ -2018,29 +2016,29 @@ bool CSG_Parameters::Set_History(CSG_MetaData &MetaData, bool bOptions, bool bDa
 					}
 					else if( pObject->Get_File_Name() && *pObject->Get_File_Name() )
 					{
-						pEntry	= pEntry->Add_Child("FILE", pObject->Get_File_Name());
+						pEntry = pEntry->Add_Child("FILE", pObject->Get_File_Name());
 					}
 				}
 
-				else if( p->is_DataObject_List() && p->asList()->Get_Item_Count() > 0 )
+				else if( P.is_DataObject_List() && P.asList()->Get_Item_Count() > 0 )
 				{
-					CSG_MetaData	*pList	= MetaData.Add_Child("INPUT_LIST");
+					CSG_MetaData *pList = MetaData.Add_Child("INPUT_LIST");
 
-					pList->Add_Property("type" , p->Get_Type_Identifier());
-					pList->Add_Property("id"   , p->Get_Identifier     ());
-					pList->Add_Property("name" , p->Get_Name           ());
-					pList->Add_Property("parms",    Get_Identifier     ());
+					pList->Add_Property("type" , P.Get_Type_Identifier());
+					pList->Add_Property("id"   , P.Get_Identifier     ());
+					pList->Add_Property("name" , P.Get_Name           ());
+					pList->Add_Property("parms",   Get_Identifier     ());
 
-					if( (p->Get_Type() == PARAMETER_TYPE_Grid_List || p->Get_Type() == PARAMETER_TYPE_Grids_List) && p->Get_Parent() && p->Get_Parent()->Get_Type() == PARAMETER_TYPE_Grid_System )
+					if( (P.Get_Type() == PARAMETER_TYPE_Grid_List || P.Get_Type() == PARAMETER_TYPE_Grids_List) && P.Get_Parent() && P.Get_Parent()->Get_Type() == PARAMETER_TYPE_Grid_System )
 					{
-						pList->Add_Property("system", p->Get_Parent()->Get_Identifier());
+						pList->Add_Property("system", P.Get_Parent()->Get_Identifier());
 					}
 
-					for(int j=0; j<p->asList()->Get_Item_Count(); j++)
+					for(int j=0; j<P.asList()->Get_Item_Count(); j++)
 					{
-						pObject	= p->asList()->Get_Item(j);
+						CSG_Data_Object *pObject = P.asList()->Get_Item(j);
 
-						pEntry	= pList->Add_Child(*pList, false);
+						CSG_MetaData *pEntry = pList->Add_Child(*pList, false);
 
 						pEntry->Set_Name("INPUT");
 						
@@ -2050,16 +2048,16 @@ bool CSG_Parameters::Set_History(CSG_MetaData &MetaData, bool bOptions, bool bDa
 						}
 						else if( pObject->Get_File_Name() && *pObject->Get_File_Name() )
 						{
-							pEntry	= pEntry->Add_Child("FILE", pObject->Get_File_Name());
+							pEntry = pEntry->Add_Child("FILE", pObject->Get_File_Name());
 						}
 					}
 				}
 			}
 
 			//---------------------------------------------
-			else if( p->is_Parameters() )
+			else if( P.is_Parameters() )
 			{
-				p->asParameters()->Set_History(MetaData, false, true);
+				P.asParameters()->Set_History(MetaData, false, true);
 			}
 		}
 	}
