@@ -55,9 +55,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -71,9 +71,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -81,9 +81,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -131,9 +131,9 @@ TSG_ADD_Shape_Copy_Mode;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -150,8 +150,6 @@ public:
 	virtual bool				Assign				(CSG_Table_Record *pRecord, bool bAssign_Attributes);
 	virtual bool				Assign				(CSG_Table_Record *pRecord, TSG_ADD_Shape_Copy_Mode mCopy);
 
-	virtual bool				is_Valid			(void)	const = 0;
-
 	TSG_Shape_Type				Get_Type			(void)	const;
 	TSG_Vertex_Type				Get_Vertex_Type		(void)	const;
 
@@ -255,9 +253,9 @@ protected:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Point							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -362,9 +360,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Points							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -476,9 +474,9 @@ protected:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Points							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -593,9 +591,9 @@ protected:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Line							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -627,9 +625,9 @@ protected:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Polygon							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -765,9 +763,9 @@ protected:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						Shapes							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -798,7 +796,7 @@ public:
 
 	virtual TSG_Data_Object_Type	Get_ObjectType			(void)	const			{	return( SG_DATAOBJECT_TYPE_Shapes );	}
 
-	virtual bool					Assign					(CSG_Data_Object *pObject);
+	virtual bool					Assign					(CSG_Data_Object *pObject, bool bProgress = false);
 
 	virtual bool					Save					(const CSG_String &File, int Format = 0);
 	virtual bool					Save					(const char       *File, int Format = 0)	{	return( Save(CSG_String(File), Format) );	}
@@ -872,9 +870,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -905,9 +903,9 @@ SAGA_API_DLL_EXPORT CSG_String				SG_Shapes_Get_File_Extension_Default	(void);
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //				Point Region QuadTree					 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1257,7 +1255,7 @@ protected:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1307,7 +1305,7 @@ public:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1358,7 +1356,7 @@ public:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1432,9 +1430,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //					Polygon Tools						 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1443,15 +1441,41 @@ SAGA_API_DLL_EXPORT bool			SG_Shape_Get_Difference		(CSG_Shape *pSubject, CSG_Sh
 SAGA_API_DLL_EXPORT bool			SG_Shape_Get_ExclusiveOr	(CSG_Shape *pSubject, CSG_Shape_Polygon *pClip, CSG_Shape *pSolution = NULL);
 SAGA_API_DLL_EXPORT bool			SG_Shape_Get_Union			(CSG_Shape *pSubject, CSG_Shape_Polygon *pClip, CSG_Shape *pSolution = NULL);
 SAGA_API_DLL_EXPORT bool			SG_Shape_Get_Dissolve		(CSG_Shape *pSubject                          , CSG_Shape *pSolution = NULL);
+#ifdef CLIPPER_ONE
 SAGA_API_DLL_EXPORT bool			SG_Shape_Get_Offset			(CSG_Shape *pSubject, double Size, double dArc, CSG_Shape *pSolution = NULL);
+#else
+//---------------------------------------------------------
+typedef enum
+{
+	SG_LINE_JOINTYPE_Square = 0,
+	SG_LINE_JOINTYPE_Bevel,
+	SG_LINE_JOINTYPE_Round,
+	SG_LINE_JOINTYPE_Miter
+}
+TSG_Line_JoinType;
+
+//---------------------------------------------------------
+typedef enum
+{
+	SG_LINE_ENDTYPE_Polygon = 0,
+	SG_LINE_ENDTYPE_Joined,
+	SG_LINE_ENDTYPE_Butt,
+	SG_LINE_ENDTYPE_Square,
+	SG_LINE_ENDTYPE_Round
+}
+TSG_Line_EndType
+;
+
+SAGA_API_DLL_EXPORT bool			SG_Shape_Get_Offset			(CSG_Shape *pSubject, double Size, double dArc, CSG_Shape *pSolution = NULL, TSG_Line_JoinType = TSG_Line_JoinType::SG_LINE_JOINTYPE_Round, TSG_Line_EndType = TSG_Line_EndType::SG_LINE_ENDTYPE_Round);
+#endif // CLIPPER_ONE
 
 SAGA_API_DLL_EXPORT const char *	SG_Clipper_Get_Version		(void);
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 //						OpenGIS							 //
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1514,7 +1538,7 @@ TSG_OGIS_Type_Geometry;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1573,7 +1597,7 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1589,9 +1613,9 @@ public:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
