@@ -367,13 +367,20 @@ CSG_Table & CSG_Table::operator = (const CSG_Table &Table)
 }
 
 //---------------------------------------------------------
-bool CSG_Table::Assign(CSG_Data_Object *pObject)
+bool CSG_Table::Assign(CSG_Data_Object *pObject, bool bProgress)
 {
-	if( CSG_Data_Object::Assign(pObject) && pObject->asTable(true) && Create(pObject->asTable(true)) )
+	if( pObject && pObject->asTable(true) && CSG_Data_Object::Assign(pObject) )
 	{
 		CSG_Table *pTable = pObject->asTable(true);
 
-		for(sLong i=0; i<pTable->Get_Count(); i++)
+		m_Encoding = pTable->m_Encoding;
+
+		for(int i=0; i<pTable->Get_Field_Count(); i++)
+		{
+			Add_Field(pTable->Get_Field_Name(i), pTable->Get_Field_Type(i));
+		}
+
+		for(sLong i=0; i<pTable->Get_Count() && (!bProgress || SG_UI_Process_Set_Progress(i, pTable->Get_Count())); i++)
 		{
 			Add_Record(pTable->Get_Record(i));
 		}
@@ -424,31 +431,15 @@ bool CSG_Table::is_Compatible(const CSG_Table &Table, bool bExactMatch) const
 {
 	if( Get_Field_Count() == Table.Get_Field_Count() )
 	{
-		for(int i=0; i<Get_Field_Count(); i++)
+		if( bExactMatch )
 		{
-			if( bExactMatch )
+			for(int i=0; i<Get_Field_Count(); i++)
 			{
 				if( Get_Field_Type(i) != Table.Get_Field_Type(i) )
 				{
 					return( false );
 				}
 			}
-			else switch( Get_Field_Type(i) )
-			{
-			case SG_DATATYPE_String:
-			//	if( Table.Get_Field_Type(i) != SG_DATATYPE_String )
-			//	{
-			//		return( false );
-			//	}
-				break;
-
-			default:
-				if( Table.Get_Field_Type(i) == SG_DATATYPE_String )
-				{
-					return( false );
-				}
-				break;
-			}
 		}
 
 		return( true );
@@ -616,66 +607,106 @@ bool CSG_Table::Set_Field_Name(int iField, const SG_Char *Name)
 }
 
 //---------------------------------------------------------
-bool CSG_Table::Set_Field_Type(int iField, TSG_Data_Type Type)
+bool CSG_Table::Set_Field_Type(int Field, TSG_Data_Type Type)
 {
-	if( iField < 0 || iField >= m_nFields )
+	if( Field < 0 || Field >= m_nFields )
 	{
 		return( false );
 	}
 
-	if( m_Field_Type[iField] == Type )
+	if( m_Field_Type[Field] == Type )
 	{
 		return( true );
 	}
 
-	m_Field_Type[iField] = Type;
-
+	#pragma omp parallel for
 	for(sLong i=0; i<m_nRecords; i++)
 	{
 		CSG_Table_Record *pRecord = m_Records[i];
 
-		CSG_Table_Value  *pValue  = CSG_Table_Record::_Create_Value(Type);
+		bool bNoData = pRecord->is_NoData(Field);
 
-		(*pValue) = *pRecord->m_Values[iField];
+		CSG_Table_Value *pValue = pRecord->m_Values[Field];
 
-		delete(pRecord->m_Values[iField]);
+		pRecord->m_Values[Field] = CSG_Table_Record::_Create_Value(Type);
 
-		pRecord->m_Values[iField] = pValue;
+		if( bNoData )
+		{
+			if( Type != SG_DATATYPE_String && Type != SG_DATATYPE_Binary )
+			{
+				pRecord->m_Values[Field]->Set_Value(Get_NoData_Value());
+			}
+		}
+		else if( pValue->Get_Type() == SG_TABLE_VALUE_TYPE_String && SG_Data_Type_is_Numeric(Type) )
+		{
+			if( !pRecord->m_Values[Field]->Set_Value(pValue->asString()) )
+			{
+				pRecord->m_Values[Field]->Set_Value(Get_NoData_Value());
+			}
+		}
+		else
+		{
+			*(pRecord->m_Values[Field]) = *pValue;
+		}
 
-		pRecord->Set_Modified();
+		delete(pValue);
+
+		pRecord->m_Flags |= SG_TABLE_REC_FLAG_Modified;
 	}
 
+	m_Field_Type[Field] = Type;
+
+	Set_Update_Flag(); _Stats_Invalidate(Field); Set_Modified();
+
 	return( true );
 }
 
 //---------------------------------------------------------
-int CSG_Table::Get_Field_Length(int iField, int Encoding)	const
+/**
+* Returns the maximum number of characters for data type string
+* or the number of bytes used for all other data types.
+*/
+//---------------------------------------------------------
+int CSG_Table::Get_Field_Length(int Field, int Encoding) const
 {
 	size_t Length = 0;
 
-	if( iField >= 0 && iField < m_nFields && m_Field_Type[iField] == SG_DATATYPE_String )
+	if( Field >= 0 && Field < m_nFields )
 	{
-		for(sLong i=0; i<m_nRecords; i++)
+		switch( m_Field_Type[Field] )
 		{
-			CSG_String s(m_Records[i]->asString(iField));
+		default:
+			Length = SG_Data_Type_Get_Size(m_Field_Type[Field]);
+			break;
 
-			size_t nBytes;
+		case SG_DATATYPE_Date:
+			Length = 10; // => YYYY-MM-DD
+			break;
 
-			switch( Encoding )
+		case SG_DATATYPE_String:
+			for(sLong i=0; i<m_nRecords; i++)
 			{
-			default                      :
-			case SG_FILE_ENCODING_UTF7   : nBytes = s.Length()            ; break;
-			case SG_FILE_ENCODING_UTF8   : nBytes = s.to_UTF8().Get_Size(); break;
-			case SG_FILE_ENCODING_UTF16LE:
-			case SG_FILE_ENCODING_UTF16BE: nBytes = s.Length() * 2        ; break;
-			case SG_FILE_ENCODING_UTF32LE:
-			case SG_FILE_ENCODING_UTF32BE: nBytes = s.Length() * 4        ; break;
-			}
+				CSG_String s(m_Records[i]->asString(Field));
 
-			if( Length < nBytes )
-			{
-				Length = nBytes;
+				size_t nBytes;
+
+				switch( Encoding )
+				{
+				default                      :
+				case SG_FILE_ENCODING_UTF7   : nBytes = s.Length()            ; break;
+				case SG_FILE_ENCODING_UTF8   : nBytes = s.to_UTF8().Get_Size(); break;
+				case SG_FILE_ENCODING_UTF16LE:
+				case SG_FILE_ENCODING_UTF16BE: nBytes = s.Length() * 2        ; break;
+				case SG_FILE_ENCODING_UTF32LE:
+				case SG_FILE_ENCODING_UTF32BE: nBytes = s.Length() * 4        ; break;
+				}
+
+				if( Length < nBytes )
+				{
+					Length = nBytes;
+				}
 			}
+			break;
 		}
 	}
 
@@ -687,11 +718,11 @@ int CSG_Table::Get_Field(const char       *Name) const { return( Get_Field(CSG_S
 int CSG_Table::Get_Field(const wchar_t    *Name) const { return( Get_Field(CSG_String(Name))); }
 int CSG_Table::Get_Field(const CSG_String &Name) const
 {
-	for(int iField=0; iField<Get_Field_Count(); iField++)
+	for(int Field=0; Field<Get_Field_Count(); Field++)
 	{
-		if( !Name.Cmp(Get_Field_Name(iField)) )
+		if( !Name.Cmp(Get_Field_Name(Field)) )
 		{
-			return( iField );
+			return( Field );
 		}
 	}
 
