@@ -111,9 +111,7 @@ int		Callback(TSG_UI_Callback_ID ID, CSG_UI_Parameter &Param_1, CSG_UI_Parameter
 	//-----------------------------------------------------
 	case CALLBACK_PROCESS_SET_READY:
 
-		STATUSBAR_Set_Text(_TL("ready"));
-
-		Result	= PROGRESSBAR_Set_Position(0);
+		Result	= PROGRESSBAR_Set_Ready();
 
 		break;
 
@@ -242,6 +240,14 @@ int		Callback(TSG_UI_Callback_ID ID, CSG_UI_Parameter &Param_1, CSG_UI_Parameter
 		break;
 
 
+	//-----------------------------------------------------
+	case CALLBACK_DATAOBJECT_DEL:
+
+		Result	= g_pData->Del((CSG_Data_Object *)Param_1.Pointer, Param_2.Boolean) ? 1 : 0;
+
+		break;
+
+
 	//-----------------------------------------------------
 	case CALLBACK_DATAOBJECT_UPDATE:
 
