@@ -63,9 +63,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -136,22 +136,22 @@ static	wxString	g_Password	= "postgres";
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 #define RUN_TOOL(TOOL, bManager, bVerbose, CONDITION)	bool bResult = false;\
 {\
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", TOOL, true);\
+	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", TOOL, true);\
 	\
 	if(	pTool )\
 	{\
 		if( !bVerbose ) SG_UI_Msg_Lock(true);\
 		pTool->On_Before_Execution();\
 		if( !bManager ) pTool->Set_Manager(NULL);\
-		bResult	= (CONDITION) && pTool->Execute();\
+		bResult = (CONDITION); if( bResult ) { bResult = pTool->Execute(); }\
 		if( !bVerbose ) SG_UI_Msg_Lock(false);\
 		SG_Get_Tool_Library_Manager().Delete_Tool(pTool);\
 	}\
@@ -162,9 +162,9 @@ static	wxString	g_Password	= "postgres";
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -199,9 +199,9 @@ bool	is_Server_Responding	(const CSG_String &Host, const CSG_String &Port, int S
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -266,7 +266,7 @@ bool	PGSQL_is_Connected		(const CSG_String &Server)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -299,16 +299,16 @@ bool	PGSQL_has_Connections	(double vPostGIS)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool	PGSQL_Save_Table	(CSG_Table *pTable)
 {
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Table_Save, true);
+	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Table_Save, true);
 
-	bool	bResult	= pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("TABLE", pTable)
-		&&  DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute();
+	bool bResult = pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("TABLE", pTable)
+		&& DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute();
 
 	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 
@@ -318,10 +318,10 @@ bool	PGSQL_Save_Table	(CSG_Table *pTable)
 //---------------------------------------------------------
 bool	PGSQL_Save_Shapes	(CSG_Shapes *pShapes)
 {
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Shapes_Save, true);
+	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Shapes_Save, true);
 
-	bool	bResult	= pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("SHAPES", pShapes)
-		&&  DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute();
+	bool bResult = pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("SHAPES", pShapes)
+		&& DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute();
 
 	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 
@@ -331,31 +331,33 @@ bool	PGSQL_Save_Shapes	(CSG_Shapes *pShapes)
 //---------------------------------------------------------
 bool	PGSQL_Save_Grid		(CSG_Grid *pGrid)
 {
-	bool	bResult	= false;
+	bool bResult = false;
 
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Raster_Save, true);
+	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Raster_Save, true);
 
 	if(	pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("NAME", pGrid->Get_Name()) )
 	{
 		pTool->Get_Parameter("GRIDS")->asList()->Del_Items();
 		pTool->Get_Parameter("GRIDS")->asList()->Add_Item(pGrid);
-		pTool->Set_Parameter("CRS_EPSG", pGrid->Get_Projection().Get_EPSG());
+
+		pTool->Set_Parameter("CRS_AUTHORITY", pGrid->Get_Projection().Get_Authority());
+		pTool->Set_Parameter("CRS_CODE"     , pGrid->Get_Projection().Get_Code     ());
 
 		bResult	= DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute();
 	}
 
 	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 
-	return( false );
+	return( bResult );
 }
 
 //---------------------------------------------------------
 bool	PGSQL_Save_Grids		(CSG_Grids *pGrids)
 {
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Rasters_Save, true);
+	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("db_pgsql", DB_PGSQL_Rasters_Save, true);
 
-	bool	bResult	= pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("GRIDS", pGrids)
-		&&  DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute();
+	bool bResult = pTool && pTool->On_Before_Execution() && pTool->Set_Parameter("GRIDS", pGrids)
+		&& DLG_Parameters(pTool->Get_Parameters()) && pTool->Execute();
 
 	SG_Get_Tool_Library_Manager().Delete_Tool(pTool);
 
@@ -364,9 +366,9 @@ bool	PGSQL_Save_Grids		(CSG_Grids *pGrids)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -403,9 +405,9 @@ private:
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -431,9 +433,9 @@ END_EVENT_TABLE()
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -528,7 +530,7 @@ CData_Source_PgSQL::~CData_Source_PgSQL(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -565,7 +567,7 @@ void CData_Source_PgSQL::Autoconnect(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -648,7 +650,7 @@ void CData_Source_PgSQL::On_Table_Drop(wxCommandEvent &WXUNUSED(event))
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -746,7 +748,7 @@ void CData_Source_PgSQL::On_Item_Menu(wxTreeEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -856,6 +858,8 @@ void CData_Source_PgSQL::Update_Sources(void)
 
 		Item = GetNextChild(GetRootItem(), Cookie);
 	}
+
+	UnselectAll();
 }
 
 //---------------------------------------------------------
@@ -953,6 +957,7 @@ void CData_Source_PgSQL::Update_Source(const wxTreeItemId &Item)
 					case SHAPE_TYPE_Points     : Append_Table(Item, Name, TYPE_SHAPES, IMG_POINTS  ); break;
 					case SHAPE_TYPE_Line       : Append_Table(Item, Name, TYPE_SHAPES, IMG_LINE    ); break;
 					case SHAPE_TYPE_Polygon    : Append_Table(Item, Name, TYPE_SHAPES, IMG_POLYGON ); break;
+					default: break;
 					}
 				}
 				else if( !Type.Cmp("GEOMETRY") ) Append_Table(Item, Name, TYPE_SHAPES, IMG_GEOMETRY); // geometry collection!(?)
@@ -999,7 +1004,7 @@ void CData_Source_PgSQL::Append_Table(const wxTreeItemId &Parent, const SG_Char
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1187,7 +1192,7 @@ void CData_Source_PgSQL::Source_SQL(const wxTreeItemId &Item)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1231,7 +1236,7 @@ void CData_Source_PgSQL::Table_Open(const wxTreeItemId &Item)
 	{
 		RUN_TOOL(DB_PGSQL_Raster_Load, true, false,
 			   SET_PARAMETER("CONNECTION", pData->Get_Server())
-			&& SET_PARAMETER("DB_TABLE"  , pData->Get_Value ())
+			&& SET_PARAMETER("DB_TABLES" , pData->Get_Value ())
 		);
 	}
 
@@ -1240,7 +1245,7 @@ void CData_Source_PgSQL::Table_Open(const wxTreeItemId &Item)
 	{
 		RUN_TOOL(DB_PGSQL_Raster_Load, true, false,
 			   SET_PARAMETER("CONNECTION", pData->Get_Server())
-			&& SET_PARAMETER("DB_TABLE"  , pData->Get_Value ().BeforeFirst(':'))
+			&& SET_PARAMETER("DB_TABLES" , pData->Get_Value ().BeforeFirst(':'))
 			&& SET_PARAMETER("WHERE"     , pData->Get_Value ().AfterFirst (':'))
 		);
 	}
@@ -1288,11 +1293,6 @@ void CData_Source_PgSQL::Table_Rename(const wxTreeItemId &Item)
 				&& SET_PARAMETER("OUTPUT"    , 0)	// none
 				&& SET_PARAMETER("SQL"       , SQL)
 			);
-
-			if( bResult )
-			{
-				SetItemText(Item, Name);
-			}
 		}
 		break;
 
@@ -1307,11 +1307,6 @@ void CData_Source_PgSQL::Table_Rename(const wxTreeItemId &Item)
 				&& SET_PARAMETER("OUTPUT"    , 0)	// none
 				&& SET_PARAMETER("SQL"       , SQL)
 			);
-
-			if( bResult )
-			{
-				SetItemText(Item, Name);
-			}
 		}
 		break;
 	}
@@ -1404,9 +1399,9 @@ void CData_Source_PgSQL::Table_Drop(const wxTreeItemId &Item)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
