@@ -47,10 +47,12 @@
 
 //---------------------------------------------------------
 #include <wx/dcclient.h>
+#include <wx/settings.h>
 
 #include "res_images.h"
 
 #include "res/xpm/logo_uhh.xpm"
+#include "res/xpm/logo_uhh_dark.xpm"
 #include "res/xpm/logo_scilands.xpm"
 #ifdef wxHAS_SVG
 #include "res/svg/logo_laserdata.svg.h"
@@ -89,7 +91,7 @@ END_EVENT_TABLE()
 CDLG_About_Logo::CDLG_About_Logo(wxWindow *pParent)
 	: wxScrolledCanvas(pParent, -1, wxDefaultPosition, wxDefaultSize, wxBORDER_SIMPLE)
 {
-	SetBackgroundColour(*wxWHITE);
+	SetBackgroundColour(wxSystemSettings::GetColour(wxSYS_COLOUR_WINDOW));
 }
 
 
@@ -125,7 +127,7 @@ void CDLG_About_Logo::On_Paint(wxPaintEvent &event)
 	FONT_NORMAL; Draw_Text(dc, Cursor += Space * 0, "_______________________");
 	FONT_NORMAL; Draw_Text(dc, Cursor += Space * 1, "Brought to you by");
 
-	Draw_XPM              (dc, Cursor += Space * 0, xpm_logo_uhh);
+	Draw_XPM              (dc, Cursor += Space * 0, wxSystemSettings::GetAppearance().IsDark() ? xpm_logo_uhh_dark : xpm_logo_uhh);
 	FONT_NORMAL; Draw_Text(dc, Cursor += Space * 0, "Department of Physical Geography");
 	FONT_ITALIC; Draw_Text(dc, Cursor += Space * 0, L"Prof. Dr. J. Böhner, Dr. O. Conrad");
 
