@@ -117,33 +117,47 @@ END_EVENT_TABLE()
 CDLG_List_Base::CDLG_List_Base(CSG_Parameter_List *pParameter, wxString Caption)
 	: CDLG_Base(-1, Caption)
 {
-	m_pParameter	= pParameter;
-	m_Type			= SG_DATAOBJECT_TYPE_Undefined;
+	m_pParameter   = pParameter;
+	m_Type         = SG_DATAOBJECT_TYPE_Undefined;
 
-	m_pChoices		= new wxListBox(this, ID_LISTBOX_SELECT, wxDefaultPosition, wxDefaultSize, 0, NULL, wxLB_EXTENDED|wxLB_NEEDED_SB);
-	m_pSelection	= new wxListBox(this, ID_LISTBOX_ADD   , wxDefaultPosition, wxDefaultSize, 0, NULL, wxLB_EXTENDED|wxLB_NEEDED_SB);
+	m_pChoices     = new wxListBox(this, ID_LISTBOX_SELECT, wxDefaultPosition, wxDefaultSize, 0, NULL, wxLB_EXTENDED|wxLB_NEEDED_SB);
+	m_pSelection   = new wxListBox(this, ID_LISTBOX_ADD   , wxDefaultPosition, wxDefaultSize, 0, NULL, wxLB_EXTENDED|wxLB_NEEDED_SB);
 
-	m_pBtn_Add_All	= new wxButton (this, ID_BTN_ADD_ALL   , ">>");
-	m_pBtn_Add		= new wxButton (this, ID_BTN_ADD       , ">" );
-	m_pBtn_Del		= new wxButton (this, ID_BTN_DELETE    , "<" );
-	m_pBtn_Del_All	= new wxButton (this, ID_BTN_DELETE_ALL, "<<");
-	m_pBtn_Up		= new wxButton (this, ID_BTN_UP        , CTRL_Get_Name(ID_BTN_UP));
-	m_pBtn_Down		= new wxButton (this, ID_BTN_DOWN      , CTRL_Get_Name(ID_BTN_DOWN));
+	m_pBtn_Add_All = new wxButton (this, ID_BTN_ADD_ALL   , ">>");
+	m_pBtn_Add     = new wxButton (this, ID_BTN_ADD       , ">" );
+	m_pBtn_Del     = new wxButton (this, ID_BTN_DELETE    , "<" );
+	m_pBtn_Del_All = new wxButton (this, ID_BTN_DELETE_ALL, "<<");
+	m_pBtn_Up      = new wxButton (this, ID_BTN_UP        , CTRL_Get_Name(ID_BTN_UP));
+	m_pBtn_Down    = new wxButton (this, ID_BTN_DOWN      , CTRL_Get_Name(ID_BTN_DOWN));
 
-	m_Btn_Height	= m_pBtn_Add->GetDefaultSize().y;
+	m_Btn_Height   = m_pBtn_Add->GetDefaultSize().y;
 
 	//-----------------------------------------------------
 	for(int i=m_pParameter->Get_Item_Count()-1; i>=0; i--)
 	{
-		CWKSP_Data_Item	*pItem	= g_pData->Get(m_pParameter->Get_Item(i));
+		wxString Name; CSG_Data_Object *pObject = m_pParameter->Get_Item(i);
 
-		if( pItem && SG_Get_Data_Manager().Exists(m_pParameter->Get_Item(i)) )
+		if( SG_Get_Data_Manager().Exists(pObject) )
 		{
-			m_pSelection->Insert(pItem->Get_Name(), 0, (void *)m_pParameter->Get_Item(i));
+			CWKSP_Data_Item *pItem = g_pData->Get(pObject);
+
+			if( pItem )
+			{
+				Name = pItem->Get_Name();
+			}
+			else if( (pItem = g_pData->Get(pObject->Get_Owner())) && pObject->Get_Owner()->asGrids() )
+			{
+				Name = pItem->Get_Name().BeforeFirst('.') + ". " + pObject->Get_Name();
+			}
+		}
+
+		if( Name.IsEmpty() )
+		{
+			m_pParameter->Del_Item(i);
 		}
 		else
 		{
-			m_pParameter->Del_Item(i);
+			m_pSelection->Insert(Name, 0, (void *)pObject);
 		}
 	}
 
@@ -159,33 +173,18 @@ CDLG_List_Base::CDLG_List_Base(CSG_Parameter_List *pParameter, wxString Caption)
 //---------------------------------------------------------
 void CDLG_List_Base::Set_Position(wxRect r)
 {
-	r.Deflate(5);
+	r.Deflate(5); int Center = r.GetLeft() + r.GetWidth() / 2;
 
-	int	Center	= r.GetLeft() + r.GetWidth() / 2;
+	r.SetWidth(r.GetWidth() / 2 - (DLG_LIST_BTN_WIDTH / 2 + DLG_LIST_BTN_DIST)); m_pChoices  ->SetSize(r);
+	r.SetLeft (Center           + (DLG_LIST_BTN_WIDTH / 2 + DLG_LIST_BTN_DIST)); m_pSelection->SetSize(r);
 
-	r.SetWidth(r.GetWidth() / 2 - (DLG_LIST_BTN_WIDTH / 2 + DLG_LIST_BTN_DIST));
-	m_pChoices->SetSize(r);
-
-	r.SetLeft(Center            + (DLG_LIST_BTN_WIDTH / 2 + DLG_LIST_BTN_DIST));
-	m_pSelection->SetSize(r);
-
-	r		= wxRect(Center - DLG_LIST_BTN_WIDTH / 2, r.GetTop(), DLG_LIST_BTN_WIDTH, m_Btn_Height);
-	m_pBtn_Add_All->SetSize(r);
-
-	r.SetTop(r.GetBottom() + DLG_LIST_BTN_DIST);
-	m_pBtn_Add->SetSize(r);
-
-	r.SetTop(r.GetBottom() + DLG_LIST_BTN_DIST * 2);
-	m_pBtn_Del->SetSize(r);
-
-	r.SetTop(r.GetBottom() + DLG_LIST_BTN_DIST);
-	m_pBtn_Del_All->SetSize(r);
-
-	r.SetTop(r.GetBottom() + DLG_LIST_BTN_DIST * 2);
-	m_pBtn_Up->SetSize(r);
-
-	r.SetTop(r.GetBottom() + DLG_LIST_BTN_DIST);
-	m_pBtn_Down->SetSize(r);
+	r = wxRect(Center - DLG_LIST_BTN_WIDTH / 2, r.GetTop(), DLG_LIST_BTN_WIDTH, m_Btn_Height);
+	                                                 m_pBtn_Add_All->SetSize(r);
+	r.SetTop(r.GetBottom() + DLG_LIST_BTN_DIST    ); m_pBtn_Add    ->SetSize(r);
+	r.SetTop(r.GetBottom() + DLG_LIST_BTN_DIST * 2); m_pBtn_Del    ->SetSize(r);
+	r.SetTop(r.GetBottom() + DLG_LIST_BTN_DIST    ); m_pBtn_Del_All->SetSize(r);
+	r.SetTop(r.GetBottom() + DLG_LIST_BTN_DIST * 2); m_pBtn_Up     ->SetSize(r);
+	r.SetTop(r.GetBottom() + DLG_LIST_BTN_DIST    ); m_pBtn_Down   ->SetSize(r);
 }
 
 
@@ -200,15 +199,15 @@ void CDLG_List_Base::Set_Data(CWKSP_Base_Manager *pManager)
 	{
 		for(int iItem=0; iItem<pManager->Get_Count(); iItem++)
 		{
-			CWKSP_Data_Item	*pItem	= (CWKSP_Data_Item *)pManager->Get_Item(iItem);
+			CWKSP_Data_Item *pItem = (CWKSP_Data_Item *)pManager->Get_Item(iItem);
 
 			if( m_Type == SG_DATAOBJECT_TYPE_Undefined || m_Type == pItem->Get_Object()->Get_ObjectType() )
 			{
-				for(size_t j=0; j<m_pSelection->GetCount() && pItem; j++)
+				for(size_t i=0; pItem && i<m_pSelection->GetCount(); i++)
 				{
-					if( pItem->Get_Object() == m_pSelection->GetClientData(j) )
+					if( pItem->Get_Object() == m_pSelection->GetClientData(i) )
 					{
-						pItem	= NULL;
+						pItem = NULL;
 					}
 				}
 
@@ -217,6 +216,32 @@ void CDLG_List_Base::Set_Data(CWKSP_Base_Manager *pManager)
 					m_pChoices->Append(pItem->Get_Name(), (void *)pItem->Get_Object());
 				}
 			}
+
+			//---------------------------------------------
+			else if( m_Type == SG_DATAOBJECT_TYPE_Grid && pItem->Get_Object()->asGrids() )
+			{
+				CSG_Grids *pGrids = pItem->Get_Object()->asGrids();
+
+				for(int iGrid=0; iGrid<pGrids->Get_Grid_Count(); iGrid++)
+				{
+					CSG_Grid *pGrid = pGrids->Get_Grid_Ptr(iGrid);
+
+					for(size_t i=0; pGrid && i<m_pSelection->GetCount(); i++)
+					{
+						if( pGrid == m_pSelection->GetClientData(i) )
+						{
+							pGrid = NULL;
+						}
+					}
+
+					if( pGrid )
+					{
+						wxString Name(pItem->Get_Name().BeforeFirst('.'));
+
+						m_pChoices->Append(Name +  + ". " + pGrid->Get_Name(), (void *)pGrid);
+					}
+				}
+			}
 		}
 	}
 }
@@ -483,9 +508,9 @@ CDLG_List_Shapes::CDLG_List_Shapes(CSG_Parameter_Shapes_List *pList, wxString Ca
 }
 
 //---------------------------------------------------------
-void CDLG_List_Shapes::_Set_Data(void)
+bool CDLG_List_Shapes::_Set_Data(void)
 {
-	CWKSP_Shapes_Manager	*pManager	= g_pData->Get_Shapes();
+	CWKSP_Shapes_Manager *pManager = g_pData->Get_Shapes();
 
 	if( m_Shape_Type == SHAPE_TYPE_Undefined )
 	{
@@ -511,6 +536,8 @@ void CDLG_List_Shapes::_Set_Data(void)
 			Set_Data(g_pData->Get_PointClouds());
 		}
 	}
+
+	return( true );
 }
 
 
@@ -591,7 +618,7 @@ void CDLG_List_Grid_Base::On_Select_System(wxCommandEvent &event)
 }
 
 //---------------------------------------------------------
-void CDLG_List_Grid_Base::_Set_Data(void)
+bool CDLG_List_Grid_Base::_Set_Data(void)
 {
 	m_pChoices->Clear();
 
@@ -601,11 +628,11 @@ void CDLG_List_Grid_Base::_Set_Data(void)
 	}
 	else if( m_pSystems )
 	{
-		CWKSP_Grid_Manager	*pManager	= g_pData->Get_Grids();
+		CWKSP_Grid_Manager *pManager = g_pData->Get_Grids();
 
 		if( pManager )
 		{
-			int	iSystem	= m_pSystems->GetSelection();
+			int iSystem = m_pSystems->GetSelection();
 
 			if( 0 <= iSystem && iSystem < pManager->Get_Count() )
 			{
@@ -620,6 +647,8 @@ void CDLG_List_Grid_Base::_Set_Data(void)
 			}
 		}
 	}
+
+	return( true );
 }
 
 
@@ -632,11 +661,19 @@ void CDLG_List_Grid_Base::_Set_Data(void)
 //---------------------------------------------------------
 IMPLEMENT_CLASS(CDLG_List_Grid, CDLG_List_Grid_Base)
 
+//---------------------------------------------------------
+BEGIN_EVENT_TABLE(CDLG_List_Grid, CDLG_List_Grid_Base)
+	EVT_CHECKBOX(wxID_ANY, CDLG_List_Grid::On_CheckBox)
+END_EVENT_TABLE()
+
+//---------------------------------------------------------
+bool CDLG_List_Grid::m_bExpand = false;
+
 //---------------------------------------------------------
 CDLG_List_Grid::CDLG_List_Grid(CSG_Parameter_Grid_List *pList, wxString Caption)
 	: CDLG_List_Grid_Base(pList, Caption)
 {
-	CWKSP_Grid_Manager	*pManager	= g_pData->Get_Grids();
+	CWKSP_Grid_Manager *pManager = g_pData->Get_Grids();
 
 	if( pManager == NULL )
 	{
@@ -645,24 +682,89 @@ CDLG_List_Grid::CDLG_List_Grid(CSG_Parameter_Grid_List *pList, wxString Caption)
 	}
 	else if( pList->Get_System() )
 	{
-		m_pSystem	= pManager->Get_System(*pList->Get_System());
-		m_pSystems	= NULL;
+		m_pSystem  = pManager->Get_System(*pList->Get_System());
+		m_pSystems = NULL;
 	}
 	else
 	{
-		m_pSystem	= NULL;
-		m_pSystems	= new wxChoice(this, ID_COMBOBOX_SELECT, wxDefaultPosition, wxDefaultSize, 0, NULL, 0 );
+		m_pSystem  = NULL;
+		m_pSystems = new wxChoice(this, ID_COMBOBOX_SELECT, wxDefaultPosition, wxDefaultSize, 0, NULL, 0 );
 
 		for(int i=0; i<pManager->Get_Count(); i++)
 		{
 			m_pSystems->Append(pManager->Get_System(i)->Get_Name());
 		}
 
-		m_pSystems->Append( _TL("<all grid systems>") );
+		m_pSystems->Append(_TL("<all grid systems>"));
 		m_pSystems->SetSelection(m_pSystems->GetCount() - 1);
 	}
 
-	_Set_Data();
+	if( pList->is_Input() )
+	{
+		m_Type = m_bExpand ? SG_DATAOBJECT_TYPE_Grid : SG_DATAOBJECT_TYPE_Undefined;
+
+		wxCheckBox *pBox = new wxCheckBox(Get_Controls(), wxID_ANY, _TL("Expand"));
+		pBox->SetToolTip(_TL("Check this to list the single grids of grid collections"));
+		pBox->SetValue(m_Type == SG_DATAOBJECT_TYPE_Grid);
+		Add_Control(pBox);
+
+		Expand_Grids(m_bExpand);
+	}
+	else
+	{
+		_Set_Data();
+	}
+}
+
+//---------------------------------------------------------
+bool CDLG_List_Grid::Expand_Grids(bool bExpand)
+{
+	if( bExpand == true  )
+	{
+		m_bExpand =  true; m_Type = SG_DATAOBJECT_TYPE_Grid;
+
+		#define EXPAND_GRIDS(pList) for(int i=pList->GetCount()-1; i>=0; i--) {\
+			CSG_Grids *pGrids = ((CSG_Data_Object *)pList->GetClientData((size_t)i))->asGrids();\
+			if( pGrids ) { wxString Name(pList->GetString(i).BeforeFirst('.')); pList->Delete((size_t)i);\
+				for(int iGrid=pGrids->Get_Grid_Count()-1; iGrid>=0; iGrid--)\
+				{	CSG_Grid *pGrid = pGrids->Get_Grid_Ptr(iGrid);\
+					if( (size_t)i >= pList->GetCount() )\
+					pList->Append(Name + ". " + pGrid->Get_Name()   , (void *)pGrid);\
+					else\
+					pList->Insert(Name + ". " + pGrid->Get_Name(), i, (void *)pGrid);\
+				}\
+			}\
+		}
+
+		EXPAND_GRIDS(m_pChoices); EXPAND_GRIDS(m_pSelection);
+
+		return( _Set_Data() );
+	}
+
+	if( bExpand == false )
+	{
+		m_bExpand = false; m_Type = SG_DATAOBJECT_TYPE_Undefined;
+
+		#define REMOVE_GRIDS(pList) for(int i=pList->GetCount()-1; i>=0; i--) {\
+			CSG_Data_Object *pObject = (CSG_Data_Object *)pList->GetClientData((size_t)i);\
+			if( pObject->Get_ObjectType() == SG_DATAOBJECT_TYPE_Grid && pObject->Get_Owner() )\
+			{\
+				pList->Delete((size_t)i);\
+			}\
+		}
+
+		REMOVE_GRIDS(m_pChoices); REMOVE_GRIDS(m_pSelection);
+
+		return( _Set_Data() );
+	}
+
+	return( false );
+}
+
+//---------------------------------------------------------
+void CDLG_List_Grid::On_CheckBox(wxCommandEvent &event)
+{
+	Expand_Grids(event.IsChecked());
 }
 
 
