@@ -94,12 +94,16 @@ wxColour			Get_Color_asWX					(int Color);
 int					Get_Color_asInt					(wxColour Color);
 
 wxColour			SYS_Get_Color					(wxSystemColour index);
-void				SYS_Set_Color_BG				(wxWindow *pWindow, wxSystemColour index);
-void				SYS_Set_Color_BG_Window			(wxWindow *pWindow);
+
+wxColour			SYS_Get_Color_Background		(int Mode = 0);
+wxColour			SYS_Get_Color_Foreground		(int Mode = 0);
 
 //---------------------------------------------------------
 wxWindow *			MDI_Get_Frame					(void);
 
+class CVIEW_Base *	MDI_Get_Active_View				(int View_ID = -1);
+class CVIEW_Base *	MDI_Get_Active_Map				(void);
+
 wxPoint				MDI_Get_Def_Position			(void);
 wxSize				MDI_Get_Def_Size				(void);
 
@@ -107,6 +111,11 @@ void				MDI_Top_Window_Push				(wxWindow *pWindow);
 void				MDI_Top_Window_Pop				(wxWindow *pWindow);
 wxWindow *			MDI_Get_Top_Window				(void);
 
+bool				MDI_Window_Arrange				(int Arrange);
+
+bool				MDI_Freeze						(void);
+bool				MDI_Thaw						(void);
+
 //---------------------------------------------------------
 void				Set_Buisy_Cursor				(bool bOn);
 
@@ -153,7 +162,7 @@ bool				PROCESS_Set_Okay				(bool bOkay = true);
 
 bool				PROCESS_Set_Busy				(bool bOn = true, const CSG_String &Message = "");
 
-bool				PROGRESSBAR_Set_Position		(int Position);
+bool				PROGRESSBAR_Set_Ready			(void);
 bool				PROGRESSBAR_Set_Position		(double Position, double Range);
 
 //---------------------------------------------------------
