@@ -74,9 +74,9 @@ class CINFO_Messages : public wxTextCtrl
 public:
 	CINFO_Messages(wxWindow *pParent);
 
-	void						Add_Time			(bool bNewLine = true);
 	void						Add_Line			(void);
-	void						Add_String			(wxString sMessage, bool bNewLine = true, bool bTime = false, TSG_UI_MSG_STYLE Style = SG_UI_MSG_STYLE_NORMAL);
+	void						Add_Time			(bool bNewLine = true);
+	void						Add_String			(const wxString &Message, bool bNewLine = true, bool bTime = false, TSG_UI_MSG_STYLE Style = SG_UI_MSG_STYLE_NORMAL);
 
 
 private:
