@@ -206,7 +206,7 @@ bool CWKSP_Project::Copy(void)
 {
 	wxString File;
 
-	if( !DLG_Save(File, ID_DLG_PROJECT_SAVE) )
+	if( !DLG_Save(File, _TL("Copy Project to..."), wxString::Format("%s|", _TL("SAGA Project"))) )
 	{
 		return( false );
 	}
@@ -437,7 +437,7 @@ bool CWKSP_Project::_Load(const wxString &File, bool bAdd, bool bUpdateMenu)
 	{
 		if( bUpdateMenu )
 		{
-			g_pData->Get_Menu_Files()->Recent_Add(SG_DATAOBJECT_TYPE_Undefined, File);
+			g_pData->Get_Menu_Files()->Recent_Add(CWKSP_Data_Menu_File::Recent_Type::Project, File);
 		}
 
 		m_File_Name	= File;
@@ -460,7 +460,7 @@ bool CWKSP_Project::_Load(const wxString &File, bool bAdd, bool bUpdateMenu)
 
 	if( bUpdateMenu )
 	{
-		g_pData->Get_Menu_Files()->Recent_Del(SG_DATAOBJECT_TYPE_Undefined, File);
+		g_pData->Get_Menu_Files()->Recent_Del(CWKSP_Data_Menu_File::Recent_Type::Project, File);
 	}
 
 	CSG_String Name(SG_File_Get_Name(&File, true));
@@ -567,14 +567,14 @@ bool CWKSP_Project::_Save(const wxString &_File, bool bSaveModified, bool bUpdat
 
 		if( bUpdateMenu )
 		{
-			g_pData->Get_Menu_Files()->Recent_Add(SG_DATAOBJECT_TYPE_Undefined, m_File_Name);
+			g_pData->Get_Menu_Files()->Recent_Add(CWKSP_Data_Menu_File::Recent_Type::Project, m_File_Name);
 		}
 
 		MSG_General_Add(_TL("Project has been saved."), true, true, SG_UI_MSG_STYLE_SUCCESS);
 
 		_Set_Project_Name();
 
-		PROGRESSBAR_Set_Position(0);
+		PROGRESSBAR_Set_Ready();
 
 		return( true );
 	}
@@ -583,12 +583,12 @@ bool CWKSP_Project::_Save(const wxString &_File, bool bSaveModified, bool bUpdat
 
 	if( bUpdateMenu )
 	{
-		g_pData->Get_Menu_Files()->Recent_Del(SG_DATAOBJECT_TYPE_Undefined, File);
+		g_pData->Get_Menu_Files()->Recent_Del(CWKSP_Data_Menu_File::Recent_Type::Project, File);
 	}
 
 	MSG_General_Add(_TL("Could not save project."), true, true, SG_UI_MSG_STYLE_FAILURE);
 
-	PROGRESSBAR_Set_Position(0);
+	PROGRESSBAR_Set_Ready();
 
 	return( false );
 }
@@ -920,7 +920,7 @@ bool CWKSP_Project::_Compatibility_Load_Data(const wxString &File)
 	CSG_String	sLine;
 	CSG_File	Stream;
 
-	if( !Stream.Open(&File, SG_FILE_R, true) )
+	if( !Stream.Open(File, SG_FILE_R, true) )
 	{
 		return( false );
 	}
