@@ -53,9 +53,9 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -66,18 +66,21 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#define RECENT_COUNT				16
+#define MAX_COUNT_RECENT_PROJECTS 16
+#define MAX_COUNT_RECENT_FILES    32
+#define MAX_COUNT_RECENT_TOOLS    16
+#define MAX_COUNT_TOOLS           2048
 
 //---------------------------------------------------------
 enum ID_COMMANDS
 {
-	ID_CMD_FIRST					= wxID_HIGHEST + 1024,
+	ID_CMD_FIRST = wxID_HIGHEST + 1024,
 
 	ID_CMD_FRAME_CASCADE,
 	ID_CMD_FRAME_TILE_HORZ,
@@ -92,6 +95,7 @@ enum ID_COMMANDS
 	ID_CMD_FRAME_SPLIT_ALL_VERT,
 	ID_CMD_FRAME_NEXT,
 	ID_CMD_FRAME_PREVIOUS,
+	ID_CMD_FRAME_FIND,
 	ID_CMD_FRAME_CLOSE,
 	ID_CMD_FRAME_CLOSE_ALL,
 	ID_CMD_FRAME_CLOSE_ALL_OTHERS,
@@ -107,7 +111,7 @@ enum ID_COMMANDS
 	ID_CMD_FRAME_WKSP_SHOW,
 
 	//-----------------------------------------------------
-	ID_CMD_WKSP_FIRST,	// Begin: Workspace Commands
+	ID_CMD_WKSP_FIRST, // begin workspace commands
 	ID_CMD_WKSP_ITEM_RETURN,
 	ID_CMD_WKSP_ITEM_CLOSE,
 	ID_CMD_WKSP_ITEM_SEARCH,
@@ -134,22 +138,11 @@ enum ID_COMMANDS
 	ID_CMD_DB_TABLE_INFO,
 	ID_CMD_DB_TABLE_FROM_QUERY,
 
-	ID_CMD_TOOL_FIRST,
-	ID_CMD_TOOL_RECENT_FIRST,
-	ID_CMD_TOOL_RECENT_LAST		= RECENT_COUNT + ID_CMD_TOOL_RECENT_FIRST,
-	ID_CMD_TOOL_OPEN,
-	ID_CMD_TOOL_RELOAD,
-	ID_CMD_TOOL_SEARCH,
-	ID_CMD_TOOL_SAVE_SCRIPT,
-	ID_CMD_TOOL_SAVE_DOCS,
-	ID_CMD_TOOL_SAVE_TO_CLIPBOARD,
-	ID_CMD_TOOL_CHAIN_RELOAD,
-	ID_CMD_TOOL_CHAIN_EDIT,
-	ID_CMD_TOOL_LAST,
-
-	ID_CMD_DATA_FIRST,
+	//-----------------------------------------------------
+	ID_CMD_DATA_FIRST, // begin data commands
+	ID_CMD_DATA_PROJECT,
 	ID_CMD_DATA_PROJECT_RECENT_FIRST,
-	ID_CMD_DATA_PROJECT_RECENT_LAST	= RECENT_COUNT + ID_CMD_DATA_PROJECT_RECENT_FIRST,
+	ID_CMD_DATA_PROJECT_RECENT_LAST = ID_CMD_DATA_PROJECT_RECENT_FIRST + MAX_COUNT_RECENT_PROJECTS,
 	ID_CMD_DATA_PROJECT_OPEN,
 	ID_CMD_DATA_PROJECT_OPEN_ADD,
 	ID_CMD_DATA_PROJECT_BROWSE,
@@ -164,7 +157,7 @@ enum ID_COMMANDS
 	ID_CMD_DATA_LEGEND_COPY,
 	ID_CMD_DATA_LEGEND_SIZE_INC,
 	ID_CMD_DATA_LEGEND_SIZE_DEC,
-	ID_CMD_DATA_LEGEND_BG_BLACK,
+	ID_CMD_DATA_LEGEND_BACKGROUND_INVERT,
 
 	ID_CMD_DATA_HISTORY_CLEAR,
 	ID_CMD_DATA_HISTORY_TO_MODEL,
@@ -174,77 +167,55 @@ enum ID_COMMANDS
 	ID_CMD_DATA_OPEN,
 	ID_CMD_DATA_SAVE,
 	ID_CMD_DATA_SAVEAS,
+	ID_CMD_DATA_SAVEAS_IMAGE,
 	ID_CMD_DATA_SAVETODB,
 	ID_CMD_DATA_RELOAD,
 	ID_CMD_DATA_DEL_FILES,
+	ID_CMD_DATA_CLIPBOARD_COPY,
+	ID_CMD_DATA_CLIPBOARD_PASTE_TABLE,
+	ID_CMD_DATA_CLIPBOARD_PASTE_IMAGE,
 	ID_CMD_DATA_PROJECTION,
 	ID_CMD_DATA_METADATA,
 	ID_CMD_DATA_FORCE_UPDATE,
 	ID_CMD_DATA_SETTINGS_LOAD,
 	ID_CMD_DATA_SETTINGS_COPY,
+	ID_CMD_DATA_RANGE_MINMAX,
+	ID_CMD_DATA_RANGE_STDDEV,
+	ID_CMD_DATA_RANGE_STDDEV150,
+	ID_CMD_DATA_RANGE_STDDEV200,
+	ID_CMD_DATA_RANGE_PERCENTILE,
+	ID_CMD_DATA_CLASSIFY,
 	ID_CMD_DATA_CLASSIFY_IMPORT,
+	ID_CMD_DATA_SELECTION_CLEAR,
+	ID_CMD_DATA_SELECTION_INVERT,
+	ID_CMD_DATA_SELECTION_DELETE,
+	ID_CMD_DATA_SHOW_MAP,
+	ID_CMD_DATA_HISTOGRAM,
+	ID_CMD_DATA_SCATTERPLOT,
+	ID_CMD_DATA_SCATTERPLOT_3D,
+	ID_CMD_DATA_DIAGRAM,
 	ID_CMD_DATA_LAST,
 
+	ID_CMD_DATA_FOLDER_RECENT,
+	ID_CMD_DATA_FOLDER_RECENT_FIRST,
+	ID_CMD_DATA_FOLDER_RECENT_LAST = ID_CMD_DATA_FOLDER_RECENT_FIRST + MAX_COUNT_RECENT_FILES,
+
+	ID_CMD_DATA_FILE_RECENT,
+	ID_CMD_DATA_FILE_RECENT_FIRST,
+	ID_CMD_DATA_FILE_RECENT_LAST = ID_CMD_DATA_FILE_RECENT_FIRST + MAX_COUNT_RECENT_FILES,
+
 	ID_CMD_GRID_FIRST,
-	ID_CMD_GRID_RECENT_FIRST,
-	ID_CMD_GRID_RECENT_LAST		= RECENT_COUNT + ID_CMD_GRID_RECENT_FIRST,
 	ID_CMD_GRID_OPEN,
-	ID_CMD_GRID_SAVEAS_IMAGE,
-	ID_CMD_GRID_CLIPBOARD_IMAGE,
-	ID_CMD_GRID_SHOW,
-	ID_CMD_GRID_HISTOGRAM,
-	ID_CMD_GRID_SCATTERPLOT,
-	ID_CMD_GRID_EQUALINTERVALS,
-	ID_CMD_GRID_SET_LUT,
-	ID_CMD_GRID_SEL_CLEAR,
-	ID_CMD_GRID_SEL_DELETE,
 	ID_CMD_GRID_LAST,
 
 	ID_CMD_GRIDS_FIRST,
-	ID_CMD_GRIDS_RECENT_FIRST,
-	ID_CMD_GRIDS_RECENT_LAST		= RECENT_COUNT + ID_CMD_GRIDS_RECENT_FIRST,
 	ID_CMD_GRIDS_OPEN,
-	ID_CMD_GRIDS_SAVEAS_IMAGE,
-	ID_CMD_GRIDS_SHOW,
-	ID_CMD_GRIDS_SCATTERPLOT,
-	ID_CMD_GRIDS_FIT_MINMAX,
-	ID_CMD_GRIDS_FIT_STDDEV,
-	ID_CMD_GRIDS_FIT_PCTL,
-	ID_CMD_GRIDS_FIT_DIALOG,
 	ID_CMD_GRIDS_LAST,
 
-	ID_CMD_SHAPES_FIRST,
-	ID_CMD_SHAPES_RECENT_FIRST,
-	ID_CMD_SHAPES_RECENT_LAST		= RECENT_COUNT + ID_CMD_SHAPES_RECENT_FIRST,
-	ID_CMD_SHAPES_OPEN,
-	ID_CMD_SHAPES_SHOW,
-	ID_CMD_SHAPES_HISTOGRAM,
-	ID_CMD_SHAPES_RANGE_MINMAX,
-	ID_CMD_SHAPES_RANGE_STDDEV150,
-	ID_CMD_SHAPES_RANGE_STDDEV200,
-	ID_CMD_SHAPES_SET_LUT,
-	ID_CMD_SHAPES_SAVE_ATTRIBUTES,
-	ID_CMD_SHAPES_EDIT_SHAPE,
-	ID_CMD_SHAPES_EDIT_SEL_CLEAR,
-	ID_CMD_SHAPES_EDIT_SEL_INVERT,
-	ID_CMD_SHAPES_EDIT_ADD_SHAPE,
-	ID_CMD_SHAPES_EDIT_ADD_PART,
-	ID_CMD_SHAPES_EDIT_DEL_SHAPE,
-	ID_CMD_SHAPES_EDIT_DEL_PART,
-	ID_CMD_SHAPES_EDIT_DEL_POINT,
-	ID_CMD_SHAPES_EDIT_SPLIT,
-	ID_CMD_SHAPES_EDIT_MERGE,
-	ID_CMD_SHAPES_EDIT_MOVE,
-    ID_CMD_SHAPES_EDIT_SEL_COPY_TO_NEW_LAYER,
-	ID_CMD_SHAPES_LAST,
-
 	ID_CMD_TABLE_FIRST,
-	ID_CMD_TABLE_RECENT_FIRST,
-	ID_CMD_TABLE_RECENT_LAST		= RECENT_COUNT + ID_CMD_TABLE_RECENT_FIRST,
 	ID_CMD_TABLE_OPEN,
 	ID_CMD_TABLE_SHOW,
-	ID_CMD_TABLE_DIAGRAM,
-	ID_CMD_TABLE_SCATTERPLOT,
+	ID_CMD_TABLE_JOIN_DATA,
 	ID_CMD_TABLE_FIELD_ADD,
 	ID_CMD_TABLE_FIELD_MOVE,
 	ID_CMD_TABLE_FIELD_DEL,
@@ -259,28 +230,34 @@ enum ID_COMMANDS
 	ID_CMD_TABLE_RECORD_INS,
 	ID_CMD_TABLE_RECORD_DEL,
 	ID_CMD_TABLE_RECORD_DEL_ALL,
-	ID_CMD_TABLE_SELECTION_CLEAR,
-	ID_CMD_TABLE_SELECTION_ONLY,
+	ID_CMD_TABLE_SELECTION_SHOW,
+	ID_CMD_TABLE_SELECT_NUMERIC,
+	ID_CMD_TABLE_SELECT_STRING,
 	ID_CMD_TABLE_AUTOSIZE_COLS,
 	ID_CMD_TABLE_AUTOSIZE_ROWS,
-	ID_CMD_TABLE_TO_CLIPBOARD,
 	ID_CMD_TABLE_LAST,
 
+	ID_CMD_SHAPES_FIRST,
+	ID_CMD_SHAPES_OPEN,
+	ID_CMD_SHAPES_SAVE_ATTRIBUTES,
+	ID_CMD_SHAPES_EDIT_SHAPE,
+    ID_CMD_SHAPES_EDIT_SEL_COPY,
+	ID_CMD_SHAPES_EDIT_ADD_SHAPE,
+	ID_CMD_SHAPES_EDIT_ADD_PART,
+	ID_CMD_SHAPES_EDIT_DEL_SHAPE,
+	ID_CMD_SHAPES_EDIT_DEL_PART,
+	ID_CMD_SHAPES_EDIT_DEL_POINT,
+	ID_CMD_SHAPES_EDIT_SPLIT,
+	ID_CMD_SHAPES_EDIT_MERGE,
+	ID_CMD_SHAPES_EDIT_MOVE,
+	ID_CMD_SHAPES_LAST,
+
 	ID_CMD_TIN_FIRST,
-	ID_CMD_TIN_RECENT_FIRST,
-	ID_CMD_TIN_RECENT_LAST			= RECENT_COUNT + ID_CMD_TIN_RECENT_FIRST,
 	ID_CMD_TIN_OPEN,
-	ID_CMD_TIN_SHOW,
 	ID_CMD_TIN_LAST,
 
 	ID_CMD_POINTCLOUD_FIRST,
-	ID_CMD_POINTCLOUD_RECENT_FIRST,
-	ID_CMD_POINTCLOUD_RECENT_LAST	= RECENT_COUNT + ID_CMD_POINTCLOUD_RECENT_FIRST,
 	ID_CMD_POINTCLOUD_OPEN,
-	ID_CMD_POINTCLOUD_SHOW,
-	ID_CMD_POINTCLOUD_RANGE_MINMAX,
-	ID_CMD_POINTCLOUD_RANGE_STDDEV150,
-	ID_CMD_POINTCLOUD_RANGE_STDDEV200,
 	ID_CMD_POINTCLOUD_LAST,
 
 	ID_CMD_MAPS_FIRST,
@@ -308,10 +285,19 @@ enum ID_COMMANDS
 	ID_CMD_MAPS_PROJECT_AREA,
 	ID_CMD_MAPS_LAST,
 
-	ID_CMD_WKSP_LAST,	// End: Workspace Commands
+	ID_CMD_WKSP_LAST, // end workspace commands
 
 	//-----------------------------------------------------
-	ID_CMD_CHILD_FIRST,	// Begin: Child Window Commands
+	ID_CMD_ACTIVE_FIRST, // begin active object's properties commands
+	ID_CMD_ACTIVE_CLIPBOARD_COPY,
+	ID_CMD_ACTIVE_LAST,  // end active object's properties commands
+
+	//-----------------------------------------------------
+	ID_CMD_CHILD_FIRST,	// begin view commands (mdi child windows)
+
+	ID_CMD_VIEW_CLIPBOARD_COPY,
+	ID_CMD_VIEW_CLIPBOARD_PASTE,
+	ID_CMD_VIEW_SAVE,
 
 	ID_CMD_MAP_FIRST,
 	ID_CMD_MAP_CLOSE,
@@ -334,10 +320,11 @@ enum ID_COMMANDS
 	ID_CMD_MAP_ZOOM_FULL,
 	ID_CMD_MAP_ZOOM_BACK,
 	ID_CMD_MAP_ZOOM_FORWARD,
-	ID_CMD_MAP_ZOOM_ACTIVE,
-	ID_CMD_MAP_PAN_ACTIVE,
-	ID_CMD_MAP_ZOOM_SELECTION,
 	ID_CMD_MAP_ZOOM_EXTENT,
+	ID_CMD_MAP_ZOOM_ACTIVE,
+	ID_CMD_MAP_ZOOM_SELECTION,
+	ID_CMD_MAP_PAN_ACTIVE,
+	ID_CMD_MAP_PAN_SELECTION,
 	ID_CMD_MAP_CROSSHAIR,
 	ID_CMD_MAP_LAST,
 
@@ -361,14 +348,14 @@ enum ID_COMMANDS
 	ID_CMD_MAP3D_CENTRAL,
 	ID_CMD_MAP3D_CENTRAL_LESS,
 	ID_CMD_MAP3D_CENTRAL_MORE,
-	ID_CMD_MAP3D_STEREO,
+	ID_CMD_MAP3D_ANAGLYPH,
+	ID_CMD_MAP3D_STEREO_VIEW,
 	ID_CMD_MAP3D_STEREO_LESS,
 	ID_CMD_MAP3D_STEREO_MORE,
 	ID_CMD_MAP3D_INTERPOLATED,
 	ID_CMD_MAP3D_SRC_RES_LESS,
 	ID_CMD_MAP3D_SRC_RES_MORE,
 	ID_CMD_MAP3D_SAVE,
-	ID_CMD_MAP3D_TO_CLIPBOARD,
 	ID_CMD_MAP3D_SEQ_POS_ADD,
 	ID_CMD_MAP3D_SEQ_POS_DEL,
 	ID_CMD_MAP3D_SEQ_POS_DEL_ALL,
@@ -384,14 +371,12 @@ enum ID_COMMANDS
 	ID_CMD_DIAGRAM_SIZE_INC,
 	ID_CMD_DIAGRAM_SIZE_DEC,
 	ID_CMD_DIAGRAM_LEGEND,
-	ID_CMD_DIAGRAM_TO_CLIPBOARD,
 	ID_CMD_DIAGRAM_LAST,
 
 	ID_CMD_SCATTERPLOT_FIRST,
 	ID_CMD_SCATTERPLOT_PARAMETERS,
 	ID_CMD_SCATTERPLOT_UPDATE,
 	ID_CMD_SCATTERPLOT_AS_TABLE,
-	ID_CMD_SCATTERPLOT_TO_CLIPBOARD,
 	ID_CMD_SCATTERPLOT_LAST,
 
 	ID_CMD_HISTOGRAM_FIRST,
@@ -401,7 +386,6 @@ enum ID_COMMANDS
 	ID_CMD_HISTOGRAM_GAUSSIAN,
 	ID_CMD_HISTOGRAM_SET_MINMAX,
 	ID_CMD_HISTOGRAM_AS_TABLE,
-	ID_CMD_HISTOGRAM_TO_CLIPBOARD,
 	ID_CMD_HISTOGRAM_LAST,
 
 	ID_CMD_LAYOUT_FIRST,
@@ -412,7 +396,6 @@ enum ID_COMMANDS
 	ID_CMD_LAYOUT_PRINT_SETUP,
 	ID_CMD_LAYOUT_PRINT_PREVIEW,
 	ID_CMD_LAYOUT_PRINT,
-	ID_CMD_LAYOUT_TO_CLIPBOARD,
 	ID_CMD_LAYOUT_EXPORT,
 	ID_CMD_LAYOUT_PROPERTIES,
 	ID_CMD_LAYOUT_ZOOM_IN,
@@ -426,7 +409,6 @@ enum ID_COMMANDS
 	ID_CMD_LAYOUT_ITEM_LABEL,
 	ID_CMD_LAYOUT_ITEM_TEXT,
 	ID_CMD_LAYOUT_ITEM_IMAGE,
-	ID_CMD_LAYOUT_ITEM_PASTE,
 	ID_CMD_LAYOUT_ITEM_PROPERTIES,
 	ID_CMD_LAYOUT_ITEM_HIDE,
 	ID_CMD_LAYOUT_ITEM_DELETE,
@@ -438,21 +420,30 @@ enum ID_COMMANDS
 	ID_CMD_LAYOUT_IMAGE_RESTORE,
 	ID_CMD_LAYOUT_LAST,
 
-	ID_CMD_CHILD_LAST,	// End: Child Window Commands
+	ID_CMD_CHILD_LAST, // end view commands (mdi child windows)
 
 	//-----------------------------------------------------
-	ID_CMD_TOOL_MENU_FIRST,	// Begin: Tool Commands
-	ID_CMD_TOOL_MENU_RECENT_FIRST,
-	ID_CMD_TOOL_MENU_RECENT_LAST	= RECENT_COUNT + ID_CMD_TOOL_MENU_RECENT_FIRST,
-	ID_CMD_TOOL_MENU_START,
-	ID_CMD_TOOL_MENU_LAST			= ID_CMD_TOOL_MENU_START + 2048	// End: Tool Commands
+	ID_CMD_TOOL_FIRST,  // begin tool commands
+	ID_CMD_TOOL_OPEN,
+	ID_CMD_TOOL_RELOAD,
+	ID_CMD_TOOL_SEARCH,
+	ID_CMD_TOOL_SAVE_SCRIPT,
+	ID_CMD_TOOL_SAVE_DOCS,
+	ID_CMD_TOOL_SAVE_TO_CLIPBOARD,
+	ID_CMD_TOOL_CHAIN_RELOAD,
+	ID_CMD_TOOL_CHAIN_EDIT,
+	ID_CMD_TOOL_RECENT_FIRST,
+	ID_CMD_TOOL_RECENT_LAST = ID_CMD_TOOL_RECENT_FIRST + MAX_COUNT_RECENT_TOOLS,
+	ID_CMD_TOOL_MENU_FIRST,
+	ID_CMD_TOOL_MENU_LAST = ID_CMD_TOOL_MENU_FIRST + MAX_COUNT_TOOLS,
+	ID_CMD_TOOL_LAST // end tool commands
 };
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -470,9 +461,9 @@ void					CMD_ToolBar_Add_Separator	(class wxToolBarBase *pToolBar);
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
