@@ -135,6 +135,16 @@ bool CSAGA::OnInit(void)
 
 	_Init_Config();
 
+	//-----------------------------------------------------
+#if _SAGA_MSW && wxCHECK_VERSION(3, 3, 0)
+	long Mode; if( !CONFIG_Read("/TOOLS", "DISPLAY_MODE", Mode) ) { Mode = 1; }
+
+	if( Mode != 1 )
+	{
+		MSWEnableDarkMode(Mode == 0 ? wxApp::DarkMode_Auto : wxApp::DarkMode_Always);
+	}
+#endif
+
 	//-----------------------------------------------------
 	long Frequency;
 
