@@ -76,14 +76,14 @@
 #include "info.h"
 #include "data_source.h"
 #include "active.h"
-#include "wksp.h"
 
+#include "wksp.h"
+#include "wksp_base_control.h"
 #include "wksp_tool_manager.h"
 #include "wksp_tool.h"
-
+#include "wksp_data_control.h"
 #include "wksp_data_manager.h"
 #include "wksp_data_menu_files.h"
-
 #include "wksp_map_manager.h"
 
 #include "view_map.h"
@@ -214,6 +214,8 @@ BEGIN_EVENT_TABLE(CSAGA_Frame, MDI_ParentFrame)
 	EVT_UPDATE_UI(ID_CMD_FRAME_SPLIT_ALL_HORZ  , CSAGA_Frame::On_Frame_Split_UI)
 	EVT_MENU     (ID_CMD_FRAME_SPLIT_ALL_VERT  , CSAGA_Frame::On_Frame_Split)
 	EVT_UPDATE_UI(ID_CMD_FRAME_SPLIT_ALL_VERT  , CSAGA_Frame::On_Frame_Split_UI)
+	EVT_MENU     (ID_CMD_FRAME_FIND            , CSAGA_Frame::On_Frame_Find)
+	EVT_UPDATE_UI(ID_CMD_FRAME_FIND            , CSAGA_Frame::On_Frame_Find_UI)
 	EVT_MENU     (ID_CMD_FRAME_NEXT            , CSAGA_Frame::On_Frame_Next)
 	EVT_UPDATE_UI(ID_CMD_FRAME_NEXT            , CSAGA_Frame::On_Frame_Next_UI)
 	EVT_MENU     (ID_CMD_FRAME_PREVIOUS        , CSAGA_Frame::On_Frame_Previous)
@@ -234,8 +236,10 @@ BEGIN_EVENT_TABLE(CSAGA_Frame, MDI_ParentFrame)
 
 	EVT_MENU_RANGE		(ID_CMD_WKSP_FIRST     , ID_CMD_WKSP_LAST     , CSAGA_Frame::On_Command_Workspace)
 	EVT_UPDATE_UI_RANGE	(ID_CMD_WKSP_FIRST     , ID_CMD_WKSP_LAST     , CSAGA_Frame::On_Command_Workspace_UI)
-	EVT_MENU_RANGE		(ID_CMD_TOOL_MENU_FIRST, ID_CMD_TOOL_MENU_LAST, CSAGA_Frame::On_Command_Tool)
-	EVT_UPDATE_UI_RANGE	(ID_CMD_TOOL_MENU_FIRST, ID_CMD_TOOL_MENU_LAST, CSAGA_Frame::On_Command_Tool_UI)
+	EVT_MENU_RANGE		(ID_CMD_DATA_FIRST     , ID_CMD_DATA_LAST     , CSAGA_Frame::On_Command_Data)
+	EVT_UPDATE_UI_RANGE	(ID_CMD_DATA_FIRST     , ID_CMD_DATA_LAST     , CSAGA_Frame::On_Command_Data_UI)
+	EVT_MENU_RANGE		(ID_CMD_TOOL_FIRST     , ID_CMD_TOOL_LAST     , CSAGA_Frame::On_Command_Tool)
+	EVT_UPDATE_UI_RANGE	(ID_CMD_TOOL_FIRST     , ID_CMD_TOOL_LAST     , CSAGA_Frame::On_Command_Tool_UI)
 
 	EVT_MENU_RANGE		(ID_CMD_CHILD_FIRST    , ID_CMD_CHILD_LAST    , CSAGA_Frame::On_Command_Child)
 	EVT_UPDATE_UI_RANGE	(ID_CMD_MAP_FIRST      , ID_CMD_MAP_LAST      , CSAGA_Frame::On_Command_Child_UI)
@@ -263,8 +267,6 @@ CSAGA_Frame::CSAGA_Frame(void)
 {
 	g_pSAGA_Frame  = this;
 
-	m_nChildren    = 0;
-
 	m_nTopWindows  = 0;
 	m_pTopWindows  = NULL;
 
@@ -637,7 +639,7 @@ void CSAGA_Frame::On_Frame_Split_UI(wxUpdateUIEvent &event)
 void CSAGA_Frame::Tile(wxOrientation orient)
 {
 #ifndef MDI_TABBED
-	if( m_nChildren == 1 && GetActiveChild() )
+	if( m_Children.Get_Size() == 1 && GetActiveChild() )
 	{
 		GetActiveChild()->Maximize();
 	}
@@ -694,6 +696,29 @@ void CSAGA_Frame::On_Frame_ArrangeIcons_UI(wxUpdateUIEvent &event)
 	event.Enable(GetActiveChild() != NULL);
 }
 
+//---------------------------------------------------------
+void CSAGA_Frame::On_Frame_Find(wxCommandEvent &WXUNUSED(event))
+{
+	wxArrayString Children;
+
+	for(sLong i=0; i<m_Children.Get_Size(); i++)
+	{
+		Children.Add(((CVIEW_Base *)m_Children[i])->GetTitle());
+	}
+
+	wxSingleChoiceDialog dlg(this, _TL("Goto Window"), _TL("Find"), Children);
+
+	if( dlg.ShowModal() == wxID_OK )
+	{
+		((CVIEW_Base *)m_Children[dlg.GetSelection()])->Activate();
+	}
+}
+
+void CSAGA_Frame::On_Frame_Find_UI(wxUpdateUIEvent &event)
+{
+	event.Enable(m_Children.Get_Size() > 1);
+}
+
 //---------------------------------------------------------
 void CSAGA_Frame::On_Frame_Next(wxCommandEvent &WXUNUSED(event))
 {
@@ -833,15 +858,26 @@ void CSAGA_Frame::On_Command_Workspace_UI(wxUpdateUIEvent &event)
 	m_pWKSP->On_Command_UI(event);
 }
 
+//---------------------------------------------------------
+void CSAGA_Frame::On_Command_Data(wxCommandEvent &event)
+{
+	m_pWKSP->Get_Data ()->On_Command(event);
+}
+
+void CSAGA_Frame::On_Command_Data_UI(wxUpdateUIEvent &event)
+{
+	m_pWKSP->Get_Data ()->On_Command_UI(event);
+}
+
 //---------------------------------------------------------
 void CSAGA_Frame::On_Command_Tool(wxCommandEvent &event)
 {
-	m_pWKSP->On_Command_Tool(event);
+	m_pWKSP->Get_Tools()->On_Command(event);
 }
 
 void CSAGA_Frame::On_Command_Tool_UI(wxUpdateUIEvent &event)
 {
-	m_pWKSP->On_Command_UI_Tool(event);
+	m_pWKSP->Get_Tools()->On_Command_UI(event);
 }
 
 //---------------------------------------------------------
@@ -1070,11 +1106,22 @@ void CSAGA_Frame::Close_Children(void)
 		delete(GetActiveChild());
 	}
 }
+//---------------------------------------------------------
+bool CSAGA_Frame::On_Child_Created(CVIEW_Base *pChild)
+{
+	return( m_Children.Add(pChild) );
+}
+
+//---------------------------------------------------------
+bool CSAGA_Frame::On_Child_Deleted(CVIEW_Base *pChild)
+{
+	return( m_Children.Del(pChild) == 1 );
+}
 
 //---------------------------------------------------------
 void CSAGA_Frame::On_Child_Activates(int View_ID)
 {
-	if( View_ID < 0 && m_nChildren > 0 ) // child view closes, but it's not the last one
+	if( View_ID < 0 && m_Children.Get_Size() > 0 ) // child view closes, but it's not the last one
 	{
 		return; // nothing to do, another child will be activated next!
 	}
@@ -1188,6 +1235,7 @@ wxMenuBar * CSAGA_Frame::_Create_MenuBar(void)
 	pMenu_Window->AppendSeparator();
 	CMD_Menu_Add_Item(pMenu_Window, false, ID_CMD_FRAME_NEXT);
 	CMD_Menu_Add_Item(pMenu_Window, false, ID_CMD_FRAME_PREVIOUS);
+	CMD_Menu_Add_Item(pMenu_Window, false, ID_CMD_FRAME_FIND);
 	CMD_Menu_Add_Item(pMenu_Window, false, ID_CMD_FRAME_CLOSE);
 	CMD_Menu_Add_Item(pMenu_Window, false, ID_CMD_FRAME_CLOSE_ALL);
 
