@@ -187,10 +187,10 @@ BEGIN_EVENT_TABLE(CVIEW_ScatterPlot, CVIEW_Base)
 	EVT_PAINT(CVIEW_ScatterPlot::On_Paint)
 	EVT_SIZE (CVIEW_ScatterPlot::On_Size)
 
-	EVT_MENU (ID_CMD_SCATTERPLOT_PARAMETERS  , CVIEW_ScatterPlot::On_Parameters)
-	EVT_MENU (ID_CMD_SCATTERPLOT_UPDATE      , CVIEW_ScatterPlot::On_Update)
-	EVT_MENU (ID_CMD_SCATTERPLOT_AS_TABLE    , CVIEW_ScatterPlot::On_AsTable)
-	EVT_MENU (ID_CMD_SCATTERPLOT_TO_CLIPBOARD, CVIEW_ScatterPlot::On_ToClipboard)
+	EVT_MENU (ID_CMD_SCATTERPLOT_PARAMETERS, CVIEW_ScatterPlot::On_Parameters)
+	EVT_MENU (ID_CMD_SCATTERPLOT_UPDATE    , CVIEW_ScatterPlot::On_Update)
+	EVT_MENU (ID_CMD_SCATTERPLOT_AS_TABLE  , CVIEW_ScatterPlot::On_AsTable)
+	EVT_MENU (ID_CMD_VIEW_CLIPBOARD_COPY   , CVIEW_ScatterPlot::On_ToClipboard)
 END_EVENT_TABLE()
 
 
@@ -202,7 +202,7 @@ END_EVENT_TABLE()
 
 //---------------------------------------------------------
 CVIEW_ScatterPlot::CVIEW_ScatterPlot(CWKSP_Data_Item *pItem)
-	: CVIEW_Base(pItem, ID_VIEW_SCATTERPLOT, wxString::Format("%s: %s", _TL("Scatterplot"), pItem->Get_Object()->Get_Name()), ID_IMG_WND_SCATTERPLOT, false)
+	: CVIEW_Base(pItem, ID_VIEW_SCATTERPLOT, wxString::Format("%s | %s", _TL("Scatterplot"), pItem->Get_Object()->Get_Name()), ID_IMG_WND_SCATTERPLOT, false)
 {
 	m_pItem  = pItem;
 
@@ -263,7 +263,7 @@ wxMenu * CVIEW_ScatterPlot::_Create_Menu(void)
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SCATTERPLOT_PARAMETERS);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SCATTERPLOT_UPDATE);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SCATTERPLOT_AS_TABLE);
-	CMD_Menu_Add_Item(pMenu, false, ID_CMD_SCATTERPLOT_TO_CLIPBOARD);
+	CMD_Menu_Add_Item(pMenu, false, ID_CMD_VIEW_CLIPBOARD_COPY);
 
 	return( pMenu );
 }
@@ -276,7 +276,7 @@ wxToolBarBase * CVIEW_ScatterPlot::_Create_ToolBar(void)
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_SCATTERPLOT_PARAMETERS);
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_SCATTERPLOT_UPDATE);
 	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_SCATTERPLOT_AS_TABLE);
-	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_SCATTERPLOT_TO_CLIPBOARD);
+	CMD_ToolBar_Add_Item(pToolBar, false, ID_CMD_VIEW_CLIPBOARD_COPY);
 
 	CMD_ToolBar_Add(pToolBar, _TL("Scatterplot"));
 
@@ -295,9 +295,6 @@ wxToolBarBase * CVIEW_ScatterPlot::_Create_ToolBar(void)
 //---------------------------------------------------------
 void CVIEW_ScatterPlot::_On_Construction(void)
 {
-	SYS_Set_Color_BG_Window(this);
-
-	//-----------------------------------------------------
 	double Range[2] = { 0., 0. };
 
 	if( m_pGrid )
@@ -372,7 +369,7 @@ void CVIEW_ScatterPlot::_On_Construction(void)
 //	m_Parameters.Add_Parameters("", "OPTIONS", _TL("Options"), _TL(""));
 
 	m_Options.Add_Int("",
-		"SAMPLES_MAX", _TL("Maximimum Number of Samples"),
+		"SAMPLES_MAX", _TL("Maximum Number of Samples"),
 		_TL(""),
 		100000, 0, true
 	);
@@ -453,15 +450,10 @@ void CVIEW_ScatterPlot::_On_Construction(void)
 		50, 10, true
 	);
 
-	CSG_Colors Colors(7, SG_COLORS_RAINBOW);
-
-	Colors.Set_Color(0, 255, 255, 255);
-	Colors.Set_Count(100);
-
 	m_Options.Add_Colors("DISPLAY",
 		"DENSITY_PAL", _TL("Colors"),
 		_TL(""),
-		&Colors
+		SG_COLORS_RAINBOW, 7
 	);
 
 	m_Options.Add_Bool("DISPLAY",
@@ -485,6 +477,12 @@ void CVIEW_ScatterPlot::_On_Construction(void)
 		0, 100, 0., true
 	);
 
+	m_Options.Add_Choice("",
+		"COLOR_MODE"  , _TL("Color Mode"),
+		_TL(""),
+		CSG_String::Format("%s|%s|%s", _TL("system"), _TL("light"), _TL("dark"))
+	);
+
 	//-----------------------------------------------------
 	m_Parameters.Set_Callback_On_Parameter_Changed(&Scatter_Plot_On_Parameter_Changed);
 }
@@ -499,6 +497,8 @@ void CVIEW_ScatterPlot::On_Parameters(wxCommandEvent &event)
 {
 	if( DLG_Parameters(&m_Parameters) )
 	{
+		SetBackgroundColour(SYS_Get_Color_Background(m_Options("COLOR_MODE")->asInt()));
+
 		_Update_Data();
 	}
 }
@@ -531,7 +531,7 @@ void CVIEW_ScatterPlot::On_AsTable(wxCommandEvent &event)
 			pRecord->Set_Value(2, m_Trend.Get_Data_Y(i));
 		}
 
-		PROGRESSBAR_Set_Position(0);
+		PROGRESSBAR_Set_Ready();
 
 		g_pData->Add(pTable);
 	}
@@ -543,7 +543,7 @@ void CVIEW_ScatterPlot::On_ToClipboard(wxCommandEvent &event)
 	wxBitmap BMP(GetSize()); wxMemoryDC dc;
 	
 	dc.SelectObject(BMP);
-	dc.SetBackground(*wxWHITE_BRUSH);
+	dc.SetBackground(SYS_Get_Color_Background(m_Options("COLOR_MODE")->asInt()));
 	dc.Clear();
 
 	_Draw(dc, wxRect(BMP.GetSize()));
@@ -586,6 +586,8 @@ void CVIEW_ScatterPlot::On_Paint(wxPaintEvent &event)
 {
 	wxPaintDC dc(this); wxRect r(wxPoint(0, 0), GetClientSize());
 
+	dc.SetBackground(SYS_Get_Color_Background(m_Options("COLOR_MODE")->asInt())); dc.Clear();
+
 	Draw_Edge(dc, EDGE_STYLE_SUNKEN, r);
 
 	_Draw(dc, r);
@@ -594,6 +596,9 @@ void CVIEW_ScatterPlot::On_Paint(wxPaintEvent &event)
 //---------------------------------------------------------
 void CVIEW_ScatterPlot::_Draw(wxDC &dc, wxRect r)
 {
+	dc.SetPen           (SYS_Get_Color_Foreground(m_Options("COLOR_MODE")->asInt()));
+	dc.SetTextForeground(SYS_Get_Color_Foreground(m_Options("COLOR_MODE")->asInt()));
+
 	r = _Draw_Get_rDiagram(r);
 
 	if( m_Trend.Get_Data_Count() > 1 )
@@ -624,6 +629,27 @@ void CVIEW_ScatterPlot::_Draw(wxDC &dc, wxRect r)
 	}
 }
 
+//---------------------------------------------------------
+CSG_Colors CVIEW_ScatterPlot::_Get_Colors(int nColors)
+{
+	CSG_Colors Colors, *pColors = m_Options("DENSITY_PAL")->asColors();
+
+	wxColor Background(SYS_Get_Color_Background(m_Options("COLOR_MODE")->asInt()));
+
+	Colors.Set_Count(pColors->Get_Count() + 1);
+
+	Colors.Set_Color(0, Background.GetRed(), Background.GetGreen(), Background.GetBlue());
+
+	for(int i=0; i<pColors->Get_Count(); i++)
+	{
+		Colors[i + 1] = pColors->Get_Color(i);
+	}
+
+	Colors.Set_Count(nColors);
+
+	return( Colors );
+}
+
 //---------------------------------------------------------
 wxRect CVIEW_ScatterPlot::_Draw_Get_rDiagram(wxRect r)
 {
@@ -679,9 +705,7 @@ void CVIEW_ScatterPlot::_Draw_Regression(wxDC &dc, wxRect r)
 //---------------------------------------------------------
 void CVIEW_ScatterPlot::_Draw_Legend(wxDC &dc, wxRect r)
 {
-	CSG_Colors Colors(*m_Options("DENSITY_PAL")->asColors());
-
-	Colors.Set_Count(r.GetHeight());
+	CSG_Colors Colors(_Get_Colors(r.GetHeight()));
 
 	for(int i=0, y=r.GetBottom(); i<Colors.Get_Count(); i++, y--)
 	{
@@ -702,7 +726,7 @@ void CVIEW_ScatterPlot::_Draw_Legend(wxDC &dc, wxRect r)
 //---------------------------------------------------------
 void CVIEW_ScatterPlot::_Draw_Image(wxDC &dc, wxRect r)
 {
-	CSG_Colors *pColors = m_Options("DENSITY_PAL")->asColors();
+	CSG_Colors Colors(_Get_Colors());
 
 	wxImage	Image(r.GetWidth(), r.GetHeight());
 
@@ -710,7 +734,7 @@ void CVIEW_ScatterPlot::_Draw_Image(wxDC &dc, wxRect r)
 	int Max = m_Options("Z_ADJUST")->asInt() ? m_Options("Z_RANGE.MAX")->asDouble() : (int)m_Count.Get_Max();
 	int Range = Max - Min;
 
-	double dCount = (pColors->Get_Count() - 2.) / log(1. + Range);
+	double dCount = (Colors.Get_Count() - 2.) / log(1. + Range);
 
 	double dx = (m_Count.Get_NX() - 1.) / (double)r.GetWidth ();
 	double dy = (m_Count.Get_NY() - 1.) / (double)r.GetHeight();
@@ -725,7 +749,7 @@ void CVIEW_ScatterPlot::_Draw_Image(wxDC &dc, wxRect r)
 		{
 			Count = !m_Count.Get_Value(ix, iy, Count) || Count < Min ? 0. : Count - Min; if( Count > Range ) { Count = Range; }
 			int i = (int)(log(1. + Count) * dCount);
-			Image.SetRGB(x, y, pColors->Get_Red(i), pColors->Get_Green(i), pColors->Get_Blue(i));
+			Image.SetRGB(x, y, Colors.Get_Red(i), Colors.Get_Green(i), Colors.Get_Blue(i));
 		}
 	}
 
@@ -813,7 +837,7 @@ bool CVIEW_ScatterPlot::_Update_Data(void)
 		bResult = _Initialize_Table();
 	}
 
-	PROCESS_Set_Okay(true);
+	PROCESS_Set_Okay();
 
 	//-----------------------------------------------------
 	if( bResult )
