@@ -222,17 +222,36 @@ bool CWKSP_Layer_Classify::Initialise(CWKSP_Layer *pLayer, CSG_Table *pLUT, CSG_
 	//-----------------------------------------------------
 	if( m_pLUT && m_pLUT->Get_Count() == 0 )
 	{
-		CSG_Table_Record	*pRecord;
+		//-------------------------------------------------
+		#define nColours 10
+
+		static int Colours[nColours]	=
+		{
+			SG_COLOR_BLUE,
+			SG_COLOR_GREEN,
+			SG_COLOR_RED,
+			SG_COLOR_YELLOW_DARK,
+			SG_COLOR_BLUE_DARK,
+			SG_COLOR_GREEN_DARK,
+			SG_COLOR_RED_DARK,
+			SG_COLOR_BLUE_GREEN,
+			SG_COLOR_PURPLE,
+			SG_COLOR_PINK
+		};
+
+		int Colour = (int)CSG_Random::Get_Uniform(0, nColours); 
+
+		CSG_Table_Record *pRecord;
 
 		pRecord	= m_pLUT->Add_Record();
-		pRecord->Set_Value(LUT_COLOR		, SG_GET_RGB(1, 1, 1));
+		pRecord->Set_Value(LUT_COLOR		, Colours[Colour]); Colour = ++Colour % nColours;
 		pRecord->Set_Value(LUT_TITLE		, _TL("Class 1"));
 		pRecord->Set_Value(LUT_DESCRIPTION	, _TL("First Class"));
 		pRecord->Set_Value(LUT_MIN			, 0.0);
 		pRecord->Set_Value(LUT_MAX			, 1.0);
 
 		pRecord	= m_pLUT->Add_Record();
-		pRecord->Set_Value(LUT_COLOR		, SG_GET_RGB(255, 0, 0));
+		pRecord->Set_Value(LUT_COLOR		, Colours[Colour]);
 		pRecord->Set_Value(LUT_TITLE		, _TL("Class 2"));
 		pRecord->Set_Value(LUT_DESCRIPTION	, _TL("Second Class"));
 		pRecord->Set_Value(LUT_MIN			, 1.0);
@@ -260,7 +279,7 @@ double CWKSP_Layer_Classify::Get_Class_Value_Minimum(int iClass)
 	switch( m_Mode )
 	{
 	case CLASSIFY_LUT:
-		if( iClass >= 0 && iClass < m_pLUT->Get_Record_Count() )
+		if( iClass >= 0 && iClass < m_pLUT->Get_Count() )
 		{
 			return( m_pLUT->Get_Record(iClass)->asDouble(LUT_MIN) );
 		}
@@ -287,7 +306,7 @@ double CWKSP_Layer_Classify::Get_Class_Value_Maximum(int iClass)
 	switch( m_Mode )
 	{
 	case CLASSIFY_LUT:
-		if( iClass >= 0 && iClass < m_pLUT->Get_Record_Count() )
+		if( iClass >= 0 && iClass < m_pLUT->Get_Count() )
 		{
 			return( m_pLUT->Get_Record(iClass)->asDouble(LUT_MAX) );
 		}
@@ -314,7 +333,7 @@ double CWKSP_Layer_Classify::Get_Class_Value_Center(int iClass)
 	switch( m_Mode )
 	{
 	case CLASSIFY_LUT:
-		if( iClass >= 0 && iClass < m_pLUT->Get_Record_Count() )
+		if( iClass >= 0 && iClass < m_pLUT->Get_Count() )
 		{
 			return( 0.5 * (m_pLUT->Get_Record(iClass)->asDouble(LUT_MIN) + m_pLUT->Get_Record(iClass)->asDouble(LUT_MAX)) );
 		}
@@ -344,7 +363,7 @@ wxString CWKSP_Layer_Classify::Get_Class_Name(int iClass)
 	switch( m_Mode )
 	{
 	case CLASSIFY_LUT:
-		if( iClass >= 0 && iClass < m_pLUT->Get_Record_Count() )
+		if( iClass >= 0 && iClass < m_pLUT->Get_Count() )
 		{
 			s.Printf(SG_T("%s"), m_pLUT->Get_Record(iClass)->asString(LUT_TITLE));
 		}
@@ -469,14 +488,14 @@ int CWKSP_Layer_Classify::_LUT_Get_Class(double Value)	const
 {
 	int		a, b, i, c;
 
-	if( m_pLUT->Get_Record_Count() > 0 )
+	if( m_pLUT->Get_Count() > 0 )
 	{
 		if( m_pLUT->Get_Index_Field(0) != LUT_MIN || m_pLUT->Get_Index_Order(0) != TABLE_INDEX_Ascending )
 		{
 			m_pLUT->Set_Index(LUT_MIN, TABLE_INDEX_Ascending);
 		}
 
-		for(a=0, b=m_pLUT->Get_Record_Count()-1; a < b; )
+		for(a=0, b=m_pLUT->Get_Count()-1; a < b; )
 		{
 			i	= a + (b - a) / 2;
 			c	= _LUT_Cmp_Class(Value, i);
@@ -534,14 +553,14 @@ int CWKSP_Layer_Classify::_LUT_Get_Class(const CSG_String &Value)	const
 {
 	int		a, b, i, c;
 
-	if( m_pLUT->Get_Record_Count() > 0 )
+	if( m_pLUT->Get_Count() > 0 )
 	{
 		if( m_pLUT->Get_Index_Field(0) != LUT_MIN || m_pLUT->Get_Index_Order(0) != TABLE_INDEX_Ascending )
 		{
 			m_pLUT->Set_Index(LUT_MIN, TABLE_INDEX_Ascending);
 		}
 
-		for(a=0, b=m_pLUT->Get_Record_Count()-1; a < b; )
+		for(a=0, b=m_pLUT->Get_Count()-1; a < b; )
 		{
 			i	= a + (b - a) / 2;
 			c	= _LUT_Cmp_Class(Value, i);
@@ -713,7 +732,7 @@ bool CWKSP_Layer_Classify::_Histogram_Update(CSG_Grid *pGrid)
 			}
 		}
 
-		if( m_Histogram.Update() && m_Histogram.Get_Element_Count() < pGrid->Get_Max_Samples() )	// any no-data cells ?
+		if( m_Histogram.Update() && m_Histogram.Get_Element_Count() < (size_t)pGrid->Get_Max_Samples() )	// any no-data cells ?
 		{
 			d	*= (double)m_Histogram.Get_Element_Count() / (double)pGrid->Get_Max_Samples();
 		}
@@ -753,7 +772,7 @@ bool CWKSP_Layer_Classify::_Histogram_Update(CSG_Grids *pGrids)
 			}
 		}
 
-		if( m_Histogram.Update() && m_Histogram.Get_Element_Count() < pGrids->Get_Max_Samples() )	// any no-data cells ?
+		if( m_Histogram.Update() && m_Histogram.Get_Element_Count() < (size_t)pGrids->Get_Max_Samples() )	// any no-data cells ?
 		{
 			d	*= (double)m_Histogram.Get_Element_Count() / (double)pGrids->Get_Max_Samples();
 		}
@@ -817,7 +836,7 @@ bool CWKSP_Layer_Classify::_Histogram_Update(CSG_Shapes *pShapes, int Attribute,
 			}
 		}
 
-		if( m_Histogram.Update() && m_Histogram.Get_Element_Count() < pShapes->Get_Max_Samples() )	// any no-data cells ?
+		if( m_Histogram.Update() && m_Histogram.Get_Element_Count() < (size_t)pShapes->Get_Max_Samples() )	// any no-data cells ?
 		{
 			d	*= (double)m_Histogram.Get_Element_Count() / (double)pShapes->Get_Max_Samples();
 		}
@@ -827,7 +846,7 @@ bool CWKSP_Layer_Classify::_Histogram_Update(CSG_Shapes *pShapes, int Attribute,
 		return( true );
 	}
 
-	for(int i=0; i<pShapes->Get_Count() && PROGRESSBAR_Set_Position(i, pShapes->Get_Count()); i++)
+	for(sLong i=0; i<pShapes->Get_Count() && PROGRESSBAR_Set_Position(i, pShapes->Get_Count()); i++)
 	{
 		CSG_Shape	*pShape	= pShapes->Get_Shape(i);
 
