@@ -82,29 +82,29 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#define LEGEND_SPACE	10
+#define LEGEND_SPACE 10
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CSG_Rect	CWKSP_Map_Extents::m_Dummy	= CSG_Rect(0, 0, 1, 1);
+CSG_Rect CWKSP_Map_Extents::m_Dummy = CSG_Rect(0, 0, 1, 1);
 
 //---------------------------------------------------------
 CWKSP_Map_Extents::CWKSP_Map_Extents(void)
 {
-	m_iExtent	= -1;
-	m_nExtents	= 0;
+	m_iExtent  = -1;
+	m_nExtents =  0;
 }
 
 //---------------------------------------------------------
@@ -173,9 +173,9 @@ bool CWKSP_Map_Extents::Add_Extent(const CSG_Rect &Extent, bool bReset)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -206,7 +206,7 @@ CWKSP_Map::~CWKSP_Map(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -277,7 +277,7 @@ wxMenu * CWKSP_Map::Get_Menu(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -383,7 +383,7 @@ bool CWKSP_Map::On_Command_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -531,10 +531,17 @@ void CWKSP_Map::On_Create_Parameters(void)
 		), 1
 	);
 
-	m_Parameters.Add_Bool("SCALE_SHOW",
+	CSG_String Units(CSG_String::Format("%s|%s", _TL("do not show"), _TL("automatically")));
+
+	for(int i=0; i<(int)ESG_Projection_Unit::Undefined; i++)
+	{
+		Units += "|" + CSG_Projections::Get_Unit_Name((ESG_Projection_Unit)i);
+	}
+
+	m_Parameters.Add_Choice("SCALE_SHOW",
 		"SCALE_UNIT"    , _TL("Unit"),
 		_TL(""),
-		true
+		Units, 1
 	);
 
 	m_Parameters.Add_Double("SCALE_SHOW",
@@ -642,7 +649,7 @@ void CWKSP_Map::Parameters_Changed(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -796,7 +803,7 @@ bool CWKSP_Map::Serialize(CSG_MetaData &Root, const wxString &ProjectDir, bool b
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1069,7 +1076,7 @@ CWKSP_Base_Item * CWKSP_Map::Add_Copy(CWKSP_Base_Item *pItem)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1267,7 +1274,7 @@ bool CWKSP_Map::Set_Extent(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1342,7 +1349,7 @@ void CWKSP_Map::Set_ScaleBar(bool bOn)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1380,7 +1387,7 @@ void CWKSP_Map::Set_CrossHair_Off(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1435,7 +1442,7 @@ void CWKSP_Map::Set_Projection(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1546,7 +1553,7 @@ void CWKSP_Map::View_Layout_Toggle(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -1586,7 +1593,7 @@ CSG_Point CWKSP_Map::Get_World(wxRect rClient, wxPoint Point)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2112,7 +2119,7 @@ void CWKSP_Map::_Img_Save(wxString file, int type)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2151,7 +2158,7 @@ bool CWKSP_Map::_Set_Thumbnail(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2162,7 +2169,7 @@ wxColour CWKSP_Map::Get_Background(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2229,9 +2236,12 @@ void CWKSP_Map::Draw_Map(CSG_Map_DC &dc, int Flags)
 	}
 
 	//-----------------------------------------------------
-	Draw_Extent     (dc);
-	Draw_ScaleBar   (dc);
-	Draw_North_Arrow(dc);
+	if( (Flags & LAYER_DRAW_FLAG_THUMBNAIL) == 0 )
+	{
+		Draw_Extent     (dc);
+		Draw_ScaleBar   (dc);
+		Draw_North_Arrow(dc);
+	}
 }
 
 //---------------------------------------------------------
@@ -2240,37 +2250,39 @@ void CWKSP_Map::Draw_Frame(wxDC &dc, wxRect rMap, int Width)
 	Draw_Frame(dc, Get_World(rMap), rMap, Width, is_ScaleBar(true));
 }
 
-void CWKSP_Map::Draw_Frame(wxDC &dc, const CSG_Rect &rWorld, wxRect rMap, int Width, bool bScaleBar)
+void CWKSP_Map::Draw_Frame(wxDC &dc, const CSG_Rect &rWorld, wxRect rMap, int Width, bool bScaleBar, bool bUseDCFont)
 {
 	Draw_Edge(dc, EDGE_STYLE_SIMPLE, rMap.GetLeft(), rMap.GetTop(), rMap.GetRight(), rMap.GetBottom());
 
-	wxRect	rFrame(rMap);	rFrame.Inflate(Width);
+	wxRect rFrame(rMap); rFrame.Inflate(Width);
 
 	Draw_Scale(dc, wxRect(rMap  .GetLeft(), rFrame.GetTop(), rMap.GetWidth (), Width),
-		rWorld.Get_XMin(), rWorld.Get_XMax(),  true,  true, false
+		rWorld.Get_XMin(), rWorld.Get_XMax(),  true,  true, false, "", bUseDCFont
 	);
 
 	Draw_Scale(dc, wxRect(rFrame.GetLeft(), rMap  .GetTop(), Width, rMap.GetHeight()),
-		rWorld.Get_YMin(), rWorld.Get_YMax(), false, false, false
+		rWorld.Get_YMin(), rWorld.Get_YMax(), false, false, false, "", bUseDCFont
 	);
 
 	if( bScaleBar == false )
 	{
 		Draw_Scale(dc, wxRect(rMap.GetLeft (), rMap.GetBottom(), rMap.GetWidth (), Width),
-			rWorld.Get_XMin(), rWorld.Get_XMax(),  true,  true, true
+			rWorld.Get_XMin(), rWorld.Get_XMax(),  true,  true, true, "", bUseDCFont
 		);
 
 		Draw_Scale(dc, wxRect(rMap.GetRight(), rMap.GetTop   (), Width, rMap.GetHeight()),
-			rWorld.Get_YMin(), rWorld.Get_YMax(), false, false, true
+			rWorld.Get_YMin(), rWorld.Get_YMax(), false, false, true, "", bUseDCFont
 		);
 	}
 	else
 	{
 		Draw_Scale(dc, wxRect(rMap.GetLeft (), rMap.GetBottom(), rMap.GetWidth (), Width),
-			0., rWorld.Get_XRange(),  true,  true, true);
+			0., rWorld.Get_XRange(),  true,  true, true, "", bUseDCFont
+		);
 
 		Draw_Scale(dc, wxRect(rMap.GetRight(), rMap.GetTop   (), Width, rMap.GetHeight()),
-			0., rWorld.Get_YRange(), false, false, true);
+			0., rWorld.Get_YRange(), false, false, true, "", bUseDCFont
+		);
 	}
 
 	Draw_Edge(dc, EDGE_STYLE_SIMPLE, rFrame.GetLeft(), rFrame.GetTop(), rFrame.GetRight(), rFrame.GetBottom());
@@ -2396,7 +2408,7 @@ bool CWKSP_Map::Draw_ScaleBar(CSG_Map_DC &dc)
 		return( true );
 	}
 
-	double dWidth = 0.01 * m_Parameters("SCALE_WIDTH")->asDouble();
+	double Width = 0.01 * m_Parameters("SCALE_WIDTH")->asDouble();
 
 	wxRect r = !m_Parameters("SCALE_EXTENT")->asBool() ? wxRect(dc.rDC()) : wxRect(
 		(int) dc.xWorld2DC    (Get_Extent().Get_XMin  ()),
@@ -2408,23 +2420,27 @@ bool CWKSP_Map::Draw_ScaleBar(CSG_Map_DC &dc)
 	r = wxRect(
 		(int)(0.5 + r.GetWidth () * 0.01 * m_Parameters("SCALE_OFFSET_X")->asDouble()) + r.GetX(), r.GetY() + r.GetHeight() -
 		(int)(0.5 + r.GetHeight() * 0.01 * m_Parameters("SCALE_OFFSET_Y")->asDouble()),
-		(int)(0.5 + r.GetWidth () * dWidth),
+		(int)(0.5 + r.GetWidth () * Width),
 		(int)(0.5 + r.GetHeight() * 0.01 * m_Parameters("SCALE_HEIGHT"  )->asDouble())
 	);
 
-	dWidth = dc.DC2World() * r.GetWidth();
+	Width = dc.DC2World() * r.GetWidth();
 
 	CSG_String Unit;
 
-	if( m_Projection.is_Okay() && m_Parameters("SCALE_UNIT")->asBool() )
+	if( m_Parameters("SCALE_UNIT")->asInt() > 0 )
 	{
-		Unit = CSG_Projections::Get_Unit_Name(m_Projection.Get_Unit(), true);
+		ESG_Projection_Unit _Unit = m_Parameters("SCALE_UNIT")->asInt() > 1
+			? (ESG_Projection_Unit)(m_Parameters("SCALE_UNIT")->asInt() - 2) : m_Projection.Get_Unit();
 
-		if( Unit.is_Empty() ) Unit = m_Projection.Get_Unit_Name();
-
-		if( m_Projection.Get_Unit() == ESG_Projection_Unit::Meter && dWidth > 10000. )
+		if( _Unit != ESG_Projection_Unit::Undefined )
 		{
-			dWidth /= 1000.; Unit = CSG_Projections::Get_Unit_Name(ESG_Projection_Unit::Kilometer, true);
+			if( Width > 10000. && _Unit == ESG_Projection_Unit::Meter )
+			{
+				Width /= 1000.; _Unit = ESG_Projection_Unit::Kilometer;
+			}
+
+			Unit = CSG_Projections::Get_Unit_Name(_Unit, true);
 		}
 	}
 
@@ -2435,7 +2451,7 @@ bool CWKSP_Map::Draw_ScaleBar(CSG_Map_DC &dc)
 		Style |= SCALE_STYLE_BLACKWHITE;
 	}
 
-	Draw_Scale(dc.Get_DC(), r, 0., dWidth, SCALE_HORIZONTAL, SCALE_TICK_TOP, Style, Unit.c_str());
+	Draw_Scale(dc.Get_DC(), r, 0., Width, SCALE_HORIZONTAL, SCALE_TICK_TOP, Style, Unit.c_str());
 
 	return( true );
 }
@@ -2450,23 +2466,30 @@ bool CWKSP_Map::Draw_Extent(CSG_Map_DC &dc)
 
 	if( dc.Draw_Image_Begin(m_Parameters("SEL_TRANSP")->asDouble() / 100.) )
 	{
-		int Color = m_Parameters("SEL_COLOUR")->asColor();
+		int Color = m_Parameters("SEL_COLOUR")->asColor(); wxRect r(dc.rDC()); r.Inflate(1);
 
-		wxRect r(dc.rDC()); r.Inflate(1);
+		double dx = dc.rWorld().Get_XRange() - Get_Extent().Get_XRange();
+		double dy = dc.rWorld().Get_YRange() - Get_Extent().Get_YRange();
 
-		if( dc.rWorld().Get_XRange() > Get_Extent().Get_XRange() )
+		if( dx > dy )
 		{
-			int d = (int)(0.5 + dc.World2DC() * (dc.rWorld().Get_XRange() - Get_Extent().Get_XRange()) / 2.);
+			int d = (int)(dx * dc.World2DC() / 2.);
 
-			dc.Draw_Image_Pixels(r.GetLeft (), r.GetTop(), r.GetLeft () + d, r.GetBottom(), Color);
-			dc.Draw_Image_Pixels(r.GetRight(), r.GetTop(), r.GetRight() - d, r.GetBottom(), Color);
+			if( d > 0 )
+			{
+				dc.Draw_Image_Pixels(r.GetLeft (), r.GetTop(), r.GetLeft () + d, r.GetBottom(), Color);
+				dc.Draw_Image_Pixels(r.GetRight(), r.GetTop(), r.GetRight() - d, r.GetBottom(), Color);
+			}
 		}
-		else
+		else // if( dx < dy )
 		{
-			int d = (int)(0.5 + dc.World2DC() * (dc.rWorld().Get_YRange() - Get_Extent().Get_YRange()) / 2.);
+			int d = (int)(dy * dc.World2DC() / 2.);
 
-			dc.Draw_Image_Pixels(r.GetLeft(), r.GetTop   (), r.GetRight(), r.GetTop   () + d, Color);
-			dc.Draw_Image_Pixels(r.GetLeft(), r.GetBottom(), r.GetRight(), r.GetBottom() - d, Color);
+			if( d > 0 )
+			{
+				dc.Draw_Image_Pixels(r.GetLeft(), r.GetTop   (), r.GetRight(), r.GetTop   () + d, Color);
+				dc.Draw_Image_Pixels(r.GetLeft(), r.GetBottom(), r.GetRight(), r.GetBottom() - d, Color);
+			}
 		}
 
 		dc.Draw_Image_End();
@@ -2477,7 +2500,7 @@ bool CWKSP_Map::Draw_Extent(CSG_Map_DC &dc)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -2523,9 +2546,9 @@ void CWKSP_Map::Show_Coordinate(const CSG_Point &Coordinate) const
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
