@@ -200,6 +200,15 @@ CWKSP_Map_Graticule::CWKSP_Map_Graticule(CSG_MetaData *pEntry)
 		2.0, 0.0, true, 10.0, true
 	);
 
+	m_Parameters.Add_Choice("LABEL",
+		"LABEL_ORIENT"	, _TL("Latitude Orientation"),
+		_TL(""),
+		CSG_String::Format("%s|%s",
+			_TL("horizontal"),
+			_TL("vertical")
+		), 1
+	);
+
 	m_Parameters.Add_Choice("LABEL",
 		"LABEL_EFFECT"	, _TL("Boundary Effect"),
 		_TL(""),
@@ -423,12 +432,12 @@ void CWKSP_Map_Graticule::Parameters_Changed(void)
 //---------------------------------------------------------
 bool CWKSP_Map_Graticule::Get_Graticule(const CSG_Rect &Extent)
 {
-	bool	bResult	= false;
+	bool bResult = false;
 
 	m_Graticule  .Create(SHAPE_TYPE_Line );
 	m_Coordinates.Create(SHAPE_TYPE_Point);
 
-	CSG_Tool	*pTool	= SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 14);
+	CSG_Tool *pTool = SG_Get_Tool_Library_Manager().Create_Tool("pj_proj4", 14);
 
 	if(	pTool && Get_Map()->Get_Projection().is_Okay() )
 	{
@@ -446,7 +455,8 @@ bool CWKSP_Map_Graticule::Get_Graticule(const CSG_Rect &Extent)
 				&& pTool->Set_Parameter("RESOLUTION", m_Parameters("RESOLUTION"))
 				&& pTool->Set_Parameter("GRATICULE" , &m_Graticule)
 				&& pTool->Set_Parameter("COORDS"    , &m_Coordinates)
-				&& pTool->Set_Parameter("CRS_STRING", Get_Map()->Get_Projection().Get_WKT())
+				&& pTool->Set_Parameter("CRS_WKT"   , Get_Map()->Get_Projection().Get_WKT2())
+				&& pTool->Set_Parameter("CRS_PROJ"  , Get_Map()->Get_Projection().Get_PROJ())
 				&& pTool->On_Before_Execution()
 				&& pTool->Execute();
 
@@ -543,6 +553,7 @@ bool CWKSP_Map_Graticule::Draw(CSG_Map_DC &dc_Map)
 
 		if( Size > 2 )
 		{
+			bool     bLatVertical  = m_Parameters("LABEL_ORIENT")->asInt() == 1;
 			int      Effect, Units = m_Parameters("LABEL_UNITS")->asInt(), Decimals = m_Parameters("LABEL_DECIMALS")->asInt();
 			wxColour Effect_Color  = Get_Color_asWX(m_Parameters("LABEL_EFFCOL")->asInt());
 			wxFont   Font          = Get_Font(m_Parameters("LABEL_FONT"));
@@ -572,15 +583,25 @@ bool CWKSP_Map_Graticule::Draw(CSG_Map_DC &dc_Map)
 
 				TSG_Point_Int p(dc_Map.World2DC(pPoint->Get_Point())); wxString Type(pPoint->asString(0));
 
-				int Align =
-					!Type.Cmp("LAT_MIN") ? TEXTALIGN_CENTERLEFT   :
-					!Type.Cmp("LAT_MAX") ? TEXTALIGN_CENTERRIGHT  :
-					!Type.Cmp("LON_MIN") ? TEXTALIGN_BOTTOMCENTER :
-					!Type.Cmp("LON_MAX") ? TEXTALIGN_TOPCENTER    : TEXTALIGN_CENTER;
+				CSG_String Coordinate(Get_Unit(pPoint, Units, Decimals, (!Type.Cmp("LAT_MIN") || !Type.Cmp("LAT_MAX"))));
 
-				CSG_String Coordinate(Get_Unit(pPoint, Units, Decimals, (Align & TEXTALIGN_YCENTER) != 0));
+				int Align; double Angle;
 
-				dc_Map.DrawText(Align, p.x, p.y, 0.0, Coordinate.c_str(), Effect, Effect_Color);
+				if( bLatVertical )
+				{
+					Align = !Type.Cmp("LON_MIN") ? TEXTALIGN_BOTTOMCENTER : TEXTALIGN_TOPCENTER;
+					Angle = !Type.Cmp("LAT_MIN") ? 90. : !Type.Cmp("LAT_MAX") ? -90. : 0.;
+				}
+				else
+				{
+					Align = !Type.Cmp("LAT_MIN") ? TEXTALIGN_CENTERLEFT
+					      : !Type.Cmp("LAT_MAX") ? TEXTALIGN_CENTERRIGHT
+					      : !Type.Cmp("LON_MIN") ? TEXTALIGN_BOTTOMCENTER
+					      : !Type.Cmp("LON_MAX") ? TEXTALIGN_TOPCENTER : TEXTALIGN_CENTER;
+					Angle = 0.;
+				}
+
+				dc_Map.DrawText(Align, p.x, p.y, Angle, Coordinate.c_str(), Effect, Effect_Color);
 			}
 		}
 	}
