@@ -48,6 +48,7 @@
 //---------------------------------------------------------
 #include <wx/dir.h>
 #include <wx/filename.h>
+#include <wx/config.h>
 
 #include <saga_api/saga_api.h>
 
@@ -71,43 +72,41 @@
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-CWKSP_Tool_Manager	*g_pTools	= NULL;
+CWKSP_Tool_Manager *g_pTools = NULL;
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 CWKSP_Tool_Manager::CWKSP_Tool_Manager(void)
 {
-	g_pTools		= this;
-
-	m_pMenu_Tools	= new CWKSP_Tool_Menu;
+	g_pTools = this; m_pMenu_Tools = new CWKSP_Tool_Menu;
 
 	//-----------------------------------------------------
 	m_Parameters.Add_Node("", "NODE_GENERAL", _TL("General"), _TL(""));
 
 	m_Parameters.Add_Bool("NODE_GENERAL",
-		"START_LOGO"	, _TL("Show Logo at Start Up"),
+		"START_LOGO"     , _TL("Show Logo at Start Up"),
 		_TL(""),
 		true
 	);
 
 	m_Parameters.Add_Int("NODE_GENERAL",
-		"PROCESS_UPDATE", _TL("Process Update Frequency"),
+		"PROCESS_UPDATE" , _TL("Process Update Frequency"),
 		_TL("[milliseconds]"),
 		g_pSAGA->Process_Get_Frequency(), 1, true
 	);
 
 	m_Parameters.Add_Bool("NODE_GENERAL",
-		"SAVE_CONFIG"	, _TL("Save Configuration"),
+		"SAVE_CONFIG"    , _TL("Save Configuration"),
 		_TL("disabling might help to shut down faster, particularly if started from slow devices"),
 		true
 	);
@@ -122,17 +121,32 @@ CWKSP_Tool_Manager::CWKSP_Tool_Manager(void)
 	);
 #endif
 
+	//-----------------------------------------------------
+#if _SAGA_MSW && wxCHECK_VERSION(3, 3, 0)
+	m_Parameters.Add_Node("", "NODE_DISPLAY", _TL("Display"), _TL(""));
+
+	m_Parameters.Add_Choice("NODE_DISPLAY",
+		"DISPLAY_MODE"   , _TL("Mode"),
+		_TL("Change display mode. You need to restart SAGA to apply the changes."),
+		CSG_String::Format("%s|%s|%s",
+			_TL("system"),
+			_TL("light"),
+			_TL("dark")
+		), 0
+	);
+#endif
+
 	//-----------------------------------------------------
 	m_Parameters.Add_Node("", "NODE_TOOLS", _TL("Tools"), _TL(""));
 
 	m_Parameters.Add_Bool("NODE_TOOLS",
-		"BEEP"			, _TL("Beep when finished"),
+		"BEEP"           , _TL("Beep when finished"),
 		_TL(""),
 		false
 	);
 
 	m_Parameters.Add_Choice("NODE_TOOLS",
-		"HELP_SOURCE"	, _TL("Tool Description Source"),
+		"HELP_SOURCE"    , _TL("Tool Description Source"),
 		_TL(""),
 		CSG_String::Format("%s|%s",
 			_TL("built-in"),
@@ -140,11 +154,20 @@ CWKSP_Tool_Manager::CWKSP_Tool_Manager(void)
 		), 0
 	);
 
+	m_Parameters.Add_Choice("NODE_TOOLS",
+		"CRS_CODE_DB"    , _TL("CRS Code Database"),
+		_TL("Preferred authority code database used to look-up coordinate reference system definitions."),
+		CSG_String::Format("%s|%s",
+			_TL("built-in"),
+			SG_T("proj")
+		), SG_Get_Projections().Get_UseInternalDB() ? 0 : 1
+	);
+
 	//-----------------------------------------------------
 	m_Parameters.Add_Node("", "NODE_FILES", _TL("Files"), _TL(""));
 
 	m_Parameters.Add_FilePath("NODE_FILES",
-		"LNG_FILE_DIC"	, _TL("Language Translations"),
+		"LNG_FILE_DIC"   , _TL("Language Translations"),
 		_TL("Dictionary for translations from built-in (English) to local language (editable text table, utf-8 encoded). You need to restart SAGA to apply the changes."),
 		CSG_String::Format("%s|*.lng;*.txt|%s (*.lng)|*.lng|%s (*.txt)|*.txt|%s|*.*",
 			_TL("Recognized Files"),
@@ -155,7 +178,7 @@ CWKSP_Tool_Manager::CWKSP_Tool_Manager(void)
 	);
 
 	m_Parameters.Add_FilePath("NODE_FILES",
-		"TOOL_MENUS"	, _TL("User defined tool menus"),
+		"TOOL_MENUS"     , _TL("User defined tool menus"),
 		_TL("User defined tool menus."),
 		CSG_String::Format("%s|*.xml|%s|*.*",
 			_TL("XML Files (*.xml)"),
@@ -167,11 +190,17 @@ CWKSP_Tool_Manager::CWKSP_Tool_Manager(void)
 	m_Parameters.Add_Node("", "NODE_LOOK", _TL("Appearance"), _TL(""));
 
 	m_Parameters.Add_Int("NODE_LOOK",
-		"LOOK_TB_SIZE"	, _TL("Tool Bar Button Size"),
+		"LOOK_TB_SIZE"   , _TL("Tool Bar Button Size"),
 		_TL("Tool bar button sizes. You need to restart SAGA to apply the changes."),
 		24, 16, true
 	);
 
+	m_Parameters.Add_Int("NODE_LOOK",
+		"MESSAGE_SCALE"  , _TL("Message Font Scaling"),
+		_TL("Percentage of the default window font size. Applies only to new message window output (general, execution, errors)."),
+		90., 10., true, 200., true
+	);
+
 	m_Parameters.Add_Int("NODE_LOOK",
 		"FLOAT_PRECISION", _TL("Floating Point Precision"),
 		_TL("Sets the (max) precision used when floating point values are rendered as text in settings controls. The value set to -1 means infinite precision."),
@@ -184,18 +213,14 @@ CWKSP_Tool_Manager::~CWKSP_Tool_Manager(void)
 {
 	delete(m_pMenu_Tools);
 
-	g_pTools	= NULL;
+	g_pTools = NULL;
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
-//---------------------------------------------------------
-#define CFG_LIBS	"/LIBS"
-#define CFG_LIBF	"LIB_%03d"
-
 //---------------------------------------------------------
 bool CWKSP_Tool_Manager::Initialise(void)
 {
@@ -207,15 +232,17 @@ bool CWKSP_Tool_Manager::Initialise(void)
 
 	g_pSAGA->Process_Set_Frequency(m_Parameters("PROCESS_UPDATE")->asInt());
 
+	SG_Get_Projections().Set_UseInternalDB(m_Parameters("CRS_CODE_DB")->asInt() == 0);
+
 	#ifdef _OPENMP
 		SG_OMP_Set_Max_Num_Threads(m_Parameters("OMP_THREADS_MAX")->asInt());
 	#endif
 
 	//-----------------------------------------------------
 	#ifdef _SAGA_MSW
-		wxString	Default_Path(g_pSAGA->Get_App_Path());
+		wxString Default_Path(g_pSAGA->Get_App_Path());
 	#else
-		wxString	Default_Path(TOOLS_PATH);
+		wxString Default_Path(TOOLS_PATH);
 	#endif
 
 	//-----------------------------------------------------
@@ -224,21 +251,21 @@ bool CWKSP_Tool_Manager::Initialise(void)
 	#ifdef __GNUC__
 	if( bCompatible ) // gcc builds: don't load stored libraries when there is no abi compatibility assured!
 	{
-		long	Number;
+		long Number;
 
 		if( !CONFIG_Read("/VERSION", "GNUC" , Number) || Number != __GNUC__ )
 		{
-			bCompatible	= false;
+			bCompatible = false;
 		}
 		#ifdef __GNUC_MINOR__
 			else if( !CONFIG_Read("/VERSION", "GNUC_MINOR" , Number) || Number != __GNUC_MINOR__ )
 			{
-				bCompatible	= false;
+				bCompatible = false;
 			}
 			#ifdef __GNUC_PATCHLEVEL__
 				else if( !CONFIG_Read("/VERSION", "GNUC_PATCHLEVEL" , Number) || Number != __GNUC_PATCHLEVEL__ )
 				{
-					bCompatible	= false;
+					bCompatible = false;
 				}
 			#endif
 		#endif
@@ -248,22 +275,32 @@ bool CWKSP_Tool_Manager::Initialise(void)
 	//-----------------------------------------------------
 	if( bCompatible )
 	{
-		wxString	Library;
+		wxConfigBase *pConfig = wxConfigBase::Get();
 
-		for(int i=0; CONFIG_Read(CFG_LIBS, wxString::Format(CFG_LIBF, i), Library); i++)
+		pConfig->SetPath("/LIBS");
+
+		long Index; wxString Entry;
+
+		if( pConfig->GetFirstEntry(Entry, Index) )
 		{
-			if( !wxFileExists(Library) )
+			do
 			{
-				wxFileName	fn(Library);
+				wxString Library = pConfig->Read(Entry);
 
-				fn.MakeAbsolute(Default_Path);
+				if( !wxFileExists(Library) )
+				{
+					wxFileName FileName(Library);
 
-				Library	= fn.GetFullPath();
+					FileName.MakeAbsolute(Default_Path);
+
+					Library	= FileName.GetFullPath();
+				}
+
+				SG_UI_Progress_Lock(true);
+				SG_Get_Tool_Library_Manager().Add_Library(&Library);
+				SG_UI_Progress_Lock(false);
 			}
-
-			SG_UI_Progress_Lock(true);
-			SG_Get_Tool_Library_Manager().Add_Library(&Library);
-			SG_UI_Progress_Lock(false);
+			while( pConfig->GetNextEntry(Entry, Index) );
 		}
 	}
 
@@ -297,33 +334,33 @@ bool CWKSP_Tool_Manager::Finalise(void)
 
 	//-----------------------------------------------------
 	#ifdef _SAGA_MSW
-		wxString	Default_Path(g_pSAGA->Get_App_Path());
+		wxString Default_Path(g_pSAGA->Get_App_Path());
 	#else
-		wxString	Default_Path(TOOLS_PATH);
+		wxString Default_Path(TOOLS_PATH);
 	#endif
 
-	CONFIG_Delete(CFG_LIBS);
+	CONFIG_Delete("/LIBS");
 
 	for(int i=0, n=0; i<Get_Count(); i++)
 	{
-		CWKSP_Tool_Group	*pGroup	= Get_Group(i);
+		CWKSP_Tool_Group *pGroup = Get_Group(i);
 
 		for(int j=0; j<pGroup->Get_Count(); j++)
 		{
-			CSG_Tool_Library	*pLibrary	= pGroup->Get_Library(j)->Get_Library();
+			CSG_Tool_Library *pLibrary = pGroup->Get_Library(j)->Get_Library();
 
-			if( pLibrary->Get_Type() == TOOL_CHAINS )
+			if( pLibrary->Get_Type() == ESG_Library_Type::Chain )
 			{
 				for(int j=0; j<pLibrary->Get_Count(); j++)
 				{
-					CONFIG_Write(CFG_LIBS, wxString::Format(CFG_LIBF, n++),
+					CONFIG_Write("/LIBS", wxString::Format("LIB_%03d", n++),
 						Get_FilePath_Relative(Default_Path.c_str(), pLibrary->Get_File_Name(j).c_str())
 					);
 				}
 			}
 			else
 			{
-				CONFIG_Write(CFG_LIBS, wxString::Format(CFG_LIBF, n++),
+				CONFIG_Write("/LIBS", wxString::Format("LIB_%03d", n++),
 					Get_FilePath_Relative(Default_Path.c_str(), pLibrary->Get_File_Name().c_str())
 				);
 			}
@@ -335,19 +372,19 @@ bool CWKSP_Tool_Manager::Finalise(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 int CWKSP_Tool_Manager::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter, int Flags)
 {
-	//-----------------------------------------------------
 	if( Flags & PARAMETER_CHECK_VALUES )
 	{
 		if( g_pSAGA_Frame && g_pData )
 		{
 			if( pParameter->Cmp_Identifier("LNG_FILE_DIC")
-			||  pParameter->Cmp_Identifier("LOOK_TB_SIZE") )
+			||  pParameter->Cmp_Identifier("LOOK_TB_SIZE")
+			||  pParameter->Cmp_Identifier("DISPLAY_MODE") )
 			{
 				if( DLG_Message_Confirm(_TL("Close now ?"), _TL("Restart SAGA to apply the changes")) )
 				{
@@ -380,6 +417,8 @@ void CWKSP_Tool_Manager::Parameters_Changed(void)
 
 	g_pSAGA->Process_Set_Frequency(m_Parameters("PROCESS_UPDATE")->asInt());
 
+	SG_Get_Projections().Set_UseInternalDB(m_Parameters("CRS_CODE_DB")->asInt() == 0);
+
 #ifdef _OPENMP
 	SG_OMP_Set_Max_Num_Threads(m_Parameters("OMP_THREADS_MAX")->asInt());
 #endif
@@ -395,7 +434,7 @@ bool CWKSP_Tool_Manager::Do_Beep(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -413,7 +452,7 @@ wxString CWKSP_Tool_Manager::Get_Description(void)
 //---------------------------------------------------------
 wxMenu * CWKSP_Tool_Manager::Get_Menu(void)
 {
-	wxMenu	*pMenu	= new wxMenu(Get_Name());
+	wxMenu *pMenu = new wxMenu(Get_Name());
 
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_TOOL_OPEN);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_TOOL_RELOAD);
@@ -432,18 +471,35 @@ wxMenu * CWKSP_Tool_Manager::Get_Menu(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 bool CWKSP_Tool_Manager::On_Command(int Cmd_ID)
 {
+	if( Cmd_ID >= ID_CMD_TOOL_RECENT_FIRST && Cmd_ID <= ID_CMD_TOOL_RECENT_LAST )
+	{
+		Cmd_ID = m_pMenu_Tools->Get_ID_Translated(Cmd_ID);
+	}
+
+	if( Cmd_ID >= ID_CMD_TOOL_MENU_FIRST && Cmd_ID <= ID_CMD_TOOL_MENU_LAST )
+	{
+		CWKSP_Tool *pTool = Get_Tool_byID(Cmd_ID);
+
+		if( pTool )
+		{
+			pTool->Execute(true);
+		}
+
+		return( true );
+	}
+
+	//-----------------------------------------------------
 	switch( Cmd_ID )
 	{
-	default:
-		return( CWKSP_Base_Manager::On_Command(Cmd_ID) );
+	default: return( CWKSP_Base_Manager::On_Command(Cmd_ID) );
 
-	case ID_CMD_TOOL_OPEN:
+	case ID_CMD_TOOL_OPEN  :
 		Open();
 		break;
 
@@ -464,11 +520,11 @@ bool CWKSP_Tool_Manager::On_Command(int Cmd_ID)
 
 	case ID_CMD_TOOL_SAVE_DOCS:
 		{
-			wxString	Path;
+			wxString Path;
 
 			if( DLG_Directory(Path, _TL("Create Tool Description Files")) )
 			{
-				MSG_General_Add(wxString::Format(SG_T("%s..."), _TL("Create Tool Description Files")), true, true);
+				MSG_General_Add(wxString::Format("%s...", _TL("Create Tool Description Files")), true, true);
 
 				SG_Get_Tool_Library_Manager().Get_Summary(&Path);
 
@@ -484,58 +540,41 @@ bool CWKSP_Tool_Manager::On_Command(int Cmd_ID)
 //---------------------------------------------------------
 bool CWKSP_Tool_Manager::On_Command_UI(wxUpdateUIEvent &event)
 {
-	switch( event.GetId() )
+	if( (event.GetId() >= ID_CMD_TOOL_MENU_FIRST   && event.GetId() <= ID_CMD_TOOL_MENU_LAST  )
+	||  (event.GetId() >= ID_CMD_TOOL_RECENT_FIRST && event.GetId() <= ID_CMD_TOOL_RECENT_LAST) )
 	{
-	default:
-		return( CWKSP_Base_Manager::On_Command_UI(event) );
+		if( g_pTool == NULL )
+		{
+			event.Enable(true ); event.Check(false);
+		}
+		else if( g_pTool->Get_Menu_ID() == m_pMenu_Tools->Get_ID_Translated(event.GetId()) )
+		{
+			event.Enable(true ); event.Check(true );
+		}
+		else
+		{
+			event.Enable(false); event.Check(false);
+		}
+	}
 
+	//-----------------------------------------------------
+	else switch( event.GetId() )
+	{
 	case ID_CMD_WKSP_ITEM_CLOSE:
 	case ID_CMD_TOOL_SEARCH    :
 	case ID_CMD_TOOL_SAVE_DOCS :
 		event.Enable(Get_Count() > 0 && g_pTool == NULL);
 		break;
+
+	default: return( CWKSP_Base_Manager::On_Command_UI(event) );
 	}
 
 	return( true );
 }
 
-//---------------------------------------------------------
-void CWKSP_Tool_Manager::On_Execute(wxCommandEvent &event)
-{
-	CWKSP_Tool *pTool = Get_Tool_byID(m_pMenu_Tools->Get_ID_Translated(event.GetId()));
-
-	if( pTool )
-	{
-		pTool->Execute(true);
-	}
-}
-
-//---------------------------------------------------------
-void CWKSP_Tool_Manager::On_Execute_UI(wxUpdateUIEvent &event)
-{
-	if( g_pTool )
-	{
-		if( g_pTool->Get_Menu_ID() == m_pMenu_Tools->Get_ID_Translated(event.GetId()) )
-		{
-			event.Enable(true);
-			event.Check(true);
-		}
-		else
-		{
-			event.Enable(false);
-			event.Check(false);
-		}
-	}
-	else
-	{
-		event.Enable(true);
-		event.Check(false);
-	}
-}
-
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -557,7 +596,7 @@ CWKSP_Tool_Library * CWKSP_Tool_Manager::Get_Library(CSG_Tool_Library *pLibrary)
 {
 	for(int i=0; i<Get_Count(); i++)
 	{
-		CWKSP_Tool_Group	*pGroup	= Get_Group(i);
+		CWKSP_Tool_Group *pGroup = Get_Group(i);
 
 		for(int j=0; j<pGroup->Get_Count(); j++)
 		{
@@ -577,8 +616,13 @@ bool CWKSP_Tool_Manager::_Reload(void)
 	#ifdef _SAGA_MSW
 		SG_Get_Tool_Library_Manager().Add_Directory(SG_File_Make_Path(&g_pSAGA->Get_App_Path(), "tools"));
 	#else // #ifdef _SAGA_LINUX
-		SG_Get_Tool_Library_Manager().Add_Directory(TOOLS_PATH);
-		SG_Get_Tool_Library_Manager().Add_Directory(SG_File_Make_Path(SHARE_PATH, "toolchains"));	// look for tool chains
+		#if defined(__WXMAC__)
+		if( SG_Get_Tool_Library_Manager().Add_Directory(SG_UI_Get_Application_Path(true) + "/../Tools", false) < 1 )
+		#endif
+		{
+			SG_Get_Tool_Library_Manager().Add_Directory(TOOLS_PATH);
+			SG_Get_Tool_Library_Manager().Add_Directory(SG_File_Make_Path(SHARE_PATH, "toolchains"));	// look for tool chains
+		}
 	#endif
 
 	wxString Path;
@@ -609,12 +653,12 @@ bool CWKSP_Tool_Manager::_Update(bool bSyncToCtrl)
 
 		for(int i=SG_Get_Tool_Library_Manager().Get_Count()-1; i>=0; i--)
 		{
-			CSG_Tool_Library	*pLibrary	= SG_Get_Tool_Library_Manager().Get_Library(i);
-			CWKSP_Tool_Library	*pItem	= Get_Library(pLibrary);
+			CSG_Tool_Library *pLibrary = SG_Get_Tool_Library_Manager().Get_Library(i);
+			CWKSP_Tool_Library  *pItem = Get_Library(pLibrary);
 
 			if( !pItem )
 			{
-				CWKSP_Tool_Group	*pGroup	= Get_Group(pLibrary->Get_Category().c_str());
+				CWKSP_Tool_Group *pGroup = Get_Group(pLibrary->Get_Category().c_str());
 
 				if( !pGroup )
 				{
@@ -623,7 +667,7 @@ bool CWKSP_Tool_Manager::_Update(bool bSyncToCtrl)
 
 				pGroup->Add_Library(pLibrary);
 			}
-			else if( pItem->Get_Library()->Get_Type() == TOOL_CHAINS )
+			else if( pItem->Get_Library()->Get_Type() == ESG_Library_Type::Chain )
 			{
 				pItem->Update();
 			}
@@ -645,7 +689,7 @@ bool CWKSP_Tool_Manager::Update(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -662,25 +706,25 @@ void CWKSP_Tool_Manager::Set_Recently_Used(CWKSP_Tool *pTool)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 void CWKSP_Tool_Manager::Open(void)
 {
-	wxArrayString	File_Paths;
+	wxArrayString File_Paths;
 
 	if( DLG_Open(File_Paths, ID_DLG_TOOL_OPEN) )
 	{
 		MSG_General_Add_Line();
 
-		bool	bUpdate	= false;
+		bool bUpdate = false;
 
 		for(size_t i=0; i<File_Paths.GetCount(); i++)
 		{
 			if( SG_Get_Tool_Library_Manager().Add_Library(&File_Paths[i]) )
 			{
-				bUpdate	= true;
+				bUpdate = true;
 			}
 		}
 
@@ -706,7 +750,7 @@ bool CWKSP_Tool_Manager::Open(const wxString &File_Name)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -714,7 +758,7 @@ bool CWKSP_Tool_Manager::Exists(CWKSP_Tool *pTool)
 {
 	for(int i=0; i<Get_Count(); i++)
 	{
-		CWKSP_Tool_Group	*pGroup	= Get_Group(i);
+		CWKSP_Tool_Group *pGroup = Get_Group(i);
 
 		for(int j=0; j<pGroup->Get_Count(); j++)
 		{
@@ -735,7 +779,7 @@ CWKSP_Tool * CWKSP_Tool_Manager::Get_Tool_byID(int CMD_ID)
 
 	for(int i=0; i<Get_Count(); i++)
 	{
-		CWKSP_Tool_Group	*pGroup	= Get_Group(i);
+		CWKSP_Tool_Group *pGroup = Get_Group(i);
 
 		for(int j=0; j<pGroup->Get_Count(); j++)
 		{
@@ -751,15 +795,15 @@ CWKSP_Tool * CWKSP_Tool_Manager::Get_Tool_byID(int CMD_ID)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 CWKSP_Tool_Group::CWKSP_Tool_Group(const wxString &Name)
 {
-	m_Name	= Name;
+	m_Name = Name;
 }
 
 //---------------------------------------------------------
@@ -768,7 +812,7 @@ CWKSP_Tool_Group::~CWKSP_Tool_Group(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -778,49 +822,49 @@ CWKSP_Tool_Group::~CWKSP_Tool_Group(void)
 //---------------------------------------------------------
 wxString CWKSP_Tool_Group::Get_Description(void)
 {
-	wxString	s;
+	wxString s;
 
-	s	+= wxString::Format("<h4>%s</h4>", _TL("Tool Libraries"));
+	s += wxString::Format("<h4>%s</h4>", _TL("Tool Libraries"));
 
-	s	+= "<table border=\"0\">";
+	s += "<table border=\"0\">";
 
-	s	+= SUMMARY_ADD_STR(_TL("Category" ), Get_Name().c_str());
-	s	+= SUMMARY_ADD_INT(_TL("Libraries"), Get_Count());
+	s += SUMMARY_ADD_STR(_TL("Category" ), Get_Name().c_str());
+	s += SUMMARY_ADD_INT(_TL("Libraries"), Get_Count());
 
-	s	+= "</table>";
+	s += "</table>";
 
 	//-----------------------------------------------------
-	s	+= wxString::Format("<hr><h4>%s</h4><table border=\"0\">", _TL("Tool Libraries"));
+	s += wxString::Format("<hr><h4>%s</h4><table border=\"0\">", _TL("Tool Libraries"));
 
-	s	+= wxString::Format("<tr align=\"left\"><th>%s</th><th>%s</th><th>%s</th></tr>",
-			_TL("Library"),
-			_TL("Name"   ),
-			_TL("Tools"  )
-		);
+	s += wxString::Format("<tr align=\"left\"><th>%s</th><th>%s</th><th>%s</th></tr>",
+		_TL("Library"),
+		_TL("Name"   ),
+		_TL("Tools"  )
+	);
 
 	for(int i=0; i<Get_Count(); i++)
 	{
-		s	+= wxString::Format("<tr><td valign=\"top\"><i>%s</i></td><td valign=\"top\">%s</td><td valign=\"top\" align=\"right\">%d</td></tr>",
-				Get_Library(i)->Get_Library()->Get_Library_Name().c_str(),
-				Get_Library(i)->Get_Name().c_str(),
-				Get_Library(i)->Get_Count()
-			);
+		s += wxString::Format("<tr><td valign=\"top\"><i>%s</i></td><td valign=\"top\">%s</td><td valign=\"top\" align=\"right\">%d</td></tr>",
+			Get_Library(i)->Get_Library()->Get_Library_Name().c_str(),
+			Get_Library(i)->Get_Name().c_str(),
+			Get_Library(i)->Get_Count()
+		);
 	}
 
-	s	+= "</table>";
+	s += "</table>";
 
 	return( s );
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
 wxMenu * CWKSP_Tool_Group::Get_Menu(void)
 {
-	wxMenu	*pMenu	= new wxMenu(Get_Name());
+	wxMenu *pMenu = new wxMenu(Get_Name());
 
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_TOOL_OPEN);
 	CMD_Menu_Add_Item(pMenu, false, ID_CMD_TOOL_RELOAD);
@@ -833,7 +877,7 @@ wxMenu * CWKSP_Tool_Group::Get_Menu(void)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -858,7 +902,7 @@ bool CWKSP_Tool_Group::On_Command_UI(wxUpdateUIEvent &event)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
@@ -883,9 +927,9 @@ CWKSP_Tool_Library * CWKSP_Tool_Group::Get_Library(CSG_Tool_Library *pLibrary)
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
