@@ -51,20 +51,20 @@
 
 
 //---------------------------------------------------------
-// 2. Place general tool library informations here...
+// 2. Place general tool library information here...
 
 CSG_String Get_Info(int i)
 {
 	switch( i )
 	{
 	case TLB_INFO_Name:	default:
-		return( _TL("Climate and Weather Tools") );
+		return( _TL("Climate & Weather Tools") );
 
 	case TLB_INFO_Category:
-		return( _TL("Climate and Weather") );
+		return( _TL("Climate & Weather") );
 
 	case TLB_INFO_Author:
-		return( "O.Conrad (c) 2012" );
+		return( "Various Authors" );
 
 	case TLB_INFO_Description:
 		return( _TL("Tools for the processing and analysis of climate and weather data.") );
@@ -110,64 +110,65 @@ CSG_Tool *		Create_Tool(int i)
 {
 	switch( i )
 	{
-	case  0: 	return( new CGrid_Levels_to_Surface );
-	case  1: 	return( new CGrid_Levels_to_Points );
+	case  0: return( new CGrid_Levels_to_Surface );
+	case  1: return( new CGrid_Levels_to_Points );
 
-	case  2:	return( new CMilankovic );
-	case  3:	return( new CMilankovic_SR_Location );
-	case  4:	return( new CMilankovic_SR_Day_Location );
-	case  5:	return( new CMilankovic_SR_Monthly_Global );
+	case  2: return( new CMilankovic );
+	case  3: return( new CMilankovic_SR_Location );
+	case  4: return( new CMilankovic_SR_Day_Location );
+	case  5: return( new CMilankovic_SR_Monthly_Global );
 
-	case  7:	return( new CETpot_Day_To_Hour );
-	case  6:	return( new CETpot_Table );
-	case  8:	return( new CETpot_Grid );
+	case  7: return( new CETpot_Day_To_Hour );
+	case  6: return( new CETpot_Table );
+	case  8: return( new CETpot_Grid );
 
-	case  9:	return( new CDaily_Sun );
-	case 31:	return( new CSolarRadiation );
+	case  9: return( new CDaily_Sun );
+	case 31: return( new CSolarRadiation );
+	case 33: return( new CSolarPosition );
 
-	case 10:	return( new CBioclimatic_Vars );
-	case 11:	return( new CTree_Growth );
-	case 20:	return( new CWater_Balance );
-	case 12:	return( new CWater_Balance_Interactive );
+	case 10: return( new CBioclimatic_Vars );
+	case 11: return( new CTree_Growth );
+	case 20: return( new CWater_Balance );
+	case 12: return( new CWater_Balance_Interactive );
 
-	case 13:	return( new CWindeffect_Correction );
+	case 13: return( new CWindeffect_Correction );
 
-	case 14:	return( new CFrost_Change_Frequency );
-	case 16:	return( new CFrost_Change_Frequency_Interactive );
-	case 15:	return( new CThermal_Belts );
+	case 14: return( new CFrost_Change_Frequency );
+	case 16: return( new CFrost_Change_Frequency_Interactive );
+	case 15: return( new CThermal_Belts );
 
-	case 17:	return( new CSnow_Cover );
-	case 18:	return( new CGrowing_Degree_Days );
+	case 17: return( new CSnow_Cover );
+	case 18: return( new CGrowing_Degree_Days );
 
-	case 19:	return( new CClimate_Classification );
+	case 19: return( new CClimate_Classification );
 
-	case 21:	return( new CPhenIps_Table );
-	case 22:	return( new CPhenIps_Grids_Annual );
-	case 23:	return( new CPhenIps_Grids_Days );
+	case 21: return( new CPhenIps_Table );
+	case 22: return( new CPhenIps_Grids_Annual );
+	case 23: return( new CPhenIps_Grids_Days );
 
-	case 24:	return( new CSoil_Water_Balance );
+	case 24: return( new CSoil_Water_Balance );
 
-	case 25:	return( new CCloud_Overlap );
-	case 26:	return( new CTemperature_Lapse_Rates );
-	case 30:	return( new CTemperature_Lapse_Downscaling );
-	case 32:	return( new CTemperature_Lapse_Interpolation );
+	case 25: return( new CCloud_Overlap );
+	case 26: return( new CTemperature_Lapse_Rates );
+	case 30: return( new CTemperature_Lapse_Downscaling );
+	case 32: return( new CTemperature_Lapse_Interpolation );
 
-	case 27:	return( new CAirPressure_Scaling );
-	case 29:	return( new CAirHumidity_Conversion );
+	case 27: return( new CAirPressure_Scaling );
+	case 29: return( new CAirHumidity_Conversion );
 
-	case 28:	return( new CLand_Surface_Temperature );
+	case 28: return( new CLand_Surface_Temperature );
 
 	//-----------------------------------------------------
-	case 33:	return( NULL );
-	default:	return( TLB_INTERFACE_SKIP_TOOL );
+	case 34: return( NULL );
+	default: return( TLB_INTERFACE_SKIP_TOOL );
 	}
 }
 
 
 ///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
+//                                                       //
+//                                                       //
+//                                                       //
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
