@@ -186,7 +186,7 @@ bool CCT_Growing_Season::Calculate(double SWC, double Latitude, double &Height,
 //---------------------------------------------------------
 bool CCT_Growing_Season::is_Growing(double SWC, double Latitude, double Height)
 {
-	const double	lapsrate	= -0.0055;	// adiabatic air temperature decline coefficient [K / m]
+	const double	lapsrate	= -0.0055;	// adiabatic air temperature decline coefficient [°K / m]
 
 	//-----------------------------------------------------
 	// 1. Temperature
@@ -296,28 +296,28 @@ CTree_Growth::CTree_Growth(void)
 		"Using the given thresholds a relative tree line height can optionally be estimated."
 	));
 
-	Add_Reference("Karger, D.N., Kessler, M., Conrad, O., Weigelt, P., Kreft, H., Knig, C., Zimmermann, N.E.", "2019",
+	Add_Reference(SG_T("Karger, D.N., Kessler, M., Conrad, O., Weigelt, P., Kreft, H., König, C., Zimmermann, N.E."), "2019",
 		"Why tree lines are lower on islands - Climatic and biogeographic effects hold the answer",
-		"Global Ecol. Biogeogr., 00:112.",
-		SG_T("https://doi.org/10.1111/geb.12897"), _TL("doi:10.1111/geb.12897")
+		"Global Ecol. Biogeogr., 00:1-12.",
+		SG_T("https://doi.org/10.1111/geb.12897"), SG_T("doi:10.1111/geb.12897")
 	);
 
-	Add_Reference("Paulsen, J. / Krner, C.", "2014",
+	Add_Reference(SG_T("Paulsen, J. / Körner, C."), "2014",
 		"A climate-based model to predict potential treeline position around the globe",
-		"Alpine Botany, 124:1, 112.",
-		SG_T("https://doi.org/10.1007/s00035-014-0124-0"), _TL("doi:10.1007/s00035-014-0124-0")
+		"Alpine Botany, 124:1, 1-12.",
+		SG_T("https://doi.org/10.1007/s00035-014-0124-0"), SG_T("doi:10.1007/s00035-014-0124-0")
 	);
 
 	//-----------------------------------------------------
-	Parameters.Add_Grid_List("", "T"   , _TL("Mean Temperature"   ), _TL(""), PARAMETER_INPUT);
-	Parameters.Add_Grid_List("", "TMIN", _TL("Minimum Temperature"), _TL(""), PARAMETER_INPUT);
-	Parameters.Add_Grid_List("", "TMAX", _TL("Maximum Temperature"), _TL(""), PARAMETER_INPUT);
-	Parameters.Add_Grid_List("", "P"   , _TL("Precipitation"      ), _TL(""), PARAMETER_INPUT);
+	Parameters.Add_Grid_List("", "T"   , _TL("Mean Temperature"   ), _TL("Monthly averages of daily mean temperature (12 grids, January to December) [°C]"), PARAMETER_INPUT);
+	Parameters.Add_Grid_List("", "TMIN", _TL("Minimum Temperature"), _TL("Monthly averages of daily minimum temperature (12 grids, January to December) [°C]"), PARAMETER_INPUT);
+	Parameters.Add_Grid_List("", "TMAX", _TL("Maximum Temperature"), _TL("Monthly averages of daily maximum temperature (12 grids, January to December) [°C]"), PARAMETER_INPUT);
+	Parameters.Add_Grid_List("", "P"   , _TL("Precipitation"      ), _TL("Monthly sums of precipitation (12 grids, January to December) [mm / m²]"), PARAMETER_INPUT);
 
 	//-----------------------------------------------------
 	Parameters.Add_Grid_or_Const("",
 		"SWC"			, _TL("Soil Water Capacity of Profile"),
-		_TL("Total soil water capacity (mm H2O)."),
+		_TL("Total soil water capacity (mm H₂O)."),
 		220., 0., true
 	);
 
@@ -485,7 +485,7 @@ bool CTree_Growth::On_Execute(void)
 	m_Model.Set_SW_min (Parameters( "SW_MIN")->asDouble() / 100.);
 
 	//-----------------------------------------------------
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 #ifndef _DEBUG
 		#pragma omp parallel for
@@ -574,10 +574,10 @@ CWater_Balance::CWater_Balance(void)
 		"Needed input is monthly data of mean, minimum, and maximum temperature as well as precipitation."
 	));
 
-	Add_Reference("Paulsen, J. / Krner, C.", "2014",
+	Add_Reference(SG_T("Paulsen, J. / Körner, C."), "2014",
 		"A climate-based model to predict potential treeline position around the globe",
-		"Alpine Botany, 124:1, 112.",
-		SG_T("https://doi.org/10.1007/s00035-014-0124-0"), _TL("doi:10.1007/s00035-014-0124-0")
+		"Alpine Botany, 124:1, 1-12.",
+		SG_T("https://doi.org/10.1007/s00035-014-0124-0"), SG_T("doi:10.1007/s00035-014-0124-0")
 	);
 
 	//-----------------------------------------------------
@@ -689,7 +689,7 @@ bool CWater_Balance::On_Execute(void)
 	m_Model.Get_Soil().Set_ET_Resistance(1, Parameters("SW1_RESIST" )->asDouble());
 
 	//-----------------------------------------------------
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 #ifndef _DEBUG
 		#pragma omp parallel for
@@ -753,10 +753,10 @@ CWater_Balance_Interactive::CWater_Balance_Interactive(void)
 		"Needed input is monthly data of mean, minimum, and maximum temperature as well as precipitation."
 	));
 
-	Add_Reference("Paulsen, J. / Krner, C.", "2014",
+	Add_Reference(SG_T("Paulsen, J. / Körner, C."), "2014",
 		"A climate-based model to predict potential treeline position around the globe",
-		"Alpine Botany, 124:1, 112.",
-		SG_T("https://doi.org/10.1007/s00035-014-0124-0"), _TL("doi:10.1007/s00035-014-0124-0")
+		"Alpine Botany, 124:1, 1-12.",
+		SG_T("https://doi.org/10.1007/s00035-014-0124-0"), SG_T("doi:10.1007/s00035-014-0124-0")
 	);
 
 	//-----------------------------------------------------
@@ -876,7 +876,7 @@ bool CWater_Balance_Interactive::On_Execute(void)
 	m_pDaily->Add_Field("ETP" , SG_DATATYPE_Double);
 	m_pDaily->Add_Field("SW_0", SG_DATATYPE_Double);
 	m_pDaily->Add_Field("SW_1", SG_DATATYPE_Double);
-	m_pDaily->Set_Record_Count(365);
+	m_pDaily->Set_Count(365);
 
 	//-----------------------------------------------------
 	return( true );
@@ -932,8 +932,8 @@ bool CWater_Balance_Interactive::On_Execute_Position(CSG_Point ptWorld, TSG_Tool
 		}
 
 		//-------------------------------------------------
-		m_pSummary->Get_Record(0)->Set_Value(1, ptWorld.Get_X());
-		m_pSummary->Get_Record(1)->Set_Value(1, ptWorld.Get_Y());
+		m_pSummary->Get_Record(0)->Set_Value(1, ptWorld.x);
+		m_pSummary->Get_Record(1)->Set_Value(1, ptWorld.y);
 		m_pSummary->Get_Record(2)->Set_Value(1, Latitude);
 
 		return( true );
