@@ -649,7 +649,8 @@ CSG_Grid * CSentinel_2_Scene_Import::Load_Band(const CSG_String &Path, const CSG
 
 				pTool->Set_Manager(NULL);
 
-				if( pTool->Set_Parameter("CRS_STRING"      , Projection.Get_WKT())
+				if( pTool->Set_Parameter("CRS_WKT"         , Projection.Get_WKT2())
+				&&  pTool->Set_Parameter("CRS_PROJ"        , Projection.Get_PROJ())
 				&&  pTool->Set_Parameter("SOURCE"          , pBand)
 				&&  pTool->Set_Parameter("RESAMPLING"      , Parameters("RESAMPLING"))
 			//	&&  pTool->Set_Parameter("DATA_TYPE"       , 10) // "Preserve" => is already default!
@@ -677,7 +678,8 @@ CSG_Grid * CSentinel_2_Scene_Import::Load_Band(const CSG_String &Path, const CSG
 
 			pTool->Set_Manager(NULL);
 
-			if( pTool->Set_Parameter("CRS_STRING", CSG_Projection::Get_GCS_WGS84().Get_WKT())
+			if( pTool->Set_Parameter("CRS_WKT"   , CSG_Projection::Get_GCS_WGS84().Get_WKT2())
+			&&  pTool->Set_Parameter("CRS_PROJ"  , CSG_Projection::Get_GCS_WGS84().Get_PROJ())
 			&&  pTool->Set_Parameter("SOURCE"    , pBand)
 			&&  pTool->Set_Parameter("RESAMPLING", Parameters("RESAMPLING"))
 		//	&&  pTool->Set_Parameter("DATA_TYPE" , 10) // "Preserve" => is already default!
