@@ -213,30 +213,31 @@ bool CGrid_Import::On_Execute(void)
 		pGrid->Get_Projection().Create(Projection);\
 		Parameters(Output)->Set_Value(pGrid);\
 		DataObject_Add(pGrid);\
-		DataObject_Set_Colors(pGrid, 11, SG_COLORS_BLACK_WHITE);\
+		DataObject_Set_Colors(pGrid, 5, SG_COLORS_BLACK_WHITE);\
 	}
 
-	wxImageHistogram	Histogram;
+	wxImageHistogram Histogram;
 
 	//-----------------------------------------------------
 	// look-up color table...
 
 	if( Parameters("METHOD")->asInt() == 0 && Image.ComputeHistogram(Histogram) <= 256 )
 	{
-		CSG_Colors	Colors((int)Histogram.size());
+		CSG_Colors Colors((int)Histogram.size());
 
 		for(wxImageHistogram::iterator i=Histogram.begin(); i!=Histogram.end(); ++i)
 		{
 			Colors.Set_Color(i->second.index, SG_GET_R(i->first), SG_GET_G(i->first), SG_GET_B(i->first));
 		}
 
-		CSG_Grid *pRGB = Parameters("OUT_GRID")->asGrid(); if( !pRGB ) { Parameters("OUT_GRID")->Set_Value(pRGB = SG_Create_Grid()); }
+		CSG_Grid *pRGB = Parameters("OUT_GRID")->asGrid(); if( !pRGB ) { pRGB = SG_Create_Grid(); }
 		
 		pRGB->Create(Histogram.size() <= 2 ? SG_DATATYPE_Bit : SG_DATATYPE_Byte, Image.GetWidth(), Image.GetHeight(), Cellsize, xMin, yMin);
+		pRGB->Set_NoData_Value(-1.);
 
 		for(int y=0; y<pRGB->Get_NY() && Set_Progress(y, pRGB->Get_NY()); y++)
 		{
-			int	yy	= bTransform ? y : pRGB->Get_NY() - 1 - y;
+			int yy = bTransform ? y : pRGB->Get_NY() - 1 - y;
 
 			for(int x=0; x<pRGB->Get_NX(); x++)
 			{
@@ -249,6 +250,8 @@ bool CGrid_Import::On_Execute(void)
 			Set_Transformation(&pRGB, m[4], m[5], m[0], m[3], m[2], m[1]);
 		}
 
+		Parameters("OUT_GRID")->Set_Value(pRGB);
+
 		SET_METADATA(pRGB, "", "OUT_GRID");
 
 		DataObject_Set_Colors(pRGB, Colors);
@@ -260,13 +263,14 @@ bool CGrid_Import::On_Execute(void)
 
 	else if( Parameters("METHOD")->asInt() != 1 ) // true color...
 	{
-		CSG_Grid *pRGB = Parameters("OUT_GRID")->asGrid(); if( !pRGB ) { Parameters("OUT_GRID")->Set_Value(pRGB = SG_Create_Grid()); }
+		CSG_Grid *pRGB = Parameters("OUT_GRID")->asGrid(); if( !pRGB ) { pRGB = SG_Create_Grid(); }
 
-		pRGB->Create(SG_DATATYPE_Int, Image.GetWidth(), Image.GetHeight(), Cellsize, xMin, yMin);
+		pRGB->Create(SG_DATATYPE_DWord, Image.GetWidth(), Image.GetHeight(), Cellsize, xMin, yMin);
+		pRGB->Set_NoData_Value(-1.);
 
 		for(int y=0; y<pRGB->Get_NY() && Set_Progress(y, pRGB->Get_NY()); y++)
 		{
-			int	yy	= bTransform ? y : pRGB->Get_NY() - 1 - y;
+			int yy = bTransform ? y : pRGB->Get_NY() - 1 - y;
 
 			for(int x=0; x<pRGB->Get_NX(); x++)
 			{
@@ -289,11 +293,11 @@ bool CGrid_Import::On_Execute(void)
 
 	else
 	{
-		CSG_Grid *pRGB = SG_Create_Grid(SG_DATATYPE_Int, Image.GetWidth(), Image.GetHeight(), Cellsize, xMin, yMin);
+		CSG_Grid *pRGB = SG_Create_Grid(SG_DATATYPE_DWord, Image.GetWidth(), Image.GetHeight(), Cellsize, xMin, yMin);
 
 		for(int y=0; y<pRGB->Get_NY() && Set_Progress(y, pRGB->Get_NY()); y++)
 		{
-			int	yy	= bTransform ? y : pRGB->Get_NY() - 1 - y;
+			int yy = bTransform ? y : pRGB->Get_NY() - 1 - y;
 
 			for(int x=0; x<pRGB->Get_NX(); x++)
 			{
@@ -306,9 +310,9 @@ bool CGrid_Import::On_Execute(void)
 			Set_Transformation(&pRGB, m[4], m[5], m[0], m[3], m[2], m[1]);
 		}
 
-		CSG_Grid *pR = Parameters("OUT_RED"  )->asGrid(); if( !pR ) { Parameters("OUT_RED"  )->Set_Value(pR = SG_Create_Grid()); } pR->Create(pRGB->Get_System(), SG_DATATYPE_Byte);
-		CSG_Grid *pG = Parameters("OUT_GREEN")->asGrid(); if( !pG ) { Parameters("OUT_GREEN")->Set_Value(pG = SG_Create_Grid()); } pG->Create(pRGB->Get_System(), SG_DATATYPE_Byte);
-		CSG_Grid *pB = Parameters("OUT_BLUE" )->asGrid(); if( !pB ) { Parameters("OUT_BLUE" )->Set_Value(pB = SG_Create_Grid()); } pB->Create(pRGB->Get_System(), SG_DATATYPE_Byte);
+		CSG_Grid *pR = Parameters("OUT_RED"  )->asGrid(); if( !pR ) { Parameters("OUT_RED"  )->Set_Value(pR = SG_Create_Grid()); } pR->Create(pRGB->Get_System(), SG_DATATYPE_Byte); pR->Set_NoData_Value(-1.);
+		CSG_Grid *pG = Parameters("OUT_GREEN")->asGrid(); if( !pG ) { Parameters("OUT_GREEN")->Set_Value(pG = SG_Create_Grid()); } pG->Create(pRGB->Get_System(), SG_DATATYPE_Byte); pG->Set_NoData_Value(-1.);
+		CSG_Grid *pB = Parameters("OUT_BLUE" )->asGrid(); if( !pB ) { Parameters("OUT_BLUE" )->Set_Value(pB = SG_Create_Grid()); } pB->Create(pRGB->Get_System(), SG_DATATYPE_Byte); pB->Set_NoData_Value(-1.);
 
 		for(int y=0; y<pRGB->Get_NY() && Set_Progress(y, pRGB->Get_NY()); y++)
 		{
@@ -350,38 +354,47 @@ void CGrid_Import::Set_Transformation(CSG_Grid **ppImage, double ax, double ay,
 	//-----------------------------------------------------
 	CSG_Grid *pSource = *ppImage;
 
-	TSG_Rect r; CSG_Vector XSrc(2), XTgt(2);
+	{
+		TSG_Rect r; CSG_Vector p(2); double c = fabs(dx) < fabs(dy) ? fabs(dx) : fabs(dy);	// guess a suitable cellsize; could be improved...
 
-	XSrc[0] = pSource->Get_XMin(); XSrc[1] = pSource->Get_YMin(); XTgt = D * XSrc + A;
-	r.xMin  = r.xMax = XTgt[0];
-	r.yMin  = r.yMax = XTgt[1];
+		p[0] = pSource->Get_XMin(); p[1] = pSource->Get_YMin(); p = D * p + A;
+		r.xMin  = r.xMax = p[0];
+		r.yMin  = r.yMax = p[1];
 
-	XSrc[0] = pSource->Get_XMin(); XSrc[1] = pSource->Get_YMax(); XTgt = D * XSrc + A;
-	if( r.xMin > XTgt[0] ) r.xMin = XTgt[0]; else if( r.xMax < XTgt[0] ) r.xMax = XTgt[0];
-	if( r.yMin > XTgt[1] ) r.yMin = XTgt[1]; else if( r.yMax < XTgt[1] ) r.yMax = XTgt[1];
+		p[0] = pSource->Get_XMin(); p[1] = pSource->Get_YMax(); p = D * p + A;
+		if( r.xMin > p[0] ) r.xMin = p[0]; else if( r.xMax < p[0] ) r.xMax = p[0];
+		if( r.yMin > p[1] ) r.yMin = p[1]; else if( r.yMax < p[1] ) r.yMax = p[1];
 
-	XSrc[0] = pSource->Get_XMax(); XSrc[1] = pSource->Get_YMax(); XTgt = D * XSrc + A;
-	if( r.xMin > XTgt[0] ) r.xMin = XTgt[0]; else if( r.xMax < XTgt[0] ) r.xMax = XTgt[0];
-	if( r.yMin > XTgt[1] ) r.yMin = XTgt[1]; else if( r.yMax < XTgt[1] ) r.yMax = XTgt[1];
+		p[0] = pSource->Get_XMax(); p[1] = pSource->Get_YMax(); p = D * p + A;
+		if( r.xMin > p[0] ) r.xMin = p[0]; else if( r.xMax < p[0] ) r.xMax = p[0];
+		if( r.yMin > p[1] ) r.yMin = p[1]; else if( r.yMax < p[1] ) r.yMax = p[1];
 
-	XSrc[0] = pSource->Get_XMax(); XSrc[1] = pSource->Get_YMin(); XTgt = D * XSrc + A;
-	if( r.xMin > XTgt[0] ) r.xMin = XTgt[0]; else if( r.xMax < XTgt[0] ) r.xMax = XTgt[0];
-	if( r.yMin > XTgt[1] ) r.yMin = XTgt[1]; else if( r.yMax < XTgt[1] ) r.yMax = XTgt[1];
+		p[0] = pSource->Get_XMax(); p[1] = pSource->Get_YMin(); p = D * p + A;
+		if( r.xMin > p[0] ) r.xMin = p[0]; else if( r.xMax < p[0] ) r.xMax = p[0];
+		if( r.yMin > p[1] ) r.yMin = p[1]; else if( r.yMax < p[1] ) r.yMax = p[1];
+
+		*ppImage = SG_Create_Grid(pSource->Get_Type(),
+			1 + (int)((r.xMax - r.xMin) / c),
+			1 + (int)((r.yMax - r.yMin) / c),
+			c, r.xMin, r.yMin
+		);
+	}
+
+	CSG_Grid *pTarget = *ppImage;
 
 	//-----------------------------------------------------
-	double z = fabs(dx) < fabs(dy) ? fabs(dx) : fabs(dy);	// guess a suitable cellsize; could be improved...
-	int    x = 1 + (int)((r.xMax - r.xMin) / z);
-	int    y = 1 + (int)((r.yMax - r.yMin) / z);
-
-	CSG_Grid *pTarget = *ppImage = SG_Create_Grid(pSource->Get_Type(), x, y, z, r.xMin, r.yMin);
-
-	for(y=0, XTgt[1]=pTarget->Get_YMin(); y<pTarget->Get_NY() && Set_Progress(y, pTarget->Get_NY()); y++, XTgt[1]+=pTarget->Get_Cellsize())
+	for(int y=0; y<pTarget->Get_NY() && Set_Progress(y, pTarget->Get_NY()); y++)
 	{
-		for(x=0, XTgt[0]=pTarget->Get_XMin(); x<pTarget->Get_NX(); x++, XTgt[0]+=pTarget->Get_Cellsize())
-		{
-			XSrc = DInv * (XTgt - A);
+		double yTarget = pTarget->Get_YMin() + y * pTarget->Get_Cellsize();
 
-			if( pSource->Get_Value(XSrc[0], XSrc[1], z, GRID_RESAMPLING_NearestNeighbour) )
+		#pragma omp parallel for
+		for(int x=0; x<pTarget->Get_NX(); x++)
+		{
+			double z; CSG_Vector p(2); p[1] = yTarget; p[0] = pTarget->Get_XMin() + x * pTarget->Get_Cellsize();
+
+			p = DInv * (p - A);
+
+			if( pSource->Get_Value(p[0], p[1], z, GRID_RESAMPLING_NearestNeighbour) )
 			{
 				pTarget->Set_Value(x, y, z);
 			}
