@@ -84,6 +84,8 @@ CSG_String Get_Info(int i)
 
 #include "geocoding.h"
 #include "global_tiles.h"
+#include "opentopography.h"
+#include "usgs_earthquakes.h"
 
 
 //---------------------------------------------------------
@@ -97,7 +99,9 @@ CSG_Tool *		Create_Tool(int i)
 
 	case  1: return( new CSRTM_CGIAR );
 //	case  2: return( new CSRTM_USGS );
-	case  3: return( new CCopernicus_DEM );
+//	case  3: return( new CCopernicus_DEM );
+	case  4: return( new COpenTopography );
+	case  5: return( new CUSGS_Earthquakes );
 
 	case 11: return( NULL );
 	default: return( TLB_INTERFACE_SKIP_TOOL );
