@@ -210,7 +210,7 @@ bool CGeoCoding::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	for(int i=0; i<pTable->Get_Count() && Process_Get_Okay(); i++)
+	for(sLong i=0; i<pTable->Get_Count() && Process_Get_Okay(); i++)
 	{
 		TSG_Point	Location;
 
@@ -254,35 +254,35 @@ bool CGeoCoding::On_Execute(void)
 //---------------------------------------------------------
 void	Replace_Special_Chars(CSG_String &String)
 {
-	const CSG_String	UTF8[][2]	= {
-		{ "",	"%c2%a1" },	{ "",	"%c2%a2" },	{ "",	"%c2%a3" },	{ "",	"%c2%a4" },
-		{ "",	"%c2%a5" },	{ "",	"%c2%a6" },	{ "",	"%c2%a7" },	{ "",	"%c2%a8" },
-		{ "",	"%c2%a9" },	{ "",	"%c2%aa" },	{ "",	"%c2%ab" },	{ "",	"%c2%ac" },
-		{ "",	"%c2%ad" },	{ "",	"%c2%ae" },	{ "",	"%c2%af" },	{ "",	"%c2%b0" },
-		{ "",	"%c2%b1" },	{ "",	"%c2%b2" },	{ "",	"%c2%b3" },	{ "",	"%c2%b4" },
-		{ "",	"%c2%b5" },	{ "",	"%c2%b6" },	{ "",	"%c2%b7" },	{ "",	"%c2%b8" },
-		{ "",	"%c2%b9" },	{ "",	"%c2%ba" },	{ "",	"%c2%bb" },	{ "",	"%c2%bc" },
-		{ "",	"%c2%bd" },	{ "",	"%c2%be" },	{ "",	"%c2%bf" },	{ "",	"%c3%80" },
-		{ "",	"%c3%81" },	{ "",	"%c3%82" },	{ "",	"%c3%83" },	{ "",	"%c3%84" },
-		{ "",	"%c3%85" },	{ "",	"%c3%86" },	{ "",	"%c3%87" },	{ "",	"%c3%88" },
-		{ "",	"%c3%89" },	{ "",	"%c3%8a" },	{ "",	"%c3%8b" },	{ "",	"%c3%8c" },
-		{ "",	"%c3%8d" },	{ "",	"%c3%8e" },	{ "",	"%c3%8f" },	{ "",	"%c3%90" },
-		{ "",	"%c3%91" },	{ "",	"%c3%92" },	{ "",	"%c3%93" },	{ "",	"%c3%94" },
-		{ "",	"%c3%95" },	{ "",	"%c3%96" },	{ "",	"%c3%97" },	{ "",	"%c3%98" },
-		{ "",	"%c3%99" },	{ "",	"%c3%9a" },	{ "",	"%c3%9b" },	{ "",	"%c3%9c" },
-		{ "",	"%c3%9d" },	{ "",	"%c3%9e" },	{ "",	"%c3%9f" },	{ "",	"%c3%a0" },
-		{ "",	"%c3%a1" },	{ "",	"%c3%a2" },	{ "",	"%c3%a3" },	{ "",	"%c3%a4" },
-		{ "",	"%c3%a5" },	{ "",	"%c3%a6" },	{ "",	"%c3%a7" },	{ "",	"%c3%a8" },
-		{ "",	"%c3%a9" },	{ "",	"%c3%aa" },	{ "",	"%c3%ab" },	{ "",	"%c3%ac" },
-		{ "",	"%c3%ad" },	{ "",	"%c3%ae" },	{ "",	"%c3%af" },	{ "",	"%c3%b0" },
-		{ "",	"%c3%b1" },	{ "",	"%c3%b2" },	{ "",	"%c3%b3" },	{ "",	"%c3%b4" },
-		{ "",	"%c3%b5" },	{ "",	"%c3%b6" },	{ "",	"%c3%b7" },	{ "",	"%c3%b8" },
-		{ "",	"%c3%b9" },	{ "",	"%c3%ba" },	{ "",	"%c3%bb" },	{ "",	"%c3%bc" },
-		{ "",	"%c3%bd" },	{ "",	"%c3%be" },	{ "",	"%c3%bf" }, { " ",	  "%%20" },	// String.Replace(" ", "+");
-		{ "" ,	""       }
+	const wchar_t *UTF8[][2] = {
+		{ SG_T("¡"), SG_T("%c2%a1") }, { SG_T("¢"), SG_T("%c2%a2") }, { SG_T("£"), SG_T("%c2%a3") }, { SG_T("¤"), SG_T("%c2%a4") },
+		{ SG_T("¥"), SG_T("%c2%a5") }, { SG_T("¦"), SG_T("%c2%a6") }, { SG_T("§"), SG_T("%c2%a7") }, { SG_T("¨"), SG_T("%c2%a8") },
+		{ SG_T("©"), SG_T("%c2%a9") }, { SG_T("ª"), SG_T("%c2%aa") }, { SG_T("«"), SG_T("%c2%ab") }, { SG_T("¬"), SG_T("%c2%ac") },
+		{ SG_T("­" ), SG_T("%c2%ad") }, { SG_T("®"), SG_T("%c2%ae") }, { SG_T("¯"), SG_T("%c2%af") }, { SG_T("°"), SG_T("%c2%b0") },
+		{ SG_T("±"), SG_T("%c2%b1") }, { SG_T("²"), SG_T("%c2%b2") }, { SG_T("³"), SG_T("%c2%b3") }, { SG_T("´"), SG_T("%c2%b4") },
+		{ SG_T("µ"), SG_T("%c2%b5") }, { SG_T("¶"), SG_T("%c2%b6") }, { SG_T("·"), SG_T("%c2%b7") }, { SG_T("¸"), SG_T("%c2%b8") },
+		{ SG_T("¹"), SG_T("%c2%b9") }, { SG_T("º"), SG_T("%c2%ba") }, { SG_T("»"), SG_T("%c2%bb") }, { SG_T("¼"), SG_T("%c2%bc") },
+		{ SG_T("½"), SG_T("%c2%bd") }, { SG_T("¾"), SG_T("%c2%be") }, { SG_T("¿"), SG_T("%c2%bf") }, { SG_T("À"), SG_T("%c3%80") },
+		{ SG_T("Á"), SG_T("%c3%81") }, { SG_T("Â"), SG_T("%c3%82") }, { SG_T("Ã"), SG_T("%c3%83") }, { SG_T("Ä"), SG_T("%c3%84") },
+		{ SG_T("Å"), SG_T("%c3%85") }, { SG_T("Æ"), SG_T("%c3%86") }, { SG_T("Ç"), SG_T("%c3%87") }, { SG_T("È"), SG_T("%c3%88") },
+		{ SG_T("É"), SG_T("%c3%89") }, { SG_T("Ê"), SG_T("%c3%8a") }, { SG_T("Ë"), SG_T("%c3%8b") }, { SG_T("Ì"), SG_T("%c3%8c") },
+		{ SG_T("Í"), SG_T("%c3%8d") }, { SG_T("Î"), SG_T("%c3%8e") }, { SG_T("Ï"), SG_T("%c3%8f") }, { SG_T("Ð"), SG_T("%c3%90") },
+		{ SG_T("Ñ"), SG_T("%c3%91") }, { SG_T("Ò"), SG_T("%c3%92") }, { SG_T("Ó"), SG_T("%c3%93") }, { SG_T("Ô"), SG_T("%c3%94") },
+		{ SG_T("Õ"), SG_T("%c3%95") }, { SG_T("Ö"), SG_T("%c3%96") }, { SG_T("×"), SG_T("%c3%97") }, { SG_T("Ø"), SG_T("%c3%98") },
+		{ SG_T("Ù"), SG_T("%c3%99") }, { SG_T("Ú"), SG_T("%c3%9a") }, { SG_T("Û"), SG_T("%c3%9b") }, { SG_T("Ü"), SG_T("%c3%9c") },
+		{ SG_T("Ý"), SG_T("%c3%9d") }, { SG_T("Þ"), SG_T("%c3%9e") }, { SG_T("ß"), SG_T("%c3%9f") }, { SG_T("à"), SG_T("%c3%a0") },
+		{ SG_T("á"), SG_T("%c3%a1") }, { SG_T("â"), SG_T("%c3%a2") }, { SG_T("ã"), SG_T("%c3%a3") }, { SG_T("ä"), SG_T("%c3%a4") },
+		{ SG_T("å"), SG_T("%c3%a5") }, { SG_T("æ"), SG_T("%c3%a6") }, { SG_T("ç"), SG_T("%c3%a7") }, { SG_T("è"), SG_T("%c3%a8") },
+		{ SG_T("é"), SG_T("%c3%a9") }, { SG_T("ê"), SG_T("%c3%aa") }, { SG_T("ë"), SG_T("%c3%ab") }, { SG_T("ì"), SG_T("%c3%ac") },
+		{ SG_T("í"), SG_T("%c3%ad") }, { SG_T("î"), SG_T("%c3%ae") }, { SG_T("ï"), SG_T("%c3%af") }, { SG_T("ð"), SG_T("%c3%b0") },
+		{ SG_T("ñ"), SG_T("%c3%b1") }, { SG_T("ò"), SG_T("%c3%b2") }, { SG_T("ó"), SG_T("%c3%b3") }, { SG_T("ô"), SG_T("%c3%b4") },
+		{ SG_T("õ"), SG_T("%c3%b5") }, { SG_T("ö"), SG_T("%c3%b6") }, { SG_T("÷"), SG_T("%c3%b7") }, { SG_T("ø"), SG_T("%c3%b8") },
+		{ SG_T("ù"), SG_T("%c3%b9") }, { SG_T("ú"), SG_T("%c3%ba") }, { SG_T("û"), SG_T("%c3%bb") }, { SG_T("ü"), SG_T("%c3%bc") },
+		{ SG_T("ý"), SG_T("%c3%bd") }, { SG_T("þ"), SG_T("%c3%be") }, { SG_T("ÿ"), SG_T("%c3%bf") }, { SG_T(" "), SG_T(  "%%20") },	// String.Replace(" ", SG_T("+");
+		{ SG_T("") , SG_T("") }
 	};
 
-	for(int i=0; !UTF8[i][1].is_Empty(); i++)
+	for(int i=0; *UTF8[i][1]; i++)
 	{
 		String.Replace(UTF8[i][0], UTF8[i][1]);
 	}
