@@ -205,13 +205,13 @@ bool CGround_Filter::On_Execute(void)
 		#pragma omp parallel for
 		for(sLong iPoint=iPstart; iPoint<iPend; iPoint++)
 		{
-			CSG_Array_Int Indices; CSG_Vector Distances;
+			CSG_Array_sLong Indices; CSG_Vector Distances;
 
 			Search.Get_Nearest_Points(pPC_in->Get_X(iPoint), pPC_in->Get_Y(iPoint), 0, dRadius, Indices, Distances);
 
 			int iClass = 2;		// ground
 
-			for(size_t i=0; i<Indices.Get_Size(); i++)
+			for(sLong i=0; i<Indices.Get_Size(); i++)
 			{
 				double dMaxDz = 0.;
 
