@@ -56,56 +56,39 @@
 ///////////////////////////////////////////////////////////
 
 //---------------------------------------------------------
-#if PROJ_VERSION_MAJOR < 6
-	extern "C" {
-		#include <projects.h>
-	}
-
-	#define PJ_GET_PROJS	pj_get_list_ref()
-	#define PJ_GET_DATUMS	pj_get_datums_ref()
-	#define PJ_GET_ELLPS	pj_get_ellps_ref()
-	#define PJ_GET_UNITS	pj_get_units_ref()
-
-	#define TPJ_PROJS		struct PJ_LIST
-	#define TPJ_DATUMS		struct PJ_DATUMS
-	#define TPJ_ELLPS		struct PJ_ELLPS
-	#define TPJ_UNITS		struct PJ_UNITS
+#include <proj.h>
 
 //---------------------------------------------------------
-#else
-	#include <proj.h>
+#define PJ_GET_PROJS proj_list_operations()
+#define PJ_GET_ELLPS proj_list_ellps()
+#define PJ_GET_UNITS proj_list_units()
 
-	#define PJ_GET_PROJS	proj_list_operations()
-	#define PJ_GET_ELLPS	proj_list_ellps()
-	#define PJ_GET_UNITS	proj_list_units()
+#define TPJ_PROJS const PJ_OPERATIONS
+#define TPJ_ELLPS const PJ_ELLPS
+#define TPJ_UNITS const PJ_UNITS
 
-	#define TPJ_PROJS		const PJ_OPERATIONS
-	#define TPJ_ELLPS		const PJ_ELLPS
-	#define TPJ_UNITS		const PJ_UNITS
+//---------------------------------------------------------
+struct PJ_DATUMS
+{
+	const char *id, *comments;
+};
 
-	struct PJ_DATUMS
-	{
-		const char *id, *comments;
-	};
+#define TPJ_DATUMS struct PJ_DATUMS
 
-	#define TPJ_DATUMS	struct PJ_DATUMS
-
-	struct PJ_DATUMS	PJ_GET_DATUMS[]	=
-	{
-		{ "WGS84"        , "WGS84"                                },
-		{ "GGRS87"       , "Greek Geodetic Reference System 1987" },
-		{ "NAD83"        , "North American Datum 1983"            },
-		{ "NAD27"        , "North American Datum 1927"            },
-		{ "potsdam"      , "Potsdam Rauenberg 1950 DHDN"          },
-		{ "carthage"     , "Carthage 1934 Tunisia"                },
-		{ "hermannskogel", "Hermannskogel"                        },
-		{ "ire65"        , "Ireland 1965"                         },
-		{ "nzgd49"       , "New Zealand Geodetic Datum 1949"      },
-		{ "OSGB36"       , "Airy 1830"                            },
-		{ NULL           , NULL                                   }
-	};
-
-#endif
+struct PJ_DATUMS PJ_GET_DATUMS[] =
+{
+	{ "WGS84"        , "WGS84"                                },
+	{ "GGRS87"       , "Greek Geodetic Reference System 1987" },
+	{ "NAD83"        , "North American Datum 1983"            },
+	{ "NAD27"        , "North American Datum 1927"            },
+	{ "potsdam"      , "Potsdam Rauenberg 1950 DHDN"          },
+	{ "carthage"     , "Carthage 1934 Tunisia"                },
+	{ "hermannskogel", "Hermannskogel"                        },
+	{ "ire65"        , "Ireland 1965"                         },
+	{ "nzgd49"       , "New Zealand Geodetic Datum 1949"      },
+	{ "OSGB36"       , "Airy 1830"                            },
+	{ NULL           , NULL                                   }
+};
 
 
 ///////////////////////////////////////////////////////////
@@ -117,48 +100,40 @@
 //---------------------------------------------------------
 CCRS_Base::CCRS_Base(void)
 {
-	Parameters.Add_Choice("",
-		"CRS_METHOD"     , _TL("Get CRS Definition from..."),
-		_TL(""),
-		CSG_String::Format("%s|%s|%s",
-			_TL("Definition String"),
-			_TL("Authority Code"),
-			_TL("Well Known Text File")
-		), 0
-	)->Set_UseInGUI(false);
+	CSG_Projection Projection; Projection.Set_GCS_WGS84();
 
-	//-----------------------------------------------------
 	Parameters.Add_String("",
 		"CRS_STRING"     , _TL("Definition String"),
 		_TL("Supported formats comprise PROJ and WKT strings, object codes (e.g. \"EPSG:4326\")."),
-		CSG_CRSProjector::Convert_CRS_To_PROJ("epsg:4326")
+		Projection.Get_PROJ()
 	);
 
+	//-----------------------------------------------------
 	if( has_GUI() )
 	{
 		Parameters.Add_Choice("CRS_STRING",
 			"CRS_DISPLAY", _TL("Display Definition as..."),
 			_TL(""),
-			CSG_String::Format("%s|%s|%s",
+			CSG_String::Format("%s|%s",
 				_TL("PROJ"),
-				_TL("WKT-1"),
-				_TL("WKT-2")
+				_TL("WKT")
 			), 0
 		)->Set_UseInCMD(false);
+
+		Parameters.Add_Int("CRS_STRING",
+			"CRS_CODE"       , _TL("Authority Code"),
+			_TL(""),
+			Projection.Get_Code()
+		)->Set_UseInCMD(false);
+
+		Parameters.Add_String("CRS_CODE",
+			"CRS_AUTHORITY"  , _TL("Authority"),
+			_TL(""),
+			Projection.Get_Authority()
+		)->Set_UseInCMD(false);
 	}
 
-	Parameters.Add_Int("CRS_STRING",
-		"CRS_CODE"       , _TL("Authority Code"),
-		_TL(""),
-		4326
-	);
-
-	Parameters.Add_String("CRS_CODE",
-		"CRS_AUTHORITY"  , _TL("Authority"),
-		_TL(""),
-		"EPSG"
-	);
-
+	//-----------------------------------------------------
 	Parameters.Add_FilePath("CRS_STRING",
 		"CRS_FILE"       , _TL("Well Known Text File"),
 		_TL(""),
@@ -211,33 +186,15 @@ CCRS_Base::CCRS_Base(void)
 		)->Set_UseInCMD(false);
 
 		Set_User_Parameters(*Parameters("CRS_DIALOG")->asParameters());
-		Set_User_Definition(*Parameters("CRS_DIALOG")->asParameters(), CSG_CRSProjector::Convert_CRS_To_PROJ("epsg:4326"));
+		Set_User_Definition(*Parameters("CRS_DIALOG")->asParameters(), Projection.Get_PROJ());
 	}
 
 	//-----------------------------------------------------
-	Parameters.Add_Info_String("", "CRS_WKT", _TL("Well Known Text"), _TL(""), CSG_CRSProjector::Convert_CRS_To_WKT1("epsg:4326", false))->Set_Enabled(false); // for requesting projection in a generic/safe way
-	Parameters("CRS_WKT")->Set_UseInCMD(false);
-	Parameters("CRS_WKT")->Set_UseInGUI(false);
+	Parameters.Add_Info_String("", "CRS_WKT" , _TL("WKT" ), _TL(""), Projection.Get_WKT2())->Set_Enabled(false); // for requesting projection in a generic/safe way
+	Parameters.Add_Info_String("", "CRS_PROJ", _TL("PROJ"), _TL(""), Projection.Get_PROJ())->Set_Enabled(false); // for requesting projection in a generic/safe way
 
-	//-----------------------------------------------------
-	#if PROJ_VERSION_MAJOR < 6
-	Parameters.Add_Bool("",
-		"PRECISE", _TL("Precise Datum Conversion"),
-		_TL("avoids precision problems when source and target crs use different geodedtic datums."),
-		false
-	);
-	#endif
-
-	//-----------------------------------------------------
-	// >>> for backward compatibility only!
-	if( !has_GUI() )
-	{
-		Parameters.Add_String("", "CRS_PROJ4"    , "[deprecated] Proj4 String"  , "Deprecated! For backward compatibility only! Use \"CRS_STRING\" parameter instead!"   , "")->Set_UseInGUI(false);
-		Parameters.Add_Int   ("", "CRS_EPSG"     , "[deprecated] Authority Code", "Deprecated! For backward compatibility only! Use \"CRS_CODE\" parameter instead!"     , -1)->Set_UseInGUI(false);
-		Parameters.Add_String("", "CRS_EPSG_AUTH", "[deprecated] Authority"     , "Deprecated! For backward compatibility only! Use \"CRS_AUTHORITY\" parameter instead!", "")->Set_UseInGUI(false);
-	}
-	// <<< for backward compatibility only!
-	//-----------------------------------------------------
+	Parameters("CRS_WKT")->Set_UseInCMD(false); Parameters("CRS_PROJ")->Set_UseInCMD(false);
+	Parameters("CRS_WKT")->Set_UseInGUI(false); Parameters("CRS_PROJ")->Set_UseInGUI(false);
 }
 
 
@@ -248,7 +205,23 @@ CCRS_Base::CCRS_Base(void)
 //---------------------------------------------------------
 bool CCRS_Base::On_Before_Execution(void)
 {
-	Parameter_Changed(&Parameters, Parameters("CRS_WKT"));
+	if( Parameters("CRS_DISPLAY") )
+	{
+		CSG_Projection Projection(Parameters["CRS_WKT"].asString(), Parameters["CRS_PROJ"].asString()); // fast construction!
+
+		bool bCallback = Parameters.Set_Callback(false);
+
+		switch( Parameters["CRS_DISPLAY"].asInt() )
+		{
+		default: Parameters["CRS_STRING"].Set_Value(Projection.Get_PROJ()); break;
+		case  1: Parameters["CRS_STRING"].Set_Value(Projection.Get_WKT2()); break;
+		}
+
+		Parameters["CRS_CODE"     ].Set_Value(Projection.Get_Code     ());
+		Parameters["CRS_AUTHORITY"].Set_Value(Projection.Get_Authority());
+
+		Parameters.Set_Callback(bCallback);
+	}
 
 	return( true );
 }
@@ -264,23 +237,10 @@ int CCRS_Base::On_Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *
 //---------------------------------------------------------
 bool CCRS_Base::Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pParameter)
 {
-	//-----------------------------------------------------
-	// >>> for backward compatibility only!
-	if( pParameter->Cmp_Identifier("CRS_PROJ4"    ) ) { pParameters->Set_Parameter("CRS_STRING"   , pParameter->asString()); return( Parameter_Changed(pParameters, (*pParameters)("CRS_STRING"   )) ); }
-	if( pParameter->Cmp_Identifier("CRS_EPSG"     ) ) { pParameters->Set_Parameter("CRS_CODE"     , pParameter->asInt   ()); return( Parameter_Changed(pParameters, (*pParameters)("CRS_CODE"     )) ); }
-	if( pParameter->Cmp_Identifier("CRS_EPSG_AUTH") ) { pParameters->Set_Parameter("CRS_AUTHORITY", pParameter->asString()); return( Parameter_Changed(pParameters, (*pParameters)("CRS_AUTHORITY")) ); }
-	// <<< for backward compatibility only!
-	//-----------------------------------------------------
-
 	CSG_Projection Projection;
 
 	//-----------------------------------------------------
-	if( pParameter->Cmp_Identifier("CRS_WKT") )
-	{
-		Projection.Create(pParameter->asString());
-	}
-
-	else if( pParameter->Cmp_Identifier("CRS_STRING") )
+	if( pParameter->Cmp_Identifier("CRS_STRING") )
 	{
 		CSG_String Definition(pParameter->asString()); Definition.Trim(); Definition.Replace("\\n", "");
 
@@ -295,9 +255,10 @@ bool CCRS_Base::Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pP
 		}
 	}
 
+	//-----------------------------------------------------
 	else if( pParameter->Cmp_Identifier("CRS_DISPLAY") )
 	{
-		Projection.Create((*pParameters)("CRS_WKT")->asString());
+		Projection.Create((*pParameters)("CRS_WKT")->asString(), (*pParameters)("CRS_PROJ")->asString());
 	}
 
 	//-----------------------------------------------------
@@ -362,6 +323,8 @@ bool CCRS_Base::Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pP
 	}
 
 	//-----------------------------------------------------
+	pParameters->Set_Parameter("CRS_PROJ", Projection.Get_PROJ());
+
 	if( !pParameter->Cmp_Identifier("CRS_WKT"   ) ) { pParameters->Set_Parameter("CRS_WKT", Projection.Get_WKT()); }
 
 	if(	!pParameter->Cmp_Identifier("CRS_GEOGCS") ) { pParameters->Set_Parameter("CRS_GEOGCS", 0); }
@@ -381,9 +344,8 @@ bool CCRS_Base::Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pP
 		{
 			switch( (*pParameters)("CRS_DISPLAY")->asInt() )
 			{
-			default: pParameters->Set_Parameter("CRS_STRING",                                       Projection.Get_PROJ()            ); break;
-			case  1: pParameters->Set_Parameter("CRS_STRING", CSG_CRSProjector::Convert_CRS_To_WKT1(Projection.Get_WKT(), true      )); break;
-			case  2: pParameters->Set_Parameter("CRS_STRING", CSG_CRSProjector::Convert_CRS_To_WKT2(Projection.Get_WKT(), true, true)); break;
+			default: pParameters->Set_Parameter("CRS_STRING", Projection.Get_PROJ()); break;
+			case  1: pParameters->Set_Parameter("CRS_STRING", Projection.Get_WKT2()); break;
 			}
 		}
 	}
@@ -401,16 +363,6 @@ bool CCRS_Base::Parameter_Changed(CSG_Parameters *pParameters, CSG_Parameter *pP
 		}
 	}
 
-	//-----------------------------------------------------
-	// >>> for backward compatibility only!
-	{	bool bCallback = pParameters->Set_Callback(false);
-	pParameters->Set_Parameter("CRS_PROJ4"    , Projection.Get_PROJ     ());
-	pParameters->Set_Parameter("CRS_EPSG"     , Projection.Get_Code     ());
-	pParameters->Set_Parameter("CRS_EPSG_AUTH", Projection.Get_Authority());
-	pParameters->Set_Callback(bCallback);	}
-	// <<< for backward compatibility only!
-	//-----------------------------------------------------
-
 	return( Projection.is_Okay() );
 }
 
@@ -505,35 +457,7 @@ bool CCRS_Base::Parameters_Enable(CSG_Parameters *pParameters, CSG_Parameter *pP
 //---------------------------------------------------------
 bool CCRS_Base::Get_Projection(CSG_Projection &Projection)
 {
-	if( has_GUI() ) // gui? projection has already been updated on parameter changed event!
-	{
-		Projection.Create(Parameters("CRS_WKT")->asString());
-	}
-	else switch( Parameters("CRS_METHOD")->asInt() )	// no gui? check out, how projection shall be initialized!
-	{
-	default: // Definition String
-		if( !Projection.Create(Parameters("CRS_STRING")->asString()) )
-		{
-			Error_Set(_TL("Definition String Error"));
-		}
-		break;
-
-	case  1: // Authority Code
-		if( !Projection.Create(Parameters("CRS_CODE")->asInt(), Parameters("CRS_AUTHORITY")->asString()) )
-		{
-			Error_Set(_TL("Authority Code Error"));
-		}
-		break;
-
-	case  2: // Well Known Text File
-		if( !Projection.Load  (Parameters("CRS_FILE")->asString()) )
-		{
-			Error_Set(_TL("Well Known Text File Error"));
-		}
-		break;
-	}
-
-	return( Projection.is_Okay() );
+	return( Projection.Create(Parameters["CRS_WKT"].asString(), Parameters["CRS_PROJ"].asString()) );
 }
 
 
@@ -1279,14 +1203,12 @@ bool CCRS_Transform::On_Execute(void)
 		return( false );
 	}
 
-	Message_Fmt("\n%s: %s", _TL("source"), m_Projector.Get_Source().Get_PROJ().c_str());
-	Message_Fmt("\n%s: %s", _TL("target"), m_Projector.Get_Target().Get_PROJ().c_str());
-
 	//-----------------------------------------------------
-	m_Projector.Set_Precise_Mode(Parameters("PRECISE") && Parameters("PRECISE")->asBool());
-
 	bool bResult = On_Execute_Transformation();
 
+	Message_Fmt("\n\n%s: %s", _TL("source"), m_Projector.Get_Source().Get_PROJ().c_str());
+	Message_Fmt(  "\n%s: %s", _TL("target"), m_Projector.Get_Target().Get_PROJ().c_str());
+
 	m_Projector.Destroy();
 
 	return( bResult );
