@@ -113,7 +113,7 @@ CTOPMODEL::CTOPMODEL(void)
 	));
 
 	Add_Reference("Beven, K., Kirkby, M.J., Schofield, N., Tagg, A.F.", "1984",
-		"Testing a physically-based flood forecasting model (TOPMODEL) for threee U.K. catchments",
+		"Testing a physically-based flood forecasting model (TOPMODEL) for three U.K. catchments",
 		"Journal of Hydrology, H.69, S.119-143."
 	);
 
@@ -182,7 +182,7 @@ CTOPMODEL::CTOPMODEL(void)
 	);
 
 	Parameters.Add_Double("",
-		"P_LNTE"		, _TL("Areal average of ln(T0) = ln(Te) [ln(m^2/h)]"),
+		"P_LNTE"		, _TL("Areal average of ln(T0) = ln(Te) [ln(m²/h)]"),
 		_TL(""),
 		5.0
 	);
@@ -278,7 +278,7 @@ bool CTOPMODEL::On_Execute(void)
 	nClasses		= Parameters("NCLASSES"   )->asInt   ();
 	bInfiltration	= Parameters("BINF"       )->asBool  ();
 
-	nTimeSteps		= m_pWeather->Get_Record_Count();
+	nTimeSteps		= m_pWeather->Get_Count();
 
 	if( (pMoist = Parameters("MOIST")->asGrid()) != NULL )
 	{
@@ -293,7 +293,7 @@ bool CTOPMODEL::On_Execute(void)
 	pTable->Set_Name(_TL("TOPMODEL - Simulation Output"));
 
 	pTable->Add_Field(_TL("Time")										, SG_DATATYPE_String);
-	pTable->Add_Field(_TL("Total flow (in watershed) (m^3/dt)")			, SG_DATATYPE_Double);
+	pTable->Add_Field(_TL("Total flow (in watershed) (m³/dt)")			, SG_DATATYPE_Double);
 	pTable->Add_Field(_TL("Total flow (m/dt)")							, SG_DATATYPE_Double);
 	pTable->Add_Field(_TL("Saturation overland flow (m/dt)")			, SG_DATATYPE_Double);
 	pTable->Add_Field(_TL("Subsurface flow (m/dt)")						, SG_DATATYPE_Double);
