@@ -1,6 +1,3 @@
-/**********************************************************
- * Version $Id: successive_flow_routing.cpp 911 2011-02-14 16:38:15Z reklov_w $
- *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -48,15 +45,6 @@
 //                                                       //
 ///////////////////////////////////////////////////////////
 
-//---------------------------------------------------------
-
-
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
 //---------------------------------------------------------
 #include "successive_flow_routing.h"
 
@@ -70,7 +58,6 @@
 //---------------------------------------------------------
 CSuccessive_Flow_Routing::CSuccessive_Flow_Routing(void)
 {
-	//-----------------------------------------------------
 	Set_Name		(_TL("Successive Flow Routing"));
 
 	Set_Author		("O.Conrad (c) 2013");
@@ -78,16 +65,23 @@ CSuccessive_Flow_Routing::CSuccessive_Flow_Routing(void)
 	Set_Description	(_TW(
 		"Calculation of flow accumulation, aka upslope contributing area, "
 		"with the multiple flow direction method after Freeman (1991)."
+
+		"<hr>This tool implements suggested code examples from the text book "
+		"<i>Quantitative Modeling of Earth Surface Processes</i> (Pelletier 2008) "
+		"and serves as demonstration on code adaptions for the SAGA API. "
+		"Note that this tool may be of limited use for operational purposes!"
 	));
 
-	Add_Reference("Freeman, G.T.",
-		"1991", "Calculating catchment area with divergent flow based on a rectangular grid",
-		"Computers & Geosciences, 17, pp.413-422."
+	Add_Reference("Freeman, G.T.", "1991",
+		"Calculating catchment area with divergent flow based on a regular grid",
+		"Computers and Geosciences, 17:413-22.",
+		SG_T("https://doi.org/10.1016/0098-3004(91)90048-I"), SG_T("doi:10.1016/0098-3004(91)90048-I")
 	);
 
 	Add_Reference("Pelletier, J.D.",
 		"2008", "Quantitative Modeling of Earth Surface Processes",
-		"Cambridge, 295p."
+		"Cambridge, 295p.",
+		SG_T("https://doi.org/10.1017/CBO9780511813849"), SG_T("doi:10.1017/CBO9780511813849")
 	);
 
 	//-----------------------------------------------------
@@ -130,37 +124,28 @@ CSuccessive_Flow_Routing::CSuccessive_Flow_Routing(void)
 //---------------------------------------------------------
 bool CSuccessive_Flow_Routing::On_Execute(void)
 {
-	int			x, y, nIterations;
-	double		Runoff;
-	CSG_Grid	*pDEM, DEM, Slope;
+	int nIterations; double Runoff; CSG_Grid *pDEM;
 
-	nIterations	= Parameters("ITERATIONS")->asInt();
-	Runoff		= Parameters("RUNOFF"    )->asDouble();
-	m_Manning	= Parameters("MANNING"   )->asDouble();
+	nIterations = Parameters("ITERATIONS")->asInt();
+	Runoff      = Parameters("RUNOFF"    )->asDouble();
+	m_Manning   = Parameters("MANNING"   )->asDouble();
 
-	pDEM		= Parameters("DEM"  )->asGrid();
-	m_pFlow		= Parameters("FLOW" )->asGrid();
+	pDEM        = Parameters("DEM"  )->asGrid();
+	m_pFlow     = Parameters("FLOW" )->asGrid();
 
-	m_pDEM		= &DEM;
-	m_pSlope	= &Slope;
+	CSG_Grid DEM  (*pDEM       ); m_pDEM   = &DEM;
+	CSG_Grid Slope(Get_System()); m_pSlope = &Slope;
 
-	DEM			.Create(*pDEM);
-	Slope		.Create(Get_System());
-
-	CSG_Colors	Colors(11, SG_COLORS_WHITE_BLUE);
-	Colors[0]	= SG_GET_RGB(255, 255, 200);
+	CSG_Colors Colors(11, SG_COLORS_WHITE_BLUE); Colors[0] = SG_GET_RGB(255, 255, 200);
 	DataObject_Set_Colors(m_pFlow, Colors);
 	DataObject_Update(m_pFlow, SG_UI_DATAOBJECT_SHOW_MAP);
 
 	Fill_Sinks();
 
-	#pragma omp parallel for private(x, y)
-	for(y=0; y<Get_NY(); y++)
+	#pragma omp parallel for
+	for(int y=0; y<Get_NY(); y++) for(int x=0; x<Get_NX(); x++)
 	{
-		for(x=0; x<Get_NX(); x++)
-		{
-			Set_Channel_Slope(x, y);
-		}
+		Set_Channel_Slope(x, y);
 	}
 
 	//-----------------------------------------------------
@@ -172,43 +157,39 @@ bool CSuccessive_Flow_Routing::On_Execute(void)
 
 		Fill_Sinks();
 
-		#pragma omp parallel for private(x, y)
-		for(y=0; y<Get_NY(); y++)
+		#pragma omp parallel for
+		for(int y=0; y<Get_NY(); y++) for(int x=0; x<Get_NX(); x++)
 		{
-			for(x=0; x<Get_NX(); x++)
-			{
-				m_pFlow->Set_Value(x, y, pow(Runoff, 1.66667) * m_pSlope->asDouble(x, y));
-			}
+			m_pFlow->Set_Value(x, y, pow(Runoff, 1.66667) * m_pSlope->asDouble(x, y));
 		}
 
 		for(sLong i=0; i<Get_NCells() && Process_Get_Okay(); i++)
 		{
+			int x, y;
+
 			if( m_pDEM->Get_Sorted(i, x, y) )
 			{
 				Set_Flow(x, y);
 			}
 		}
 
-		#pragma omp parallel for private(x, y)
-		for(y=0; y<Get_NY(); y++)
+		#pragma omp parallel for
+		for(int y=0; y<Get_NY(); y++) for(int x=0; x<Get_NX(); x++)
 		{
-			for(x=0; x<Get_NX(); x++)
+			if( m_pDEM->is_NoData(x, y) )
 			{
-				if( m_pDEM->is_NoData(x, y) )
-				{
-					m_pFlow->Set_NoData(x, y);
-				}
-				else
-				{
-					double	Depth	= pow(m_pFlow->asDouble(x, y) / m_pSlope->asDouble(x, y), 0.6);
+				m_pFlow->Set_NoData(x, y);
+			}
+			else
+			{
+				double Depth = pow(m_pFlow->asDouble(x, y) / m_pSlope->asDouble(x, y), 0.6);
 
-					if( m_pDEM->asDouble(x, y) < pDEM->asDouble(x, y) + Depth )
-					{
-						m_pDEM->Set_Value(x, y, pDEM->asDouble(x, y) + Depth / nIterations);
-					}
-
-					m_pFlow->Set_Value(x, y, m_pDEM->asDouble(x, y) - pDEM->asDouble(x, y));
+				if( m_pDEM->asDouble(x, y) < pDEM->asDouble(x, y) + Depth )
+				{
+					m_pDEM->Set_Value(x, y, pDEM->asDouble(x, y) + Depth / nIterations);
 				}
+
+				m_pFlow->Set_Value(x, y, m_pDEM->asDouble(x, y) - pDEM->asDouble(x, y));
 			}
 		}
 
@@ -251,29 +232,29 @@ void CSuccessive_Flow_Routing::Set_Flow(int x, int y)
 {
 	if( !m_pDEM->is_NoData(x, y) )
 	{
-		int		i;
-		double	z, dz[8], dzSum;
+		double dz[8], dzSum = 0., z = m_pDEM->asDouble(x, y);
 
-		for(i=0, dzSum=0.0, z=m_pDEM->asDouble(x, y); i<8; i++)
+		for(int i=0; i<8; i++)
 		{
-			int	ix	= Get_xTo(i, x);
-			int	iy	= Get_yTo(i, y);
+			int ix = Get_xTo(i, x), iy = Get_yTo(i, y);
 
-			if( m_pDEM->is_InGrid(ix, iy) && (dz[i] = z - m_pDEM->asDouble(ix, iy)) > 0.0 )
+			if( m_pDEM->is_InGrid(ix, iy) && (dz[i] = z - m_pDEM->asDouble(ix, iy)) > 0. )
 			{
-				dzSum	+= (dz[i] = pow(dz[i] / Get_Length(i), 1.1));
+				dzSum += (dz[i] = pow(dz[i] / Get_Length(i), 1.1));
 			}
 			else
 			{
-				dz[i]	= 0.0;
+				dz[i] = 0.;
 			}
 		}
 
-		if( dzSum > 0.0 )
+		if( dzSum > 0. )
 		{
-			for(i=0, z=m_pFlow->asDouble(x, y)/dzSum; i<8; i++)
+			z = m_pFlow->asDouble(x, y) / dzSum;
+
+			for(int i=0; i<8; i++)
 			{
-				if( dz[i] > 0.0 )
+				if( dz[i] > 0. )
 				{
 					m_pFlow->Add_Value(Get_xTo(i, x), Get_yTo(i, y), z * dz[i]);
 				}
@@ -291,17 +272,15 @@ void CSuccessive_Flow_Routing::Set_Channel_Slope(int x, int y)
 	}
 	else
 	{
-		int		i;
-		double	z, dz, Slope;
+		double dz, Slope = 0., z = m_pDEM->asDouble(x, y);
 
-		for(i=0, Slope=0.0, z=m_pDEM->asDouble(x, y); i<8; i++)
+		for(int i=0; i<8; i++)
 		{
-			int	ix	= Get_xTo(i, x);
-			int	iy	= Get_yTo(i, y);
+			int ix = Get_xTo(i, x), iy = Get_yTo(i, y);
 
 			if( m_pDEM->is_InGrid(ix, iy) && (dz = (z - m_pDEM->asDouble(ix, iy)) / Get_Length(i)) > Slope )
 			{
-				Slope	= dz;
+				Slope = dz;
 			}
 		}
 
