@@ -213,7 +213,7 @@ bool CGSGrid_Statistics::On_Execute(void)
 	}
 
 	//-----------------------------------------------------
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
@@ -297,14 +297,22 @@ CGSGrid_Unique_Value_Statistics::CGSGrid_Unique_Value_Statistics(void)
 	));
 
 	Parameters.Add_Grid_List("",
-		"GRIDS"		, _TL("Values"),
+		"GRIDS", _TL("Values"),
 		_TL(""),
 		PARAMETER_INPUT
 	);
 
-	Parameters.Add_Grid("", "MAJORITY", _TL("Majority"               ), _TL(""), PARAMETER_OUTPUT_OPTIONAL);
-	Parameters.Add_Grid("", "MINORITY", _TL("Minority"               ), _TL(""), PARAMETER_OUTPUT_OPTIONAL);
-	Parameters.Add_Grid("", "NUNIQUES", _TL("Number of Unique Values"), _TL(""), PARAMETER_OUTPUT_OPTIONAL);
+	Parameters.Add_Grid("", "MAJORITY"      , _TL("Majority"               ), _TL(""), PARAMETER_OUTPUT_OPTIONAL);
+	Parameters.Add_Grid("", "MAJORITY_COUNT", _TL("Majority Count"         ), _TL(""), PARAMETER_OUTPUT_OPTIONAL, true, SG_DATATYPE_Byte);
+	Parameters.Add_Grid("", "MINORITY"      , _TL("Minority"               ), _TL(""), PARAMETER_OUTPUT_OPTIONAL);
+	Parameters.Add_Grid("", "MINORITY_COUNT", _TL("Minority Count"         ), _TL(""), PARAMETER_OUTPUT_OPTIONAL, true, SG_DATATYPE_Byte);
+	Parameters.Add_Grid("", "NUNIQUES"      , _TL("Number of Unique Values"), _TL(""), PARAMETER_OUTPUT_OPTIONAL, true, SG_DATATYPE_Byte);
+
+	Parameters.Add_Bool("",
+		"UNAMBIGUOUS", _TL("Unambiguous"),
+		_TL("Set no-data if more than one value reaches the same majority count."),
+		false
+	);
 }
 
 
@@ -338,11 +346,13 @@ bool CGSGrid_Unique_Value_Statistics::On_Execute(void)
 	//-----------------------------------------------------
 	#define Get_Output(id) Parameters(id)->asGrid(); if( Parameters(id)->asGrid() ) bHasOutput = true;
 
-	bool	bHasOutput	= false;
+	bool bHasOutput = false;
 
-	CSG_Grid *pMajority   = Get_Output("MAJORITY");
-	CSG_Grid *pMinority   = Get_Output("MINORITY");
-	CSG_Grid *pNUniques   = Get_Output("NUNIQUES");
+	CSG_Grid *pMajority = Get_Output("MAJORITY"      );
+	CSG_Grid *pMajCount = Get_Output("MAJORITY_COUNT");
+	CSG_Grid *pMinority = Get_Output("MINORITY"      );
+	CSG_Grid *pMinCount = Get_Output("MINORITY_COUNT");
+	CSG_Grid *pNUniques = Get_Output("NUNIQUES"      );
 
 	//-----------------------------------------------------
 	if( !bHasOutput )
@@ -352,8 +362,10 @@ bool CGSGrid_Unique_Value_Statistics::On_Execute(void)
 		return( false );
 	}
 
+	bool bUnambigous = Parameters("UNAMBIGUOUS")->asBool();
+
 	//-----------------------------------------------------
-	for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+	for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 	{
 		#pragma omp parallel for
 		for(int x=0; x<Get_NX(); x++)
@@ -364,7 +376,7 @@ bool CGSGrid_Unique_Value_Statistics::On_Execute(void)
 			{
 				if( !pGrids->Get_Grid(i)->is_NoData(x, y) )
 				{
-					s	+= pGrids->Get_Grid(i)->asDouble(x, y);
+					s += pGrids->Get_Grid(i)->asDouble(x, y);
 				}
 			}
 
@@ -372,13 +384,51 @@ bool CGSGrid_Unique_Value_Statistics::On_Execute(void)
 			if( s.Get_Count() < 1 )
 			{
 				if( pMajority ) pMajority->Set_NoData(x, y);
+				if( pMajCount ) pMajCount->Set_NoData(x, y);
 				if( pMinority ) pMinority->Set_NoData(x, y);
+				if( pMinCount ) pMinCount->Set_NoData(x, y);
 				if( pNUniques ) pNUniques->Set_NoData(x, y);
 			}
 			else
 			{
-				if( pMajority ) { double d; s.Get_Majority(d); pMajority->Set_Value(x, y, d); }
-				if( pMinority ) { double d; s.Get_Minority(d); pMinority->Set_Value(x, y, d); }
+				double d; int n;
+
+				if( (pMajority || pMajCount) && s.Get_Majority(d, n) )
+				{
+					if( pMajority )
+					{
+						int nMajorities = 0;
+
+						if( bUnambigous )
+						{
+							for(int i=0; nMajorities<2 && i<s.Get_Count(); i++)
+							{
+								if( n == s.Get_Count(i) )
+								{
+									nMajorities++;
+								}
+							}
+						}
+
+						if( nMajorities > 1 )
+						{
+							pMajority->Set_NoData(x, y);
+						}
+						else
+						{
+							pMajority->Set_Value(x, y, d);
+						}
+					}
+
+					if( pMajCount ) pMajCount->Set_Value(x, y, n);
+				}
+
+				if( (pMinority || pMajCount) && s.Get_Minority(d, n) )
+				{
+					if( pMinority ) pMinority->Set_Value(x, y, d);
+					if( pMinCount ) pMinCount->Set_Value(x, y, n);
+				}
+
 				if( pNUniques ) pNUniques->Set_Value(x, y, s.Get_Count());
 			}
 		}
@@ -525,7 +575,7 @@ bool CGSGrid_Statistics_To_Table::On_Execute(void)
 
 		if( s.asDouble(v) && v >= 0. && v <= 100. )
 		{
-			int n = Percentiles.Get_Count();
+			sLong n = Percentiles.Get_Count();
 
 			Percentiles.Add_Record();
 
@@ -742,7 +792,7 @@ bool CGSGrid_Histogram::On_Execute(void)
 	//-----------------------------------------------------
 	if( Parameters("PARALLEL")->asBool() == false )
 	{
-		for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+		for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 		{
 			for(int x=0; x<Get_NX(); x+=Step)
 			{
@@ -761,7 +811,7 @@ bool CGSGrid_Histogram::On_Execute(void)
 			Histograms[iThread].Create(Histogram);
 		}
 
-		for(int y=0; y<Get_NY() && Set_Progress(y); y++)
+		for(int y=0; y<Get_NY() && Set_Progress_Rows(y); y++)
 		{
 			#pragma omp parallel for
 			for(int x=0; x<Get_NX(); x+=Step)
@@ -815,9 +865,9 @@ bool CGSGrid_Histogram::On_Execute(void)
 //---------------------------------------------------------
 bool CGSGrid_Histogram::Add_Value(CSG_Table &Histogram, double Value, bool bUnclassed)
 {
-	int n = bUnclassed ? Histogram.Get_Count() - 1 : Histogram.Get_Count();
+	sLong n = bUnclassed ? Histogram.Get_Count() - 1 : Histogram.Get_Count();
 
-	for(int i=0; i<n; i++)
+	for(sLong i=0; i<n; i++)
 	{
 		if( Histogram[i].asDouble(FIELD_MIN) <= Value && Value <= Histogram[i].asDouble(FIELD_MAX) )
 		{
