@@ -264,7 +264,7 @@ bool CSAGA_Wetness_Index::Get_Area(void)
 	double    wSlope  = Parameters("SLOPE_WEIGHT")->asDouble();
 
 	//-----------------------------------------------------
-	for(sLong n=0; n<Get_NCells() && Set_Progress_NCells(n); n++)
+	for(sLong n=0; n<Get_NCells() && Set_Progress_Cells(n); n++)
 	{
 		int	x, y; m_pDEM->Get_Sorted(n, x, y, true, false);
 
@@ -330,11 +330,11 @@ bool CSAGA_Wetness_Index::Get_Area(void)
 
 //---------------------------------------------------------
 // in den folgenden drei Schritten wird die gesaugte
-// Einzugsgebietsgroee CS ermittelt, wobei der t-Parameter
+// Einzugsgebietsgroeße CS ermittelt, wobei der t-Parameter
 // die Staerke der Saugung steuert. Werte unter 10 (z.B.  5)
 // fuehren zu einer starken Saugung, Werte ueber 10 (z.B. 15)
 // zu einer schwachen Saugung. Die gesaugte
-// Einzugsgebietsgroee selbst stellt bereits einen Parameter
+// Einzugsgebietsgroeße selbst stellt bereits einen Parameter
 // dar, der die raeumliche Relief-bedingte Feuchteverteilung
 // in guter Weise annaehert
 //---------------------------------------------------------
@@ -899,7 +899,7 @@ foreach p in UU do
 		{UU[p] = 0;}
 		}
 }
-// in den folgenden drei Schritten wird nach der "multiple flow methode" die Einzugsgebietsgroee C ermittelt //
+// in den folgenden drei Schritten wird nach der "multiple flow methode" die Einzugsgebietsgroeße C ermittelt //
 foreach p in Z do
 {Z[p] = 1;}
 foreach ploop in Loop do
@@ -916,7 +916,7 @@ foreach ploop in Loop do
 setRandN(Z);
 foreach p in C do
 {C[p] = Z[p] * O.dxy^2;}
-// in den folgenden drei Schritten wird die gesaugte Einzugsgebietsgroee CS ermittelt, wobei der t-Parameter die Staerke der Saugung steuert. Werte unter 10 (z.B.: 5) fuehren zu einer starken Saugung, Werte ueber 10 (z.B. 15) zu einer schwachen Saugung. Die gesaugte Einzugsgebietsgroee selbst stellt bereits einen Parameter Dar, der die raeumliche Relief-bedingte Feuchteverteilung in guter Weise annaehert //
+// in den folgenden drei Schritten wird die gesaugte Einzugsgebietsgroeße CS ermittelt, wobei der t-Parameter die Staerke der Saugung steuert. Werte unter 10 (z.B.: 5) fuehren zu einer starken Saugung, Werte ueber 10 (z.B. 15) zu einer schwachen Saugung. Die gesaugte Einzugsgebietsgroeße selbst stellt bereits einen Parameter Dar, der die raeumliche Relief-bedingte Feuchteverteilung in guter Weise annaehert //
 foreach p in X do
 {X[p] = C[p];}
 foreach ploop in Loop do
