@@ -1,6 +1,3 @@
-/**********************************************************
- * Version $Id: flow_by_slope.cpp 911 2011-02-14 16:38:15Z reklov_w $
- *********************************************************/
 
 ///////////////////////////////////////////////////////////
 //                                                       //
@@ -48,15 +45,6 @@
 //                                                       //
 ///////////////////////////////////////////////////////////
 
-//---------------------------------------------------------
-
-
-///////////////////////////////////////////////////////////
-//														 //
-//														 //
-//														 //
-///////////////////////////////////////////////////////////
-
 //---------------------------------------------------------
 #include "flow_by_slope.h"
 
@@ -70,10 +58,9 @@
 //---------------------------------------------------------
 CFlow_by_Slope::CFlow_by_Slope(void)
 {
-	//-----------------------------------------------------
-	Set_Name	(_TL("Slope Limited Flow Accumulation"));
+	Set_Name		(_TL("Slope Limited Flow Accumulation"));
 
-	Set_Author	("O.Conrad (c) 2014");
+	Set_Author		("O.Conrad (c) 2014");
 
 	Set_Description	(_TW(
 		"Flow accumulation is calculated as upslope contributing (catchment) area "
@@ -91,45 +78,27 @@ CFlow_by_Slope::CFlow_by_Slope(void)
 	);
 
 	//-----------------------------------------------------
-	Parameters.Add_Grid("",
-		"DEM"		, _TL("Elevation"),
-		_TL(""),
-		PARAMETER_INPUT
-	);
+	Parameters.Add_Grid("", "DEM"   , _TL("Elevation"        ), _TL(""), PARAMETER_INPUT);
+	Parameters.Add_Grid("", "WEIGHT", _TL("Weight"           ), _TL(""), PARAMETER_INPUT_OPTIONAL);
+	Parameters.Add_Grid("", "FLOW"  , _TL("Flow Accumulation"), _TL(""), PARAMETER_OUTPUT);
 
-	Parameters.Add_Grid("",
-		"WEIGHT"	, _TL("Weight"),
-		_TL(""),
-		PARAMETER_INPUT_OPTIONAL
-	);
-
-	Parameters.Add_Grid("",
-		"FLOW"		, _TL("Flow Accumulation"),
-		_TL(""),
-		PARAMETER_OUTPUT
-	);
-
-	Parameters.Add_Double("",
-		"SLOPE_MIN"	, _TL("Slope Minimum"),
+	Parameters.Add_Double("", "SLOPE_MIN", _TL("Slope Minimum"),
 		_TL("Assume a given minimum slope for each cell."),
-		0.0, 0.0, true
+		0., 0., true
 	);
 
-	Parameters.Add_Double("",
-		"SLOPE_MAX"	, _TL("Slope Threshold"),
+	Parameters.Add_Double("", "SLOPE_MAX", _TL("Slope Threshold"),
 		_TL("Slope threshold, given as degree, above which flow transport is unlimited."),
-		5.0, 0.0, true, 90.0, true
+		5., 0., true, 90., true
 	);
 
-	Parameters.Add_Bool("",
-		"B_FLOW"	, _TL("Use Flow Threshold"),
+	Parameters.Add_Bool("", "B_FLOW", _TL("Use Flow Threshold"),
 		_TL("")
 	);
 
-	Parameters.Add_Range("B_FLOW",
-		"T_FLOW"	, _TL("Flow Threshold"),
+	Parameters.Add_Range("B_FLOW", "T_FLOW", _TL("Flow Threshold"),
 		_TL("Flow threshold, given as amount of cells, above which flow transport is unlimited. Ignored if range equals zero."),
-		1.0, 100.0, 1.0, true
+		1., 100., 1., true
 	);
 }
 
@@ -143,10 +112,10 @@ int CFlow_by_Slope::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parame
 {
 	if( pParameter->Cmp_Identifier("B_FLOW") )
 	{
-		pParameters->Get_Parameter("T_FLOW")->Set_Enabled(pParameter->asBool());
+		pParameters->Set_Enabled("T_FLOW", pParameter->asBool());
 	}
 
-	return( 1 );
+	return( CSG_Tool_Grid::On_Parameters_Enable(pParameters, pParameter) );
 }
 
 
@@ -157,10 +126,10 @@ int CFlow_by_Slope::On_Parameters_Enable(CSG_Parameters *pParameters, CSG_Parame
 //---------------------------------------------------------
 bool CFlow_by_Slope::On_Execute(void)
 {
-	m_Slope_Min	= Parameters("SLOPE_MIN")->asDouble() * M_DEG_TO_RAD;
+	m_Slope_Min = Parameters("SLOPE_MIN")->asDouble() * M_DEG_TO_RAD;
 	m_Slope_Max = Parameters("SLOPE_MAX")->asDouble() * M_DEG_TO_RAD;
 
-	if( m_Slope_Max <= 0.0 )
+	if( m_Slope_Max <= 0. )
 	{
 		Error_Set(_TL("slope threshold must not be zero!"));
 
@@ -169,17 +138,17 @@ bool CFlow_by_Slope::On_Execute(void)
 
 	if( Parameters("B_FLOW")->asBool() )
 	{
-		m_Flow_Min	= Parameters("T_FLOW")->asRange()->Get_Min() * Get_Cellarea();
-		m_Flow_Max	= Parameters("T_FLOW")->asRange()->Get_Max() * Get_Cellarea();
+		m_Flow_Min = Parameters("T_FLOW")->asRange()->Get_Min() * Get_Cellarea();
+		m_Flow_Max = Parameters("T_FLOW")->asRange()->Get_Max() * Get_Cellarea();
 	}
 	else
 	{
-		m_Flow_Min	= m_Flow_Max	= 0.0;
+		m_Flow_Min = m_Flow_Max = 0.;
 	}
 
 	//-----------------------------------------------------
-	m_pDEM		= Parameters("DEM"   )->asGrid();
-	m_pFlow		= Parameters("FLOW"  )->asGrid();
+	m_pDEM  = Parameters("DEM" )->asGrid();
+	m_pFlow = Parameters("FLOW")->asGrid();
 
 	m_pFlow->Assign(Get_Cellarea());
 
@@ -202,13 +171,16 @@ bool CFlow_by_Slope::On_Execute(void)
 	{
 		int	x, y;
 
-		if( !m_pDEM->Get_Sorted(i, x, y, true) || m_pDEM->is_NoData(x, y) )
+		if( m_pDEM->Get_Sorted(i, x, y, true) )
 		{
-			m_pFlow->Set_NoData(x, y);
-		}
-		else
-		{
-			Set_Area(x, y);
+			if( m_pDEM->is_NoData(x, y) )
+			{
+				m_pFlow->Set_NoData(x, y);
+			}
+			else
+			{
+				Set_Area(x, y);
+			}
 		}
 	}
 
@@ -224,15 +196,15 @@ bool CFlow_by_Slope::On_Execute(void)
 //---------------------------------------------------------
 inline double CFlow_by_Slope::Get_Fuzzy(double Value, double Minimum, double Maximum)
 {
-	return( Value <= Minimum ? 0.0 : Value >= Maximum ? 1.0 :
-		0.5 * (1.0 - cos(M_PI * ((Value - Minimum) / (Maximum - Minimum))))
+	return( Value <= Minimum ? 0. : Value >= Maximum ? 1. :
+		0.5 * (1. - cos(M_PI * ((Value - Minimum) / (Maximum - Minimum))))
 	);
 }
 
 //---------------------------------------------------------
 inline bool CFlow_by_Slope::Get_Decay(int x, int y, double &Decay)
 {
-	double	d;
+	double d;
 
 	if( !m_pDEM->Get_Gradient(x, y, d, Decay) )
 	{
@@ -241,28 +213,23 @@ inline bool CFlow_by_Slope::Get_Decay(int x, int y, double &Decay)
 
 	if( d < m_Slope_Min )
 	{
-		d	= m_Slope_Min;
+		d = m_Slope_Min;
 	}
 
-	Decay	= Get_Fuzzy(d, 0.0, m_Slope_Max);
+	Decay = Get_Fuzzy(d, 0., m_Slope_Max);
 
-	if( m_Flow_Min > 0.0 )
+	if( m_Flow_Min > 0. )
 	{
-		d	= Get_Fuzzy(m_pFlow->asDouble(x, y), m_Flow_Min, m_Flow_Max);
+		d = Get_Fuzzy(m_pFlow->asDouble(x, y), m_Flow_Min, m_Flow_Max);
 
 		switch( 1 )
 		{
-		default:
-			Decay	= M_GET_MAX(Decay, d);
-			break;
-
-		case 1:
-			Decay	= Decay + d - Decay * d;
-			break;
+		default: Decay = M_GET_MAX(Decay, d)  ; break;
+		case  1: Decay = Decay + d - Decay * d; break;
 		}
 	}
 
-	return( Decay > 0.0 );
+	return( Decay > 0. );
 }
 
 
@@ -273,32 +240,33 @@ inline bool CFlow_by_Slope::Get_Decay(int x, int y, double &Decay)
 //---------------------------------------------------------
 void CFlow_by_Slope::Set_Area(int x, int y)
 {
-	double	Decay;
+	double Decay;
 
 	if( Get_Decay(x, y, Decay) )
 	{
-		int		i, ix, iy;
-		double	z, dzSum, dz[8];
+		double z = m_pDEM->asDouble(x, y), dzSum = 0., dz[8];
 
-		for(i=0, dzSum=0.0, z=m_pDEM->asDouble(x, y); i<8; i++)
+		for(int i=0; i<8; i++)
 		{
-			if( m_pDEM->is_InGrid(ix = Get_xTo(i, x), iy = Get_yTo(i, y)) && (dz[i] = z - m_pDEM->asDouble(ix, iy)) > 0.0 )
+			int ix = Get_xTo(i, x), iy = Get_yTo(i, y);
+
+			if( m_pDEM->is_InGrid(ix, iy) && (dz[i] = z - m_pDEM->asDouble(ix, iy)) > 0. )
 			{
-				dzSum	+= (dz[i] = pow(dz[i] / Get_Length(i), 1.1));
+				dzSum += (dz[i] = pow(dz[i] / Get_Length(i), 1.1));
 			}
 			else
 			{
-				dz[i]	= 0.0;
+				dz[i] = 0.;
 			}
 		}
 
-		if( dzSum > 0.0 )
+		if( dzSum > 0. )
 		{
-			Decay	*= m_pFlow->asDouble(x, y) / dzSum;
+			Decay *= m_pFlow->asDouble(x, y) / dzSum;
 
-			for(i=0; i<8; i++)
+			for(int i=0; i<8; i++)
 			{
-				if( dz[i] > 0.0 )
+				if( dz[i] > 0. )
 				{
 					m_pFlow->Add_Value(Get_xTo(i, x), Get_yTo(i, y), Decay * dz[i]);
 				}
