@@ -387,6 +387,21 @@ public:
 		Create(new C3D_Viewer_Shapes_Panel(this, pShapes, Field_Color));
 	}
 
+
+protected:
+
+	#ifdef __WXMAC__
+	virtual void				On_Menu					(wxCommandEvent &event)
+	{
+		switch( event.GetId() )
+		{
+		default: CSG_3DView_Dialog::On_Menu(event); return;
+
+		case MENU_PROPERTIES: if( SG_UI_Dlg_Parameters(&m_pPanel->Get_Parameters(), "") ) { m_pPanel->Set_Parameters(); } return;
+		}
+	}
+	#endif
+
 };
 
 
